@@ -16,6 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """Local client API."""
+
 from __future__ import annotations
 
 from airflow.api.client import api_client
@@ -43,8 +44,8 @@ class Client(api_client.Client):
                 "conf": dag_run.conf,
                 "dag_id": dag_run.dag_id,
                 "dag_run_id": dag_run.run_id,
-                "data_interval_end": dag_run.data_interval_start,
-                "data_interval_start": dag_run.data_interval_end,
+                "data_interval_start": dag_run.data_interval_start,
+                "data_interval_end": dag_run.data_interval_end,
                 "end_date": dag_run.end_date,
                 "external_trigger": dag_run.external_trigger,
                 "last_scheduling_decision": dag_run.last_scheduling_decision,
@@ -63,12 +64,12 @@ class Client(api_client.Client):
         pool = Pool.get_pool(pool_name=name)
         if not pool:
             raise PoolNotFound(f"Pool {name} not found")
-        return pool.pool, pool.slots, pool.description
+        return pool.pool, pool.slots, pool.description, pool.include_deferred
 
     def get_pools(self):
-        return [(p.pool, p.slots, p.description) for p in Pool.get_pools()]
+        return [(p.pool, p.slots, p.description, p.include_deferred) for p in Pool.get_pools()]
 
-    def create_pool(self, name, slots, description):
+    def create_pool(self, name, slots, description, include_deferred):
         if not (name and name.strip()):
             raise AirflowBadRequest("Pool name shouldn't be empty")
         pool_name_length = Pool.pool.property.columns[0].type.length
@@ -78,7 +79,9 @@ class Client(api_client.Client):
             slots = int(slots)
         except ValueError:
             raise AirflowBadRequest(f"Bad value for `slots`: {slots}")
-        pool = Pool.create_or_update_pool(name=name, slots=slots, description=description)
+        pool = Pool.create_or_update_pool(
+            name=name, slots=slots, description=description, include_deferred=include_deferred
+        )
         return pool.pool, pool.slots, pool.description
 
     def delete_pool(self, name):
