@@ -16,33 +16,33 @@
 # under the License.
 from __future__ import annotations
 
+from typing import TYPE_CHECKING
+
 from sqlalchemy import select
-from sqlalchemy.orm.session import Session
 
-from airflow import DAG
 from airflow.api_connexion import security
 from airflow.api_connexion.exceptions import NotFound
-from airflow.api_connexion.types import APIResponse
+from airflow.auth.managers.models.resource_details import DagAccessEntity
 from airflow.exceptions import TaskNotFound
-from airflow.models.dagbag import DagBag
-from airflow.security import permissions
 from airflow.utils.airflow_flask_app import get_airflow_app
 from airflow.utils.session import NEW_SESSION, provide_session
 
+if TYPE_CHECKING:
+    from sqlalchemy.orm.session import Session
 
-@security.requires_access(
-    [
-        (permissions.ACTION_CAN_READ, permissions.RESOURCE_DAG),
-        (permissions.ACTION_CAN_READ, permissions.RESOURCE_DAG_RUN),
-        (permissions.ACTION_CAN_READ, permissions.RESOURCE_TASK_INSTANCE),
-    ],
-)
+    from airflow import DAG
+    from airflow.api_connexion.types import APIResponse
+    from airflow.models.dagbag import DagBag
+
+
+@security.requires_access_dag("GET", DagAccessEntity.TASK_INSTANCE)
 @provide_session
 def get_extra_links(
     *,
     dag_id: str,
     dag_run_id: str,
     task_id: str,
+    map_index: int = -1,
     session: Session = NEW_SESSION,
 ) -> APIResponse:
     """Get extra links for task instance."""
@@ -63,6 +63,7 @@ def get_extra_links(
             TaskInstance.dag_id == dag_id,
             TaskInstance.run_id == dag_run_id,
             TaskInstance.task_id == task_id,
+            TaskInstance.map_index == map_index,
         )
     )
 
@@ -72,7 +73,5 @@ def get_extra_links(
     all_extra_link_pairs = (
         (link_name, task.get_extra_links(ti, link_name)) for link_name in task.extra_links
     )
-    all_extra_links = {
-        link_name: link_url if link_url else None for link_name, link_url in sorted(all_extra_link_pairs)
-    }
+    all_extra_links = {link_name: link_url or None for link_name, link_url in sorted(all_extra_link_pairs)}
     return all_extra_links
