@@ -20,7 +20,7 @@ from marshmallow import Schema, fields
 
 
 class VariableSchema(Schema):
-    """Variable Schema"""
+    """Variable Schema."""
 
     key = fields.String(required=True)
     value = fields.String(attribute="val", required=True)
@@ -28,7 +28,7 @@ class VariableSchema(Schema):
 
 
 class VariableCollectionSchema(Schema):
-    """Variable Collection Schema"""
+    """Variable Collection Schema."""
 
     variables = fields.List(fields.Nested(VariableSchema))
     total_entries = fields.Int()
