@@ -28,9 +28,7 @@ class BaseUser:
         return True
 
     @abstractmethod
-    def get_id(self) -> str:
-        ...
+    def get_id(self) -> str: ...
 
     @abstractmethod
-    def get_name(self) -> str:
-        ...
+    def get_name(self) -> str: ...
