@@ -29,6 +29,7 @@ import sys
 import warnings
 from typing import TYPE_CHECKING
 
+import re2
 from sqlalchemy import delete, select
 
 from airflow import settings
@@ -137,6 +138,7 @@ def dag_backfill(args, dag: list[DAG] | DAG | None = None) -> None:
         warnings.warn(
             "--ignore-first-depends-on-past is deprecated as the value is always set to True",
             category=RemovedInAirflow3Warning,
+            stacklevel=4,
         )
     args.ignore_first_depends_on_past = True
 
@@ -144,6 +146,7 @@ def dag_backfill(args, dag: list[DAG] | DAG | None = None) -> None:
         warnings.warn(
             "--treat-dag-as-regex is deprecated, use --treat-dag-id-as-regex instead",
             category=RemovedInAirflow3Warning,
+            stacklevel=4,
         )
         args.treat_dag_id_as_regex = args.treat_dag_as_regex
 
@@ -262,7 +265,11 @@ def set_is_paused(is_paused: bool, args) -> None:
 @providers_configuration_loaded
 def dag_dependencies_show(args) -> None:
     """Display DAG dependencies, save to file or show as imgcat image."""
-    dot = render_dag_dependencies(SerializedDagModel.get_dag_dependencies())
+    deduplicated_dag_dependencies = {
+        dag_id: list(set(dag_dependencies))
+        for dag_id, dag_dependencies in SerializedDagModel.get_dag_dependencies().items()
+    }
+    dot = render_dag_dependencies(deduplicated_dag_dependencies)
     filename = args.save
     imgcat = args.imgcat
 
@@ -603,9 +610,21 @@ def dag_test(args, dag: DAG | None = None, session: Session = NEW_SESSION) -> No
         except ValueError as e:
             raise SystemExit(f"Configuration {args.conf!r} is not valid JSON. Error: {e}")
     execution_date = args.execution_date or timezone.utcnow()
+    use_executor = args.use_executor
+
+    mark_success_pattern = (
+        re2.compile(args.mark_success_pattern) if args.mark_success_pattern is not None else None
+    )
+
     with _airflow_parsing_context_manager(dag_id=args.dag_id):
         dag = dag or get_dag(subdir=args.subdir, dag_id=args.dag_id)
-    dr: DagRun = dag.test(execution_date=execution_date, run_conf=run_conf, session=session)
+    dr: DagRun = dag.test(
+        execution_date=execution_date,
+        run_conf=run_conf,
+        use_executor=use_executor,
+        mark_success_pattern=mark_success_pattern,
+        session=session,
+    )
     show_dagrun = args.show_dagrun
     imgcat = args.imgcat_dagrun
     filename = args.save_dagrun
