@@ -16,6 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """Variable subcommands."""
+
 from __future__ import annotations
 
 import json
@@ -25,11 +26,12 @@ from json import JSONDecodeError
 from sqlalchemy import select
 
 from airflow.cli.simple_table import AirflowConsole
+from airflow.cli.utils import print_export_output
 from airflow.models import Variable
 from airflow.utils import cli as cli_utils
 from airflow.utils.cli import suppress_logs_and_warning
 from airflow.utils.providers_configuration_loader import providers_configuration_loaded
-from airflow.utils.session import create_session
+from airflow.utils.session import create_session, provide_session
 
 
 @suppress_logs_and_warning
@@ -59,8 +61,8 @@ def variables_get(args):
 @cli_utils.action_cli
 @providers_configuration_loaded
 def variables_set(args):
-    """Create new variable with a given name and value."""
-    Variable.set(args.key, args.value, serialize_json=args.json)
+    """Create new variable with a given name, value and description."""
+    Variable.set(args.key, args.value, args.description, serialize_json=args.json)
     print(f"Variable {args.key} created")
 
 
@@ -74,46 +76,48 @@ def variables_delete(args):
 
 @cli_utils.action_cli
 @providers_configuration_loaded
-def variables_import(args):
+@provide_session
+def variables_import(args, session):
     """Import variables from a given file."""
-    if os.path.exists(args.file):
-        _import_helper(args.file)
-    else:
+    if not os.path.exists(args.file):
         raise SystemExit("Missing variables file.")
+    with open(args.file) as varfile:
+        try:
+            var_json = json.load(varfile)
+        except JSONDecodeError:
+            raise SystemExit("Invalid variables file.")
+    suc_count = fail_count = 0
+    skipped = set()
+    action_on_existing = args.action_on_existing_key
+    existing_keys = set()
+    if action_on_existing != "overwrite":
+        existing_keys = set(session.scalars(select(Variable.key).where(Variable.key.in_(var_json))))
+    if action_on_existing == "fail" and existing_keys:
+        raise SystemExit(f"Failed. These keys: {sorted(existing_keys)} already exists.")
+    for k, v in var_json.items():
+        if action_on_existing == "skip" and k in existing_keys:
+            skipped.add(k)
+            continue
+        try:
+            Variable.set(k, v, serialize_json=not isinstance(v, str))
+        except Exception as e:
+            print(f"Variable import failed: {e!r}")
+            fail_count += 1
+        else:
+            suc_count += 1
+    print(f"{suc_count} of {len(var_json)} variables successfully updated.")
+    if fail_count:
+        print(f"{fail_count} variable(s) failed to be updated.")
+    if skipped:
+        print(
+            f"The variables with these keys: {list(sorted(skipped))} "
+            f"were skipped because they already exists"
+        )
 
 
 @providers_configuration_loaded
 def variables_export(args):
     """Export all the variables to the file."""
-    _variable_export_helper(args.file)
-
-
-def _import_helper(filepath):
-    """Help import variables from the file."""
-    with open(filepath) as varfile:
-        data = varfile.read()
-
-    try:
-        var_json = json.loads(data)
-    except JSONDecodeError:
-        raise SystemExit("Invalid variables file.")
-    else:
-        suc_count = fail_count = 0
-        for k, v in var_json.items():
-            try:
-                Variable.set(k, v, serialize_json=not isinstance(v, str))
-            except Exception as e:
-                print(f"Variable import failed: {repr(e)}")
-                fail_count += 1
-            else:
-                suc_count += 1
-        print(f"{suc_count} of {len(var_json)} variables successfully updated.")
-        if fail_count:
-            print(f"{fail_count} variable(s) failed to be updated.")
-
-
-def _variable_export_helper(filepath):
-    """Helps export all the variables to the file."""
     var_dict = {}
     with create_session() as session:
         qry = session.scalars(select(Variable))
@@ -126,6 +130,6 @@ def _variable_export_helper(filepath):
                 val = var.val
             var_dict[var.key] = val
 
-    with open(filepath, "w") as varfile:
-        varfile.write(json.dumps(var_dict, sort_keys=True, indent=4))
-    print(f"{len(var_dict)} variables successfully exported to {filepath}")
+    with args.file as varfile:
+        json.dump(var_dict, varfile, sort_keys=True, indent=4)
+        print_export_output("Variables", var_dict, varfile)
