@@ -19,11 +19,6 @@ from __future__ import annotations
 
 import sys
 
-if sys.version_info >= (3, 8):
-    from functools import cached_property
-else:
-    from cached_property import cached_property
-
 if sys.version_info >= (3, 9):
     from functools import cache
 else:
@@ -31,5 +26,8 @@ else:
 
     cache = lru_cache(maxsize=None)
 
+# We need to keep it around, in case it was used in the code of old providers, but since we are
+# Python 3.8+ we can directly import the functools one
+from functools import cached_property  # type: ignore
 
 __all__ = ["cache", "cached_property"]
