@@ -23,15 +23,16 @@ import signal
 import threading
 import time
 import zipfile
-from contextlib import redirect_stderr, redirect_stdout, suppress
+from contextlib import contextmanager, redirect_stderr, redirect_stdout, suppress
+from dataclasses import dataclass
 from datetime import timedelta
-from typing import TYPE_CHECKING, Iterable, Iterator
+from typing import TYPE_CHECKING, Generator, Iterable, Iterator
 
 from setproctitle import setproctitle
-from sqlalchemy import delete, func, or_, select
+from sqlalchemy import delete, event, func, or_, select
 
 from airflow import settings
-from airflow.api_internal.internal_api_call import internal_api_call
+from airflow.api_internal.internal_api_call import InternalApiConfig, internal_api_call
 from airflow.callbacks.callback_requests import (
     DagCallbackRequest,
     SlaCallbackRequest,
@@ -39,13 +40,15 @@ from airflow.callbacks.callback_requests import (
 )
 from airflow.configuration import conf
 from airflow.exceptions import AirflowException, TaskNotFound
-from airflow.models import SlaMiss, errors
+from airflow.listeners.listener import get_listener_manager
+from airflow.models import SlaMiss
 from airflow.models.dag import DAG, DagModel
 from airflow.models.dagbag import DagBag
 from airflow.models.dagrun import DagRun as DR
 from airflow.models.dagwarning import DagWarning, DagWarningType
+from airflow.models.errors import ParseImportError
 from airflow.models.serialized_dag import SerializedDagModel
-from airflow.models.taskinstance import TaskInstance, TaskInstance as TI
+from airflow.models.taskinstance import TaskInstance, TaskInstance as TI, _run_finished_callback
 from airflow.stats import Stats
 from airflow.utils import timezone
 from airflow.utils.email import get_email_address_list, send_email
@@ -66,6 +69,28 @@ if TYPE_CHECKING:
     from airflow.models.operator import Operator
 
 
+@dataclass
+class _QueryCounter:
+    queries_number: int = 0
+
+    def inc(self):
+        self.queries_number += 1
+
+
+@contextmanager
+def count_queries(session: Session) -> Generator[_QueryCounter, None, None]:
+    # using list allows to read the updated counter from what context manager returns
+    counter: _QueryCounter = _QueryCounter()
+
+    @event.listens_for(session, "do_orm_execute")
+    def _count_db_queries(orm_execute_state):
+        nonlocal counter
+        counter.inc()
+
+    yield counter
+    event.remove(session, "do_orm_execute", _count_db_queries)
+
+
 class DagFileProcessorProcess(LoggingMixin, MultiprocessingStartMethodMixin):
     """
     Runs DAG processing in a separate process using DagFileProcessor.
@@ -97,7 +122,7 @@ class DagFileProcessorProcess(LoggingMixin, MultiprocessingStartMethodMixin):
         # The process that was launched to process the given .
         self._process: multiprocessing.process.BaseProcess | None = None
         # The result of DagFileProcessor.process_file(file_path).
-        self._result: tuple[int, int] | None = None
+        self._result: tuple[int, int, int] | None = None
         # Whether the process is done running.
         self._done = False
         # When the process started.
@@ -160,7 +185,7 @@ class DagFileProcessorProcess(LoggingMixin, MultiprocessingStartMethodMixin):
 
             log.info("Started process (PID=%s) to work on %s", os.getpid(), file_path)
             dag_file_processor = DagFileProcessor(dag_ids=dag_ids, dag_directory=dag_directory, log=log)
-            result: tuple[int, int] = dag_file_processor.process_file(
+            result: tuple[int, int, int] = dag_file_processor.process_file(
                 file_path=file_path,
                 pickle_dags=pickle_dags,
                 callback_requests=callback_requests,
@@ -348,7 +373,7 @@ class DagFileProcessorProcess(LoggingMixin, MultiprocessingStartMethodMixin):
         return False
 
     @property
-    def result(self) -> tuple[int, int] | None:
+    def result(self) -> tuple[int, int, int] | None:
         """Result of running ``DagFileProcessor.process_file()``."""
         if not self.done:
             raise AirflowException("Tried to get the result before it's done!")
@@ -413,6 +438,7 @@ class DagFileProcessor(LoggingMixin):
         self._log = log
         self._dag_directory = dag_directory
         self.dag_warnings: set[tuple[str, str]] = set()
+        self._last_num_of_db_queries = 0
 
     @classmethod
     @internal_api_call
@@ -603,8 +629,8 @@ class DagFileProcessor(LoggingMixin):
         For the DAGs in the given DagBag, record any associated import errors and clears
         errors for files that no longer have them. These are usually displayed through the
         Airflow UI so that users know that there are issues parsing DAGs.
-
-        :param dagbag: DagBag containing DAGs with import errors
+        :param file_last_changed: Dictionary containing the last changed time of the files
+        :param import_errors: Dictionary containing the import errors
         :param session: session for ORM operations
         """
         files_without_error = file_last_changed - import_errors.keys()
@@ -613,30 +639,36 @@ class DagFileProcessor(LoggingMixin):
         # that no longer have errors
         for dagbag_file in files_without_error:
             session.execute(
-                delete(errors.ImportError)
-                .where(errors.ImportError.filename.startswith(dagbag_file))
+                delete(ParseImportError)
+                .where(ParseImportError.filename.startswith(dagbag_file))
                 .execution_options(synchronize_session="fetch")
             )
 
         # files that still have errors
-        existing_import_error_files = [x.filename for x in session.query(errors.ImportError.filename).all()]
+        existing_import_error_files = [x.filename for x in session.query(ParseImportError.filename).all()]
 
         # Add the errors of the processed files
         for filename, stacktrace in import_errors.items():
             if filename in existing_import_error_files:
-                session.query(errors.ImportError).filter(errors.ImportError.filename == filename).update(
+                session.query(ParseImportError).filter(ParseImportError.filename == filename).update(
                     {"filename": filename, "timestamp": timezone.utcnow(), "stacktrace": stacktrace},
                     synchronize_session="fetch",
                 )
+                # sending notification when an existing dag import error occurs
+                get_listener_manager().hook.on_existing_dag_import_error(
+                    filename=filename, stacktrace=stacktrace
+                )
             else:
                 session.add(
-                    errors.ImportError(
+                    ParseImportError(
                         filename=filename,
                         timestamp=timezone.utcnow(),
                         stacktrace=stacktrace,
                         processor_subdir=processor_subdir,
                     )
                 )
+                # sending notification when a new dag import error occurs
+                get_listener_manager().hook.on_new_dag_import_error(filename=filename, stacktrace=stacktrace)
             (
                 session.query(DagModel)
                 .filter(DagModel.fileloc == filename)
@@ -644,54 +676,63 @@ class DagFileProcessor(LoggingMixin):
             )
 
         session.commit()
+        session.flush()
 
-    @provide_session
-    def _validate_task_pools(self, *, dagbag: DagBag, session: Session = NEW_SESSION):
+    @classmethod
+    def update_dag_warnings(cla, *, dagbag: DagBag) -> None:
         """Validate and raise exception if any task in a dag is using a non-existent pool."""
+
+        def get_pools(dag) -> dict[str, set[str]]:
+            return {dag.dag_id: {task.pool for task in dag.tasks}}
+
+        pool_dict: dict[str, set[str]] = {}
+        for dag in dagbag.dags.values():
+            pool_dict.update(get_pools(dag))
+            for subdag in dag.subdags:
+                pool_dict.update(get_pools(subdag))
+        dag_ids = {dag.dag_id for dag in dagbag.dags.values()}
+        return DagFileProcessor._validate_task_pools_and_update_dag_warnings(pool_dict, dag_ids)
+
+    @classmethod
+    @internal_api_call
+    @provide_session
+    def _validate_task_pools_and_update_dag_warnings(
+        cls, pool_dict: dict[str, set[str]], dag_ids: set[str], session: Session = NEW_SESSION
+    ) -> None:
         from airflow.models.pool import Pool
 
-        def check_pools(dag):
-            task_pools = {task.pool for task in dag.tasks}
-            nonexistent_pools = task_pools - pools
+        all_pools = {p.pool for p in Pool.get_pools(session)}
+        warnings: set[DagWarning] = set()
+        for dag_id, dag_pools in pool_dict.items():
+            nonexistent_pools = dag_pools - all_pools
             if nonexistent_pools:
-                return f"Dag '{dag.dag_id}' references non-existent pools: {sorted(nonexistent_pools)!r}"
+                warnings.add(
+                    DagWarning(
+                        dag_id,
+                        DagWarningType.NONEXISTENT_POOL,
+                        f"Dag '{dag_id}' references non-existent pools: {sorted(nonexistent_pools)!r}",
+                    )
+                )
 
-        pools = {p.pool for p in Pool.get_pools(session)}
-        for dag in dagbag.dags.values():
-            message = check_pools(dag)
-            if message:
-                self.dag_warnings.add(DagWarning(dag.dag_id, DagWarningType.NONEXISTENT_POOL, message))
-            for subdag in dag.subdags:
-                message = check_pools(subdag)
-                if message:
-                    self.dag_warnings.add(DagWarning(subdag.dag_id, DagWarningType.NONEXISTENT_POOL, message))
+        stored_warnings = set(session.query(DagWarning).filter(DagWarning.dag_id.in_(dag_ids)).all())
 
-    def update_dag_warnings(self, *, session: Session, dagbag: DagBag) -> None:
-        """
-        Update any import warnings to be displayed in the UI.
-
-        For the DAGs in the given DagBag, record any associated configuration warnings and clear
-        warnings for files that no longer have them. These are usually displayed through the
-        Airflow UI so that users know that there are issues parsing DAGs.
-
-        :param session: session for ORM operations
-        :param dagbag: DagBag containing DAGs with configuration warnings
-        """
-        self._validate_task_pools(dagbag=dagbag)
-
-        stored_warnings = set(session.query(DagWarning).filter(DagWarning.dag_id.in_(dagbag.dags)).all())
-
-        for warning_to_delete in stored_warnings - self.dag_warnings:
+        for warning_to_delete in stored_warnings - warnings:
             session.delete(warning_to_delete)
 
-        for warning_to_add in self.dag_warnings:
+        for warning_to_add in warnings:
             session.merge(warning_to_add)
-
+        session.flush()
         session.commit()
 
+    @classmethod
+    @internal_api_call
     @provide_session
     def execute_callbacks(
-        self, dagbag: DagBag, callback_requests: list[CallbackRequest], session: Session = NEW_SESSION
+        cls,
+        dagbag: DagBag,
+        callback_requests: list[CallbackRequest],
+        unit_test_mode: bool,
+        session: Session = NEW_SESSION,
     ) -> None:
         """
         Execute on failure callbacks.
@@ -701,27 +742,37 @@ class DagFileProcessor(LoggingMixin):
         :param dagbag: Dag Bag of dags
         :param callback_requests: failure callbacks to execute
         :param session: DB session.
+
+        :return: number of queries executed
         """
         for request in callback_requests:
-            self.log.debug("Processing Callback Request: %s", request)
+            cls.logger().debug("Processing Callback Request: %s", request)
             try:
                 if isinstance(request, TaskCallbackRequest):
-                    self._execute_task_callbacks(dagbag, request, session=session)
+                    cls._execute_task_callbacks(dagbag, request, unit_test_mode, session=session)
                 elif isinstance(request, SlaCallbackRequest):
-                    DagFileProcessor.manage_slas(dagbag.dag_folder, request.dag_id, session=session)
+                    if InternalApiConfig.get_use_internal_api():
+                        cls.logger().warning(
+                            "SlaCallbacks are not supported when the Internal API is enabled"
+                        )
+                    else:
+                        DagFileProcessor.manage_slas(dagbag.dag_folder, request.dag_id, session=session)
                 elif isinstance(request, DagCallbackRequest):
-                    self._execute_dag_callbacks(dagbag, request, session)
+                    cls._execute_dag_callbacks(dagbag, request, session=session)
             except Exception:
-                self.log.exception(
+                cls.logger().exception(
                     "Error executing %s callback for file: %s",
                     request.__class__.__name__,
                     request.full_filepath,
                 )
-
         session.flush()
+        session.commit()
 
+    @classmethod
+    @internal_api_call
+    @provide_session
     def execute_callbacks_without_dag(
-        self, callback_requests: list[CallbackRequest], session: Session
+        cls, callback_requests: list[CallbackRequest], unit_test_mode: bool, session: Session = NEW_SESSION
     ) -> None:
         """
         Execute what callbacks we can as "best effort" when the dag cannot be found/had parse errors.
@@ -730,18 +781,20 @@ class DagFileProcessor(LoggingMixin):
         error don't get stuck in queued state.
         """
         for request in callback_requests:
-            self.log.debug("Processing Callback Request: %s", request)
+            cls.logger().debug("Processing Callback Request: %s", request)
             if isinstance(request, TaskCallbackRequest):
-                self._execute_task_callbacks(None, request, session)
+                cls._execute_task_callbacks(None, request, unit_test_mode, session)
             else:
-                self.log.info(
+                cls.logger().info(
                     "Not executing %s callback for file %s as there was a dag parse error",
                     request.__class__.__name__,
                     request.full_filepath,
                 )
+        session.flush()
+        session.commit()
 
-    @provide_session
-    def _execute_dag_callbacks(self, dagbag: DagBag, request: DagCallbackRequest, session: Session):
+    @classmethod
+    def _execute_dag_callbacks(cls, dagbag: DagBag, request: DagCallbackRequest, session: Session):
         dag = dagbag.dags[request.dag_id]
         callbacks, context = DAG.fetch_callback(
             dag=dag,
@@ -754,8 +807,31 @@ class DagFileProcessor(LoggingMixin):
         if callbacks and context:
             DAG.execute_callback(callbacks, context, dag.dag_id)
 
-    def _execute_task_callbacks(self, dagbag: DagBag | None, request: TaskCallbackRequest, session: Session):
-        if not request.is_failure_callback:
+    @classmethod
+    @internal_api_call
+    @provide_session
+    def _execute_task_callbacks(
+        cls, dagbag: DagBag | None, request: TaskCallbackRequest, unit_test_mode: bool, session: Session
+    ) -> None:
+        """
+        Execute the task callbacks.
+
+        :param dagbag: the DagBag to use to get the task instance
+        :param request: the task callback request
+        :param session: the session to use
+        """
+        try:
+            callback_type = TaskInstanceState(request.task_callback_type)
+        except ValueError:
+            callback_type = None
+        is_remote = callback_type in (TaskInstanceState.SUCCESS, TaskInstanceState.FAILED)
+
+        # previously we ignored any request besides failures. now if given callback type directly,
+        # then we respect it and execute it. additionally because in this scenario the callback
+        # is submitted remotely, we assume there is no need to mess with state; we simply run
+        # the callback
+
+        if not is_remote and not request.is_failure_callback:
             return
 
         simple_ti = request.simple_task_instance
@@ -766,6 +842,7 @@ class DagFileProcessor(LoggingMixin):
             map_index=simple_ti.map_index,
             session=session,
         )
+
         if not ti:
             return
 
@@ -787,8 +864,16 @@ class DagFileProcessor(LoggingMixin):
         if task:
             ti.refresh_from_task(task)
 
-        ti.handle_failure(error=request.msg, test_mode=self.UNIT_TEST_MODE, session=session)
-        self.log.info("Executed failure callback for %s in state %s", ti, ti.state)
+        if callback_type is TaskInstanceState.SUCCESS:
+            context = ti.get_template_context(session=session)
+            if TYPE_CHECKING:
+                assert ti.task
+            callbacks = ti.task.on_success_callback
+            _run_finished_callback(callbacks=callbacks, context=context)
+            cls.logger().info("Executed callback for %s in state %s", ti, ti.state)
+        elif not is_remote or callback_type is TaskInstanceState.FAILED:
+            ti.handle_failure(error=request.msg, test_mode=unit_test_mode, session=session)
+            cls.logger().info("Executed callback for %s in state %s", ti, ti.state)
         session.flush()
 
     @classmethod
@@ -807,7 +892,7 @@ class DagFileProcessor(LoggingMixin):
         callback_requests: list[CallbackRequest],
         pickle_dags: bool = False,
         session: Session = NEW_SESSION,
-    ) -> tuple[int, int]:
+    ) -> tuple[int, int, int]:
         """
         Process a Python file containing Airflow DAGs.
 
@@ -824,64 +909,66 @@ class DagFileProcessor(LoggingMixin):
         :param callback_requests: failure callback to execute
         :param pickle_dags: whether serialize the DAGs found in the file and
             save them to the db
-        :param session: Sqlalchemy ORM Session
-        :return: number of dags found, count of import errors
+        :return: number of dags found, count of import errors, last number of db queries
         """
         self.log.info("Processing file %s for tasks to queue", file_path)
 
-        try:
-            dagbag = DagFileProcessor._get_dagbag(file_path)
-        except Exception:
-            self.log.exception("Failed at reloading the DAG file %s", file_path)
-            Stats.incr("dag_file_refresh_error", 1, 1, tags={"file_path": file_path})
-            return 0, 0
+        with count_queries(session) as query_counter:
+            try:
+                dagbag = DagFileProcessor._get_dagbag(file_path)
+            except Exception:
+                self.log.exception("Failed at reloading the DAG file %s", file_path)
+                Stats.incr("dag_file_refresh_error", 1, 1, tags={"file_path": file_path})
+                return 0, 0, self._cache_last_num_of_db_queries(query_counter)
 
-        if dagbag.dags:
-            self.log.info("DAG(s) %s retrieved from %s", ", ".join(map(repr, dagbag.dags)), file_path)
-        else:
-            self.log.warning("No viable dags retrieved from %s", file_path)
-            DagFileProcessor.update_import_errors(
-                file_last_changed=dagbag.file_last_changed,
-                import_errors=dagbag.import_errors,
-                processor_subdir=self._dag_directory,
-                session=session,
+            if dagbag.dags:
+                self.log.info("DAG(s) %s retrieved from %s", ", ".join(map(repr, dagbag.dags)), file_path)
+            else:
+                self.log.warning("No viable dags retrieved from %s", file_path)
+                DagFileProcessor.update_import_errors(
+                    file_last_changed=dagbag.file_last_changed,
+                    import_errors=dagbag.import_errors,
+                    processor_subdir=self._dag_directory,
+                )
+                if callback_requests:
+                    # If there were callback requests for this file but there was a
+                    # parse error we still need to progress the state of TIs,
+                    # otherwise they might be stuck in queued/running for ever!
+                    DagFileProcessor.execute_callbacks_without_dag(callback_requests, self.UNIT_TEST_MODE)
+                return 0, len(dagbag.import_errors), self._cache_last_num_of_db_queries(query_counter)
+
+            self.execute_callbacks(dagbag, callback_requests, self.UNIT_TEST_MODE)
+
+            serialize_errors = DagFileProcessor.save_dag_to_db(
+                dags=dagbag.dags,
+                dag_directory=self._dag_directory,
+                pickle_dags=pickle_dags,
             )
-            if callback_requests:
-                # If there were callback requests for this file but there was a
-                # parse error we still need to progress the state of TIs,
-                # otherwise they might be stuck in queued/running for ever!
-                self.execute_callbacks_without_dag(callback_requests, session)
-            return 0, len(dagbag.import_errors)
 
-        self.execute_callbacks(dagbag, callback_requests, session)
-        session.commit()
+            dagbag.import_errors.update(dict(serialize_errors))
 
-        serialize_errors = DagFileProcessor.save_dag_to_db(
-            dags=dagbag.dags,
-            dag_directory=self._dag_directory,
-            pickle_dags=pickle_dags,
-        )
+            # Record import errors into the ORM
+            try:
+                DagFileProcessor.update_import_errors(
+                    file_last_changed=dagbag.file_last_changed,
+                    import_errors=dagbag.import_errors,
+                    processor_subdir=self._dag_directory,
+                )
+            except Exception:
+                self.log.exception("Error logging import errors!")
 
-        dagbag.import_errors.update(dict(serialize_errors))
+            # Record DAG warnings in the metadatabase.
+            try:
+                self.update_dag_warnings(dagbag=dagbag)
+            except Exception:
+                self.log.exception("Error logging DAG warnings.")
 
-        # Record import errors into the ORM
-        try:
-            DagFileProcessor.update_import_errors(
-                file_last_changed=dagbag.file_last_changed,
-                import_errors=dagbag.import_errors,
-                processor_subdir=self._dag_directory,
-                session=session,
-            )
-        except Exception:
-            self.log.exception("Error logging import errors!")
+        return len(dagbag.dags), len(dagbag.import_errors), self._cache_last_num_of_db_queries(query_counter)
 
-        # Record DAG warnings in the metadatabase.
-        try:
-            self.update_dag_warnings(session=session, dagbag=dagbag)
-        except Exception:
-            self.log.exception("Error logging DAG warnings.")
-
-        return len(dagbag.dags), len(dagbag.import_errors)
+    def _cache_last_num_of_db_queries(self, query_counter: _QueryCounter | None = None):
+        if query_counter:
+            self._last_num_of_db_queries = query_counter.queries_number
+        return self._last_num_of_db_queries
 
     @staticmethod
     @internal_api_call
