@@ -16,14 +16,15 @@
 # specific language governing permissions and limitations
 # under the License.
 """Example DAG demonstrating the usage of dynamic task mapping."""
+
 from __future__ import annotations
 
 from datetime import datetime
 
-from airflow import DAG
 from airflow.decorators import task
+from airflow.models.dag import DAG
 
-with DAG(dag_id="example_dynamic_task_mapping", start_date=datetime(2022, 3, 4)) as dag:
+with DAG(dag_id="example_dynamic_task_mapping", schedule=None, start_date=datetime(2022, 3, 4)) as dag:
 
     @task
     def add_one(x: int):
