@@ -57,5 +57,5 @@ with DAG(
     BashOperator(
         task_id="read_dataset_event_from_classic",
         inlets=[ds],
-        bash_command="echo '{{ inlet_events['s3://output/1.txt'][-1].extra | tojson }}'",
+        bash_command="echo '{{ inlet_events[Dataset('s3://output/1.txt')][-1].extra | tojson }}'",
     )
