@@ -261,8 +261,8 @@ class LocalTaskJobRunner(BaseJobRunner, LoggingMixin):
             _set_task_deferred_context_var()
         else:
             message = f"Task exited with return code {return_code}"
-            if return_code == -signal.SIGKILL:
-                message += "For more information, see https://airflow.apache.org/docs/apache-airflow/stable/troubleshooting.html#LocalTaskJob-killed"
+            if not IS_WINDOWS and return_code == -signal.SIGKILL:
+                message += ". For more information, see https://airflow.apache.org/docs/apache-airflow/stable/troubleshooting.html#LocalTaskJob-killed"
             self.log.info(message)
 
         if not (self.task_instance.test_mode or is_deferral):
