@@ -15,7 +15,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Sends lineage metadata to a backend"""
+"""Sends lineage metadata to a backend."""
+
 from __future__ import annotations
 
 from typing import TYPE_CHECKING
@@ -25,7 +26,7 @@ if TYPE_CHECKING:
 
 
 class LineageBackend:
-    """Sends lineage metadata to a backend"""
+    """Sends lineage metadata to a backend."""
 
     def send_lineage(
         self,
@@ -35,7 +36,7 @@ class LineageBackend:
         context: dict | None = None,
     ):
         """
-        Sends lineage metadata to a backend
+        Send lineage metadata to a backend.
 
         :param operator: the operator executing a transformation on the inlets and outlets
         :param inlets: the inlets to this operator
