@@ -37,12 +37,14 @@ class ListenerManager:
     """Manage listener registration and provides hook property for calling them."""
 
     def __init__(self):
-        from airflow.listeners.spec import dagrun, lifecycle, taskinstance
+        from airflow.listeners.spec import dagrun, dataset, importerrors, lifecycle, taskinstance
 
         self.pm = pluggy.PluginManager("airflow")
         self.pm.add_hookspecs(lifecycle)
         self.pm.add_hookspecs(dagrun)
+        self.pm.add_hookspecs(dataset)
         self.pm.add_hookspecs(taskinstance)
+        self.pm.add_hookspecs(importerrors)
 
     @property
     def has_listeners(self) -> bool:
