@@ -15,28 +15,30 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Add indices in ``job`` table
+"""
+Add indices in ``job`` table.
 
 Revision ID: 52d714495f0
 Revises: 338e90f54d61
 Create Date: 2015-10-20 03:17:01.962542
 
 """
+
 from __future__ import annotations
 
 from alembic import op
 
 # revision identifiers, used by Alembic.
-revision = '52d714495f0'
-down_revision = '338e90f54d61'
+revision = "52d714495f0"
+down_revision = "338e90f54d61"
 branch_labels = None
 depends_on = None
-airflow_version = '1.5.2'
+airflow_version = "1.5.2"
 
 
 def upgrade():
-    op.create_index('idx_job_state_heartbeat', 'job', ['state', 'latest_heartbeat'], unique=False)
+    op.create_index("idx_job_state_heartbeat", "job", ["state", "latest_heartbeat"], unique=False)
 
 
 def downgrade():
-    op.drop_index('idx_job_state_heartbeat', table_name='job')
+    op.drop_index("idx_job_state_heartbeat", table_name="job")
