@@ -15,13 +15,15 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Rename user table
+"""
+Rename user table.
 
 Revision ID: 2e82aab8ef20
 Revises: 1968acfc09e3
 Create Date: 2016-04-02 19:28:15.211915
 
 """
+
 from __future__ import annotations
 
 from alembic import op
