@@ -15,13 +15,15 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Resource based permissions.
+"""
+Resource based permissions.
 
 Revision ID: 2c6edca13270
 Revises: 849da589634d
 Create Date: 2020-10-21 00:18:52.529438
 
 """
+
 from __future__ import annotations
 
 import logging
@@ -312,7 +314,7 @@ def remap_permissions():
 
 
 def undo_remap_permissions():
-    """Unapply Map Airflow permissions"""
+    """Unapply Map Airflow permissions."""
     appbuilder = cached_app(config={"FAB_UPDATE_PERMS": False}).appbuilder
     for old, new in mapping.items():
         (new_resource_name, new_action_name) = new[0]
