@@ -15,12 +15,14 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Add ``LogTemplate`` table to track changes to config values ``log_filename_template``
+"""
+Add ``LogTemplate`` table to track changes to config values ``log_filename_template``.
 
 Revision ID: f9da662e7089
 Revises: 786e3737b18f
 Create Date: 2021-12-09 06:11:21.044940
 """
+
 from __future__ import annotations
 
 from alembic import op
@@ -34,7 +36,7 @@ revision = "f9da662e7089"
 down_revision = "786e3737b18f"
 branch_labels = None
 depends_on = None
-airflow_version = '2.3.0'
+airflow_version = "2.3.0"
 
 
 def upgrade():
