@@ -15,8 +15,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-
-"""Add index for ``event`` column in ``log`` table.
+"""
+Add index for ``event`` column in ``log`` table.
 
 Revision ID: 1de7bc13c950
 Revises: b1b348e02d07
@@ -24,21 +24,23 @@ Create Date: 2022-05-10 18:18:43.484829
 
 """
 
+from __future__ import annotations
+
 from alembic import op
 
 # revision identifiers, used by Alembic.
-revision = '1de7bc13c950'
-down_revision = 'b1b348e02d07'
+revision = "1de7bc13c950"
+down_revision = "b1b348e02d07"
 branch_labels = None
 depends_on = None
-airflow_version = '2.3.1'
+airflow_version = "2.3.1"
 
 
 def upgrade():
     """Apply Add index for ``event`` column in ``log`` table."""
-    op.create_index('idx_log_event', 'log', ['event'], unique=False)
+    op.create_index("idx_log_event", "log", ["event"], unique=False)
 
 
 def downgrade():
     """Unapply Add index for ``event`` column in ``log`` table."""
-    op.drop_index('idx_log_event', table_name='log')
+    op.drop_index("idx_log_event", table_name="log")
