@@ -17,13 +17,16 @@
 # under the License.
 from __future__ import annotations
 
+import warnings
+
 from sqlalchemy import Column, Integer, String, Text
 
+from airflow.exceptions import RemovedInAirflow3Warning
 from airflow.models.base import Base
 from airflow.utils.sqlalchemy import UtcDateTime
 
 
-class ImportError(Base):
+class ParseImportError(Base):
     """Stores all Import Errors which are recorded when parsing DAGs and displayed on the Webserver."""
 
     __tablename__ = "import_error"
@@ -31,3 +34,18 @@ class ImportError(Base):
     timestamp = Column(UtcDateTime)
     filename = Column(String(1024))
     stacktrace = Column(Text)
+    processor_subdir = Column(String(2000), nullable=True)
+
+
+def __getattr__(name: str):
+    # PEP-562: Lazy loaded attributes on python modules
+    if name == "ImportError":
+        warnings.warn(
+            f"Model class '{__name__}.ImportError' is deprecated due to shadowing with builtin exception "
+            f"ImportError and will be removed in the future. "
+            f"Please consider to use '{__name__}.ParseImportError' instead.",
+            RemovedInAirflow3Warning,
+            stacklevel=2,
+        )
+        return ParseImportError
+    raise AttributeError(f"module {__name__} has no attribute {name}")
