@@ -35,7 +35,8 @@ from airflow.models.base import ID_LEN, Base
 from airflow.models.dag import DagModel
 from airflow.models.dagcode import DagCode
 from airflow.models.dagrun import DagRun
-from airflow.serialization.serialized_objects import DagDependency, SerializedDAG
+from airflow.serialization.dag_dependency import DagDependency
+from airflow.serialization.serialized_objects import SerializedDAG
 from airflow.settings import COMPRESS_SERIALIZED_DAGS, MIN_SERIALIZED_DAG_UPDATE_INTERVAL, json
 from airflow.utils import timezone
 from airflow.utils.hashlib_wrapper import md5
@@ -54,7 +55,8 @@ log = logging.getLogger(__name__)
 
 
 class SerializedDagModel(Base):
-    """A table for serialized DAGs.
+    """
+    A table for serialized DAGs.
 
     serialized_dag table is a snapshot of DAG files synchronized by scheduler.
     This feature is controlled by:
@@ -185,7 +187,8 @@ class SerializedDagModel(Base):
     @classmethod
     @provide_session
     def read_all_dags(cls, session: Session = NEW_SESSION) -> dict[str, SerializedDAG]:
-        """Read all DAGs in serialized_dag table.
+        """
+        Read all DAGs in serialized_dag table.
 
         :param session: ORM Session
         :returns: a dict of DAGs read from database
@@ -243,6 +246,7 @@ class SerializedDagModel(Base):
         session.execute(cls.__table__.delete().where(cls.dag_id == dag_id))
 
     @classmethod
+    @internal_api_call
     @provide_session
     def remove_deleted_dags(
         cls,
@@ -250,7 +254,8 @@ class SerializedDagModel(Base):
         processor_subdir: str | None = None,
         session: Session = NEW_SESSION,
     ) -> None:
-        """Delete DAGs not included in alive_dag_filelocs.
+        """
+        Delete DAGs not included in alive_dag_filelocs.
 
         :param alive_dag_filelocs: file paths of alive DAGs
         :param processor_subdir: dag processor subdir
@@ -278,7 +283,8 @@ class SerializedDagModel(Base):
     @classmethod
     @provide_session
     def has_dag(cls, dag_id: str, session: Session = NEW_SESSION) -> bool:
-        """Check a DAG exist in serialized_dag table.
+        """
+        Check a DAG exist in serialized_dag table.
 
         :param dag_id: the DAG to check
         :param session: ORM Session
