@@ -19,13 +19,15 @@ from __future__ import annotations
 
 import contextlib
 import inspect
+import itertools
 from typing import TYPE_CHECKING, Any, Callable, Iterable, Iterator, Mapping, Sequence, Union, overload
 
 from sqlalchemy import func, or_, select
 
+from airflow.api_internal.internal_api_call import internal_api_call
 from airflow.exceptions import AirflowException, XComNotFound
+from airflow.models import MappedOperator, TaskInstance
 from airflow.models.abstractoperator import AbstractOperator
-from airflow.models.mappedoperator import MappedOperator
 from airflow.models.taskmixin import DependencyMixin
 from airflow.utils.db import exists_query
 from airflow.utils.mixins import ResolveMixin
@@ -53,7 +55,8 @@ MapCallables = Sequence[Union[Callable[[Any], Any], str]]
 
 
 class XComArg(ResolveMixin, DependencyMixin):
-    """Reference to an XCom value pushed from another operator.
+    """
+    Reference to an XCom value pushed from another operator.
 
     The implementation supports::
 
@@ -100,7 +103,8 @@ class XComArg(ResolveMixin, DependencyMixin):
 
     @staticmethod
     def iter_xcom_references(arg: Any) -> Iterator[tuple[Operator, str]]:
-        """Return XCom references in an arbitrary value.
+        """
+        Return XCom references in an arbitrary value.
 
         Recursively traverse ``arg`` and look for XComArg instances in any
         collection objects, and instances with ``template_fields`` set.
@@ -119,7 +123,8 @@ class XComArg(ResolveMixin, DependencyMixin):
 
     @staticmethod
     def apply_upstream_relationship(op: Operator, arg: Any):
-        """Set dependency for XComArgs.
+        """
+        Set dependency for XComArgs.
 
         This looks for XComArg objects in ``arg`` "deeply" (looking inside
         collections objects and classes decorated with ``template_fields``), and
@@ -158,7 +163,7 @@ class XComArg(ResolveMixin, DependencyMixin):
 
     def _serialize(self) -> dict[str, Any]:
         """
-        Serialize a DAG.
+        Serialize an XComArg.
 
         The implementation should be the inverse function to ``deserialize``,
         returning a data dict converted from this XComArg derivative. DAG
@@ -171,7 +176,7 @@ class XComArg(ResolveMixin, DependencyMixin):
     @classmethod
     def _deserialize(cls, data: dict[str, Any], dag: DAG) -> XComArg:
         """
-        Deserialize a DAG.
+        Deserialize an XComArg.
 
         The implementation should be the inverse function to ``serialize``,
         implementing given a data dict converted from this XComArg derivative,
@@ -188,8 +193,12 @@ class XComArg(ResolveMixin, DependencyMixin):
     def zip(self, *others: XComArg, fillvalue: Any = NOTSET) -> ZipXComArg:
         return ZipXComArg([self, *others], fillvalue=fillvalue)
 
+    def concat(self, *others: XComArg) -> ConcatXComArg:
+        return ConcatXComArg([self, *others])
+
     def get_task_map_length(self, run_id: str, *, session: Session) -> int | None:
-        """Inspect length of pushed value for task-mapping.
+        """
+        Inspect length of pushed value for task-mapping.
 
         This is used to determine how many task instances the scheduler should
         create for a downstream using this XComArg for task-mapping.
@@ -199,8 +208,9 @@ class XComArg(ResolveMixin, DependencyMixin):
         raise NotImplementedError()
 
     @provide_session
-    def resolve(self, context: Context, session: Session = NEW_SESSION) -> Any:
-        """Pull XCom value.
+    def resolve(self, context: Context, session: Session = NEW_SESSION, *, include_xcom: bool = True) -> Any:
+        """
+        Pull XCom value.
 
         This should only be called during ``op.execute()`` with an appropriate
         context (e.g. generated from ``TaskInstance.get_template_context()``).
@@ -222,8 +232,56 @@ class XComArg(ResolveMixin, DependencyMixin):
         SetupTeardownContext.set_work_task_roots_and_leaves()
 
 
+@internal_api_call
+@provide_session
+def _get_task_map_length(
+    *,
+    dag_id: str,
+    task_id: str,
+    run_id: str,
+    is_mapped: bool,
+    session: Session = NEW_SESSION,
+) -> int | None:
+    from airflow.models.taskinstance import TaskInstance
+    from airflow.models.taskmap import TaskMap
+    from airflow.models.xcom import XCom
+
+    if is_mapped:
+        unfinished_ti_exists = exists_query(
+            TaskInstance.dag_id == dag_id,
+            TaskInstance.run_id == run_id,
+            TaskInstance.task_id == task_id,
+            # Special NULL treatment is needed because 'state' can be NULL.
+            # The "IN" part would produce "NULL NOT IN ..." and eventually
+            # "NULl = NULL", which is a big no-no in SQL.
+            or_(
+                TaskInstance.state.is_(None),
+                TaskInstance.state.in_(s.value for s in State.unfinished if s is not None),
+            ),
+            session=session,
+        )
+        if unfinished_ti_exists:
+            return None  # Not all of the expanded tis are done yet.
+        query = select(func.count(XCom.map_index)).where(
+            XCom.dag_id == dag_id,
+            XCom.run_id == run_id,
+            XCom.task_id == task_id,
+            XCom.map_index >= 0,
+            XCom.key == XCOM_RETURN_KEY,
+        )
+    else:
+        query = select(TaskMap.length).where(
+            TaskMap.dag_id == dag_id,
+            TaskMap.run_id == run_id,
+            TaskMap.task_id == task_id,
+            TaskMap.map_index < 0,
+        )
+    return session.scalar(query)
+
+
 class PlainXComArg(XComArg):
-    """Reference to one single XCom without any additional semantics.
+    """
+    Reference to one single XCom without any additional semantics.
 
     This class should not be accessed directly, but only through XComArg. The
     class inheritance chain and ``__new__`` is implemented in this slightly
@@ -256,7 +314,8 @@ class PlainXComArg(XComArg):
         return PlainXComArg(operator=self.operator, key=item)
 
     def __iter__(self):
-        """Override iterable protocol to raise error explicitly.
+        """
+        Override iterable protocol to raise error explicitly.
 
         The default ``__iter__`` implementation in Python calls ``__getitem__``
         with 0, 1, 2, etc. until it hits an ``IndexError``. This does not work
@@ -363,51 +422,25 @@ class PlainXComArg(XComArg):
             raise ValueError("cannot map against non-return XCom")
         return super().zip(*others, fillvalue=fillvalue)
 
-    def get_task_map_length(self, run_id: str, *, session: Session) -> int | None:
-        from airflow.models.taskinstance import TaskInstance
-        from airflow.models.taskmap import TaskMap
-        from airflow.models.xcom import XCom
+    def concat(self, *others: XComArg) -> ConcatXComArg:
+        if self.key != XCOM_RETURN_KEY:
+            raise ValueError("cannot concatenate non-return XCom")
+        return super().concat(*others)
 
-        task = self.operator
-        if isinstance(task, MappedOperator):
-            unfinished_ti_exists = exists_query(
-                TaskInstance.dag_id == task.dag_id,
-                TaskInstance.run_id == run_id,
-                TaskInstance.task_id == task.task_id,
-                # Special NULL treatment is needed because 'state' can be NULL.
-                # The "IN" part would produce "NULL NOT IN ..." and eventually
-                # "NULl = NULL", which is a big no-no in SQL.
-                or_(
-                    TaskInstance.state.is_(None),
-                    TaskInstance.state.in_(s.value for s in State.unfinished if s is not None),
-                ),
-                session=session,
-            )
-            if unfinished_ti_exists:
-                return None  # Not all of the expanded tis are done yet.
-            query = select(func.count(XCom.map_index)).where(
-                XCom.dag_id == task.dag_id,
-                XCom.run_id == run_id,
-                XCom.task_id == task.task_id,
-                XCom.map_index >= 0,
-                XCom.key == XCOM_RETURN_KEY,
-            )
-        else:
-            query = select(TaskMap.length).where(
-                TaskMap.dag_id == task.dag_id,
-                TaskMap.run_id == run_id,
-                TaskMap.task_id == task.task_id,
-                TaskMap.map_index < 0,
-            )
-        return session.scalar(query)
+    def get_task_map_length(self, run_id: str, *, session: Session) -> int | None:
+        return _get_task_map_length(
+            dag_id=self.operator.dag_id,
+            task_id=self.operator.task_id,
+            is_mapped=isinstance(self.operator, MappedOperator),
+            run_id=run_id,
+            session=session,
+        )
 
     @provide_session
-    def resolve(self, context: Context, session: Session = NEW_SESSION) -> Any:
-        from airflow.models.taskinstance import TaskInstance
-
+    def resolve(self, context: Context, session: Session = NEW_SESSION, *, include_xcom: bool = True) -> Any:
         ti = context["ti"]
-        assert isinstance(ti, TaskInstance), "Wait for AIP-44 implementation to complete"
-
+        if TYPE_CHECKING:
+            assert isinstance(ti, TaskInstance)
         task_id = self.operator.task_id
         map_indexes = ti.get_relevant_upstream_map_indexes(
             self.operator,
@@ -475,7 +508,8 @@ class _MapResult(Sequence):
 
 
 class MapXComArg(XComArg):
-    """An XCom reference with ``map()`` call(s) applied.
+    """
+    An XCom reference with ``map()`` call(s) applied.
 
     This is based on an XComArg, but also applies a series of "transforms" that
     convert the pulled XCom value.
@@ -517,8 +551,8 @@ class MapXComArg(XComArg):
         return self.arg.get_task_map_length(run_id, session=session)
 
     @provide_session
-    def resolve(self, context: Context, session: Session = NEW_SESSION) -> Any:
-        value = self.arg.resolve(context, session=session)
+    def resolve(self, context: Context, session: Session = NEW_SESSION, *, include_xcom: bool = True) -> Any:
+        value = self.arg.resolve(context, session=session, include_xcom=include_xcom)
         if not isinstance(value, (Sequence, dict)):
             raise ValueError(f"XCom map expects sequence or dict, not {type(value).__name__}")
         return _MapResult(value, self.callables)
@@ -549,7 +583,8 @@ class _ZipResult(Sequence):
 
 
 class ZipXComArg(XComArg):
-    """An XCom reference with ``zip()`` applied.
+    """
+    An XCom reference with ``zip()`` applied.
 
     This is constructed from multiple XComArg instances, and presents an
     iterable that "zips" them together like the built-in ``zip()`` (and
@@ -597,16 +632,92 @@ class ZipXComArg(XComArg):
         return max(ready_lengths)
 
     @provide_session
-    def resolve(self, context: Context, session: Session = NEW_SESSION) -> Any:
-        values = [arg.resolve(context, session=session) for arg in self.args]
+    def resolve(self, context: Context, session: Session = NEW_SESSION, *, include_xcom: bool = True) -> Any:
+        values = [arg.resolve(context, session=session, include_xcom=include_xcom) for arg in self.args]
         for value in values:
             if not isinstance(value, (Sequence, dict)):
                 raise ValueError(f"XCom zip expects sequence or dict, not {type(value).__name__}")
         return _ZipResult(values, fillvalue=self.fillvalue)
 
 
+class _ConcatResult(Sequence):
+    def __init__(self, values: Sequence[Sequence | dict]) -> None:
+        self.values = values
+
+    def __getitem__(self, index: Any) -> Any:
+        if index >= 0:
+            i = index
+        else:
+            i = len(self) + index
+        for value in self.values:
+            if i < 0:
+                break
+            elif i >= (curlen := len(value)):
+                i -= curlen
+            elif isinstance(value, Sequence):
+                return value[i]
+            else:
+                return next(itertools.islice(iter(value), i, None))
+        raise IndexError("list index out of range")
+
+    def __len__(self) -> int:
+        return sum(len(v) for v in self.values)
+
+
+class ConcatXComArg(XComArg):
+    """
+    Concatenating multiple XCom references into one.
+
+    This is done by calling ``concat()`` on an XComArg to combine it with
+    others. The effect is similar to Python's :func:`itertools.chain`, but the
+    return value also supports index access.
+    """
+
+    def __init__(self, args: Sequence[XComArg]) -> None:
+        if not args:
+            raise ValueError("At least one input is required")
+        self.args = args
+
+    def __repr__(self) -> str:
+        args_iter = iter(self.args)
+        first = repr(next(args_iter))
+        rest = ", ".join(repr(arg) for arg in args_iter)
+        return f"{first}.concat({rest})"
+
+    def _serialize(self) -> dict[str, Any]:
+        return {"args": [serialize_xcom_arg(arg) for arg in self.args]}
+
+    @classmethod
+    def _deserialize(cls, data: dict[str, Any], dag: DAG) -> XComArg:
+        return cls([deserialize_xcom_arg(arg, dag) for arg in data["args"]])
+
+    def iter_references(self) -> Iterator[tuple[Operator, str]]:
+        for arg in self.args:
+            yield from arg.iter_references()
+
+    def concat(self, *others: XComArg) -> ConcatXComArg:
+        # Flatten foo.concat(x).concat(y) into one call.
+        return ConcatXComArg([*self.args, *others])
+
+    def get_task_map_length(self, run_id: str, *, session: Session) -> int | None:
+        all_lengths = (arg.get_task_map_length(run_id, session=session) for arg in self.args)
+        ready_lengths = [length for length in all_lengths if length is not None]
+        if len(ready_lengths) != len(self.args):
+            return None  # If any of the referenced XComs is not ready, we are not ready either.
+        return sum(ready_lengths)
+
+    @provide_session
+    def resolve(self, context: Context, session: Session = NEW_SESSION, *, include_xcom: bool = True) -> Any:
+        values = [arg.resolve(context, session=session, include_xcom=include_xcom) for arg in self.args]
+        for value in values:
+            if not isinstance(value, (Sequence, dict)):
+                raise ValueError(f"XCom concat expects sequence or dict, not {type(value).__name__}")
+        return _ConcatResult(values)
+
+
 _XCOM_ARG_TYPES: Mapping[str, type[XComArg]] = {
     "": PlainXComArg,
+    "concat": ConcatXComArg,
     "map": MapXComArg,
     "zip": ZipXComArg,
 }
@@ -614,7 +725,7 @@ _XCOM_ARG_TYPES: Mapping[str, type[XComArg]] = {
 
 def serialize_xcom_arg(value: XComArg) -> dict[str, Any]:
     """DAG serialization interface."""
-    key = next(k for k, v in _XCOM_ARG_TYPES.items() if v == type(value))
+    key = next(k for k, v in _XCOM_ARG_TYPES.items() if isinstance(value, v))
     if key:
         return {"type": key, **value._serialize()}
     return value._serialize()
