@@ -20,13 +20,14 @@ from __future__ import annotations
 from abc import abstractmethod
 from typing import TYPE_CHECKING, Sequence
 
-import jinja2
-
 from airflow.template.templater import Templater
-from airflow.utils.context import Context, context_merge
+from airflow.utils.context import context_merge
 
 if TYPE_CHECKING:
+    import jinja2
+
     from airflow import DAG
+    from airflow.utils.context import Context
 
 
 class BaseNotifier(Templater):
@@ -58,7 +59,8 @@ class BaseNotifier(Templater):
         context: Context,
         jinja_env: jinja2.Environment | None = None,
     ) -> None:
-        """Template all attributes listed in *self.template_fields*.
+        """
+        Template all attributes listed in *self.template_fields*.
 
         This mutates the attributes in-place and is irreversible.
 
