@@ -18,29 +18,47 @@
 """
 This module contains AWS Athena hook.
 
-.. spelling::
+.. spelling:word-list::
 
     PageIterator
 """
+
 from __future__ import annotations
 
 import warnings
-from time import sleep
-from typing import Any
-
-from botocore.paginate import PageIterator
+from typing import TYPE_CHECKING, Any, Collection
 
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
+from airflow.providers.amazon.aws.utils.waiter_with_logging import wait
+
+if TYPE_CHECKING:
+    from botocore.paginate import PageIterator
+
+MULTI_LINE_QUERY_LOG_PREFIX = "\n\t\t"
+
+
+def query_params_to_string(params: dict[str, str | Collection[str]]) -> str:
+    result = ""
+    for key, value in params.items():
+        if key == "QueryString":
+            value = (
+                MULTI_LINE_QUERY_LOG_PREFIX + str(value).replace("\n", MULTI_LINE_QUERY_LOG_PREFIX).rstrip()
+            )
+        result += f"\t{key}: {value}\n"
+    return result.rstrip()
 
 
 class AthenaHook(AwsBaseHook):
     """
     Interact with Amazon Athena.
-    Provide thick wrapper around :external+boto3:py:class:`boto3.client("athena") <Athena.Client>`.
 
-    :param sleep_time: Time (in seconds) to wait between two consecutive calls to check query status on Athena
-    :param log_query: Whether to log athena query and other execution params when it's executed.
-        Defaults to *True*.
+    Provide thick wrapper around
+    :external+boto3:py:class:`boto3.client("athena") <Athena.Client>`.
+
+    :param sleep_time: obsolete, please use the parameter of `poll_query_status` method instead
+    :param log_query: Whether to log athena query and other execution params
+        when it's executed. Defaults to *True*.
 
     Additional arguments (such as ``aws_conn_id``) may be specified and
     are passed down to the underlying AwsBaseHook.
@@ -64,10 +82,22 @@ class AthenaHook(AwsBaseHook):
         "CANCELLED",
     )
 
-    def __init__(self, *args: Any, sleep_time: int = 30, log_query: bool = True, **kwargs: Any) -> None:
+    def __init__(
+        self, *args: Any, sleep_time: int | None = None, log_query: bool = True, **kwargs: Any
+    ) -> None:
         super().__init__(client_type="athena", *args, **kwargs)  # type: ignore
-        self.sleep_time = sleep_time
+        if sleep_time is not None:
+            self.sleep_time = sleep_time
+            warnings.warn(
+                "The `sleep_time` parameter of the Athena hook is deprecated, "
+                "please pass this parameter to the poll_query_status method instead.",
+                AirflowProviderDeprecationWarning,
+                stacklevel=2,
+            )
+        else:
+            self.sleep_time = 30  # previous default value
         self.log_query = log_query
+        self.__query_results: dict[str, Any] = {}
 
     def run_query(
         self,
@@ -78,16 +108,19 @@ class AthenaHook(AwsBaseHook):
         workgroup: str = "primary",
     ) -> str:
         """
-        Run Presto query on athena with provided config and return submitted query_execution_id
+        Run a Trino/Presto query on Athena with provided config.
 
         .. seealso::
             - :external+boto3:py:meth:`Athena.Client.start_query_execution`
 
-        :param query: Presto query to run
-        :param query_context: Context in which query need to be run
-        :param result_configuration: Dict with path to store results in and config related to encryption
-        :param client_request_token: Unique token created by user to avoid multiple executions of same query
-        :param workgroup: Athena workgroup name, when not specified, will be 'primary'
+        :param query: Trino/Presto query to run.
+        :param query_context: Context in which query need to be run.
+        :param result_configuration: Dict with path to store results in and
+            config related to encryption.
+        :param client_request_token: Unique token created by user to avoid
+            multiple executions of same query.
+        :param workgroup: Athena workgroup name, when not specified, will be ``'primary'``.
+        :return: Submitted query execution ID.
         """
         params = {
             "QueryString": query,
@@ -98,22 +131,41 @@ class AthenaHook(AwsBaseHook):
         if client_request_token:
             params["ClientRequestToken"] = client_request_token
         if self.log_query:
-            self.log.info("Running Query with params: %s", params)
+            self.log.info("Running Query with params:\n%s", query_params_to_string(params))
         response = self.get_conn().start_query_execution(**params)
         query_execution_id = response["QueryExecutionId"]
         self.log.info("Query execution id: %s", query_execution_id)
         return query_execution_id
 
-    def check_query_status(self, query_execution_id: str) -> str | None:
+    def get_query_info(self, query_execution_id: str, use_cache: bool = False) -> dict:
         """
-        Fetch the status of submitted athena query. Returns None or one of valid query states.
+        Get information about a single execution of a query.
 
         .. seealso::
             - :external+boto3:py:meth:`Athena.Client.get_query_execution`
 
         :param query_execution_id: Id of submitted athena query
+        :param use_cache: If True, use execution information cache
         """
+        if use_cache and query_execution_id in self.__query_results:
+            return self.__query_results[query_execution_id]
         response = self.get_conn().get_query_execution(QueryExecutionId=query_execution_id)
+        if use_cache:
+            self.__query_results[query_execution_id] = response
+        return response
+
+    def check_query_status(self, query_execution_id: str, use_cache: bool = False) -> str | None:
+        """
+        Fetch the state of a submitted query.
+
+        .. seealso::
+            - :external+boto3:py:meth:`Athena.Client.get_query_execution`
+
+        :param query_execution_id: Id of submitted athena query
+        :return: One of valid query states, or *None* if the response is
+            malformed.
+        """
+        response = self.get_query_info(query_execution_id=query_execution_id, use_cache=use_cache)
         state = None
         try:
             state = response["QueryExecution"]["Status"]["State"]
@@ -126,7 +178,7 @@ class AthenaHook(AwsBaseHook):
             # The error is being absorbed to implement retries.
             return state
 
-    def get_state_change_reason(self, query_execution_id: str) -> str | None:
+    def get_state_change_reason(self, query_execution_id: str, use_cache: bool = False) -> str | None:
         """
         Fetch the reason for a state change (e.g. error message). Returns None or reason string.
 
@@ -135,7 +187,7 @@ class AthenaHook(AwsBaseHook):
 
         :param query_execution_id: Id of submitted athena query
         """
-        response = self.get_conn().get_query_execution(QueryExecutionId=query_execution_id)
+        response = self.get_query_info(query_execution_id=query_execution_id, use_cache=use_cache)
         reason = None
         try:
             reason = response["QueryExecution"]["Status"]["StateChangeReason"]
@@ -153,8 +205,7 @@ class AthenaHook(AwsBaseHook):
         self, query_execution_id: str, next_token_id: str | None = None, max_results: int = 1000
     ) -> dict | None:
         """
-        Fetch submitted athena query results. returns none if query is in intermediate state or
-        failed/cancelled state else dict of query output
+        Fetch submitted query results.
 
         .. seealso::
             - :external+boto3:py:meth:`Athena.Client.get_query_results`
@@ -162,6 +213,8 @@ class AthenaHook(AwsBaseHook):
         :param query_execution_id: Id of submitted athena query
         :param next_token_id:  The token that specifies where to start pagination.
         :param max_results: The maximum number of results (rows) to return in this request.
+        :return: *None* if the query is in intermediate, failed, or cancelled
+            state. Otherwise a dict of query outputs.
         """
         query_state = self.check_query_status(query_execution_id)
         if query_state is None:
@@ -187,9 +240,7 @@ class AthenaHook(AwsBaseHook):
         starting_token: str | None = None,
     ) -> PageIterator | None:
         """
-        Fetch submitted athena query results. returns none if query is in intermediate state or
-        failed/cancelled state else a paginator to iterate through pages of results. If you
-        wish to get all results at once, call build_full_result() on the returned PageIterator
+        Fetch submitted Athena query results.
 
         .. seealso::
             - :external+boto3:py:class:`Athena.Paginator.GetQueryResults`
@@ -198,6 +249,11 @@ class AthenaHook(AwsBaseHook):
         :param max_items: The total number of items to return.
         :param page_size: The size of each page.
         :param starting_token: A token to specify where to start paginating.
+        :return: *None* if the query is in intermediate, failed, or cancelled
+            state. Otherwise a paginator to iterate through pages of results.
+
+        Call :meth`.build_full_result()` on the returned paginator to get all
+        results at once.
         """
         query_state = self.check_query_status(query_execution_id)
         if query_state is None:
@@ -222,98 +278,57 @@ class AthenaHook(AwsBaseHook):
         return paginator.paginate(**result_params)
 
     def poll_query_status(
-        self,
-        query_execution_id: str,
-        max_tries: int | None = None,
-        max_polling_attempts: int | None = None,
+        self, query_execution_id: str, max_polling_attempts: int | None = None, sleep_time: int | None = None
     ) -> str | None:
         """
-        Poll the status of submitted athena query until query state reaches final state.
-        Returns one of the final states
+        Poll the state of a submitted query until it reaches final state.
 
-        :param query_execution_id: Id of submitted athena query
-        :param max_tries: Deprecated - Use max_polling_attempts instead
+        :param query_execution_id: ID of submitted athena query
         :param max_polling_attempts: Number of times to poll for query state before function exits
+        :param sleep_time: Time (in seconds) to wait between two consecutive query status checks.
+        :return: One of the final states
         """
-        if max_tries:
-            warnings.warn(
-                f"Passing 'max_tries' to {self.__class__.__name__}.poll_query_status is deprecated "
-                f"and will be removed in a future release. Please use 'max_polling_attempts' instead.",
-                DeprecationWarning,
-                stacklevel=2,
+        try:
+            wait(
+                waiter=self.get_waiter("query_complete"),
+                waiter_delay=self.sleep_time if sleep_time is None else sleep_time,
+                waiter_max_attempts=max_polling_attempts or 120,
+                args={"QueryExecutionId": query_execution_id},
+                failure_message=f"Error while waiting for query {query_execution_id} to complete",
+                status_message=f"Query execution id: {query_execution_id}, "
+                f"Query is still in non-terminal state",
+                status_args=["QueryExecution.Status.State"],
             )
-            if max_polling_attempts and max_polling_attempts != max_tries:
-                raise Exception("max_polling_attempts must be the same value as max_tries")
-            else:
-                max_polling_attempts = max_tries
-
-        try_number = 1
-        final_query_state = None  # Query state when query reaches final state or max_polling_attempts reached
-        while True:
-            query_state = self.check_query_status(query_execution_id)
-            if query_state is None:
-                self.log.info(
-                    "Query execution id: %s, trial %s: Invalid query state. Retrying again",
-                    query_execution_id,
-                    try_number,
-                )
-            elif query_state in self.TERMINAL_STATES:
-                self.log.info(
-                    "Query execution id: %s, trial %s: Query execution completed. Final state is %s",
-                    query_execution_id,
-                    try_number,
-                    query_state,
-                )
-                final_query_state = query_state
-                break
-            else:
-                self.log.info(
-                    "Query execution id: %s, trial %s: Query is still in non-terminal state - %s",
-                    query_execution_id,
-                    try_number,
-                    query_state,
-                )
-            if (
-                max_polling_attempts and try_number >= max_polling_attempts
-            ):  # Break loop if max_polling_attempts reached
-                final_query_state = query_state
-                break
-            try_number += 1
-            sleep(self.sleep_time)
-        return final_query_state
+        except AirflowException as error:
+            # this function does not raise errors to keep previous behavior.
+            self.log.warning(error)
+        finally:
+            return self.check_query_status(query_execution_id)
 
     def get_output_location(self, query_execution_id: str) -> str:
         """
-        Function to get the output location of the query results
-        in s3 uri format.
+        Get the output location of the query results in S3 URI format.
 
         .. seealso::
             - :external+boto3:py:meth:`Athena.Client.get_query_execution`
 
         :param query_execution_id: Id of submitted athena query
         """
-        output_location = None
-        if query_execution_id:
-            response = self.get_conn().get_query_execution(QueryExecutionId=query_execution_id)
+        if not query_execution_id:
+            raise ValueError(f"Invalid Query execution id. Query execution id: {query_execution_id}")
 
-            if response:
-                try:
-                    output_location = response["QueryExecution"]["ResultConfiguration"]["OutputLocation"]
-                except KeyError:
-                    self.log.error(
-                        "Error retrieving OutputLocation. Query execution id: %s", query_execution_id
-                    )
-                    raise
-            else:
-                raise
-        else:
-            raise ValueError("Invalid Query execution id. Query execution id: %s", query_execution_id)
+        if not (response := self.get_query_info(query_execution_id=query_execution_id, use_cache=True)):
+            raise ValueError(f"Unable to get query information for execution id: {query_execution_id}")
 
-        return output_location
+        try:
+            return response["QueryExecution"]["ResultConfiguration"]["OutputLocation"]
+        except KeyError:
+            self.log.error("Error retrieving OutputLocation. Query execution id: %s", query_execution_id)
+            raise
 
     def stop_query(self, query_execution_id: str) -> dict:
         """
-        Cancel the submitted athena query
+        Cancel the submitted query.
 
         .. seealso::
             - :external+boto3:py:meth:`Athena.Client.stop_query_execution`
