@@ -70,7 +70,8 @@ class EcrHook(AwsBaseHook):
         super().__init__(**kwargs)
 
     def get_temporary_credentials(self, registry_ids: list[str] | str | None = None) -> list[EcrCredentials]:
-        """Get temporary credentials for Amazon ECR.
+        """
+        Get temporary credentials for Amazon ECR.
 
         .. seealso::
             - :external+boto3:py:meth:`ECR.Client.get_authorization_token`
