@@ -21,10 +21,10 @@ import time
 from functools import cached_property
 
 from botocore.exceptions import ClientError
+from deprecated import deprecated
 
-from airflow import AirflowException
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.providers.amazon.aws.hooks.base_aws import AwsBaseHook
-from airflow.providers.amazon.aws.hooks.sts import StsHook
 
 
 class QuickSightHook(AwsBaseHook):
@@ -46,10 +46,6 @@ class QuickSightHook(AwsBaseHook):
     def __init__(self, *args, **kwargs):
         super().__init__(client_type="quicksight", *args, **kwargs)
 
-    @cached_property
-    def sts_hook(self):
-        return StsHook(aws_conn_id=self.aws_conn_id)
-
     def create_ingestion(
         self,
         data_set_id: str,
@@ -57,27 +53,28 @@ class QuickSightHook(AwsBaseHook):
         ingestion_type: str,
         wait_for_completion: bool = True,
         check_interval: int = 30,
+        aws_account_id: str | None = None,
     ) -> dict:
         """
-        Creates and starts a new SPICE ingestion for a dataset. Refreshes the SPICE datasets.
+        Create and start a new SPICE ingestion for a dataset; refresh the SPICE datasets.
 
         .. seealso::
             - :external+boto3:py:meth:`QuickSight.Client.create_ingestion`
 
         :param data_set_id:  ID of the dataset used in the ingestion.
         :param ingestion_id: ID for the ingestion.
-        :param ingestion_type: Type of ingestion . "INCREMENTAL_REFRESH"|"FULL_REFRESH"
+        :param ingestion_type: Type of ingestion: "INCREMENTAL_REFRESH"|"FULL_REFRESH"
         :param wait_for_completion: if the program should keep running until job finishes
         :param check_interval: the time interval in seconds which the operator
             will check the status of QuickSight Ingestion
+        :param aws_account_id: An AWS Account ID, if set to ``None`` then use associated AWS Account ID.
         :return: Returns descriptive information about the created data ingestion
             having Ingestion ARN, HTTP status, ingestion ID and ingestion status.
         """
+        aws_account_id = aws_account_id or self.account_id
         self.log.info("Creating QuickSight Ingestion for data set id %s.", data_set_id)
-        quicksight_client = self.get_conn()
         try:
-            aws_account_id = self.sts_hook.get_account_number()
-            create_ingestion_response = quicksight_client.create_ingestion(
+            create_ingestion_response = self.conn.create_ingestion(
                 DataSetId=data_set_id,
                 IngestionId=ingestion_id,
                 IngestionType=ingestion_type,
@@ -97,20 +94,21 @@ class QuickSightHook(AwsBaseHook):
             self.log.error("Failed to run Amazon QuickSight create_ingestion API, error: %s", general_error)
             raise
 
-    def get_status(self, aws_account_id: str, data_set_id: str, ingestion_id: str) -> str:
+    def get_status(self, aws_account_id: str | None, data_set_id: str, ingestion_id: str) -> str:
         """
         Get the current status of QuickSight Create Ingestion API.
 
         .. seealso::
             - :external+boto3:py:meth:`QuickSight.Client.describe_ingestion`
 
-        :param aws_account_id: An AWS Account ID
+        :param aws_account_id: An AWS Account ID, if set to ``None`` then use associated AWS Account ID.
         :param data_set_id: QuickSight Data Set ID
         :param ingestion_id: QuickSight Ingestion ID
         :return: An QuickSight Ingestion Status
         """
+        aws_account_id = aws_account_id or self.account_id
         try:
-            describe_ingestion_response = self.get_conn().describe_ingestion(
+            describe_ingestion_response = self.conn.describe_ingestion(
                 AwsAccountId=aws_account_id, DataSetId=data_set_id, IngestionId=ingestion_id
             )
             return describe_ingestion_response["Ingestion"]["IngestionStatus"]
@@ -119,17 +117,19 @@ class QuickSightHook(AwsBaseHook):
         except ClientError as e:
             raise AirflowException(f"AWS request failed: {e}")
 
-    def get_error_info(self, aws_account_id: str, data_set_id: str, ingestion_id: str) -> dict | None:
+    def get_error_info(self, aws_account_id: str | None, data_set_id: str, ingestion_id: str) -> dict | None:
         """
-        Gets info about the error if any.
+        Get info about the error if any.
 
-        :param aws_account_id: An AWS Account ID
+        :param aws_account_id: An AWS Account ID, if set to ``None`` then use associated AWS Account ID.
         :param data_set_id: QuickSight Data Set ID
         :param ingestion_id: QuickSight Ingestion ID
         :return: Error info dict containing the error type (key 'Type') and message (key 'Message')
             if available. Else, returns None.
         """
-        describe_ingestion_response = self.get_conn().describe_ingestion(
+        aws_account_id = aws_account_id or self.account_id
+
+        describe_ingestion_response = self.conn.describe_ingestion(
             AwsAccountId=aws_account_id, DataSetId=data_set_id, IngestionId=ingestion_id
         )
         # using .get() to get None if the key is not present, instead of an exception.
@@ -137,7 +137,7 @@ class QuickSightHook(AwsBaseHook):
 
     def wait_for_state(
         self,
-        aws_account_id: str,
+        aws_account_id: str | None,
         data_set_id: str,
         ingestion_id: str,
         target_state: set,
@@ -146,7 +146,7 @@ class QuickSightHook(AwsBaseHook):
         """
         Check status of a QuickSight Create Ingestion API.
 
-        :param aws_account_id: An AWS Account ID
+        :param aws_account_id: An AWS Account ID, if set to ``None`` then use associated AWS Account ID.
         :param data_set_id: QuickSight Data Set ID
         :param ingestion_id: QuickSight Ingestion ID
         :param target_state: Describes the QuickSight Job's Target State
@@ -154,6 +154,8 @@ class QuickSightHook(AwsBaseHook):
             will check the status of QuickSight Ingestion
         :return: response of describe_ingestion call after Ingestion is done
         """
+        aws_account_id = aws_account_id or self.account_id
+
         while True:
             status = self.get_status(aws_account_id, data_set_id, ingestion_id)
             self.log.info("Current status is %s", status)
@@ -168,3 +170,17 @@ class QuickSightHook(AwsBaseHook):
 
         self.log.info("QuickSight Ingestion completed")
         return status
+
+    @cached_property
+    @deprecated(
+        reason=(
+            "`QuickSightHook.sts_hook` property is deprecated and will be removed in the future. "
+            "This property used for obtain AWS Account ID, "
+            "please consider to use `QuickSightHook.account_id` instead"
+        ),
+        category=AirflowProviderDeprecationWarning,
+    )
+    def sts_hook(self):
+        from airflow.providers.amazon.aws.hooks.sts import StsHook
+
+        return StsHook(aws_conn_id=self.aws_conn_id)
