@@ -14,7 +14,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""This module contains AWS SES Hook"""
+"""This module contains AWS SES Hook."""
+
 from __future__ import annotations
 
 from typing import Any, Iterable
@@ -27,11 +28,13 @@ class SesHook(AwsBaseHook):
     """
     Interact with Amazon Simple Email Service.
 
+    Provide thin wrapper around :external+boto3:py:class:`boto3.client("ses") <SES.Client>`.
+
     Additional arguments (such as ``aws_conn_id``) may be specified and
     are passed down to the underlying AwsBaseHook.
 
     .. seealso::
-        :class:`~airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
+        - :class:`airflow.providers.amazon.aws.hooks.base_aws.AwsBaseHook`
     """
 
     def __init__(self, *args, **kwargs) -> None:
@@ -54,7 +57,10 @@ class SesHook(AwsBaseHook):
         custom_headers: dict[str, Any] | None = None,
     ) -> dict:
         """
-        Send email using Amazon Simple Email Service
+        Send email using Amazon Simple Email Service.
+
+        .. seealso::
+            - :external+boto3:py:meth:`SES.Client.send_raw_email`
 
         :param mail_from: Email address to set as email's from
         :param to: List of email addresses to set as email's to
