@@ -20,10 +20,11 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, ClassVar
 
 from airflow.models import BaseOperatorLink, XCom
+from airflow.providers.amazon.aws.utils.suppress import return_on_error
 
 if TYPE_CHECKING:
     from airflow.models import BaseOperator
-    from airflow.models.taskinstance import TaskInstanceKey
+    from airflow.models.taskinstancekey import TaskInstanceKey
     from airflow.utils.context import Context
 
 
@@ -31,7 +32,7 @@ BASE_AWS_CONSOLE_LINK = "https://console.{aws_domain}"
 
 
 class BaseAwsLink(BaseOperatorLink):
-    """Base Helper class for constructing AWS Console Link"""
+    """Base Helper class for constructing AWS Console Link."""
 
     name: ClassVar[str]
     key: ClassVar[str]
@@ -50,7 +51,7 @@ class BaseAwsLink(BaseOperatorLink):
 
     def format_link(self, **kwargs) -> str:
         """
-        Format AWS Service Link
+        Format AWS Service Link.
 
         Some AWS Service Link should require additional escaping
         in this case this method should be overridden.
@@ -60,6 +61,7 @@ class BaseAwsLink(BaseOperatorLink):
         except KeyError:
             return ""
 
+    @return_on_error("")
     def get_link(
         self,
         operator: BaseOperator,
@@ -77,10 +79,11 @@ class BaseAwsLink(BaseOperatorLink):
         return self.format_link(**conf) if conf else ""
 
     @classmethod
+    @return_on_error(None)
     def persist(
         cls, context: Context, operator: BaseOperator, region_name: str, aws_partition: str, **kwargs
     ) -> None:
-        """Store link information into XCom"""
+        """Store link information into XCom."""
         if not operator.do_xcom_push:
             return
 
