@@ -16,16 +16,17 @@
 # under the License.
 from __future__ import annotations
 
+import time
+import warnings
 from datetime import datetime, timedelta
-from functools import cached_property
-from time import sleep
 from typing import TYPE_CHECKING, cast
 
-from airflow.exceptions import AirflowException
-from airflow.models import BaseOperator
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.operators.python import ShortCircuitOperator
 from airflow.providers.amazon.aws.hooks.appflow import AppflowHook
+from airflow.providers.amazon.aws.operators.base_aws import AwsBaseOperator
 from airflow.providers.amazon.aws.utils import datetime_to_epoch_ms
+from airflow.providers.amazon.aws.utils.mixins import AwsBaseHookMixin, AwsHookParams, aws_template_fields
 
 if TYPE_CHECKING:
     from mypy_boto3_appflow.type_defs import (
@@ -41,9 +42,9 @@ MANDATORY_FILTER_DATE_MSG = "The filter_date argument is mandatory for {entity}!
 NOT_SUPPORTED_SOURCE_MSG = "Source {source} is not supported for {entity}!"
 
 
-class AppflowBaseOperator(BaseOperator):
+class AppflowBaseOperator(AwsBaseOperator[AppflowHook]):
     """
-    Amazon Appflow Base Operator class (not supposed to be used directly in DAGs).
+    Amazon AppFlow Base Operator class (not supposed to be used directly in DAGs).
 
     :param source: The source name (Supported: salesforce, zendesk)
     :param flow_name: The flow name
@@ -51,56 +52,61 @@ class AppflowBaseOperator(BaseOperator):
     :param source_field: The field name to apply filters
     :param filter_date: The date value (or template) to be used in filters.
     :param poll_interval: how often in seconds to check the query status
-    :param aws_conn_id: aws connection to use
-    :param region: aws region to use
+    :param max_attempts: how many times to check for status before timing out
     :param wait_for_completion: whether to wait for the run to end to return
+    :param aws_conn_id: The Airflow connection used for AWS credentials.
+        If this is ``None`` or empty then the default boto3 behaviour is used. If
+        running Airflow in a distributed manner and aws_conn_id is None or
+        empty, then default boto3 configuration would be used (and must be
+        maintained on each worker node).
+    :param region_name: AWS region_name. If not specified then the default boto3 behaviour is used.
+    :param verify: Whether or not to verify SSL certificates. See:
+        https://boto3.amazonaws.com/v1/documentation/api/latest/reference/core/session.html
+    :param botocore_config: Configuration dictionary (key-values) for botocore client. See:
+        https://botocore.amazonaws.com/v1/documentation/api/latest/reference/config.html
     """
 
+    aws_hook_class = AppflowHook
     ui_color = "#2bccbd"
+    template_fields = aws_template_fields("flow_name", "source", "source_field", "filter_date")
 
     UPDATE_PROPAGATION_TIME: int = 15
 
     def __init__(
         self,
-        source: str,
         flow_name: str,
         flow_update: bool,
+        source: str | None = None,
         source_field: str | None = None,
         filter_date: str | None = None,
         poll_interval: int = 20,
-        aws_conn_id: str = "aws_default",
-        region: str | None = None,
+        max_attempts: int = 60,
         wait_for_completion: bool = True,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
-        if source not in SUPPORTED_SOURCES:
+        if source is not None and source not in SUPPORTED_SOURCES:
             raise ValueError(f"{source} is not a supported source (options: {SUPPORTED_SOURCES})!")
         self.filter_date = filter_date
         self.flow_name = flow_name
         self.source = source
         self.source_field = source_field
         self.poll_interval = poll_interval
-        self.aws_conn_id = aws_conn_id
-        self.region = region
+        self.max_attempts = max_attempts
         self.flow_update = flow_update
         self.wait_for_completion = wait_for_completion
 
-    @cached_property
-    def hook(self) -> AppflowHook:
-        """Create and return an AppflowHook."""
-        return AppflowHook(aws_conn_id=self.aws_conn_id, region_name=self.region)
-
     def execute(self, context: Context) -> None:
         self.filter_date_parsed: datetime | None = (
             datetime.fromisoformat(self.filter_date) if self.filter_date else None
         )
-        self.connector_type = self._get_connector_type()
+        if self.source is not None:
+            self.connector_type = self._get_connector_type()
         if self.flow_update:
             self._update_flow()
             # while schedule flows will pick up the update right away, on-demand flows might use out of date
             # info if triggered right after an update, so we need to wait a bit for the DB to be consistent.
-            sleep(AppflowBaseOperator.UPDATE_PROPAGATION_TIME)
+            time.sleep(AppflowBaseOperator.UPDATE_PROPAGATION_TIME)
 
         self._run_flow(context)
 
@@ -118,6 +124,7 @@ class AppflowBaseOperator(BaseOperator):
         execution_id = self.hook.run_flow(
             flow_name=self.flow_name,
             poll_interval=self.poll_interval,
+            max_attempts=self.max_attempts,
             wait_for_completion=self.wait_for_completion,
         )
         task_instance = context["task_instance"]
@@ -127,41 +134,44 @@ class AppflowBaseOperator(BaseOperator):
 
 class AppflowRunOperator(AppflowBaseOperator):
     """
-    Execute a Appflow run with filters as is.
+    Execute an AppFlow run as is.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:AppflowRunOperator`
 
-    :param source: The source name (Supported: salesforce, zendesk)
+    :param source: Obsolete, unnecessary for this operator
     :param flow_name: The flow name
     :param poll_interval: how often in seconds to check the query status
-    :param aws_conn_id: aws connection to use
+    :param aws_conn_id: The Airflow connection used for AWS credentials.
+        If this is None or empty then the default boto3 behaviour is used. If
+        running Airflow in a distributed manner and aws_conn_id is None or
+        empty, then default boto3 configuration would be used (and must be
+        maintained on each worker node).
     :param region: aws region to use
     :param wait_for_completion: whether to wait for the run to end to return
     """
 
     def __init__(
         self,
-        source: str,
         flow_name: str,
+        source: str | None = None,
         poll_interval: int = 20,
-        aws_conn_id: str = "aws_default",
-        region: str | None = None,
         wait_for_completion: bool = True,
         **kwargs,
     ) -> None:
-        if source not in {"salesforce", "zendesk"}:
-            raise ValueError(NOT_SUPPORTED_SOURCE_MSG.format(source=source, entity="AppflowRunOperator"))
+        if source is not None:
+            warnings.warn(
+                "The `source` parameter is unused when simply running a flow, please remove it.",
+                AirflowProviderDeprecationWarning,
+                stacklevel=2,
+            )
         super().__init__(
-            source=source,
             flow_name=flow_name,
             flow_update=False,
             source_field=None,
             filter_date=None,
             poll_interval=poll_interval,
-            aws_conn_id=aws_conn_id,
-            region=region,
             wait_for_completion=wait_for_completion,
             **kwargs,
         )
@@ -169,7 +179,7 @@ class AppflowRunOperator(AppflowBaseOperator):
 
 class AppflowRunFullOperator(AppflowBaseOperator):
     """
-    Execute a Appflow full run removing any filter.
+    Execute an AppFlow full run removing any filter.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -178,8 +188,6 @@ class AppflowRunFullOperator(AppflowBaseOperator):
     :param source: The source name (Supported: salesforce, zendesk)
     :param flow_name: The flow name
     :param poll_interval: how often in seconds to check the query status
-    :param aws_conn_id: aws connection to use
-    :param region: aws region to use
     :param wait_for_completion: whether to wait for the run to end to return
     """
 
@@ -188,8 +196,6 @@ class AppflowRunFullOperator(AppflowBaseOperator):
         source: str,
         flow_name: str,
         poll_interval: int = 20,
-        aws_conn_id: str = "aws_default",
-        region: str | None = None,
         wait_for_completion: bool = True,
         **kwargs,
     ) -> None:
@@ -202,8 +208,6 @@ class AppflowRunFullOperator(AppflowBaseOperator):
             source_field=None,
             filter_date=None,
             poll_interval=poll_interval,
-            aws_conn_id=aws_conn_id,
-            region=region,
             wait_for_completion=wait_for_completion,
             **kwargs,
         )
@@ -211,7 +215,7 @@ class AppflowRunFullOperator(AppflowBaseOperator):
 
 class AppflowRunBeforeOperator(AppflowBaseOperator):
     """
-    Execute a Appflow run after updating the filters to select only previous data.
+    Execute an AppFlow run after updating the filters to select only previous data.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -222,13 +226,15 @@ class AppflowRunBeforeOperator(AppflowBaseOperator):
     :param source_field: The field name to apply filters
     :param filter_date: The date value (or template) to be used in filters.
     :param poll_interval: how often in seconds to check the query status
-    :param aws_conn_id: aws connection to use
+    :param aws_conn_id: The Airflow connection used for AWS credentials.
+        If this is None or empty then the default boto3 behaviour is used. If
+        running Airflow in a distributed manner and aws_conn_id is None or
+        empty, then default boto3 configuration would be used (and must be
+        maintained on each worker node).
     :param region: aws region to use
     :param wait_for_completion: whether to wait for the run to end to return
     """
 
-    template_fields = ("filter_date",)
-
     def __init__(
         self,
         source: str,
@@ -236,8 +242,6 @@ class AppflowRunBeforeOperator(AppflowBaseOperator):
         source_field: str,
         filter_date: str,
         poll_interval: int = 20,
-        aws_conn_id: str = "aws_default",
-        region: str | None = None,
         wait_for_completion: bool = True,
         **kwargs,
     ) -> None:
@@ -254,8 +258,6 @@ class AppflowRunBeforeOperator(AppflowBaseOperator):
             source_field=source_field,
             filter_date=filter_date,
             poll_interval=poll_interval,
-            aws_conn_id=aws_conn_id,
-            region=region,
             wait_for_completion=wait_for_completion,
             **kwargs,
         )
@@ -281,7 +283,7 @@ class AppflowRunBeforeOperator(AppflowBaseOperator):
 
 class AppflowRunAfterOperator(AppflowBaseOperator):
     """
-    Execute a Appflow run after updating the filters to select only future data.
+    Execute an AppFlow run after updating the filters to select only future data.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -292,13 +294,9 @@ class AppflowRunAfterOperator(AppflowBaseOperator):
     :param source_field: The field name to apply filters
     :param filter_date: The date value (or template) to be used in filters.
     :param poll_interval: how often in seconds to check the query status
-    :param aws_conn_id: aws connection to use
-    :param region: aws region to use
     :param wait_for_completion: whether to wait for the run to end to return
     """
 
-    template_fields = ("filter_date",)
-
     def __init__(
         self,
         source: str,
@@ -306,8 +304,6 @@ class AppflowRunAfterOperator(AppflowBaseOperator):
         source_field: str,
         filter_date: str,
         poll_interval: int = 20,
-        aws_conn_id: str = "aws_default",
-        region: str | None = None,
         wait_for_completion: bool = True,
         **kwargs,
     ) -> None:
@@ -322,8 +318,6 @@ class AppflowRunAfterOperator(AppflowBaseOperator):
             source_field=source_field,
             filter_date=filter_date,
             poll_interval=poll_interval,
-            aws_conn_id=aws_conn_id,
-            region=region,
             wait_for_completion=wait_for_completion,
             **kwargs,
         )
@@ -349,7 +343,7 @@ class AppflowRunAfterOperator(AppflowBaseOperator):
 
 class AppflowRunDailyOperator(AppflowBaseOperator):
     """
-    Execute a Appflow run after updating the filters to select only a single day.
+    Execute an AppFlow run after updating the filters to select only a single day.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -360,13 +354,9 @@ class AppflowRunDailyOperator(AppflowBaseOperator):
     :param source_field: The field name to apply filters
     :param filter_date: The date value (or template) to be used in filters.
     :param poll_interval: how often in seconds to check the query status
-    :param aws_conn_id: aws connection to use
-    :param region: aws region to use
     :param wait_for_completion: whether to wait for the run to end to return
     """
 
-    template_fields = ("filter_date",)
-
     def __init__(
         self,
         source: str,
@@ -374,8 +364,6 @@ class AppflowRunDailyOperator(AppflowBaseOperator):
         source_field: str,
         filter_date: str,
         poll_interval: int = 20,
-        aws_conn_id: str = "aws_default",
-        region: str | None = None,
         wait_for_completion: bool = True,
         **kwargs,
     ) -> None:
@@ -390,8 +378,6 @@ class AppflowRunDailyOperator(AppflowBaseOperator):
             source_field=source_field,
             filter_date=filter_date,
             poll_interval=poll_interval,
-            aws_conn_id=aws_conn_id,
-            region=region,
             wait_for_completion=wait_for_completion,
             **kwargs,
         )
@@ -418,9 +404,9 @@ class AppflowRunDailyOperator(AppflowBaseOperator):
         )
 
 
-class AppflowRecordsShortCircuitOperator(ShortCircuitOperator):
+class AppflowRecordsShortCircuitOperator(ShortCircuitOperator, AwsBaseHookMixin[AppflowHook]):
     """
-    Short-circuit in case of a empty Appflow's run.
+    Short-circuit in case of an empty AppFlow's run.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -429,10 +415,20 @@ class AppflowRecordsShortCircuitOperator(ShortCircuitOperator):
     :param flow_name: The flow name
     :param appflow_run_task_id: Run task ID from where this operator should extract the execution ID
     :param ignore_downstream_trigger_rules: Ignore downstream trigger rules
-    :param aws_conn_id: aws connection to use
-    :param region: aws region to use
+    :param aws_conn_id: The Airflow connection used for AWS credentials.
+        If this is ``None`` or empty then the default boto3 behaviour is used. If
+        running Airflow in a distributed manner and aws_conn_id is None or
+        empty, then default boto3 configuration would be used (and must be
+        maintained on each worker node).
+    :param region_name: AWS region_name. If not specified then the default boto3 behaviour is used.
+    :param verify: Whether or not to verify SSL certificates. See:
+        https://boto3.amazonaws.com/v1/documentation/api/latest/reference/core/session.html
+    :param botocore_config: Configuration dictionary (key-values) for botocore client. See:
+        https://botocore.amazonaws.com/v1/documentation/api/latest/reference/config.html
     """
 
+    aws_hook_class = AppflowHook
+    template_fields = aws_template_fields()
     ui_color = "#33ffec"  # Light blue
 
     def __init__(
@@ -441,10 +437,15 @@ class AppflowRecordsShortCircuitOperator(ShortCircuitOperator):
         flow_name: str,
         appflow_run_task_id: str,
         ignore_downstream_trigger_rules: bool = True,
-        aws_conn_id: str = "aws_default",
-        region: str | None = None,
+        aws_conn_id: str | None = "aws_default",
+        region_name: str | None = None,
+        verify: bool | str | None = None,
+        botocore_config: dict | None = None,
         **kwargs,
     ) -> None:
+        hook_params = AwsHookParams.from_constructor(
+            aws_conn_id, region_name, verify, botocore_config, additional_params=kwargs
+        )
         super().__init__(
             python_callable=self._has_new_records_func,
             op_kwargs={
@@ -454,8 +455,11 @@ class AppflowRecordsShortCircuitOperator(ShortCircuitOperator):
             ignore_downstream_trigger_rules=ignore_downstream_trigger_rules,
             **kwargs,
         )
-        self.aws_conn_id = aws_conn_id
-        self.region = region
+        self.aws_conn_id = hook_params.aws_conn_id
+        self.region_name = hook_params.region_name
+        self.verify = hook_params.verify
+        self.botocore_config = hook_params.botocore_config
+        self.validate_attributes()
 
     @staticmethod
     def _get_target_execution_id(
@@ -466,11 +470,6 @@ class AppflowRecordsShortCircuitOperator(ShortCircuitOperator):
                 return record
         return None
 
-    @cached_property
-    def hook(self) -> AppflowHook:
-        """Create and return an AppflowHook."""
-        return AppflowHook(aws_conn_id=self.aws_conn_id, region_name=self.region)
-
     def _has_new_records_func(self, **kwargs) -> bool:
         appflow_task_id = kwargs["appflow_run_task_id"]
         self.log.info("appflow_task_id: %s", appflow_task_id)
