@@ -15,22 +15,27 @@
 # specific language governing permissions and limitations
 # under the License.
 """Create, get, update, execute and delete an AWS DataSync Task."""
+
 from __future__ import annotations
 
 import logging
 import random
-from typing import TYPE_CHECKING, Sequence
+from typing import TYPE_CHECKING, Any, Sequence
 
-from airflow.exceptions import AirflowException, AirflowTaskTimeout
-from airflow.models import BaseOperator
+from deprecated.classic import deprecated
+
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning, AirflowTaskTimeout
 from airflow.providers.amazon.aws.hooks.datasync import DataSyncHook
+from airflow.providers.amazon.aws.operators.base_aws import AwsBaseOperator
+from airflow.providers.amazon.aws.utils.mixins import aws_template_fields
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
-class DataSyncOperator(BaseOperator):
-    """Find, Create, Update, Execute and Delete AWS DataSync Tasks.
+class DataSyncOperator(AwsBaseOperator[DataSyncHook]):
+    """
+    Find, Create, Update, Execute and Delete AWS DataSync Tasks.
 
     If ``do_xcom_push`` is True, then the DataSync TaskArn and TaskExecutionArn
     which were executed will be pushed to an XCom.
@@ -43,7 +48,6 @@ class DataSyncOperator(BaseOperator):
         environment. The default behavior is to create a new Task if there are 0, or
         execute the Task if there was 1 Task, or fail if there were many Tasks.
 
-    :param aws_conn_id: AWS connection to use.
     :param wait_interval_seconds: Time to wait between two
         consecutive calls to check TaskExecution status.
     :param max_iterations: Maximum number of
@@ -88,6 +92,16 @@ class DataSyncOperator(BaseOperator):
         ``boto3.start_task_execution(TaskArn=task_arn, **task_execution_kwargs)``
     :param  delete_task_after_execution: If True then the TaskArn which was executed
         will be deleted from AWS DataSync on successful completion.
+    :param aws_conn_id: The Airflow connection used for AWS credentials.
+        If this is ``None`` or empty then the default boto3 behaviour is used. If
+        running Airflow in a distributed manner and aws_conn_id is None or
+        empty, then default boto3 configuration would be used (and must be
+        maintained on each worker node).
+    :param region_name: AWS region_name. If not specified then the default boto3 behaviour is used.
+    :param verify: Whether or not to verify SSL certificates. See:
+        https://boto3.amazonaws.com/v1/documentation/api/latest/reference/core/session.html
+    :param botocore_config: Configuration dictionary (key-values) for botocore client. See:
+        https://botocore.amazonaws.com/v1/documentation/api/latest/reference/config.html
     :raises AirflowException: If ``task_arn`` was not specified, or if
         either ``source_location_uri`` or ``destination_location_uri`` were
         not specified.
@@ -97,7 +111,8 @@ class DataSyncOperator(BaseOperator):
     :raises AirflowException: If Task creation, update, execution or delete fails.
     """
 
-    template_fields: Sequence[str] = (
+    aws_hook_class = DataSyncHook
+    template_fields: Sequence[str] = aws_template_fields(
         "task_arn",
         "source_location_uri",
         "destination_location_uri",
@@ -119,7 +134,6 @@ class DataSyncOperator(BaseOperator):
     def __init__(
         self,
         *,
-        aws_conn_id: str = "aws_default",
         wait_interval_seconds: int = 30,
         max_iterations: int = 60,
         wait_for_completion: bool = True,
@@ -139,7 +153,6 @@ class DataSyncOperator(BaseOperator):
         super().__init__(**kwargs)
 
         # Assignments
-        self.aws_conn_id = aws_conn_id
         self.wait_interval_seconds = wait_interval_seconds
         self.max_iterations = max_iterations
         self.wait_for_completion = wait_for_completion
@@ -151,16 +164,12 @@ class DataSyncOperator(BaseOperator):
         self.allow_random_task_choice = allow_random_task_choice
         self.allow_random_location_choice = allow_random_location_choice
 
-        self.create_task_kwargs = create_task_kwargs if create_task_kwargs else {}
-        self.create_source_location_kwargs = {}
-        if create_source_location_kwargs:
-            self.create_source_location_kwargs = create_source_location_kwargs
-        self.create_destination_location_kwargs = {}
-        if create_destination_location_kwargs:
-            self.create_destination_location_kwargs = create_destination_location_kwargs
+        self.create_task_kwargs = create_task_kwargs or {}
+        self.create_source_location_kwargs = create_source_location_kwargs or {}
+        self.create_destination_location_kwargs = create_destination_location_kwargs or {}
 
-        self.update_task_kwargs = update_task_kwargs if update_task_kwargs else {}
-        self.task_execution_kwargs = task_execution_kwargs if task_execution_kwargs else {}
+        self.update_task_kwargs = update_task_kwargs or {}
+        self.task_execution_kwargs = task_execution_kwargs or {}
         self.delete_task_after_execution = delete_task_after_execution
 
         # Validations
@@ -176,8 +185,6 @@ class DataSyncOperator(BaseOperator):
                 f"destination_location_uri={destination_location_uri!r}"
             )
 
-        # Others
-        self.hook: DataSyncHook | None = None
         # Candidates - these are found in AWS as possible things
         # for us to use
         self.candidate_source_location_arns: list[str] | None = None
@@ -188,18 +195,13 @@ class DataSyncOperator(BaseOperator):
         self.destination_location_arn: str | None = None
         self.task_execution_arn: str | None = None
 
+    @property
+    def _hook_parameters(self) -> dict[str, Any]:
+        return {**super()._hook_parameters, "wait_interval_seconds": self.wait_interval_seconds}
+
+    @deprecated(reason="use `hook` property instead.", category=AirflowProviderDeprecationWarning)
     def get_hook(self) -> DataSyncHook:
-        """Create and return DataSyncHook.
-
-        :return DataSyncHook: An DataSyncHook instance.
-        """
-        if self.hook:
-            return self.hook
-
-        self.hook = DataSyncHook(
-            aws_conn_id=self.aws_conn_id,
-            wait_interval_seconds=self.wait_interval_seconds,
-        )
+        """Create and return DataSyncHook."""
         return self.hook
 
     def execute(self, context: Context):
@@ -239,8 +241,6 @@ class DataSyncOperator(BaseOperator):
 
     def _get_tasks_and_locations(self) -> None:
         """Find existing DataSync Task based on source and dest Locations."""
-        hook = self.get_hook()
-
         self.candidate_source_location_arns = self._get_location_arns(self.source_location_uri)
 
         self.candidate_destination_location_arns = self._get_location_arns(self.destination_location_uri)
@@ -254,7 +254,7 @@ class DataSyncOperator(BaseOperator):
             return
 
         self.log.info("Finding DataSync TaskArns that have these LocationArns")
-        self.candidate_task_arns = hook.get_task_arns_for_location_arns(
+        self.candidate_task_arns = self.hook.get_task_arns_for_location_arns(
             self.candidate_source_location_arns,
             self.candidate_destination_location_arns,
         )
@@ -290,12 +290,10 @@ class DataSyncOperator(BaseOperator):
 
     def _create_datasync_task(self) -> None:
         """Create a AWS DataSyncTask."""
-        hook = self.get_hook()
-
         self.source_location_arn = self.choose_location(self.candidate_source_location_arns)
         if not self.source_location_arn and self.source_location_uri and self.create_source_location_kwargs:
             self.log.info("Attempting to create source Location")
-            self.source_location_arn = hook.create_location(
+            self.source_location_arn = self.hook.create_location(
                 self.source_location_uri, **self.create_source_location_kwargs
             )
         if not self.source_location_arn:
@@ -310,7 +308,7 @@ class DataSyncOperator(BaseOperator):
             and self.create_destination_location_kwargs
         ):
             self.log.info("Attempting to create destination Location")
-            self.destination_location_arn = hook.create_location(
+            self.destination_location_arn = self.hook.create_location(
                 self.destination_location_uri, **self.create_destination_location_kwargs
             )
         if not self.destination_location_arn:
@@ -319,7 +317,7 @@ class DataSyncOperator(BaseOperator):
             )
 
         self.log.info("Creating a Task.")
-        self.task_arn = hook.create_task(
+        self.task_arn = self.hook.create_task(
             self.source_location_arn, self.destination_location_arn, **self.create_task_kwargs
         )
         if not self.task_arn:
@@ -331,9 +329,8 @@ class DataSyncOperator(BaseOperator):
         if not self.task_arn:
             return
 
-        hook = self.get_hook()
         self.log.info("Updating TaskArn %s", self.task_arn)
-        hook.update_task(self.task_arn, **self.update_task_kwargs)
+        self.hook.update_task(self.task_arn, **self.update_task_kwargs)
         self.log.info("Updated TaskArn %s", self.task_arn)
 
     def _execute_datasync_task(self) -> None:
@@ -341,11 +338,9 @@ class DataSyncOperator(BaseOperator):
         if not self.task_arn:
             raise AirflowException("Missing TaskArn")
 
-        hook = self.get_hook()
-
         # Create a task execution:
         self.log.info("Starting execution for TaskArn %s", self.task_arn)
-        self.task_execution_arn = hook.start_task_execution(self.task_arn, **self.task_execution_kwargs)
+        self.task_execution_arn = self.hook.start_task_execution(self.task_arn, **self.task_execution_kwargs)
         self.log.info("Started TaskExecutionArn %s", self.task_execution_arn)
 
         if not self.wait_for_completion:
@@ -354,14 +349,18 @@ class DataSyncOperator(BaseOperator):
         # Wait for task execution to complete
         self.log.info("Waiting for TaskExecutionArn %s", self.task_execution_arn)
         try:
-            result = hook.wait_for_task_execution(self.task_execution_arn, max_iterations=self.max_iterations)
+            result = self.hook.wait_for_task_execution(
+                self.task_execution_arn, max_iterations=self.max_iterations
+            )
         except (AirflowTaskTimeout, AirflowException) as e:
             self.log.error("Cancelling TaskExecution after Exception: %s", e)
             self._cancel_datasync_task_execution()
             raise
         self.log.info("Completed TaskExecutionArn %s", self.task_execution_arn)
 
-        task_execution_description = hook.describe_task_execution(task_execution_arn=self.task_execution_arn)
+        task_execution_description = self.hook.describe_task_execution(
+            task_execution_arn=self.task_execution_arn
+        )
         self.log.info("task_execution_description=%s", task_execution_description)
 
         # Log some meaningful statuses
@@ -377,10 +376,9 @@ class DataSyncOperator(BaseOperator):
 
     def _cancel_datasync_task_execution(self):
         """Cancel the submitted DataSync task."""
-        hook = self.get_hook()
         if self.task_execution_arn:
             self.log.info("Cancelling TaskExecutionArn %s", self.task_execution_arn)
-            hook.cancel_task_execution(task_execution_arn=self.task_execution_arn)
+            self.hook.cancel_task_execution(task_execution_arn=self.task_execution_arn)
             self.log.info("Cancelled TaskExecutionArn %s", self.task_execution_arn)
 
     def on_kill(self):
@@ -388,17 +386,16 @@ class DataSyncOperator(BaseOperator):
         self._cancel_datasync_task_execution()
 
     def _delete_datasync_task(self) -> None:
-        """Deletes an AWS DataSync Task."""
+        """Delete an AWS DataSync Task."""
         if not self.task_arn:
             return
 
-        hook = self.get_hook()
         # Delete task:
         self.log.info("Deleting Task with TaskArn %s", self.task_arn)
-        hook.delete_task(self.task_arn)
+        self.hook.delete_task(self.task_arn)
         self.log.info("Task Deleted")
 
     def _get_location_arns(self, location_uri) -> list[str]:
-        location_arns = self.get_hook().get_location_arns(location_uri)
+        location_arns = self.hook.get_location_arns(location_uri)
         self.log.info("Found LocationArns %s for LocationUri %s", location_arns, location_uri)
         return location_arns
