@@ -14,19 +14,21 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""Publish message to SQS queue"""
+"""Publish message to SQS queue."""
+
 from __future__ import annotations
 
 from typing import TYPE_CHECKING, Sequence
 
-from airflow.models import BaseOperator
 from airflow.providers.amazon.aws.hooks.sqs import SqsHook
+from airflow.providers.amazon.aws.operators.base_aws import AwsBaseOperator
+from airflow.providers.amazon.aws.utils.mixins import aws_template_fields
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
-class SqsPublishOperator(BaseOperator):
+class SqsPublishOperator(AwsBaseOperator[SqsHook]):
     """
     Publish a message to an Amazon SQS queue.
 
@@ -41,10 +43,20 @@ class SqsPublishOperator(BaseOperator):
     :param delay_seconds: message delay (templated) (default: 1 second)
     :param message_group_id: This parameter applies only to FIFO (first-in-first-out) queues. (default: None)
         For details of the attributes parameter see :py:meth:`botocore.client.SQS.send_message`
-    :param aws_conn_id: AWS connection id (default: aws_default)
+    :param aws_conn_id: The Airflow connection used for AWS credentials.
+        If this is ``None`` or empty then the default boto3 behaviour is used. If
+        running Airflow in a distributed manner and aws_conn_id is None or
+        empty, then default boto3 configuration would be used (and must be
+        maintained on each worker node).
+    :param region_name: AWS region_name. If not specified then the default boto3 behaviour is used.
+    :param verify: Whether or not to verify SSL certificates. See:
+        https://boto3.amazonaws.com/v1/documentation/api/latest/reference/core/session.html
+    :param botocore_config: Configuration dictionary (key-values) for botocore client. See:
+        https://botocore.amazonaws.com/v1/documentation/api/latest/reference/config.html
     """
 
-    template_fields: Sequence[str] = (
+    aws_hook_class = SqsHook
+    template_fields: Sequence[str] = aws_template_fields(
         "sqs_queue",
         "message_content",
         "delay_seconds",
@@ -62,12 +74,10 @@ class SqsPublishOperator(BaseOperator):
         message_attributes: dict | None = None,
         delay_seconds: int = 0,
         message_group_id: str | None = None,
-        aws_conn_id: str = "aws_default",
         **kwargs,
     ):
         super().__init__(**kwargs)
         self.sqs_queue = sqs_queue
-        self.aws_conn_id = aws_conn_id
         self.message_content = message_content
         self.delay_seconds = delay_seconds
         self.message_attributes = message_attributes or {}
@@ -75,15 +85,13 @@ class SqsPublishOperator(BaseOperator):
 
     def execute(self, context: Context) -> dict:
         """
-        Publish the message to the Amazon SQS queue
+        Publish the message to the Amazon SQS queue.
 
         :param context: the context object
         :return: dict with information about the message sent
             For details of the returned dict see :py:meth:`botocore.client.SQS.send_message`
         """
-        hook = SqsHook(aws_conn_id=self.aws_conn_id)
-
-        result = hook.send_message(
+        result = self.hook.send_message(
             queue_url=self.sqs_queue,
             message_body=self.message_content,
             delay_seconds=self.delay_seconds,
