@@ -17,19 +17,20 @@
 # under the License.
 from __future__ import annotations
 
+from functools import cached_property
 from typing import TYPE_CHECKING, Sequence
 
-from airflow.compat.functools import cached_property
-from airflow.exceptions import AirflowException
+from deprecated import deprecated
+
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning, AirflowSkipException
 from airflow.providers.amazon.aws.hooks.quicksight import QuickSightHook
-from airflow.providers.amazon.aws.hooks.sts import StsHook
-from airflow.sensors.base import BaseSensorOperator
+from airflow.providers.amazon.aws.sensors.base_aws import AwsBaseSensor
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
-class QuickSightSensor(BaseSensorOperator):
+class QuickSightSensor(AwsBaseSensor[QuickSightHook]):
     """
     Watches for the status of an Amazon QuickSight Ingestion.
 
@@ -39,27 +40,25 @@ class QuickSightSensor(BaseSensorOperator):
 
     :param data_set_id:  ID of the dataset used in the ingestion.
     :param ingestion_id: ID for the ingestion.
-    :param aws_conn_id: The Airflow connection used for AWS credentials. (templated)
-         If this is None or empty then the default boto3 behaviour is used. If
-         running Airflow in a distributed manner and aws_conn_id is None or
-         empty, then the default boto3 configuration would be used (and must be
-         maintained on each worker node).
+    :param aws_conn_id: The Airflow connection used for AWS credentials.
+        If this is ``None`` or empty then the default boto3 behaviour is used. If
+        running Airflow in a distributed manner and aws_conn_id is None or
+        empty, then default boto3 configuration would be used (and must be
+        maintained on each worker node).
+    :param region_name: AWS region_name. If not specified then the default boto3 behaviour is used.
+    :param verify: Whether or not to verify SSL certificates. See:
+        https://boto3.amazonaws.com/v1/documentation/api/latest/reference/core/session.html
+    :param botocore_config: Configuration dictionary (key-values) for botocore client. See:
+        https://botocore.amazonaws.com/v1/documentation/api/latest/reference/config.html
     """
 
+    aws_hook_class = QuickSightHook
     template_fields: Sequence[str] = ("data_set_id", "ingestion_id", "aws_conn_id")
 
-    def __init__(
-        self,
-        *,
-        data_set_id: str,
-        ingestion_id: str,
-        aws_conn_id: str = "aws_default",
-        **kwargs,
-    ) -> None:
+    def __init__(self, *, data_set_id: str, ingestion_id: str, **kwargs):
         super().__init__(**kwargs)
         self.data_set_id = data_set_id
         self.ingestion_id = ingestion_id
-        self.aws_conn_id = aws_conn_id
         self.success_status = "COMPLETED"
         self.errored_statuses = ("FAILED", "CANCELLED")
 
@@ -71,20 +70,37 @@ class QuickSightSensor(BaseSensorOperator):
         :return: True if it COMPLETED and False if not.
         """
         self.log.info("Poking for Amazon QuickSight Ingestion ID: %s", self.ingestion_id)
-        aws_account_id = self.sts_hook.get_account_number()
-        quicksight_ingestion_state = self.quicksight_hook.get_status(
-            aws_account_id, self.data_set_id, self.ingestion_id
-        )
+        quicksight_ingestion_state = self.hook.get_status(None, self.data_set_id, self.ingestion_id)
         self.log.info("QuickSight Status: %s", quicksight_ingestion_state)
         if quicksight_ingestion_state in self.errored_statuses:
-            error = self.quicksight_hook.get_error_info(aws_account_id, self.data_set_id, self.ingestion_id)
-            raise AirflowException(f"The QuickSight Ingestion failed. Error info: {error}")
+            error = self.hook.get_error_info(None, self.data_set_id, self.ingestion_id)
+            message = f"The QuickSight Ingestion failed. Error info: {error}"
+            if self.soft_fail:
+                raise AirflowSkipException(message)
+            raise AirflowException(message)
         return quicksight_ingestion_state == self.success_status
 
     @cached_property
+    @deprecated(
+        reason=(
+            "`QuickSightSensor.quicksight_hook` property is deprecated, "
+            "please use `QuickSightSensor.hook` property instead."
+        ),
+        category=AirflowProviderDeprecationWarning,
+    )
     def quicksight_hook(self):
-        return QuickSightHook(aws_conn_id=self.aws_conn_id)
+        return self.hook
 
     @cached_property
+    @deprecated(
+        reason=(
+            "`QuickSightSensor.sts_hook` property is deprecated and will be removed in the future. "
+            "This property used for obtain AWS Account ID, "
+            "please consider to use `QuickSightSensor.hook.account_id` instead"
+        ),
+        category=AirflowProviderDeprecationWarning,
+    )
     def sts_hook(self):
+        from airflow.providers.amazon.aws.hooks.sts import StsHook
+
         return StsHook(aws_conn_id=self.aws_conn_id)
