@@ -22,7 +22,7 @@ from typing import TYPE_CHECKING, Sequence
 
 from deprecated import deprecated
 
-from airflow.exceptions import AirflowException
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning, AirflowSkipException
 from airflow.providers.amazon.aws.hooks.sagemaker import LogState, SageMakerHook
 from airflow.sensors.base import BaseSensorOperator
 
@@ -40,12 +40,12 @@ class SageMakerBaseSensor(BaseSensorOperator):
 
     ui_color = "#ededed"
 
-    def __init__(self, *, aws_conn_id: str = "aws_default", resource_type: str = "job", **kwargs):
+    def __init__(self, *, aws_conn_id: str | None = "aws_default", resource_type: str = "job", **kwargs):
         super().__init__(**kwargs)
         self.aws_conn_id = aws_conn_id
         self.resource_type = resource_type  # only used for logs, to say what kind of resource we are sensing
 
-    @deprecated(reason="use `hook` property instead.")
+    @deprecated(reason="use `hook` property instead.", category=AirflowProviderDeprecationWarning)
     def get_hook(self) -> SageMakerHook:
         """Get SageMakerHook."""
         return self.hook
@@ -65,29 +65,31 @@ class SageMakerBaseSensor(BaseSensorOperator):
             return False
         if state in self.failed_states():
             failed_reason = self.get_failed_reason_from_response(response)
-            raise AirflowException(
-                f"Sagemaker {self.resource_type} failed for the following reason: {failed_reason}"
-            )
+            # TODO: remove this if block when min_airflow_version is set to higher than 2.7.1
+            message = f"Sagemaker {self.resource_type} failed for the following reason: {failed_reason}"
+            if self.soft_fail:
+                raise AirflowSkipException(message)
+            raise AirflowException(message)
         return True
 
     def non_terminal_states(self) -> set[str]:
-        """Placeholder for returning states with should not terminate."""
+        """Return states with should not terminate."""
         raise NotImplementedError("Please implement non_terminal_states() in subclass")
 
     def failed_states(self) -> set[str]:
-        """Placeholder for returning states with are considered failed."""
+        """Return states with are considered failed."""
         raise NotImplementedError("Please implement failed_states() in subclass")
 
     def get_sagemaker_response(self) -> dict:
-        """Placeholder for checking status of a SageMaker task."""
+        """Check status of a SageMaker task."""
         raise NotImplementedError("Please implement get_sagemaker_response() in subclass")
 
     def get_failed_reason_from_response(self, response: dict) -> str:
-        """Placeholder for extracting the reason for failure from an AWS response."""
+        """Extract the reason for failure from an AWS response."""
         return "Unknown"
 
     def state_from_response(self, response: dict) -> str:
-        """Placeholder for extracting the state from an AWS response."""
+        """Extract the state from an AWS response."""
         raise NotImplementedError("Please implement state_from_response() in subclass")
 
 
