@@ -30,7 +30,7 @@ if TYPE_CHECKING:
 
 class GlacierToGCSOperator(BaseOperator):
     """
-    Transfers data from Amazon Glacier to Google Cloud Storage
+    Transfers data from Amazon Glacier to Google Cloud Storage.
 
     .. note::
         Please be warn that GlacierToGCSOperator may depends on memory usage.
@@ -47,10 +47,7 @@ class GlacierToGCSOperator(BaseOperator):
     :param object_name: the name of the object to check in the Google cloud
         storage bucket.
     :param gzip: option to compress local file or file data for upload
-    :param chunk_size: size of chunk in bytes the that will downloaded from Glacier vault
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
+    :param chunk_size: size of chunk in bytes the that will be downloaded from Glacier vault
     :param google_impersonation_chain: Optional Google service account to impersonate using
         short-term credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -66,14 +63,13 @@ class GlacierToGCSOperator(BaseOperator):
     def __init__(
         self,
         *,
-        aws_conn_id: str = "aws_default",
+        aws_conn_id: str | None = "aws_default",
         gcp_conn_id: str = "google_cloud_default",
         vault_name: str,
         bucket_name: str,
         object_name: str,
         gzip: bool,
         chunk_size: int = 1024,
-        delegate_to: str | None = None,
         google_impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -85,14 +81,12 @@ class GlacierToGCSOperator(BaseOperator):
         self.object_name = object_name
         self.gzip = gzip
         self.chunk_size = chunk_size
-        self.delegate_to = delegate_to
         self.impersonation_chain = google_impersonation_chain
 
     def execute(self, context: Context) -> str:
         glacier_hook = GlacierHook(aws_conn_id=self.aws_conn_id)
         gcs_hook = GCSHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
         job_id = glacier_hook.retrieve_inventory(vault_name=self.vault_name)
@@ -104,7 +98,7 @@ class GlacierToGCSOperator(BaseOperator):
             # Read the file content in chunks using StreamingBody
             # https://botocore.amazonaws.com/v1/documentation/api/latest/reference/response.html
             stream = glacier_data["body"]
-            for chunk in stream.iter_chunk(chunk_size=self.chunk_size):
+            for chunk in stream.iter_chunks(chunk_size=self.chunk_size):
                 temp_file.write(chunk)
             temp_file.flush()
             gcs_hook.upload(
