@@ -16,6 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains operator to move data from Hive to DynamoDB."""
+
 from __future__ import annotations
 
 import json
@@ -31,9 +32,10 @@ if TYPE_CHECKING:
 
 class HiveToDynamoDBOperator(BaseOperator):
     """
-    Moves data from Hive to DynamoDB, note that for now the data is loaded
-    into memory before being pushed to DynamoDB, so this operator should
-    be used for smallish amount of data.
+    Moves data from Hive to DynamoDB.
+
+    Note that for now the data is loaded into memory before being pushed
+    to DynamoDB, so this operator should be used for smallish amount of data.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -69,7 +71,7 @@ class HiveToDynamoDBOperator(BaseOperator):
         region_name: str | None = None,
         schema: str = "default",
         hiveserver2_conn_id: str = "hiveserver2_default",
-        aws_conn_id: str = "aws_default",
+        aws_conn_id: str | None = "aws_default",
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
