@@ -21,7 +21,7 @@ from typing import TYPE_CHECKING, Sequence
 
 from kubernetes import client
 
-from airflow.exceptions import AirflowException
+from airflow.exceptions import AirflowException, AirflowSkipException
 from airflow.providers.cncf.kubernetes.hooks.kubernetes import KubernetesHook
 from airflow.sensors.base import BaseSensorOperator
 
@@ -91,24 +91,23 @@ class FlinkKubernetesSensor(BaseSensorOperator):
         )
 
         namespace = response["metadata"]["namespace"]
-        if len(all_pods.items) > 0:
-            for task_manager in all_pods.items:
-                task_manager_pod_name = task_manager.metadata.name
+        for task_manager in all_pods.items:
+            task_manager_pod_name = task_manager.metadata.name
 
-                self.log.info("Starting logging of task manager pod %s ", task_manager_pod_name)
-                try:
-                    log = ""
-                    for line in self.hook.get_pod_logs(task_manager_pod_name, namespace=namespace):
-                        log += line.decode()
-                    log_method(log)
-                except client.rest.ApiException as e:
-                    self.log.warning(
-                        "Could not read logs for pod %s. It may have been disposed.\n"
-                        "Make sure timeToLiveSeconds is set on your flinkDeployment spec.\n"
-                        "underlying exception: %s",
-                        task_manager_pod_name,
-                        e,
-                    )
+            self.log.info("Starting logging of task manager pod %s ", task_manager_pod_name)
+            try:
+                log = ""
+                for line in self.hook.get_pod_logs(task_manager_pod_name, namespace=namespace):
+                    log += line.decode()
+                log_method(log)
+            except client.rest.ApiException as e:
+                self.log.warning(
+                    "Could not read logs for pod %s. It may have been disposed.\n"
+                    "Make sure timeToLiveSeconds is set on your flinkDeployment spec.\n"
+                    "underlying exception: %s",
+                    task_manager_pod_name,
+                    e,
+                )
 
     def poke(self, context: Context) -> bool:
         self.log.info("Poking: %s", self.application_name)
@@ -126,7 +125,11 @@ class FlinkKubernetesSensor(BaseSensorOperator):
         if self.attach_log and application_state in self.FAILURE_STATES + self.SUCCESS_STATES:
             self._log_driver(application_state, response)
         if application_state in self.FAILURE_STATES:
-            raise AirflowException(f"Flink application failed with state: {application_state}")
+            # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
+            message = f"Flink application failed with state: {application_state}"
+            if self.soft_fail:
+                raise AirflowSkipException(message)
+            raise AirflowException(message)
         elif application_state in self.SUCCESS_STATES:
             self.log.info("Flink application ended successfully")
             return True
