@@ -15,6 +15,8 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
+from __future__ import annotations
+
 from typing import TYPE_CHECKING, Any, Sequence
 
 from airflow.sensors.base import BaseSensorOperator
@@ -24,18 +26,18 @@ if TYPE_CHECKING:
 
 
 class WebHdfsSensor(BaseSensorOperator):
-    """Waits for a file or folder to land in HDFS"""
+    """Waits for a file or folder to land in HDFS."""
 
-    template_fields: Sequence[str] = ('filepath',)
+    template_fields: Sequence[str] = ("filepath",)
 
-    def __init__(self, *, filepath: str, webhdfs_conn_id: str = 'webhdfs_default', **kwargs: Any) -> None:
+    def __init__(self, *, filepath: str, webhdfs_conn_id: str = "webhdfs_default", **kwargs: Any) -> None:
         super().__init__(**kwargs)
         self.filepath = filepath
         self.webhdfs_conn_id = webhdfs_conn_id
 
-    def poke(self, context: "Context") -> bool:
+    def poke(self, context: Context) -> bool:
         from airflow.providers.apache.hdfs.hooks.webhdfs import WebHDFSHook
 
         hook = WebHDFSHook(self.webhdfs_conn_id)
-        self.log.info('Poking for file %s', self.filepath)
+        self.log.info("Poking for file %s", self.filepath)
         return hook.check_for_path(hdfs_path=self.filepath)
