@@ -16,6 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains an operator to move data from MSSQL to Hive."""
+
 from __future__ import annotations
 
 import csv
@@ -100,7 +101,7 @@ class MsSqlToHiveOperator(BaseOperator):
 
     @classmethod
     def type_map(cls, mssql_type: int) -> str:
-        """Maps MsSQL type to Hive type."""
+        """Map MsSQL type to Hive type."""
         map_dict = {
             pymssql.BINARY.value: "INT",
             pymssql.DECIMAL.value: "FLOAT",
