@@ -19,7 +19,7 @@ from __future__ import annotations
 from typing import Any, Sequence
 
 from confluent_kafka import KafkaException
-from confluent_kafka.admin import AdminClient, NewTopic
+from confluent_kafka.admin import NewTopic
 
 from airflow.providers.apache.kafka.hooks.base import KafkaBaseHook
 
@@ -34,14 +34,12 @@ class KafkaAdminClientHook(KafkaBaseHook):
     def __init__(self, kafka_config_id=KafkaBaseHook.default_conn_name) -> None:
         super().__init__(kafka_config_id=kafka_config_id)
 
-    def _get_client(self, config) -> AdminClient:
-        return AdminClient(config)
-
     def create_topic(
         self,
         topics: Sequence[Sequence[Any]],
     ) -> None:
-        """Create a topic.
+        """
+        Create a topic.
 
         :param topics: a list of topics to create including the number of partitions for the topic
           and the replication factor. Format: [ ("topic_name", number of partitions, replication factor)]
@@ -61,3 +59,19 @@ class KafkaAdminClientHook(KafkaBaseHook):
                     self.log.warning("The topic %s already exists.", t)
                 else:
                     raise
+
+    def delete_topic(
+        self,
+        topics: Sequence[str],
+    ) -> None:
+        """
+        Delete a topic.
+
+        :param topics: a list of topics to delete.
+        """
+        admin_client = self.get_conn
+        futures = admin_client.delete_topics(topics)
+
+        for t, f in futures.items():
+            f.result()
+            self.log.info("The topic %s has been deleted.", t)
