@@ -15,13 +15,14 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains the Apache Livy hook."""
+
 from __future__ import annotations
 
 import asyncio
 import json
 import re
 from enum import Enum
-from typing import Any, Sequence
+from typing import TYPE_CHECKING, Any, Sequence
 
 import aiohttp
 import requests
@@ -29,10 +30,12 @@ from aiohttp import ClientResponseError
 from asgiref.sync import sync_to_async
 
 from airflow.exceptions import AirflowException
-from airflow.models import Connection
 from airflow.providers.http.hooks.http import HttpAsyncHook, HttpHook
 from airflow.utils.log.logging_mixin import LoggingMixin
 
+if TYPE_CHECKING:
+    from airflow.models import Connection
+
 
 class BatchState(Enum):
     """Batch session states."""
@@ -92,7 +95,7 @@ class LivyHook(HttpHook, LoggingMixin):
 
     def get_conn(self, headers: dict[str, Any] | None = None) -> Any:
         """
-        Returns http session for use with requests.
+        Return http session for use with requests.
 
         :param headers: additional headers to be passed through as a dictionary
         :return: requests session
@@ -111,7 +114,7 @@ class LivyHook(HttpHook, LoggingMixin):
         retry_args: dict[str, Any] | None = None,
     ) -> Any:
         """
-        Wrapper for HttpHook, allows to change method on the same HttpHook.
+        Wrap HttpHook; allows to change method on the same HttpHook.
 
         :param method: http method
         :param endpoint: endpoint
@@ -254,7 +257,7 @@ class LivyHook(HttpHook, LoggingMixin):
 
     def get_batch_logs(self, session_id: int | str, log_start_position, log_batch_size) -> dict:
         """
-        Gets the session logs for a specified batch.
+        Get the session logs for a specified batch.
 
         :param session_id: identifier of the batch sessions
         :param log_start_position: Position from where to pull the logs
@@ -279,7 +282,7 @@ class LivyHook(HttpHook, LoggingMixin):
 
     def dump_batch_logs(self, session_id: int | str) -> None:
         """
-        Dumps the session logs for a specified batch.
+        Dump the session logs for a specified batch.
 
         :param session_id: identifier of the batch sessions
         :return: response body
@@ -417,7 +420,7 @@ class LivyHook(HttpHook, LoggingMixin):
         :param size: size value
         :return: true if valid format
         """
-        if size and not (isinstance(size, str) and re.match(r"^\d+[kmgt]b?$", size, re.IGNORECASE)):
+        if size and not (isinstance(size, str) and re.fullmatch(r"\d+[kmgt]b?", size, re.IGNORECASE)):
             raise ValueError(f"Invalid java size format for string'{size}'")
         return True
 
@@ -432,7 +435,7 @@ class LivyHook(HttpHook, LoggingMixin):
         if (
             vals is None
             or not isinstance(vals, (tuple, list))
-            or any(1 for val in vals if not isinstance(val, (str, int, float)))
+            or not all(isinstance(val, (str, int, float)) for val in vals)
         ):
             raise ValueError("List of strings expected")
         return True
@@ -448,7 +451,7 @@ class LivyHook(HttpHook, LoggingMixin):
         if conf:
             if not isinstance(conf, dict):
                 raise ValueError("'conf' argument must be a dict")
-            if any(True for k, v in conf.items() if not (v and isinstance(v, str) or isinstance(v, int))):
+            if not all(isinstance(v, (str, int)) and v != "" for v in conf.values()):
                 raise ValueError("'conf' values must be either strings or ints")
         return True
 
@@ -498,7 +501,7 @@ class LivyAsyncHook(HttpAsyncHook, LoggingMixin):
         extra_options: dict[str, Any] | None = None,
     ) -> Any:
         """
-        Performs an asynchronous HTTP request call.
+        Perform an asynchronous HTTP request call.
 
         :param endpoint: the endpoint to be called i.e. resource/v1/query?
         :param data: payload to be uploaded or request parameters
@@ -542,8 +545,7 @@ class LivyAsyncHook(HttpAsyncHook, LoggingMixin):
             else:
                 return {"Response": f"Unexpected HTTP Method: {self.method}", "status": "error"}
 
-            attempt_num = 1
-            while True:
+            for attempt_num in range(1, 1 + self.retry_limit):
                 response = await request_func(
                     url,
                     json=data if self.method in ("POST", "PATCH") else None,
@@ -568,7 +570,6 @@ class LivyAsyncHook(HttpAsyncHook, LoggingMixin):
                         # Don't retry.
                         return {"Response": {e.message}, "Status Code": {e.status}, "status": "error"}
 
-                attempt_num += 1
                 await asyncio.sleep(self.retry_delay)
 
     def _generate_base_url(self, conn: Connection) -> str:
@@ -591,7 +592,7 @@ class LivyAsyncHook(HttpAsyncHook, LoggingMixin):
         headers: dict[str, Any] | None = None,
     ) -> Any:
         """
-        Wrapper for HttpAsyncHook, allows to change method on the same HttpAsyncHook.
+        Wrap HttpAsyncHook; allows to change method on the same HttpAsyncHook.
 
         :param method: http method
         :param endpoint: endpoint
@@ -645,7 +646,7 @@ class LivyAsyncHook(HttpAsyncHook, LoggingMixin):
         self, session_id: int | str, log_start_position: int, log_batch_size: int
     ) -> Any:
         """
-        Gets the session logs for a specified batch asynchronously.
+        Get the session logs for a specified batch asynchronously.
 
         :param session_id: identifier of the batch sessions
         :param log_start_position: Position from where to pull the logs
@@ -662,7 +663,7 @@ class LivyAsyncHook(HttpAsyncHook, LoggingMixin):
 
     async def dump_batch_logs(self, session_id: int | str) -> Any:
         """
-        Dumps the session logs for a specified batch asynchronously.
+        Dump the session logs for a specified batch asynchronously.
 
         :param session_id: identifier of the batch sessions
         :return: response body
@@ -800,7 +801,7 @@ class LivyAsyncHook(HttpAsyncHook, LoggingMixin):
         :param size: size value
         :return: true if valid format
         """
-        if size and not (isinstance(size, str) and re.match(r"^\d+[kmgt]b?$", size, re.IGNORECASE)):
+        if size and not (isinstance(size, str) and re.fullmatch(r"\d+[kmgt]b?", size, re.IGNORECASE)):
             raise ValueError(f"Invalid java size format for string'{size}'")
         return True
 
@@ -815,7 +816,7 @@ class LivyAsyncHook(HttpAsyncHook, LoggingMixin):
         if (
             vals is None
             or not isinstance(vals, (tuple, list))
-            or any(1 for val in vals if not isinstance(val, (str, int, float)))
+            or not all(isinstance(val, (str, int, float)) for val in vals)
         ):
             raise ValueError("List of strings expected")
         return True
@@ -831,6 +832,6 @@ class LivyAsyncHook(HttpAsyncHook, LoggingMixin):
         if conf:
             if not isinstance(conf, dict):
                 raise ValueError("'conf' argument must be a dict")
-            if any(True for k, v in conf.items() if not (v and isinstance(v, str) or isinstance(v, int))):
+            if not all(isinstance(v, (str, int)) and v != "" for v in conf.values()):
                 raise ValueError("'conf' values must be either strings or ints")
         return True
