@@ -19,6 +19,9 @@ from __future__ import annotations
 
 from typing import TYPE_CHECKING, Any, Sequence
 
+from deprecated import deprecated
+
+from airflow.exceptions import AirflowProviderDeprecationWarning
 from airflow.models import BaseOperator
 from airflow.providers.apache.spark.hooks.spark_sql import SparkSqlHook
 
@@ -28,7 +31,7 @@ if TYPE_CHECKING:
 
 class SparkSqlOperator(BaseOperator):
     """
-    Execute Spark SQL query
+    Execute Spark SQL query.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -52,9 +55,9 @@ class SparkSqlOperator(BaseOperator):
         (Default: The ``queue`` value set in the Connection, or ``"default"``)
     """
 
-    template_fields: Sequence[str] = ("_sql",)
+    template_fields: Sequence[str] = ("sql",)
     template_ext: Sequence[str] = (".sql", ".hql")
-    template_fields_renderers = {"_sql": "sql"}
+    template_fields_renderers = {"sql": "sql"}
 
     def __init__(
         self,
@@ -75,7 +78,7 @@ class SparkSqlOperator(BaseOperator):
         **kwargs: Any,
     ) -> None:
         super().__init__(**kwargs)
-        self._sql = sql
+        self.sql = sql
         self._conf = conf
         self._conn_id = conn_id
         self._total_executor_cores = total_executor_cores
@@ -90,8 +93,17 @@ class SparkSqlOperator(BaseOperator):
         self._yarn_queue = yarn_queue
         self._hook: SparkSqlHook | None = None
 
+    @property
+    @deprecated(
+        reason="`_sql` is deprecated and will be removed in the future. Please use `sql` instead.",
+        category=AirflowProviderDeprecationWarning,
+    )
+    def _sql(self):
+        """Alias for ``sql``, used for compatibility (deprecated)."""
+        return self.sql
+
     def execute(self, context: Context) -> None:
-        """Call the SparkSqlHook to run the provided sql query"""
+        """Call the SparkSqlHook to run the provided sql query."""
         if self._hook is None:
             self._hook = self._get_hook()
         self._hook.run_query()
@@ -102,7 +114,7 @@ class SparkSqlOperator(BaseOperator):
         self._hook.kill()
 
     def _get_hook(self) -> SparkSqlHook:
-        """Get SparkSqlHook"""
+        """Get SparkSqlHook."""
         return SparkSqlHook(
             sql=self._sql,
             conf=self._conf,
