@@ -16,9 +16,10 @@
 # specific language governing permissions and limitations
 # under the License.
 """Connect to Asana."""
+
 from __future__ import annotations
 
-from functools import cached_property, wraps
+from functools import cached_property
 from typing import Any
 
 from asana import Client  # type: ignore[attr-defined]
@@ -27,31 +28,6 @@ from asana.error import NotFoundError  # type: ignore[attr-defined]
 from airflow.hooks.base import BaseHook
 
 
-def _ensure_prefixes(conn_type):
-    """Remove when provider min airflow version >= 2.5.0 since this is now handled by provider manager."""
-
-    def dec(func):
-        @wraps(func)
-        def inner():
-            field_behaviors = func()
-            conn_attrs = {"host", "schema", "login", "password", "port", "extra"}
-
-            def _ensure_prefix(field):
-                if field not in conn_attrs and not field.startswith("extra__"):
-                    return f"extra__{conn_type}__{field}"
-                else:
-                    return field
-
-            if "placeholders" in field_behaviors:
-                placeholders = field_behaviors["placeholders"]
-                field_behaviors["placeholders"] = {_ensure_prefix(k): v for k, v in placeholders.items()}
-            return field_behaviors
-
-        return inner
-
-    return dec
-
-
 class AsanaHook(BaseHook):
     """Wrapper around Asana Python client library."""
 
@@ -83,9 +59,9 @@ class AsanaHook(BaseHook):
     def get_conn(self) -> Client:
         return self.client
 
-    @staticmethod
-    def get_connection_form_widgets() -> dict[str, Any]:
-        """Returns connection widgets to add to connection form."""
+    @classmethod
+    def get_connection_form_widgets(cls) -> dict[str, Any]:
+        """Return connection widgets to add to connection form."""
         from flask_appbuilder.fieldwidgets import BS3TextFieldWidget
         from flask_babel import lazy_gettext
         from wtforms import StringField
@@ -95,10 +71,9 @@ class AsanaHook(BaseHook):
             "project": StringField(lazy_gettext("Project"), widget=BS3TextFieldWidget()),
         }
 
-    @staticmethod
-    @_ensure_prefixes(conn_type="asana")
-    def get_ui_field_behaviour() -> dict[str, Any]:
-        """Returns custom field behaviour."""
+    @classmethod
+    def get_ui_field_behaviour(cls) -> dict[str, Any]:
+        """Return custom field behaviour."""
         return {
             "hidden_fields": ["port", "host", "login", "schema"],
             "relabeling": {},
@@ -111,7 +86,7 @@ class AsanaHook(BaseHook):
 
     @cached_property
     def client(self) -> Client:
-        """Instantiates python-asana Client."""
+        """Instantiate python-asana Client."""
         if not self.connection.password:
             raise ValueError(
                 "Asana connection password must contain a personal access token: "
@@ -122,7 +97,7 @@ class AsanaHook(BaseHook):
 
     def create_task(self, task_name: str, params: dict | None) -> dict:
         """
-        Creates an Asana task.
+        Create an Asana task.
 
         :param task_name: Name of the new task
         :param params: Other task attributes, such as due_on, parent, and notes. For a complete list
@@ -168,7 +143,7 @@ class AsanaHook(BaseHook):
 
     def delete_task(self, task_id: str) -> dict:
         """
-        Deletes an Asana task.
+        Delete an Asana task.
 
         :param task_id: Asana GID of the task to delete
         :return: A dict containing the response from Asana
@@ -182,7 +157,7 @@ class AsanaHook(BaseHook):
 
     def find_task(self, params: dict | None) -> list:
         """
-        Retrieves a list of Asana tasks that match search parameters.
+        Retrieve a list of Asana tasks that match search parameters.
 
         :param params: Attributes that matching tasks should have. For a list of possible parameters,
             see https://developers.asana.com/docs/get-multiple-tasks
@@ -231,7 +206,7 @@ class AsanaHook(BaseHook):
 
     def update_task(self, task_id: str, params: dict) -> dict:
         """
-        Updates an existing Asana task.
+        Update an existing Asana task.
 
         :param task_id: Asana GID of task to update
         :param params: New values of the task's attributes. For a list of possible parameters, see
@@ -243,7 +218,7 @@ class AsanaHook(BaseHook):
 
     def create_project(self, params: dict) -> dict:
         """
-        Creates a new project.
+        Create a new project.
 
         :param params: Attributes that the new project should have. See
             https://developers.asana.com/docs/create-a-project#create-a-project-parameters
@@ -283,7 +258,7 @@ class AsanaHook(BaseHook):
 
     def find_project(self, params: dict) -> list:
         """
-        Retrieves a list of Asana projects that match search parameters.
+        Retrieve a list of Asana projects that match search parameters.
 
         :param params: Attributes which matching projects should have. See
             https://developers.asana.com/docs/get-multiple-projects
@@ -296,7 +271,7 @@ class AsanaHook(BaseHook):
 
     def update_project(self, project_id: str, params: dict) -> dict:
         """
-        Updates an existing project.
+        Update an existing project.
 
         :param project_id: Asana GID of the project to update
         :param params: New attributes that the project should have. See
@@ -309,7 +284,7 @@ class AsanaHook(BaseHook):
 
     def delete_project(self, project_id: str) -> dict:
         """
-        Deletes a project.
+        Delete a project.
 
         :param project_id: Asana GID of the project to delete
         :return: A dict containing the response from Asana
