@@ -61,7 +61,7 @@ class KubernetesPodTrigger(BaseTrigger):
     :param kubernetes_conn_id: The :ref:`kubernetes connection id <howto/connection:kubernetes>`
         for the Kubernetes cluster.
     :param cluster_context: Context that points to kubernetes cluster.
-    :param config_file: Path to kubeconfig file.
+    :param config_dict: Content of kubeconfig file in dict format.
     :param poll_interval: Polling period in seconds to check for the status.
     :param trigger_start_time: time in Datetime format when the trigger was started
     :param in_cluster: run kubernetes client with in_cluster configuration.
@@ -89,7 +89,7 @@ class KubernetesPodTrigger(BaseTrigger):
         kubernetes_conn_id: str | None = None,
         poll_interval: float = 2,
         cluster_context: str | None = None,
-        config_file: str | None = None,
+        config_dict: dict | None = None,
         in_cluster: bool | None = None,
         get_logs: bool = True,
         startup_timeout: int = 120,
@@ -107,7 +107,7 @@ class KubernetesPodTrigger(BaseTrigger):
         self.kubernetes_conn_id = kubernetes_conn_id
         self.poll_interval = poll_interval
         self.cluster_context = cluster_context
-        self.config_file = config_file
+        self.config_dict = config_dict
         self.in_cluster = in_cluster
         self.get_logs = get_logs
         self.startup_timeout = startup_timeout
@@ -142,7 +142,7 @@ class KubernetesPodTrigger(BaseTrigger):
                 "kubernetes_conn_id": self.kubernetes_conn_id,
                 "poll_interval": self.poll_interval,
                 "cluster_context": self.cluster_context,
-                "config_file": self.config_file,
+                "config_dict": self.config_dict,
                 "in_cluster": self.in_cluster,
                 "get_logs": self.get_logs,
                 "startup_timeout": self.startup_timeout,
@@ -219,15 +219,17 @@ class KubernetesPodTrigger(BaseTrigger):
 
     async def _wait_for_pod_start(self) -> ContainerState:
         """Loops until pod phase leaves ``PENDING`` If timeout is reached, throws error."""
-        delta = datetime.datetime.now(tz=datetime.timezone.utc) - self.trigger_start_time
-        while self.startup_timeout >= delta.total_seconds():
+        while True:
             pod = await self.hook.get_pod(self.pod_name, self.pod_namespace)
             if not pod.status.phase == "Pending":
                 return self.define_container_state(pod)
+
+            delta = datetime.datetime.now(tz=datetime.timezone.utc) - self.trigger_start_time
+            if self.startup_timeout < delta.total_seconds():
+                raise PodLaunchTimeoutException("Pod did not leave 'Pending' phase within specified timeout")
+
             self.log.info("Still waiting for pod to start. The pod state is %s", pod.status.phase)
             await asyncio.sleep(self.startup_check_interval)
-            delta = datetime.datetime.now(tz=datetime.timezone.utc) - self.trigger_start_time
-        raise PodLaunchTimeoutException("Pod did not leave 'Pending' phase within specified timeout")
 
     async def _wait_for_container_completion(self) -> TriggerEvent:
         """
@@ -262,6 +264,7 @@ class KubernetesPodTrigger(BaseTrigger):
                         "last_log_time": self.last_log_time,
                     }
                 )
+            self.log.debug("Container is not completed and still working.")
             if time_get_more_logs and datetime.datetime.now(tz=datetime.timezone.utc) > time_get_more_logs:
                 return TriggerEvent(
                     {
@@ -271,6 +274,7 @@ class KubernetesPodTrigger(BaseTrigger):
                         "name": self.pod_name,
                     }
                 )
+            self.log.debug("Sleeping for %s seconds.", self.poll_interval)
             await asyncio.sleep(self.poll_interval)
 
     def _get_async_hook(self) -> AsyncKubernetesHook:
@@ -278,7 +282,7 @@ class KubernetesPodTrigger(BaseTrigger):
         return AsyncKubernetesHook(
             conn_id=self.kubernetes_conn_id,
             in_cluster=self.in_cluster,
-            config_file=self.config_file,
+            config_dict=self.config_dict,
             cluster_context=self.cluster_context,
         )
 
