@@ -18,15 +18,13 @@ from __future__ import annotations
 
 import packaging.version
 
-try:
-    from airflow import __version__ as airflow_version
-except ImportError:
-    from airflow.version import version as airflow_version
+from airflow import __version__ as airflow_version
+from airflow.exceptions import AirflowOptionalProviderFeatureException
 
 if packaging.version.parse(packaging.version.parse(airflow_version).base_version) < packaging.version.parse(
     "2.9.0"
 ):
-    raise RuntimeError(
+    raise AirflowOptionalProviderFeatureException(
         "The package xcom backend feature of `apache-airflow-providers-common-io` needs "
         "Apache Airflow 2.9.0+"
     )
