@@ -27,18 +27,18 @@ from airflow.providers.http.hooks.http import HttpHook
 
 
 class DingdingHook(HttpHook):
-    """Send message using a custom Dingding bot.
+    """
+    Send message using a DingTalk Custom Robot API.
 
-    Get Dingding token from the connection's ``password``. If ``host`` is not
-    set in the connection, the default ``https://oapi.dingtalk.com`` is used.
+    .. seealso::
+        `How to get webhook token <https://open.dingtalk.com/document/robots/custom-robot-access>`__
 
-    For more detail message in
-    `Dingding custom bot <https://open-doc.dingtalk.com/microapp/serverapi2/qf2nxq>`_
-
-    :param dingding_conn_id: The name of the Dingding connection to use
+    :param dingding_conn_id: Dingding connection id that has access token in the password field,
+        and optional host name in host field, if host not set than default
+        ``https://oapi.dingtalk.com`` will use.
     :param message_type: Message type you want to send to Dingding, support five type so far
-        including text, link, markdown, actionCard, feedCard
-    :param message: The message send to Dingding chat group
+        including ``text``, ``link``, ``markdown``, ``actionCard``, ``feedCard``.
+    :param message: The message send to chat group
     :param at_mobiles: Remind specific users with this message
     :param at_all: Remind all people in group or not. If True, will overwrite ``at_mobiles``
     """
@@ -46,7 +46,7 @@ class DingdingHook(HttpHook):
     conn_name_attr = "dingding_conn_id"
     default_conn_name = "dingding_default"
     conn_type = "dingding"
-    hook_name = "Dingding"
+    hook_name = "DingTalk Custom Robot (Dingding)"
 
     def __init__(
         self,
@@ -65,7 +65,7 @@ class DingdingHook(HttpHook):
         self.at_all = at_all
 
     def _get_endpoint(self) -> str:
-        """Get Dingding endpoint for sending message."""
+        """Get DingTalk Custom Robot endpoint for sending message."""
         conn = self.get_connection(self.http_conn_id)
         token = conn.password
         if not token:
@@ -75,7 +75,7 @@ class DingdingHook(HttpHook):
         return f"robot/send?access_token={token}"
 
     def _build_message(self) -> str:
-        """Build different type of Dingding messages."""
+        """Build different type of DingTalk custom robot messages."""
         if self.message_type in ["text", "markdown"]:
             data = {
                 "msgtype": self.message_type,
@@ -87,7 +87,8 @@ class DingdingHook(HttpHook):
         return json.dumps(data)
 
     def get_conn(self, headers: dict | None = None) -> Session:
-        """Overwrite HttpHook get_conn.
+        """
+        Overwrite HttpHook get_conn.
 
         We just need base_url and headers, and not don't need generic params.
 
@@ -101,7 +102,7 @@ class DingdingHook(HttpHook):
         return session
 
     def send(self) -> None:
-        """Send Dingding message."""
+        """Send DingTalk Custom Robot message."""
         support_type = ["text", "link", "markdown", "actionCard", "feedCard"]
         if self.message_type not in support_type:
             raise ValueError(
@@ -114,7 +115,7 @@ class DingdingHook(HttpHook):
             endpoint=self._get_endpoint(), data=data, headers={"Content-Type": "application/json"}
         )
 
-        # Dingding success send message will with errcode equal to 0
+        # Success send message will return errcode = 0
         if int(resp.json().get("errcode")) != 0:
             raise AirflowException(f"Send Dingding message failed, receive error message {resp.text}")
         self.log.info("Success Send Dingding message")
