@@ -63,7 +63,8 @@ def stringify(line: str | bytes):
 
 
 class DockerOperator(BaseOperator):
-    """Execute a command inside a docker container.
+    """
+    Execute a command inside a docker container.
 
     By default, a temporary directory is
     created on the host and mounted into a container to allow storing files
@@ -95,7 +96,7 @@ class DockerOperator(BaseOperator):
     :param cpus: Number of CPUs to assign to the container.
         This value gets multiplied with 1024. See
         https://docs.docker.com/engine/reference/run/#cpu-share-constraint
-    :param docker_url: URL of the host running the docker daemon.
+    :param docker_url: URL or list of URLs of the host(s) running the docker daemon.
         Default is the value of the ``DOCKER_HOST`` environment variable or unix://var/run/docker.sock
         if it is unset.
     :param environment: Environment variables to set in the container. (templated)
@@ -161,6 +162,7 @@ class DockerOperator(BaseOperator):
         file before manually shutting down the image. Useful for cases where users want a pickle serialized
         output that is not posted to logs
     :param retrieve_output_path: path for output file that will be retrieved and passed to xcom
+    :param timeout: Timeout for API calls, in seconds. Default is 60 seconds.
     :param device_requests: Expose host resources such as GPUs to the container.
     :param log_opts_max_size: The maximum size of the log before it is rolled.
         A positive integer plus a modifier representing the unit of measure (k, m, or g).
@@ -200,7 +202,7 @@ class DockerOperator(BaseOperator):
         command: str | list[str] | None = None,
         container_name: str | None = None,
         cpus: float = 1.0,
-        docker_url: str | None = None,
+        docker_url: str | list[str] | None = None,
         environment: dict | None = None,
         private_environment: dict | None = None,
         env_file: str | None = None,
@@ -432,7 +434,8 @@ class DockerOperator(BaseOperator):
             for log_chunk in logstream:
                 log_chunk = stringify(log_chunk).strip()
                 log_lines.append(log_chunk)
-                self.log.info("%s", log_chunk)
+                for log_chunk_line in log_chunk.split("\n"):
+                    self.log.info("%s", log_chunk_line)
 
             result = self.cli.wait(self.container["Id"])
             if result["StatusCode"] in self.skip_on_exit_code:
@@ -463,7 +466,8 @@ class DockerOperator(BaseOperator):
                 self.cli.remove_container(self.container["Id"], force=True)
 
     def _attempt_to_retrieve_result(self):
-        """Attempt to pull the result from the expected file.
+        """
+        Attempt to pull the result from the expected file.
 
         This uses Docker's ``get_archive`` function. If the file is not yet
         ready, *None* is returned.
@@ -489,7 +493,7 @@ class DockerOperator(BaseOperator):
     def execute(self, context: Context) -> list[str] | str | None:
         # Pull the docker image if `force_pull` is set or image does not exist locally
         if self.force_pull or not self.cli.images(name=self.image):
-            self.log.info("Pulling docker image %s", self.image)
+            self.log.info("::group::Pulling docker image %s", self.image)
             latest_status: dict[str, str] = {}
             for output in self.cli.pull(self.image, stream=True, decode=True):
                 if isinstance(output, str):
@@ -505,11 +509,13 @@ class DockerOperator(BaseOperator):
                     if latest_status.get(output_id) != output_status:
                         self.log.info("%s: %s", output_id, output_status)
                         latest_status[output_id] = output_status
+            self.log.info("::endgroup::")
         return self._run_image()
 
     @staticmethod
     def format_command(command: list[str] | str | None) -> list[str] | str | None:
-        """Retrieve command(s).
+        """
+        Retrieve command(s).
 
         If command string starts with ``[``, the string is treated as a Python
         literal and parsed into a list of commands.
@@ -532,7 +538,8 @@ class DockerOperator(BaseOperator):
 
     @staticmethod
     def unpack_environment_variables(env_str: str) -> dict:
-        r"""Parse environment variables from the string.
+        r"""
+        Parse environment variables from the string.
 
         :param env_str: environment variables in the ``{key}={value}`` format,
             separated by a ``\n`` (newline)
