@@ -30,7 +30,8 @@ if TYPE_CHECKING:
 
 
 class GoogleAdsToGcsOperator(BaseOperator):
-    """Fetch daily results from the Google Ads API for 1-n clients.
+    """
+    Fetch daily results from the Google Ads API for 1-n clients.
 
     Converts and saves the data as a temporary CSV file Uploads the CSV to
     Google Cloud Storage.
