@@ -16,23 +16,27 @@
 # specific language governing permissions and limitations
 # under the License.
 """Hook for Google Cloud Build service."""
+
 from __future__ import annotations
 
-import warnings
-from typing import Sequence
+from typing import TYPE_CHECKING, Sequence
 
+from deprecated import deprecated
 from google.api_core.client_options import ClientOptions
 from google.api_core.exceptions import AlreadyExists
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
-from google.api_core.operation import Operation
-from google.api_core.retry import Retry
 from google.cloud.devtools.cloudbuild_v1 import CloudBuildAsyncClient, CloudBuildClient, GetBuildRequest
-from google.cloud.devtools.cloudbuild_v1.types import Build, BuildTrigger, RepoSource
 
-from airflow.exceptions import AirflowException
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID, GoogleBaseHook
 
+if TYPE_CHECKING:
+    from google.api_core.operation import Operation
+    from google.api_core.retry import Retry
+    from google.api_core.retry_async import AsyncRetry
+    from google.cloud.devtools.cloudbuild_v1.types import Build, BuildTrigger, RepoSource
+
 # Time to sleep between active checks of the operation results
 TIME_TO_SLEEP_IN_SECONDS = 5
 
@@ -42,9 +46,6 @@ class CloudBuildHook(GoogleBaseHook):
     Hook for the Google Cloud Build Service.
 
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -58,16 +59,15 @@ class CloudBuildHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
+        **kwargs,
     ) -> None:
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
             )
-        super().__init__(
-            gcp_conn_id=gcp_conn_id, delegate_to=delegate_to, impersonation_chain=impersonation_chain
-        )
+        super().__init__(gcp_conn_id=gcp_conn_id, impersonation_chain=impersonation_chain)
         self._client: dict[str, CloudBuildClient] = {}
 
     def _get_build_id_from_operation(self, operation: Operation) -> str:
@@ -85,7 +85,7 @@ class CloudBuildHook(GoogleBaseHook):
             raise AirflowException("Could not retrieve Build ID from Operation.")
 
     def wait_for_operation(self, operation: Operation, timeout: float | None = None):
-        """Waits for long-lasting operation to complete."""
+        """Wait for long-lasting operation to complete."""
         try:
             return operation.result(timeout=timeout)
         except Exception:
@@ -94,7 +94,7 @@ class CloudBuildHook(GoogleBaseHook):
 
     def get_conn(self, location: str = "global") -> CloudBuildClient:
         """
-        Retrieves the connection to Google Cloud Build.
+        Retrieve the connection to Google Cloud Build.
 
         :param location: The location of the project.
 
@@ -122,7 +122,7 @@ class CloudBuildHook(GoogleBaseHook):
         location: str = "global",
     ) -> Build:
         """
-        Cancels a build in progress.
+        Cancel a build in progress.
 
         :param id_: The ID of the build.
         :param project_id: Optional, Google Cloud Project project_id where the function belongs.
@@ -159,7 +159,7 @@ class CloudBuildHook(GoogleBaseHook):
         location: str = "global",
     ) -> tuple[Operation, str]:
         """
-        Starts a build with the specified configuration without waiting for it to finish.
+        Start a build with the specified configuration without waiting for it to finish.
 
         :param build: The build resource to create. If a dict is provided, it must be of the same form
             as the protobuf message `google.cloud.devtools.cloudbuild_v1.types.Build`
@@ -185,9 +185,15 @@ class CloudBuildHook(GoogleBaseHook):
             metadata=metadata,
         )
         id_ = self._get_build_id_from_operation(operation)
+        self.log.info("Build has been created: %s.", id_)
+
         return operation, id_
 
     @GoogleBaseHook.fallback_to_default_project_id
+    @deprecated(
+        reason="Please use `create_build_without_waiting_for_result`",
+        category=AirflowProviderDeprecationWarning,
+    )
     def create_build(
         self,
         build: dict | Build,
@@ -198,7 +204,7 @@ class CloudBuildHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> Build:
         """
-        Starts a build with the specified configuration.
+        Start a build with the specified configuration.
 
         :param build: The build resource to create. If a dict is provided, it must be of the same form
             as the protobuf message `google.cloud.devtools.cloudbuild_v1.types.Build`
@@ -245,7 +251,7 @@ class CloudBuildHook(GoogleBaseHook):
         location: str = "global",
     ) -> BuildTrigger:
         """
-        Creates a new BuildTrigger.
+        Create a new BuildTrigger.
 
         :param trigger: The BuildTrigger to create. If a dict is provided, it must be of the same form
             as the protobuf message `google.cloud.devtools.cloudbuild_v1.types.BuildTrigger`
@@ -287,7 +293,7 @@ class CloudBuildHook(GoogleBaseHook):
         location: str = "global",
     ) -> None:
         """
-        Deletes a BuildTrigger by its project ID and trigger ID.
+        Delete a BuildTrigger by its project ID and trigger ID.
 
         :param trigger_id: The ID of the BuildTrigger to delete.
         :param project_id: Optional, Google Cloud Project project_id where the function belongs.
@@ -323,7 +329,7 @@ class CloudBuildHook(GoogleBaseHook):
         location: str = "global",
     ) -> Build:
         """
-        Returns information about a previously requested build.
+        Return information about a previously requested build.
 
         :param id_: The ID of the build.
         :param project_id: Optional, Google Cloud Project project_id where the function belongs.
@@ -361,7 +367,7 @@ class CloudBuildHook(GoogleBaseHook):
         location: str = "global",
     ) -> BuildTrigger:
         """
-        Returns information about a BuildTrigger.
+        Return information about a BuildTrigger.
 
         :param trigger_id: The ID of the BuildTrigger to get.
         :param project_id: Optional, Google Cloud Project project_id where the function belongs.
@@ -400,7 +406,7 @@ class CloudBuildHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> list[BuildTrigger]:
         """
-        Lists existing BuildTriggers.
+        List existing BuildTriggers.
 
         :param project_id: Google Cloud Project project_id where the function belongs.
             If set to None or missing, the default project_id from the GCP connection is used.
@@ -449,7 +455,7 @@ class CloudBuildHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> list[Build]:
         """
-        Lists previously requested builds.
+        List previously requested builds.
 
         :param project_id: Google Cloud Project project_id where the function belongs.
             If set to None or missing, the default project_id from the Google Cloud connection is used.
@@ -499,8 +505,7 @@ class CloudBuildHook(GoogleBaseHook):
         location: str = "global",
     ) -> Build:
         """
-        Creates a new build based on the specified build. This method creates a new build
-        using the original build request, which may or may not result in an identical build.
+        Create a new build using the original build request; may or may not result in an identical build.
 
         :param id_: Build ID of the original build.
         :param project_id: Optional, Google Cloud Project project_id where the function belongs.
@@ -525,13 +530,12 @@ class CloudBuildHook(GoogleBaseHook):
         )
 
         id_ = self._get_build_id_from_operation(operation)
+        self.log.info("Build has been retried: %s.", id_)
 
         if not wait:
             return self.get_build(id_=id_, project_id=project_id, location=location)
 
-        operation.result()
-
-        self.log.info("Build has been retried: %s.", id_)
+        self.wait_for_operation(operation, timeout)
 
         return self.get_build(id_=id_, project_id=project_id, location=location)
 
@@ -548,7 +552,7 @@ class CloudBuildHook(GoogleBaseHook):
         location: str = "global",
     ) -> Build:
         """
-        Runs a BuildTrigger at a particular source revision.
+        Run a BuildTrigger at a particular source revision.
 
         :param trigger_id: The ID of the trigger.
         :param source: Source to build against this trigger. If a dict is provided, it must be of the
@@ -572,14 +576,15 @@ class CloudBuildHook(GoogleBaseHook):
             timeout=timeout,
             metadata=metadata,
         )
+        self.log.info("Build trigger has been run: %s.", trigger_id)
 
         id_ = self._get_build_id_from_operation(operation)
+        self.log.info("Build has been created: %s.", id_)
 
         if not wait:
             return self.get_build(id_=id_, project_id=project_id, location=location)
-        operation.result()
 
-        self.log.info("Build trigger has been run: %s.", trigger_id)
+        self.wait_for_operation(operation, timeout)
 
         return self.get_build(id_=id_, project_id=project_id, location=location)
 
@@ -595,7 +600,7 @@ class CloudBuildHook(GoogleBaseHook):
         location: str = "global",
     ) -> BuildTrigger:
         """
-        Updates a BuildTrigger by its project ID and trigger ID.
+        Update a BuildTrigger by its project ID and trigger ID.
 
         :param trigger_id: The ID of the trigger.
         :param trigger: The BuildTrigger to create. If a dict is provided, it must be of the same form
@@ -628,17 +633,25 @@ class CloudBuildHook(GoogleBaseHook):
 class CloudBuildAsyncHook(GoogleBaseHook):
     """Asynchronous Hook for the Google Cloud Build Service."""
 
+    def __init__(self, **kwargs):
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
+            )
+        super().__init__(**kwargs)
+
     @GoogleBaseHook.fallback_to_default_project_id
     async def get_cloud_build(
         self,
         id_: str,
         project_id: str = PROVIDE_PROJECT_ID,
-        retry: Retry | _MethodDefault = DEFAULT,
+        retry: AsyncRetry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         location: str = "global",
     ) -> Build:
-        """Retrieves a Cloud Build with a specified id."""
+        """Retrieve a Cloud Build with a specified id."""
         if not id_:
             raise AirflowException("Google Cloud Build id is required.")
 
