@@ -16,11 +16,9 @@
 # under the License.
 from __future__ import annotations
 
-import warnings
-from typing import Sequence
+from typing import TYPE_CHECKING, Sequence
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
-from google.api_core.retry import Retry
 from google.cloud import datacatalog
 from google.cloud.datacatalog import (
     CreateTagRequest,
@@ -32,21 +30,21 @@ from google.cloud.datacatalog import (
     TagTemplate,
     TagTemplateField,
 )
-from google.protobuf.field_mask_pb2 import FieldMask
 
-from airflow import AirflowException
+from airflow.exceptions import AirflowException
 from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID, GoogleBaseHook
 
+if TYPE_CHECKING:
+    from google.api_core.retry import Retry
+    from google.protobuf.field_mask_pb2 import FieldMask
+
 
 class CloudDataCatalogHook(GoogleBaseHook):
     """
     Hook for Google Cloud Data Catalog Service.
 
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -60,22 +58,22 @@ class CloudDataCatalogHook(GoogleBaseHook):
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
+        **kwargs,
     ) -> None:
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
             )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
-            delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
         self._client: DataCatalogClient | None = None
 
     def get_conn(self) -> DataCatalogClient:
-        """Retrieves client library object that allow access to Cloud Data Catalog service."""
+        """Retrieve client library object that allow access to Cloud Data Catalog service."""
         if not self._client:
             self._client = DataCatalogClient(credentials=self.get_credentials(), client_info=CLIENT_INFO)
         return self._client
@@ -93,7 +91,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> Entry:
         """
-        Creates an entry.
+        Create an entry.
 
         Currently only entries of 'FILESET' type can be created.
 
@@ -135,7 +133,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> EntryGroup:
         """
-        Creates an EntryGroup.
+        Create an EntryGroup.
 
         :param location: Required. The location of the entry group to create.
         :param entry_group_id: Required. The id of the entry group to create. The id must begin with a letter
@@ -181,7 +179,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> Tag:
         """
-        Creates a tag on an entry.
+        Create a tag on an entry.
 
         :param location: Required. The location of the tag to create.
         :param entry_group: Required. Entry group ID under which the tag is created.
@@ -244,7 +242,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> TagTemplate:
         """
-        Creates a tag template.
+        Create a tag template.
 
         :param location: Required. The location of the tag template to create.
         :param tag_template_id: Required. The id of the tag template to create.
@@ -303,7 +301,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> TagTemplateField:
         r"""
-        Creates a field in a tag template.
+        Create a field in a tag template.
 
         :param location: Required. The location of the tag template field to create.
         :param tag_template: Required. The id of the tag template to create.
@@ -355,7 +353,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
-        Deletes an existing entry.
+        Delete an existing entry.
 
         :param location: Required. The location of the entry to delete.
         :param entry_group: Required. Entry group ID for entries that is deleted.
@@ -385,7 +383,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
-        Deletes an EntryGroup.
+        Delete an EntryGroup.
 
         Only entry groups that do not contain entries can be deleted.
 
@@ -421,7 +419,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
-        Deletes a tag.
+        Delete a tag.
 
         :param location: Required. The location of the tag to delete.
         :param entry_group: Entry group ID for tag that is deleted.
@@ -456,7 +454,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
-        Deletes a tag template and all tags using the template.
+        Delete a tag template and all tags using the template.
 
         :param location: Required. The location of the tag template to delete.
         :param tag_template: ID for tag template that is deleted.
@@ -493,7 +491,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
-        Deletes a field in a tag template and all uses of that field.
+        Delete a field in a tag template and all uses of that field.
 
         :param location: Required. The location of the tag template to delete.
         :param tag_template: Tag Template ID for tag template field that is deleted.
@@ -528,7 +526,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> Entry:
         """
-        Gets an entry.
+        Get an entry.
 
         :param location: Required. The location of the entry to get.
         :param entry_group: Required. The entry group of the entry to get.
@@ -564,7 +562,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> EntryGroup:
         """
-        Gets an entry group.
+        Get an entry group.
 
         :param location: Required. The location of the entry group to get.
         :param entry_group: The ID of the entry group to get.
@@ -607,7 +605,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> TagTemplate:
         """
-        Gets a tag template.
+        Get a tag template.
 
         :param location: Required. The location of the tag template to get.
         :param tag_template: Required. The ID of the tag template to get.
@@ -645,7 +643,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ):
         """
-        Lists the tags on an Entry.
+        List the tags on an Entry.
 
         :param location: Required. The location of the tags to get.
         :param entry_group: Required. The entry group of the tags to get.
@@ -690,7 +688,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> Tag:
         """
-        Gets for a tag with a specific template for a specific entry.
+        Get for a tag with a specific template for a specific entry.
 
         :param location: Required. The location which contains the entry to search for.
         :param entry_group: The entry group ID which contains the entry to search for.
@@ -781,7 +779,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> TagTemplateField:
         """
-        Renames a field in a tag template.
+        Rename a field in a tag template.
 
         :param location: Required. The location of the tag template field to rename.
         :param tag_template: The tag template ID for field that is renamed.
@@ -826,7 +824,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ):
         r"""
-        Searches Data Catalog for multiple resources like entries, tags that match a query.
+        Search Data Catalog for multiple resources like entries, tags that match a query.
 
         This does not return the complete resource, only the resource identifier and high level fields.
         Clients can subsequently call ``Get`` methods.
@@ -900,7 +898,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> Entry:
         """
-        Updates an existing entry.
+        Update an existing entry.
 
         :param entry: Required. The updated entry. The "name" field must be set.
 
@@ -970,7 +968,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> Tag:
         """
-        Updates an existing tag.
+        Update an existing tag.
 
         :param tag: Required. The updated tag. The "name" field must be set.
 
@@ -1040,7 +1038,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> TagTemplate:
         """
-        Updates a tag template.
+        Update a tag template.
 
         This method cannot be used to update the fields of a template. The tag
         template fields are represented as separate resources and should be updated using their own
@@ -1114,7 +1112,7 @@ class CloudDataCatalogHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ):
         """
-        Updates a field in a tag template. This method cannot be used to update the field type.
+        Update a field in a tag template. This method cannot be used to update the field type.
 
         :param tag_template_field: Required. The template to update.
 
