@@ -35,6 +35,7 @@ from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 
 if TYPE_CHECKING:
     from google.api_core.retry import Retry
+    from google.cloud.dataform_v1beta1.services.dataform.pagers import QueryWorkflowInvocationActionsPager
 
 
 class DataformHook(GoogleBaseHook):
@@ -49,7 +50,7 @@ class DataformHook(GoogleBaseHook):
         super().__init__(**kwargs)
 
     def get_dataform_client(self) -> DataformClient:
-        """Retrieves client library object that allow access to Cloud Dataform service."""
+        """Retrieve client library object that allow access to Cloud Dataform service."""
         return DataformClient(credentials=self.get_credentials())
 
     @GoogleBaseHook.fallback_to_default_project_id
@@ -63,7 +64,7 @@ class DataformHook(GoogleBaseHook):
         timeout: int | None = None,
     ) -> None:
         """
-        Helper method which polls a job to check if it finishes.
+        Poll a job to check if it finishes.
 
         :param workflow_invocation_id: Id of the Workflow Invocation
         :param repository_id: Id of the Dataform repository
@@ -116,7 +117,7 @@ class DataformHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> CompilationResult:
         """
-        Creates a new CompilationResult in a given project and location.
+        Create a new CompilationResult in a given project and location.
 
         :param project_id: Required. The ID of the Google Cloud project that the task belongs to.
         :param region: Required. The ID of the Google Cloud region that the task belongs to.
@@ -150,7 +151,7 @@ class DataformHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> CompilationResult:
         """
-        Fetches a single CompilationResult.
+        Fetch a single CompilationResult.
 
         :param project_id: Required. The ID of the Google Cloud project that the task belongs to.
         :param region: Required. The ID of the Google Cloud region that the task belongs to.
@@ -181,7 +182,7 @@ class DataformHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> WorkflowInvocation:
         """
-        Creates a new WorkflowInvocation in a given Repository.
+        Create a new WorkflowInvocation in a given Repository.
 
         :param project_id: Required. The ID of the Google Cloud project that the task belongs to.
         :param region: Required. The ID of the Google Cloud region that the task belongs to.
@@ -212,7 +213,7 @@ class DataformHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> WorkflowInvocation:
         """
-        Fetches a single WorkflowInvocation.
+        Fetch a single WorkflowInvocation.
 
         :param project_id: Required. The ID of the Google Cloud project that the task belongs to.
         :param region: Required. The ID of the Google Cloud region that the task belongs to.
@@ -237,7 +238,7 @@ class DataformHook(GoogleBaseHook):
         )
 
     @GoogleBaseHook.fallback_to_default_project_id
-    def cancel_workflow_invocation(
+    def query_workflow_invocation_actions(
         self,
         project_id: str,
         region: str,
@@ -246,9 +247,9 @@ class DataformHook(GoogleBaseHook):
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
-    ):
+    ) -> QueryWorkflowInvocationActionsPager:
         """
-        Requests cancellation of a running WorkflowInvocation.
+        Fetch WorkflowInvocation actions.
 
         :param project_id: Required. The ID of the Google Cloud project that the task belongs to.
         :param region: Required. The ID of the Google Cloud region that the task belongs to.
@@ -263,9 +264,65 @@ class DataformHook(GoogleBaseHook):
             f"projects/{project_id}/locations/{region}/repositories/"
             f"{repository_id}/workflowInvocations/{workflow_invocation_id}"
         )
-        client.cancel_workflow_invocation(
-            request={"name": name}, retry=retry, timeout=timeout, metadata=metadata
+        response = client.query_workflow_invocation_actions(
+            request={
+                "name": name,
+            },
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
         )
+        return response
+
+    @GoogleBaseHook.fallback_to_default_project_id
+    def cancel_workflow_invocation(
+        self,
+        project_id: str,
+        region: str,
+        repository_id: str,
+        workflow_invocation_id: str,
+        retry: Retry | _MethodDefault = DEFAULT,
+        timeout: float | None = None,
+        metadata: Sequence[tuple[str, str]] = (),
+    ):
+        """
+        Request cancellation of a running WorkflowInvocation.
+
+        :param project_id: Required. The ID of the Google Cloud project that the task belongs to.
+        :param region: Required. The ID of the Google Cloud region that the task belongs to.
+        :param repository_id: Required. The ID of the Dataform repository that the task belongs to.
+        :param workflow_invocation_id:  Required. The workflow invocation resource's id.
+        :param retry: Designation of what errors, if any, should be retried.
+        :param timeout: The timeout for this request.
+        :param metadata: Strings which should be sent along with the request as metadata.
+        """
+        client = self.get_dataform_client()
+        name = (
+            f"projects/{project_id}/locations/{region}/repositories/"
+            f"{repository_id}/workflowInvocations/{workflow_invocation_id}"
+        )
+        try:
+            workflow_invocation = self.get_workflow_invocation(
+                project_id=project_id,
+                region=region,
+                repository_id=repository_id,
+                workflow_invocation_id=workflow_invocation_id,
+            )
+            state = workflow_invocation.state
+        except Exception as err:
+            raise AirflowException(
+                f"Dataform API returned error when waiting for workflow invocation:\n{err}"
+            )
+
+        if state == WorkflowInvocation.State.RUNNING:
+            client.cancel_workflow_invocation(
+                request={"name": name}, retry=retry, timeout=timeout, metadata=metadata
+            )
+        else:
+            self.log.info(
+                "Workflow is not active. Either the execution has already finished or has been canceled. "
+                "Please check the logs above for more details."
+            )
 
     @GoogleBaseHook.fallback_to_default_project_id
     def create_repository(
@@ -279,7 +336,7 @@ class DataformHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> Repository:
         """
-        Creates repository.
+        Create repository.
 
         :param project_id: Required. The ID of the Google Cloud project where repository should be.
         :param region: Required. The ID of the Google Cloud region where repository should be.
@@ -317,7 +374,7 @@ class DataformHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
-        Deletes repository.
+        Delete repository.
 
         :param project_id: Required. The ID of the Google Cloud project where repository located.
         :param region: Required. The ID of the Google Cloud region where repository located.
@@ -354,7 +411,7 @@ class DataformHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> Workspace:
         """
-        Creates workspace.
+        Create workspace.
 
         :param project_id: Required. The ID of the Google Cloud project where workspace should be.
         :param region: Required. The ID of the Google Cloud region where workspace should be.
@@ -391,7 +448,7 @@ class DataformHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ):
         """
-        Deletes workspace.
+        Delete workspace.
 
         :param project_id: Required. The ID of the Google Cloud project where workspace located.
         :param region: Required. The ID of the Google Cloud region where workspace located.
@@ -432,7 +489,7 @@ class DataformHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> WriteFileResponse:
         """
-        Writes a new file to the specified workspace.
+        Write a new file to the specified workspace.
 
         :param project_id: Required. The ID of the Google Cloud project where workspace located.
         :param region: Required. The ID of the Google Cloud region where workspace located.
@@ -478,7 +535,7 @@ class DataformHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> dict:
         """
-        Makes new directory in specified workspace.
+        Make new directory in specified workspace.
 
         :param project_id: Required. The ID of the Google Cloud project where workspace located.
         :param region: Required. The ID of the Google Cloud region where workspace located.
@@ -523,7 +580,7 @@ class DataformHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ):
         """
-        Removes directory in specified workspace.
+        Remove directory in specified workspace.
 
         :param project_id: Required. The ID of the Google Cloud project where workspace located.
         :param region: Required. The ID of the Google Cloud region where workspace located.
@@ -566,7 +623,7 @@ class DataformHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ):
         """
-        Removes file in specified workspace.
+        Remove file in specified workspace.
 
         :param project_id: Required. The ID of the Google Cloud project where workspace located.
         :param region: Required. The ID of the Google Cloud region where workspace located.
@@ -606,7 +663,8 @@ class DataformHook(GoogleBaseHook):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
     ) -> InstallNpmPackagesResponse:
-        """Install NPM dependencies in the provided workspace.
+        """
+        Install NPM dependencies in the provided workspace.
 
         Requires "package.json" to be created in the workspace.
 
