@@ -16,6 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Dataprep hook."""
+
 from __future__ import annotations
 
 import json
@@ -58,7 +59,9 @@ class JobGroupStatuses(str, Enum):
 class GoogleDataprepHook(BaseHook):
     """
     Hook for connection with Dataprep API.
+
     To get connection Dataprep with Airflow you need Dataprep token.
+
     https://clouddataprep.com/documentation/api#section/Authentication
 
     It should be added to the Connection in Airflow in JSON format.
@@ -70,9 +73,10 @@ class GoogleDataprepHook(BaseHook):
     conn_type = "dataprep"
     hook_name = "Google Dataprep"
 
-    def __init__(self, dataprep_conn_id: str = default_conn_name) -> None:
+    def __init__(self, dataprep_conn_id: str = default_conn_name, api_version: str = "v4") -> None:
         super().__init__()
         self.dataprep_conn_id = dataprep_conn_id
+        self.api_version = api_version
         conn = self.get_connection(self.dataprep_conn_id)
         extras = conn.extra_dejson
         self._token = _get_field(extras, "token")
@@ -93,7 +97,7 @@ class GoogleDataprepHook(BaseHook):
 
         :param job_id: The ID of the job that will be fetched
         """
-        endpoint_path = f"v4/jobGroups/{job_id}/jobs"
+        endpoint_path = f"{self.api_version}/jobGroups/{job_id}/jobs"
         url: str = urljoin(self._base_url, endpoint_path)
         response = requests.get(url, headers=self._headers)
         self._raise_for_status(response)
@@ -103,6 +107,7 @@ class GoogleDataprepHook(BaseHook):
     def get_job_group(self, job_group_id: int, embed: str, include_deleted: bool) -> dict[str, Any]:
         """
         Get the specified job group.
+
         A job group is a job that is executed from a specific node in a flow.
 
         :param job_group_id: The ID of the job that will be fetched
@@ -110,7 +115,7 @@ class GoogleDataprepHook(BaseHook):
         :param include_deleted: if set to "true", will include deleted objects
         """
         params: dict[str, Any] = {"embed": embed, "includeDeleted": include_deleted}
-        endpoint_path = f"v4/jobGroups/{job_group_id}"
+        endpoint_path = f"{self.api_version}/jobGroups/{job_group_id}"
         url: str = urljoin(self._base_url, endpoint_path)
         response = requests.get(url, headers=self._headers, params=params)
         self._raise_for_status(response)
@@ -119,19 +124,35 @@ class GoogleDataprepHook(BaseHook):
     @retry(stop=stop_after_attempt(5), wait=wait_exponential(multiplier=1, max=10))
     def run_job_group(self, body_request: dict) -> dict[str, Any]:
         """
-        Creates a ``jobGroup``, which launches the specified job as the authenticated user.
+        Create a ``jobGroup``, which launches the specified job as the authenticated user.
+
         This performs the same action as clicking on the Run Job button in the application.
+
         To get recipe_id please follow the Dataprep API documentation
-        https://clouddataprep.com/documentation/api#operation/runJobGroup
+        https://clouddataprep.com/documentation/api#operation/runJobGroup.
 
         :param body_request: The identifier for the recipe you would like to run.
         """
-        endpoint_path = "v4/jobGroups"
+        endpoint_path = f"{self.api_version}/jobGroups"
         url: str = urljoin(self._base_url, endpoint_path)
         response = requests.post(url, headers=self._headers, data=json.dumps(body_request))
         self._raise_for_status(response)
         return response.json()
 
+    @retry(stop=stop_after_attempt(5), wait=wait_exponential(multiplier=1, max=10))
+    def create_flow(self, *, body_request: dict) -> dict:
+        """
+        Create flow.
+
+        :param body_request: Body of the POST request to be sent.
+            For more details check https://clouddataprep.com/documentation/api#operation/createFlow
+        """
+        endpoint = f"/{self.api_version}/flows"
+        url: str = urljoin(self._base_url, endpoint)
+        response = requests.post(url, headers=self._headers, data=json.dumps(body_request))
+        self._raise_for_status(response)
+        return response.json()
+
     @retry(stop=stop_after_attempt(5), wait=wait_exponential(multiplier=1, max=10))
     def copy_flow(
         self, *, flow_id: int, name: str = "", description: str = "", copy_datasources: bool = False
@@ -144,7 +165,7 @@ class GoogleDataprepHook(BaseHook):
         :param description: Description of the copy of the flow
         :param copy_datasources: Bool value to define should copies of data inputs be made or not.
         """
-        endpoint_path = f"v4/flows/{flow_id}/copy"
+        endpoint_path = f"{self.api_version}/flows/{flow_id}/copy"
         url: str = urljoin(self._base_url, endpoint_path)
         body_request = {
             "name": name,
@@ -162,7 +183,7 @@ class GoogleDataprepHook(BaseHook):
 
         :param flow_id: ID of the flow to be copied
         """
-        endpoint_path = f"v4/flows/{flow_id}"
+        endpoint_path = f"{self.api_version}/flows/{flow_id}"
         url: str = urljoin(self._base_url, endpoint_path)
         response = requests.delete(url, headers=self._headers)
         self._raise_for_status(response)
@@ -170,12 +191,12 @@ class GoogleDataprepHook(BaseHook):
     @retry(stop=stop_after_attempt(5), wait=wait_exponential(multiplier=1, max=10))
     def run_flow(self, *, flow_id: int, body_request: dict) -> dict:
         """
-        Runs the flow with the provided id copy of the provided flow id.
+        Run the flow with the provided id copy of the provided flow id.
 
         :param flow_id: ID of the flow to be copied
         :param body_request: Body of the POST request to be sent.
         """
-        endpoint = f"v4/flows/{flow_id}/run"
+        endpoint = f"{self.api_version}/flows/{flow_id}/run"
         url: str = urljoin(self._base_url, endpoint)
         response = requests.post(url, headers=self._headers, data=json.dumps(body_request))
         self._raise_for_status(response)
@@ -188,7 +209,7 @@ class GoogleDataprepHook(BaseHook):
 
         :param job_group_id: ID of the job group to check
         """
-        endpoint = f"/v4/jobGroups/{job_group_id}/status"
+        endpoint = f"/{self.api_version}/jobGroups/{job_group_id}/status"
         url: str = urljoin(self._base_url, endpoint)
         response = requests.get(url, headers=self._headers)
         self._raise_for_status(response)
@@ -200,3 +221,74 @@ class GoogleDataprepHook(BaseHook):
         except HTTPError:
             self.log.error(response.json().get("exception"))
             raise
+
+    @retry(stop=stop_after_attempt(5), wait=wait_exponential(multiplier=1, max=10))
+    def create_imported_dataset(self, *, body_request: dict) -> dict:
+        """
+        Create imported dataset.
+
+        :param body_request: Body of the POST request to be sent.
+            For more details check https://clouddataprep.com/documentation/api#operation/createImportedDataset
+        """
+        endpoint = f"/{self.api_version}/importedDatasets"
+        url: str = urljoin(self._base_url, endpoint)
+        response = requests.post(url, headers=self._headers, data=json.dumps(body_request))
+        self._raise_for_status(response)
+        return response.json()
+
+    @retry(stop=stop_after_attempt(5), wait=wait_exponential(multiplier=1, max=10))
+    def create_wrangled_dataset(self, *, body_request: dict) -> dict:
+        """
+        Create wrangled dataset.
+
+        :param body_request: Body of the POST request to be sent.
+            For more details check
+            https://clouddataprep.com/documentation/api#operation/createWrangledDataset
+        """
+        endpoint = f"/{self.api_version}/wrangledDatasets"
+        url: str = urljoin(self._base_url, endpoint)
+        response = requests.post(url, headers=self._headers, data=json.dumps(body_request))
+        self._raise_for_status(response)
+        return response.json()
+
+    @retry(stop=stop_after_attempt(5), wait=wait_exponential(multiplier=1, max=10))
+    def create_output_object(self, *, body_request: dict) -> dict:
+        """
+        Create output.
+
+        :param body_request: Body of the POST request to be sent.
+            For more details check
+            https://clouddataprep.com/documentation/api#operation/createOutputObject
+        """
+        endpoint = f"/{self.api_version}/outputObjects"
+        url: str = urljoin(self._base_url, endpoint)
+        response = requests.post(url, headers=self._headers, data=json.dumps(body_request))
+        self._raise_for_status(response)
+        return response.json()
+
+    @retry(stop=stop_after_attempt(5), wait=wait_exponential(multiplier=1, max=10))
+    def create_write_settings(self, *, body_request: dict) -> dict:
+        """
+        Create write settings.
+
+        :param body_request: Body of the POST request to be sent.
+            For more details check
+            https://clouddataprep.com/documentation/api#tag/createWriteSetting
+        """
+        endpoint = f"/{self.api_version}/writeSettings"
+        url: str = urljoin(self._base_url, endpoint)
+        response = requests.post(url, headers=self._headers, data=json.dumps(body_request))
+        self._raise_for_status(response)
+        return response.json()
+
+    @retry(stop=stop_after_attempt(5), wait=wait_exponential(multiplier=1, max=10))
+    def delete_imported_dataset(self, *, dataset_id: int) -> None:
+        """
+        Delete imported dataset.
+
+        :param dataset_id: ID of the imported dataset for removal.
+        """
+        endpoint = f"/{self.api_version}/importedDatasets/{dataset_id}"
+        url: str = urljoin(self._base_url, endpoint)
+        response = requests.delete(url, headers=self._headers)
+        self._raise_for_status(response)
