@@ -15,59 +15,59 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-#
+from __future__ import annotations
 
-from typing import Any, Dict, List, Optional, Sequence, Union
+from typing import Any, Sequence
 
 from googleapiclient.discovery import Resource, build
 
 from airflow.exceptions import AirflowException
-from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
+from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID, GoogleBaseHook
 
 
 class GoogleDeploymentManagerHook(GoogleBaseHook):
     """
     Interact with Google Cloud Deployment Manager using the Google Cloud connection.
+
     This allows for scheduled and programmatic inspection and deletion of resources managed by GDM.
     """
 
     def __init__(
         self,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
+        **kwargs,
     ) -> None:
+        if kwargs.get("delegate_to") is not None:
+            raise RuntimeError(
+                "The `delegate_to` parameter has been deprecated before and finally removed in this version"
+                " of Google Provider. You MUST convert it to `impersonate_chain`"
+            )
         super().__init__(
             gcp_conn_id=gcp_conn_id,
-            delegate_to=delegate_to,
             impersonation_chain=impersonation_chain,
         )
 
     def get_conn(self) -> Resource:
-        """
-        Returns a Google Deployment Manager service object.
-
-        :rtype: googleapiclient.discovery.Resource
-        """
+        """Return a Google Deployment Manager service object."""
         http_authorized = self._authorize()
-        return build('deploymentmanager', 'v2', http=http_authorized, cache_discovery=False)
+        return build("deploymentmanager", "v2", http=http_authorized, cache_discovery=False)
 
     @GoogleBaseHook.fallback_to_default_project_id
     def list_deployments(
         self,
-        project_id: Optional[str] = None,
-        deployment_filter: Optional[str] = None,
-        order_by: Optional[str] = None,
-    ) -> List[Dict[str, Any]]:
+        project_id: str = PROVIDE_PROJECT_ID,
+        deployment_filter: str | None = None,
+        order_by: str | None = None,
+    ) -> list[dict[str, Any]]:
         """
-        Lists deployments in a google cloud project.
+        List deployments in a google cloud project.
 
         :param project_id: The project ID for this request.
         :param deployment_filter: A filter expression which limits resources returned in the response.
         :param order_by: A field name to order by, ex: "creationTimestamp desc"
-        :rtype: list
         """
-        deployments = []  # type: List[Dict]
+        deployments: list[dict] = []
         conn = self.get_conn()
 
         request = conn.deployments().list(project=project_id, filter=deployment_filter, orderBy=order_by)
@@ -81,16 +81,14 @@ class GoogleDeploymentManagerHook(GoogleBaseHook):
 
     @GoogleBaseHook.fallback_to_default_project_id
     def delete_deployment(
-        self, project_id: Optional[str], deployment: Optional[str] = None, delete_policy: Optional[str] = None
+        self, project_id: str | None, deployment: str | None = None, delete_policy: str | None = None
     ) -> None:
         """
-        Deletes a deployment and all associated resources in a google cloud project.
+        Delete a deployment and all associated resources in a google cloud project.
 
         :param project_id: The project ID for this request.
         :param deployment: The name of the deployment for this request.
         :param delete_policy: Sets the policy to use for deleting resources. (ABANDON | DELETE)
-
-        :rtype: None
         """
         conn = self.get_conn()
 
@@ -98,7 +96,7 @@ class GoogleDeploymentManagerHook(GoogleBaseHook):
             project=project_id, deployment=deployment, deletePolicy=delete_policy
         )
         resp = request.execute()
-        if 'error' in resp.keys():
+        if "error" in resp.keys():
             raise AirflowException(
-                'Errors deleting deployment: ', ', '.join(err['message'] for err in resp['error']['errors'])
+                "Errors deleting deployment: ", ", ".join(err["message"] for err in resp["error"]["errors"])
             )
