@@ -16,24 +16,32 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google ML Engine Hook."""
+
 from __future__ import annotations
 
+import contextlib
 import logging
 import random
 import time
-from typing import Callable
+from typing import TYPE_CHECKING, Callable
 
 from aiohttp import ClientSession
 from gcloud.aio.auth import AioSession, Token
 from googleapiclient.discovery import Resource, build
 from googleapiclient.errors import HttpError
-from httplib2 import Response
-from requests import Session
 
 from airflow.exceptions import AirflowException
-from airflow.providers.google.common.hooks.base_google import GoogleBaseAsyncHook, GoogleBaseHook
+from airflow.providers.google.common.hooks.base_google import (
+    PROVIDE_PROJECT_ID,
+    GoogleBaseAsyncHook,
+    GoogleBaseHook,
+)
 from airflow.version import version as airflow_version
 
+if TYPE_CHECKING:
+    from httplib2 import Response
+    from requests import Session
+
 log = logging.getLogger(__name__)
 
 _AIRFLOW_VERSION = "v" + airflow_version.replace(".", "-").replace("+", "-")
@@ -94,7 +102,7 @@ class MLEngineHook(GoogleBaseHook):
 
     def get_conn(self) -> Resource:
         """
-        Retrieves the connection to MLEngine.
+        Retrieve the connection to MLEngine.
 
         :return: Google MLEngine services object.
         """
@@ -104,7 +112,7 @@ class MLEngineHook(GoogleBaseHook):
     @GoogleBaseHook.fallback_to_default_project_id
     def create_job(self, job: dict, project_id: str, use_existing_job_fn: Callable | None = None) -> dict:
         """
-        Launches a MLEngine job and wait for it to reach a terminal state.
+        Launch a MLEngine job and wait for it to reach a terminal state.
 
         :param project_id: The Google Cloud project id within which MLEngine
             job will be launched. If set to None or missing, the default project_id from the Google Cloud
@@ -166,7 +174,7 @@ class MLEngineHook(GoogleBaseHook):
         project_id: str,
     ):
         """
-        Launches a MLEngine job and wait for it to reach a terminal state.
+        Launch a MLEngine job and wait for it to reach a terminal state.
 
         :param project_id: The Google Cloud project id within which MLEngine
             job will be launched. If set to None or missing, the default project_id from the Google Cloud
@@ -199,7 +207,7 @@ class MLEngineHook(GoogleBaseHook):
         project_id: str,
     ) -> dict:
         """
-        Cancels a MLEngine job.
+        Cancel a MLEngine job.
 
         :param project_id: The Google Cloud project id within which MLEngine
             job will be cancelled. If set to None or missing, the default project_id from the Google Cloud
@@ -228,7 +236,7 @@ class MLEngineHook(GoogleBaseHook):
 
     def get_job(self, project_id: str, job_id: str) -> dict:
         """
-        Gets a MLEngine job based on the job id.
+        Get a MLEngine job based on the job id.
 
         :param project_id: The project in which the Job is located. If set to None or missing, the default
             project_id from the Google Cloud connection is used. (templated)
@@ -252,7 +260,7 @@ class MLEngineHook(GoogleBaseHook):
 
     def _wait_for_job_done(self, project_id: str, job_id: str, interval: int = 30):
         """
-        Waits for the Job to reach a terminal state.
+        Wait for the Job to reach a terminal state.
 
         This method will periodically check the job state until the job reach
         a terminal state.
@@ -281,7 +289,7 @@ class MLEngineHook(GoogleBaseHook):
         project_id: str,
     ) -> dict:
         """
-        Creates the Version on Google Cloud ML Engine.
+        Create the Version on Google Cloud ML Engine.
 
         :param version_spec: A dictionary containing the information about the version. (templated)
         :param model_name: The name of the Google Cloud ML Engine model that the version belongs to.
@@ -317,7 +325,7 @@ class MLEngineHook(GoogleBaseHook):
         project_id: str,
     ) -> dict:
         """
-        Sets a version to be the default. Blocks until finished.
+        Set a version to be the default. Blocks until finished.
 
         :param model_name: The name of the Google Cloud ML Engine model that the version belongs to.
             (templated)
@@ -348,7 +356,7 @@ class MLEngineHook(GoogleBaseHook):
         project_id: str,
     ) -> list[dict]:
         """
-        Lists all available versions of a model. Blocks until finished.
+        List all available versions of a model. Blocks until finished.
 
         :param model_name: The name of the Google Cloud ML Engine model that the version
             belongs to. (templated)
@@ -384,7 +392,7 @@ class MLEngineHook(GoogleBaseHook):
         project_id: str,
     ) -> dict:
         """
-        Deletes the given version of a model. Blocks until finished.
+        Delete the given version of a model. Blocks until finished.
 
         :param model_name: The name of the Google Cloud ML Engine model that the version
             belongs to. (templated)
@@ -464,7 +472,7 @@ class MLEngineHook(GoogleBaseHook):
         project_id: str,
     ) -> dict | None:
         """
-        Gets a Model. Blocks until finished.
+        Get a Model. Blocks until finished.
 
         :param model_name: The name of the model.
         :param project_id: The Google Cloud project name to which MLEngine model belongs. If set to None
@@ -546,7 +554,7 @@ class MLEngineAsyncHook(GoogleBaseAsyncHook):
     def _check_fileds(
         self,
         job_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
     ):
         if not project_id:
             raise AirflowException("Google Cloud project id is required.")
@@ -559,14 +567,13 @@ class MLEngineAsyncHook(GoogleBaseAsyncHook):
             headers = {
                 "Authorization": f"Bearer {await token.get()}",
             }
-            try:
+            with contextlib.suppress(AirflowException):
+                # suppress AirflowException because we don't want to raise exception
                 job = await session_aio.get(url=url, headers=headers)
-            except AirflowException:
-                pass  # Because the job may not be visible in system yet
 
         return job
 
-    async def get_job(self, job_id: str, session: Session, project_id: str | None = None):
+    async def get_job(self, job_id: str, session: Session, project_id: str = PROVIDE_PROJECT_ID):
         """Get the specified job resource by job ID and project ID."""
         self._check_fileds(project_id=project_id, job_id=job_id)
 
@@ -576,10 +583,10 @@ class MLEngineAsyncHook(GoogleBaseAsyncHook):
     async def get_job_status(
         self,
         job_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
     ) -> str | None:
         """
-        Polls for job status asynchronously using gcloud-aio.
+        Poll for job status asynchronously using gcloud-aio.
 
         Note that an OSError is raised when Job results are still pending.
         Exception means that Job finished with errors
@@ -588,7 +595,9 @@ class MLEngineAsyncHook(GoogleBaseAsyncHook):
         async with ClientSession() as session:
             try:
                 job = await self.get_job(
-                    project_id=project_id, job_id=job_id, session=session  #  type: ignore
+                    project_id=project_id,
+                    job_id=job_id,
+                    session=session,  #  type: ignore
                 )
                 job = await job.json(content_type=None)
                 self.log.info("Retrieving json_response: %s", job)
