@@ -16,14 +16,15 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Cloud Stackdriver operators."""
+
 from __future__ import annotations
 
+import contextlib
 import json
-from typing import Any, Sequence
+from typing import TYPE_CHECKING, Any, Sequence
 
 from google.api_core.exceptions import InvalidArgument
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
-from google.api_core.retry import Retry
 from google.cloud import monitoring_v3
 from google.cloud.monitoring_v3 import AlertPolicy, NotificationChannel
 from google.protobuf.field_mask_pb2 import FieldMask
@@ -32,6 +33,9 @@ from googleapiclient.errors import HttpError
 from airflow.exceptions import AirflowException
 from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID, GoogleBaseHook
 
+if TYPE_CHECKING:
+    from google.api_core.retry import Retry
+
 
 class StackdriverHook(GoogleBaseHook):
     """Stackdriver Hook for connecting with Google Cloud Stackdriver."""
@@ -77,7 +81,7 @@ class StackdriverHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> Any:
         """
-        Fetches all the Alert Policies identified by the filter passed as filter parameter.
+        Fetch all the Alert Policies identified by the filter passed as filter parameter.
 
         The desired return type can be specified by the format parameter, the supported formats
         are "dict", "json" and None which returns python dictionary, stringified JSON and protobuf
@@ -158,7 +162,7 @@ class StackdriverHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
-        Enables one or more disabled alerting policies identified by filter parameter.
+        Enable one or more disabled alerting policies identified by filter parameter.
 
         Inoperative in case the policy is already enabled.
 
@@ -226,7 +230,7 @@ class StackdriverHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
-         Creates a new alert or updates an existing policy identified the name field in the alerts parameter.
+         Create a new alert or updates an existing policy identified the name field in the alerts parameter.
 
         :param project_id: The project in which alert needs to be created/updated.
         :param alerts: A JSON string or file that specifies all the alerts that needs
@@ -293,15 +297,13 @@ class StackdriverHook(GoogleBaseHook):
                     policy.notification_channels[i] = new_channel
 
             if policy.name in existing_policies:
-                try:
+                with contextlib.suppress(InvalidArgument):
                     policy_client.update_alert_policy(
                         request={"alert_policy": policy},
                         retry=retry,
                         timeout=timeout,
                         metadata=metadata,
                     )
-                except InvalidArgument:
-                    pass
             else:
                 policy.name = None
                 for condition in policy.conditions:
@@ -321,7 +323,7 @@ class StackdriverHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
-        Deletes an alerting policy.
+        Delete an alerting policy.
 
         :param name: The alerting policy to delete. The format is:
                          ``projects/[PROJECT_ID]/alertPolicies/[ALERT_POLICY_ID]``.
@@ -353,7 +355,7 @@ class StackdriverHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> Any:
         """
-        Fetches all the Notification Channels identified by the filter passed as filter parameter.
+        Fetch all the Notification Channels identified by the filter passed as filter parameter.
 
         The desired return type can be specified by the format parameter, the supported formats are
         "dict", "json" and None which returns python dictionary, stringified JSON and protobuf
@@ -436,7 +438,7 @@ class StackdriverHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
-        Enables one or more disabled alerting policies identified by filter parameter.
+        Enable one or more disabled alerting policies identified by filter parameter.
 
         Inoperative in case the policy is already enabled.
 
@@ -566,7 +568,7 @@ class StackdriverHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> None:
         """
-        Deletes a notification channel.
+        Delete a notification channel.
 
         :param name: The alerting policy to delete. The format is:
                          ``projects/[PROJECT_ID]/notificationChannels/[CHANNEL_ID]``.
