@@ -16,12 +16,12 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Cloud Text to Speech Hook."""
+
 from __future__ import annotations
 
-from typing import Sequence
+from typing import TYPE_CHECKING, Sequence
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
-from google.api_core.retry import Retry
 from google.cloud.texttospeech_v1 import TextToSpeechClient
 from google.cloud.texttospeech_v1.types import (
     AudioConfig,
@@ -33,6 +33,9 @@ from google.cloud.texttospeech_v1.types import (
 from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 
+if TYPE_CHECKING:
+    from google.api_core.retry import Retry
+
 
 class CloudTextToSpeechHook(GoogleBaseHook):
     """
@@ -71,12 +74,11 @@ class CloudTextToSpeechHook(GoogleBaseHook):
 
     def get_conn(self) -> TextToSpeechClient:
         """
-        Retrieves connection to Cloud Text to Speech.
+        Retrieve connection to Cloud Text to Speech.
 
         :return: Google Cloud Text to Speech client object.
         """
         if not self._client:
-
             self._client = TextToSpeechClient(credentials=self.get_credentials(), client_info=CLIENT_INFO)
 
         return self._client
