@@ -16,13 +16,12 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Cloud Video Intelligence Hook."""
+
 from __future__ import annotations
 
-from typing import Sequence
+from typing import TYPE_CHECKING, Sequence
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
-from google.api_core.operation import Operation
-from google.api_core.retry import Retry
 from google.cloud.videointelligence_v1 import (
     Feature,
     VideoContext,
@@ -32,6 +31,10 @@ from google.cloud.videointelligence_v1 import (
 from airflow.providers.google.common.consts import CLIENT_INFO
 from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 
+if TYPE_CHECKING:
+    from google.api_core.operation import Operation
+    from google.api_core.retry import Retry
+
 
 class CloudVideoIntelligenceHook(GoogleBaseHook):
     """
@@ -69,7 +72,7 @@ class CloudVideoIntelligenceHook(GoogleBaseHook):
         self._conn: VideoIntelligenceServiceClient | None = None
 
     def get_conn(self) -> VideoIntelligenceServiceClient:
-        """Returns Gcp Video Intelligence Service client."""
+        """Return Gcp Video Intelligence Service client."""
         if not self._conn:
             self._conn = VideoIntelligenceServiceClient(
                 credentials=self.get_credentials(), client_info=CLIENT_INFO
@@ -90,7 +93,7 @@ class CloudVideoIntelligenceHook(GoogleBaseHook):
         metadata: Sequence[tuple[str, str]] = (),
     ) -> Operation:
         """
-        Performs video annotation.
+        Perform video annotation.
 
         :param input_uri: Input video location. Currently, only Google Cloud Storage URIs are supported,
             which must be specified in the following format: ``gs://bucket-id/object-id``.
