@@ -16,25 +16,29 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Cloud Bigtable operators."""
+
 from __future__ import annotations
 
-import enum
 from typing import TYPE_CHECKING, Iterable, Sequence
 
 import google.api_core.exceptions
-from google.cloud.bigtable.column_family import GarbageCollectionRule
-from google.cloud.bigtable_admin_v2 import enums
 
 from airflow.exceptions import AirflowException
-from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.bigtable import BigtableHook
 from airflow.providers.google.cloud.links.bigtable import (
     BigtableClusterLink,
     BigtableInstanceLink,
     BigtableTablesLink,
 )
+from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
+from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID
 
 if TYPE_CHECKING:
+    import enum
+
+    from google.cloud.bigtable import enums
+    from google.cloud.bigtable.column_family import GarbageCollectionRule
+
     from airflow.utils.context import Context
 
 
@@ -49,12 +53,13 @@ class BigtableValidationMixin:
                 raise AirflowException(f"Empty parameter: {attr_name}")
 
 
-class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
+class BigtableCreateInstanceOperator(GoogleCloudBaseOperator, BigtableValidationMixin):
     """
     Creates a new Cloud Bigtable instance.
+
     If the Cloud Bigtable instance with the given ID exists, the operator does not
-    compare its configuration
-    and immediately succeeds. No changes are made to the existing instance.
+    compare its configuration and immediately succeeds. No changes are made to the
+    existing instance.
 
     For more details about instance creation have a look at the reference:
     https://googleapis.github.io/google-cloud-python/latest/bigtable/instance.html#google.cloud.bigtable.instance.Instance.create
@@ -108,7 +113,7 @@ class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
         instance_id: str,
         main_cluster_id: str,
         main_cluster_zone: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         replica_clusters: list[dict[str, str]] | None = None,
         instance_display_name: str | None = None,
         instance_type: enums.Instance.Type | None = None,
@@ -171,7 +176,7 @@ class BigtableCreateInstanceOperator(BaseOperator, BigtableValidationMixin):
             raise e
 
 
-class BigtableUpdateInstanceOperator(BaseOperator, BigtableValidationMixin):
+class BigtableUpdateInstanceOperator(GoogleCloudBaseOperator, BigtableValidationMixin):
     """
     Updates an existing Cloud Bigtable instance.
 
@@ -214,7 +219,7 @@ class BigtableUpdateInstanceOperator(BaseOperator, BigtableValidationMixin):
         self,
         *,
         instance_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         instance_display_name: str | None = None,
         instance_type: enums.Instance.Type | enum.IntEnum | None = None,
         instance_labels: dict | None = None,
@@ -258,7 +263,7 @@ class BigtableUpdateInstanceOperator(BaseOperator, BigtableValidationMixin):
             raise e
 
 
-class BigtableDeleteInstanceOperator(BaseOperator, BigtableValidationMixin):
+class BigtableDeleteInstanceOperator(GoogleCloudBaseOperator, BigtableValidationMixin):
     """
     Deletes the Cloud Bigtable instance, including its clusters and all related tables.
 
@@ -294,7 +299,7 @@ class BigtableDeleteInstanceOperator(BaseOperator, BigtableValidationMixin):
         self,
         *,
         instance_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -324,7 +329,7 @@ class BigtableDeleteInstanceOperator(BaseOperator, BigtableValidationMixin):
             raise e
 
 
-class BigtableCreateTableOperator(BaseOperator, BigtableValidationMixin):
+class BigtableCreateTableOperator(GoogleCloudBaseOperator, BigtableValidationMixin):
     """
     Creates the table in the Cloud Bigtable instance.
 
@@ -370,7 +375,7 @@ class BigtableCreateTableOperator(BaseOperator, BigtableValidationMixin):
         *,
         instance_id: str,
         table_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         initial_split_keys: list | None = None,
         column_families: dict[str, GarbageCollectionRule] | None = None,
         gcp_conn_id: str = "google_cloud_default",
@@ -434,7 +439,7 @@ class BigtableCreateTableOperator(BaseOperator, BigtableValidationMixin):
             self.log.info("The table '%s' already exists. Consider it as created", self.table_id)
 
 
-class BigtableDeleteTableOperator(BaseOperator, BigtableValidationMixin):
+class BigtableDeleteTableOperator(GoogleCloudBaseOperator, BigtableValidationMixin):
     """
     Deletes the Cloud Bigtable table.
 
@@ -474,7 +479,7 @@ class BigtableDeleteTableOperator(BaseOperator, BigtableValidationMixin):
         *,
         instance_id: str,
         table_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         app_profile_id: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
@@ -512,7 +517,7 @@ class BigtableDeleteTableOperator(BaseOperator, BigtableValidationMixin):
             raise e
 
 
-class BigtableUpdateClusterOperator(BaseOperator, BigtableValidationMixin):
+class BigtableUpdateClusterOperator(GoogleCloudBaseOperator, BigtableValidationMixin):
     """
     Updates a Cloud Bigtable cluster.
 
@@ -555,7 +560,7 @@ class BigtableUpdateClusterOperator(BaseOperator, BigtableValidationMixin):
         instance_id: str,
         cluster_id: str,
         nodes: int,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
