@@ -16,13 +16,13 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Compute Engine operators."""
+
 from __future__ import annotations
 
 from copy import deepcopy
 from typing import TYPE_CHECKING, Any, Sequence
 
 from google.api_core import exceptions
-from google.api_core.retry import Retry
 from google.cloud.compute_v1.types import Instance, InstanceGroupManager, InstanceTemplate
 from json_merge_patch import merge
 
@@ -36,8 +36,11 @@ from airflow.providers.google.cloud.links.compute import (
 from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
 from airflow.providers.google.cloud.utils.field_sanitizer import GcpBodyFieldSanitizer
 from airflow.providers.google.cloud.utils.field_validator import GcpBodyFieldValidator
+from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID
 
 if TYPE_CHECKING:
+    from google.api_core.retry import Retry
+
     from airflow.utils.context import Context
 
 
@@ -48,8 +51,8 @@ class ComputeEngineBaseOperator(GoogleCloudBaseOperator):
         self,
         *,
         zone: str,
-        resource_id: str,
-        project_id: str | None = None,
+        resource_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         gcp_conn_id: str = "google_cloud_default",
         api_version: str = "v1",
         impersonation_chain: str | Sequence[str] | None = None,
@@ -126,6 +129,7 @@ class ComputeEngineInsertInstanceOperator(ComputeEngineBaseOperator):
         "gcp_conn_id",
         "api_version",
         "impersonation_chain",
+        "resource_id",
     )
     # [END gce_instance_insert_fields]
 
@@ -135,7 +139,7 @@ class ComputeEngineInsertInstanceOperator(ComputeEngineBaseOperator):
         body: dict,
         zone: str,
         resource_id: str | None = None,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         request_id: str | None = None,
         retry: Retry | None = None,
         timeout: float | None = None,
@@ -149,7 +153,8 @@ class ComputeEngineInsertInstanceOperator(ComputeEngineBaseOperator):
         self.body = body
         self.zone = zone
         self.request_id = request_id
-        self.resource_id = self.body["name"] if "name" in body else resource_id
+        if "name" in body:
+            resource_id = self.body["name"]
         self._field_validator = None  # Optional[GcpBodyFieldValidator]
         self.retry = retry
         self.timeout = timeout
@@ -161,7 +166,7 @@ class ComputeEngineInsertInstanceOperator(ComputeEngineBaseOperator):
             )
         self._field_sanitizer = GcpBodyFieldSanitizer(GCE_INSTANCE_FIELDS_TO_SANITIZE)
         super().__init__(
-            resource_id=self.resource_id,
+            resource_id=resource_id,
             zone=zone,
             project_id=project_id,
             gcp_conn_id=gcp_conn_id,
@@ -173,14 +178,13 @@ class ComputeEngineInsertInstanceOperator(ComputeEngineBaseOperator):
     def check_body_fields(self) -> None:
         required_params = ["machine_type", "disks", "network_interfaces"]
         for param in required_params:
-            if param in self.body:
-                continue
-            readable_param = param.replace("_", " ")
-            raise AirflowException(
-                f"The body '{self.body}' should contain at least {readable_param} for the new operator "
-                f"in the '{param}' field. Check (google.cloud.compute_v1.types.Instance) "
-                f"for more details about body fields description."
-            )
+            if param not in self.body:
+                readable_param = param.replace("_", " ")
+                raise AirflowException(
+                    f"The body '{self.body}' should contain at least {readable_param} for the new operator "
+                    f"in the '{param}' field. Check (google.cloud.compute_v1.types.Instance) "
+                    f"for more details about body fields description."
+                )
 
     def _validate_inputs(self) -> None:
         super()._validate_inputs()
@@ -214,7 +218,7 @@ class ComputeEngineInsertInstanceOperator(ComputeEngineBaseOperator):
             )
         except exceptions.NotFound as e:
             # We actually expect to get 404 / Not Found here as the should not yet exist
-            if not e.code == 404:
+            if e.code != 404:
                 raise e
         else:
             self.log.info("The %s Instance already exists", self.resource_id)
@@ -306,6 +310,7 @@ class ComputeEngineInsertInstanceFromTemplateOperator(ComputeEngineBaseOperator)
         "gcp_conn_id",
         "api_version",
         "impersonation_chain",
+        "resource_id",
     )
     # [END gce_instance_insert_from_template_fields]
 
@@ -316,7 +321,7 @@ class ComputeEngineInsertInstanceFromTemplateOperator(ComputeEngineBaseOperator)
         body: dict,
         zone: str,
         resource_id: str | None = None,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         request_id: str | None = None,
         retry: Retry | None = None,
         timeout: float | None = None,
@@ -330,7 +335,8 @@ class ComputeEngineInsertInstanceFromTemplateOperator(ComputeEngineBaseOperator)
         self.source_instance_template = source_instance_template
         self.body = body
         self.zone = zone
-        self.resource_id = self.body["name"] if "name" in body else resource_id
+        if "name" in body:
+            resource_id = self.body["name"]
         self.request_id = request_id
         self._field_validator = None  # Optional[GcpBodyFieldValidator]
         self.retry = retry
@@ -343,7 +349,7 @@ class ComputeEngineInsertInstanceFromTemplateOperator(ComputeEngineBaseOperator)
             )
         self._field_sanitizer = GcpBodyFieldSanitizer(GCE_INSTANCE_FIELDS_TO_SANITIZE)
         super().__init__(
-            resource_id=self.resource_id,
+            resource_id=resource_id,
             zone=zone,
             project_id=project_id,
             gcp_conn_id=gcp_conn_id,
@@ -384,7 +390,7 @@ class ComputeEngineInsertInstanceFromTemplateOperator(ComputeEngineBaseOperator)
         except exceptions.NotFound as e:
             # We actually expect to get 404 / Not Found here as the template should
             # not yet exist
-            if not e.code == 404:
+            if e.code != 404:
                 raise e
         else:
             self.log.info("The %s Instance already exists", self.resource_id)
@@ -472,7 +478,7 @@ class ComputeEngineDeleteInstanceOperator(ComputeEngineBaseOperator):
         resource_id: str,
         zone: str,
         request_id: str | None = None,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | None = None,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -661,14 +667,13 @@ class ComputeEngineStopInstanceOperator(ComputeEngineBaseOperator):
 
 
 SET_MACHINE_TYPE_VALIDATION_SPECIFICATION = [
-    dict(name="machineType", regexp="^.+$"),
+    {"name": "machineType", "regexp": "^.+$"},
 ]
 
 
 class ComputeEngineSetMachineTypeOperator(ComputeEngineBaseOperator):
     """
-    Changes the machine type for a stopped instance to the machine type specified in
-        the request.
+    Changes the machine type for a stopped instance to the machine type specified in the request.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -717,7 +722,7 @@ class ComputeEngineSetMachineTypeOperator(ComputeEngineBaseOperator):
         zone: str,
         resource_id: str,
         body: dict,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         gcp_conn_id: str = "google_cloud_default",
         api_version: str = "v1",
         validate_body: bool = True,
@@ -769,44 +774,44 @@ class ComputeEngineSetMachineTypeOperator(ComputeEngineBaseOperator):
 
 
 GCE_INSTANCE_TEMPLATE_VALIDATION_PATCH_SPECIFICATION: list[dict[str, Any]] = [
-    dict(name="name", regexp="^.+$"),
-    dict(name="description", optional=True),
-    dict(
-        name="properties",
-        type="dict",
-        optional=True,
-        fields=[
-            dict(name="description", optional=True),
-            dict(name="tags", optional=True, fields=[dict(name="items", optional=True)]),
-            dict(name="machineType", optional=True),
-            dict(name="canIpForward", optional=True),
-            dict(name="networkInterfaces", optional=True),  # not validating deeper
-            dict(name="disks", optional=True),  # not validating the array deeper
-            dict(
-                name="metadata",
-                optional=True,
-                fields=[
-                    dict(name="fingerprint", optional=True),
-                    dict(name="items", optional=True),
-                    dict(name="kind", optional=True),
+    {"name": "name", "regexp": "^.+$"},
+    {"name": "description", "optional": True},
+    {
+        "name": "properties",
+        "type": "dict",
+        "optional": True,
+        "fields": [
+            {"name": "description", "optional": True},
+            {"name": "tags", "optional": True, "fields": [{"name": "items", "optional": True}]},
+            {"name": "machineType", "optional": True},
+            {"name": "canIpForward", "optional": True},
+            {"name": "networkInterfaces", "optional": True},  # not validating deeper
+            {"name": "disks", "optional": True},  # not validating the array deeper
+            {
+                "name": "metadata",
+                "optional": True,
+                "fields": [
+                    {"name": "fingerprint", "optional": True},
+                    {"name": "items", "optional": True},
+                    {"name": "kind", "optional": True},
                 ],
-            ),
-            dict(name="serviceAccounts", optional=True),  # not validating deeper
-            dict(
-                name="scheduling",
-                optional=True,
-                fields=[
-                    dict(name="onHostMaintenance", optional=True),
-                    dict(name="automaticRestart", optional=True),
-                    dict(name="preemptible", optional=True),
-                    dict(name="nodeAffinities", optional=True),  # not validating deeper
+            },
+            {"name": "serviceAccounts", "optional": True},  # not validating deeper
+            {
+                "name": "scheduling",
+                "optional": True,
+                "fields": [
+                    {"name": "onHostMaintenance", "optional": True},
+                    {"name": "automaticRestart", "optional": True},
+                    {"name": "preemptible", "optional": True},
+                    {"name": "nodeAffinities", "optional": True},  # not validating deeper
                 ],
-            ),
-            dict(name="labels", optional=True),
-            dict(name="guestAccelerators", optional=True),  # not validating deeper
-            dict(name="minCpuPlatform", optional=True),
+            },
+            {"name": "labels", "optional": True},
+            {"name": "guestAccelerators", "optional": True},  # not validating deeper
+            {"name": "minCpuPlatform", "optional": True},
         ],
-    ),
+    },
 ]
 
 GCE_INSTANCE_FIELDS_TO_SANITIZE = [
@@ -870,6 +875,7 @@ class ComputeEngineInsertInstanceTemplateOperator(ComputeEngineBaseOperator):
         "gcp_conn_id",
         "api_version",
         "impersonation_chain",
+        "resource_id",
     )
     # [END gce_instance_template_insert_fields]
 
@@ -877,7 +883,7 @@ class ComputeEngineInsertInstanceTemplateOperator(ComputeEngineBaseOperator):
         self,
         *,
         body: dict,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         resource_id: str | None = None,
         request_id: str | None = None,
         retry: Retry | None = None,
@@ -891,7 +897,8 @@ class ComputeEngineInsertInstanceTemplateOperator(ComputeEngineBaseOperator):
     ) -> None:
         self.body = body
         self.request_id = request_id
-        self.resource_id = self.body["name"] if "name" in body else resource_id
+        if "name" in body:
+            resource_id = self.body["name"]
         self._field_validator = None  # Optional[GcpBodyFieldValidator]
         self.retry = retry
         self.timeout = timeout
@@ -905,7 +912,7 @@ class ComputeEngineInsertInstanceTemplateOperator(ComputeEngineBaseOperator):
         super().__init__(
             project_id=project_id,
             zone="global",
-            resource_id=self.resource_id,
+            resource_id=resource_id,
             gcp_conn_id=gcp_conn_id,
             api_version=api_version,
             impersonation_chain=impersonation_chain,
@@ -915,14 +922,13 @@ class ComputeEngineInsertInstanceTemplateOperator(ComputeEngineBaseOperator):
     def check_body_fields(self) -> None:
         required_params = ["machine_type", "disks", "network_interfaces"]
         for param in required_params:
-            if param in self.body["properties"]:
-                continue
-            readable_param = param.replace("_", " ")
-            raise AirflowException(
-                f"The body '{self.body}' should contain at least {readable_param} for the new operator "
-                f"in the '{param}' field. Check (google.cloud.compute_v1.types.Instance) "
-                f"for more details about body fields description."
-            )
+            if param not in self.body["properties"]:
+                readable_param = param.replace("_", " ")
+                raise AirflowException(
+                    f"The body '{self.body}' should contain at least {readable_param} for the new operator "
+                    f"in the '{param}' field. Check (google.cloud.compute_v1.types.Instance) "
+                    f"for more details about body fields description."
+                )
 
     def _validate_all_body_fields(self) -> None:
         if self._field_validator:
@@ -959,7 +965,7 @@ class ComputeEngineInsertInstanceTemplateOperator(ComputeEngineBaseOperator):
         except exceptions.NotFound as e:
             # We actually expect to get 404 / Not Found here as the template should
             # not yet exist
-            if not e.code == 404:
+            if e.code != 404:
                 raise e
         else:
             self.log.info("The %s Template already exists.", existing_template)
@@ -1039,7 +1045,7 @@ class ComputeEngineDeleteInstanceTemplateOperator(ComputeEngineBaseOperator):
         *,
         resource_id: str,
         request_id: str | None = None,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | None = None,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -1159,7 +1165,7 @@ class ComputeEngineCopyInstanceTemplateOperator(ComputeEngineBaseOperator):
         *,
         resource_id: str,
         body_patch: dict,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         request_id: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
         api_version: str = "v1",
@@ -1221,7 +1227,7 @@ class ComputeEngineCopyInstanceTemplateOperator(ComputeEngineBaseOperator):
         except exceptions.NotFound as e:
             # We actually expect to get 404 / Not Found here as the template should
             # not yet exist
-            if not e.code == 404:
+            if e.code != 404:
                 raise e
         else:
             self.log.info(
@@ -1261,9 +1267,10 @@ class ComputeEngineCopyInstanceTemplateOperator(ComputeEngineBaseOperator):
 
 class ComputeEngineInstanceGroupUpdateManagerTemplateOperator(ComputeEngineBaseOperator):
     """
-    Patches the Instance Group Manager, replacing source template URL with the
-    destination one. API V1 does not have update/patch operations for Instance
-    Group Manager, so you must use beta or newer API version. Beta is the default.
+    Patches the Instance Group Manager, replacing source template URL with the destination one.
+
+    API V1 does not have update/patch operations for Instance Group Manager,
+    so you must use beta or newer API version. Beta is the default.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -1317,7 +1324,7 @@ class ComputeEngineInstanceGroupUpdateManagerTemplateOperator(ComputeEngineBaseO
         zone: str,
         source_template: str,
         destination_template: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         update_policy: dict[str, Any] | None = None,
         request_id: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
@@ -1339,7 +1346,7 @@ class ComputeEngineInstanceGroupUpdateManagerTemplateOperator(ComputeEngineBaseO
             )
         super().__init__(
             project_id=project_id,
-            zone=self.zone,
+            zone=zone,
             resource_id=resource_id,
             gcp_conn_id=gcp_conn_id,
             api_version=api_version,
@@ -1409,6 +1416,7 @@ class ComputeEngineInstanceGroupUpdateManagerTemplateOperator(ComputeEngineBaseO
 class ComputeEngineInsertInstanceGroupManagerOperator(ComputeEngineBaseOperator):
     """
     Creates an Instance Group Managers using the body specified.
+
     After the group is created, instances in the group are created using the specified Instance Template.
 
     .. seealso::
@@ -1452,6 +1460,7 @@ class ComputeEngineInsertInstanceGroupManagerOperator(ComputeEngineBaseOperator)
         "gcp_conn_id",
         "api_version",
         "impersonation_chain",
+        "resource_id",
     )
     # [END gce_igm_insert_fields]
 
@@ -1460,7 +1469,7 @@ class ComputeEngineInsertInstanceGroupManagerOperator(ComputeEngineBaseOperator)
         *,
         body: dict,
         zone: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         resource_id: str | None = None,
         request_id: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
@@ -1473,9 +1482,9 @@ class ComputeEngineInsertInstanceGroupManagerOperator(ComputeEngineBaseOperator)
         **kwargs,
     ) -> None:
         self.body = body
-        self.zone = zone
         self.request_id = request_id
-        self.resource_id = self.body["name"] if "name" in body else resource_id
+        if "name" in body:
+            resource_id = self.body["name"]
         self._field_validator = None  # Optional[GcpBodyFieldValidator]
         self.retry = retry
         self.timeout = timeout
@@ -1488,7 +1497,7 @@ class ComputeEngineInsertInstanceGroupManagerOperator(ComputeEngineBaseOperator)
         super().__init__(
             project_id=project_id,
             zone=zone,
-            resource_id=self.resource_id,
+            resource_id=resource_id,
             gcp_conn_id=gcp_conn_id,
             api_version=api_version,
             impersonation_chain=impersonation_chain,
@@ -1498,14 +1507,13 @@ class ComputeEngineInsertInstanceGroupManagerOperator(ComputeEngineBaseOperator)
     def check_body_fields(self) -> None:
         required_params = ["base_instance_name", "target_size", "instance_template"]
         for param in required_params:
-            if param in self.body:
-                continue
-            readable_param = param.replace("_", " ")
-            raise AirflowException(
-                f"The body '{self.body}' should contain at least {readable_param} for the new operator "
-                f"in the '{param}' field. Check (google.cloud.compute_v1.types.Instance) "
-                f"for more details about body fields description."
-            )
+            if param not in self.body:
+                readable_param = param.replace("_", " ")
+                raise AirflowException(
+                    f"The body '{self.body}' should contain at least {readable_param} for the new operator "
+                    f"in the '{param}' field. Check (google.cloud.compute_v1.types.Instance) "
+                    f"for more details about body fields description."
+                )
 
     def _validate_all_body_fields(self) -> None:
         if self._field_validator:
@@ -1538,7 +1546,7 @@ class ComputeEngineInsertInstanceGroupManagerOperator(ComputeEngineBaseOperator)
         except exceptions.NotFound as e:
             # We actually expect to get 404 / Not Found here as the Instance Group Manager should
             # not yet exist
-            if not e.code == 404:
+            if e.code != 404:
                 raise e
         else:
             self.log.info("The %s Instance Group Manager already exists", existing_instance_group_manager)
@@ -1576,8 +1584,7 @@ class ComputeEngineInsertInstanceGroupManagerOperator(ComputeEngineBaseOperator)
 
 class ComputeEngineDeleteInstanceGroupManagerOperator(ComputeEngineBaseOperator):
     """
-    Deletes an Instance Group Managers.
-    Deleting an Instance Group Manager is permanent and cannot be undone.
+    Permanently and irrevocably deletes an Instance Group Managers.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -1624,7 +1631,7 @@ class ComputeEngineDeleteInstanceGroupManagerOperator(ComputeEngineBaseOperator)
         *,
         resource_id: str,
         zone: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         request_id: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
         api_version="v1",
