@@ -20,7 +20,6 @@ from typing import TYPE_CHECKING, Sequence
 
 from google.api_core.exceptions import AlreadyExists, NotFound
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
-from google.api_core.retry import Retry
 from google.cloud.datacatalog import (
     DataCatalogClient,
     Entry,
@@ -31,21 +30,24 @@ from google.cloud.datacatalog import (
     TagTemplate,
     TagTemplateField,
 )
-from google.protobuf.field_mask_pb2 import FieldMask
 
-from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.datacatalog import CloudDataCatalogHook
 from airflow.providers.google.cloud.links.datacatalog import (
     DataCatalogEntryGroupLink,
     DataCatalogEntryLink,
     DataCatalogTagTemplateLink,
 )
+from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
+from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID
 
 if TYPE_CHECKING:
+    from google.api_core.retry import Retry
+    from google.protobuf.field_mask_pb2 import FieldMask
+
     from airflow.utils.context import Context
 
 
-class CloudDataCatalogCreateEntryOperator(BaseOperator):
+class CloudDataCatalogCreateEntryOperator(GoogleCloudBaseOperator):
     """
     Creates an entry.
 
@@ -103,7 +105,7 @@ class CloudDataCatalogCreateEntryOperator(BaseOperator):
         entry_group: str,
         entry_id: str,
         entry: dict | Entry,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -163,7 +165,7 @@ class CloudDataCatalogCreateEntryOperator(BaseOperator):
         return Entry.to_dict(result)
 
 
-class CloudDataCatalogCreateEntryGroupOperator(BaseOperator):
+class CloudDataCatalogCreateEntryGroupOperator(GoogleCloudBaseOperator):
     """
     Creates an EntryGroup.
 
@@ -219,7 +221,7 @@ class CloudDataCatalogCreateEntryGroupOperator(BaseOperator):
         location: str,
         entry_group_id: str,
         entry_group: dict | EntryGroup,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -276,7 +278,7 @@ class CloudDataCatalogCreateEntryGroupOperator(BaseOperator):
         return EntryGroup.to_dict(result)
 
 
-class CloudDataCatalogCreateTagOperator(BaseOperator):
+class CloudDataCatalogCreateTagOperator(GoogleCloudBaseOperator):
     """
     Creates a tag on an entry.
 
@@ -335,7 +337,7 @@ class CloudDataCatalogCreateTagOperator(BaseOperator):
         entry: str,
         tag: dict | Tag,
         template_id: str | None = None,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -412,7 +414,7 @@ class CloudDataCatalogCreateTagOperator(BaseOperator):
         return Tag.to_dict(tag)
 
 
-class CloudDataCatalogCreateTagTemplateOperator(BaseOperator):
+class CloudDataCatalogCreateTagTemplateOperator(GoogleCloudBaseOperator):
     """
     Creates a tag template.
 
@@ -466,7 +468,7 @@ class CloudDataCatalogCreateTagTemplateOperator(BaseOperator):
         location: str,
         tag_template_id: str,
         tag_template: dict | TagTemplate,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -522,7 +524,7 @@ class CloudDataCatalogCreateTagTemplateOperator(BaseOperator):
         return TagTemplate.to_dict(result)
 
 
-class CloudDataCatalogCreateTagTemplateFieldOperator(BaseOperator):
+class CloudDataCatalogCreateTagTemplateFieldOperator(GoogleCloudBaseOperator):
     r"""
     Creates a field in a tag template.
 
@@ -582,7 +584,7 @@ class CloudDataCatalogCreateTagTemplateFieldOperator(BaseOperator):
         tag_template: str,
         tag_template_field_id: str,
         tag_template_field: dict | TagTemplateField,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -641,7 +643,7 @@ class CloudDataCatalogCreateTagTemplateFieldOperator(BaseOperator):
         return TagTemplateField.to_dict(result)
 
 
-class CloudDataCatalogDeleteEntryOperator(BaseOperator):
+class CloudDataCatalogDeleteEntryOperator(GoogleCloudBaseOperator):
     """
     Deletes an existing entry.
 
@@ -689,7 +691,7 @@ class CloudDataCatalogDeleteEntryOperator(BaseOperator):
         location: str,
         entry_group: str,
         entry: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -726,7 +728,7 @@ class CloudDataCatalogDeleteEntryOperator(BaseOperator):
             self.log.info("Entry doesn't exists. Skipping.")
 
 
-class CloudDataCatalogDeleteEntryGroupOperator(BaseOperator):
+class CloudDataCatalogDeleteEntryGroupOperator(GoogleCloudBaseOperator):
     """
     Deletes an EntryGroup.
 
@@ -773,7 +775,7 @@ class CloudDataCatalogDeleteEntryGroupOperator(BaseOperator):
         *,
         location: str,
         entry_group: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -808,7 +810,7 @@ class CloudDataCatalogDeleteEntryGroupOperator(BaseOperator):
             self.log.info("Entry doesn't exists. skipping")
 
 
-class CloudDataCatalogDeleteTagOperator(BaseOperator):
+class CloudDataCatalogDeleteTagOperator(GoogleCloudBaseOperator):
     """
     Deletes a tag.
 
@@ -859,7 +861,7 @@ class CloudDataCatalogDeleteTagOperator(BaseOperator):
         entry_group: str,
         entry: str,
         tag: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -898,7 +900,7 @@ class CloudDataCatalogDeleteTagOperator(BaseOperator):
             self.log.info("Entry doesn't exists. skipping")
 
 
-class CloudDataCatalogDeleteTagTemplateOperator(BaseOperator):
+class CloudDataCatalogDeleteTagTemplateOperator(GoogleCloudBaseOperator):
     """
     Deletes a tag template and all tags using the template.
 
@@ -948,7 +950,7 @@ class CloudDataCatalogDeleteTagTemplateOperator(BaseOperator):
         location: str,
         tag_template: str,
         force: bool,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -985,7 +987,7 @@ class CloudDataCatalogDeleteTagTemplateOperator(BaseOperator):
             self.log.info("Tag Template doesn't exists. skipping")
 
 
-class CloudDataCatalogDeleteTagTemplateFieldOperator(BaseOperator):
+class CloudDataCatalogDeleteTagTemplateFieldOperator(GoogleCloudBaseOperator):
     """
     Deletes a field in a tag template and all uses of that field.
 
@@ -1036,7 +1038,7 @@ class CloudDataCatalogDeleteTagTemplateFieldOperator(BaseOperator):
         tag_template: str,
         field: str,
         force: bool,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -1075,7 +1077,7 @@ class CloudDataCatalogDeleteTagTemplateFieldOperator(BaseOperator):
             self.log.info("Tag Template field doesn't exists. skipping")
 
 
-class CloudDataCatalogGetEntryOperator(BaseOperator):
+class CloudDataCatalogGetEntryOperator(GoogleCloudBaseOperator):
     """
     Gets an entry.
 
@@ -1124,7 +1126,7 @@ class CloudDataCatalogGetEntryOperator(BaseOperator):
         location: str,
         entry_group: str,
         entry: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -1167,7 +1169,7 @@ class CloudDataCatalogGetEntryOperator(BaseOperator):
         return Entry.to_dict(result)
 
 
-class CloudDataCatalogGetEntryGroupOperator(BaseOperator):
+class CloudDataCatalogGetEntryGroupOperator(GoogleCloudBaseOperator):
     """
     Gets an entry group.
 
@@ -1219,7 +1221,7 @@ class CloudDataCatalogGetEntryGroupOperator(BaseOperator):
         location: str,
         entry_group: str,
         read_mask: FieldMask,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -1261,7 +1263,7 @@ class CloudDataCatalogGetEntryGroupOperator(BaseOperator):
         return EntryGroup.to_dict(result)
 
 
-class CloudDataCatalogGetTagTemplateOperator(BaseOperator):
+class CloudDataCatalogGetTagTemplateOperator(GoogleCloudBaseOperator):
     """
     Gets a tag template.
 
@@ -1307,7 +1309,7 @@ class CloudDataCatalogGetTagTemplateOperator(BaseOperator):
         *,
         location: str,
         tag_template: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -1347,7 +1349,7 @@ class CloudDataCatalogGetTagTemplateOperator(BaseOperator):
         return TagTemplate.to_dict(result)
 
 
-class CloudDataCatalogListTagsOperator(BaseOperator):
+class CloudDataCatalogListTagsOperator(GoogleCloudBaseOperator):
     """
     Lists the tags on an Entry.
 
@@ -1402,7 +1404,7 @@ class CloudDataCatalogListTagsOperator(BaseOperator):
         entry_group: str,
         entry: str,
         page_size: int = 100,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -1447,7 +1449,7 @@ class CloudDataCatalogListTagsOperator(BaseOperator):
         return [Tag.to_dict(item) for item in result]
 
 
-class CloudDataCatalogLookupEntryOperator(BaseOperator):
+class CloudDataCatalogLookupEntryOperator(GoogleCloudBaseOperator):
     r"""
     Get an entry by target resource name.
 
@@ -1496,7 +1498,7 @@ class CloudDataCatalogLookupEntryOperator(BaseOperator):
         *,
         linked_resource: str | None = None,
         sql_resource: str | None = None,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -1538,7 +1540,7 @@ class CloudDataCatalogLookupEntryOperator(BaseOperator):
         return Entry.to_dict(result)
 
 
-class CloudDataCatalogRenameTagTemplateFieldOperator(BaseOperator):
+class CloudDataCatalogRenameTagTemplateFieldOperator(GoogleCloudBaseOperator):
     """
     Renames a field in a tag template.
 
@@ -1592,7 +1594,7 @@ class CloudDataCatalogRenameTagTemplateFieldOperator(BaseOperator):
         tag_template: str,
         field: str,
         new_tag_template_field_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -1635,7 +1637,7 @@ class CloudDataCatalogRenameTagTemplateFieldOperator(BaseOperator):
         )
 
 
-class CloudDataCatalogSearchCatalogOperator(BaseOperator):
+class CloudDataCatalogSearchCatalogOperator(GoogleCloudBaseOperator):
     r"""
     Searches Data Catalog for multiple resources like entries, tags that match a query.
 
@@ -1745,7 +1747,7 @@ class CloudDataCatalogSearchCatalogOperator(BaseOperator):
         return [SearchCatalogResult.to_dict(item) for item in result]
 
 
-class CloudDataCatalogUpdateEntryOperator(BaseOperator):
+class CloudDataCatalogUpdateEntryOperator(GoogleCloudBaseOperator):
     """
     Updates an existing entry.
 
@@ -1807,7 +1809,7 @@ class CloudDataCatalogUpdateEntryOperator(BaseOperator):
         location: str | None = None,
         entry_group: str | None = None,
         entry_id: str | None = None,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -1855,7 +1857,7 @@ class CloudDataCatalogUpdateEntryOperator(BaseOperator):
         )
 
 
-class CloudDataCatalogUpdateTagOperator(BaseOperator):
+class CloudDataCatalogUpdateTagOperator(GoogleCloudBaseOperator):
     """
     Updates an existing tag.
 
@@ -1919,7 +1921,7 @@ class CloudDataCatalogUpdateTagOperator(BaseOperator):
         entry_group: str | None = None,
         entry: str | None = None,
         tag_id: str | None = None,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -1969,7 +1971,7 @@ class CloudDataCatalogUpdateTagOperator(BaseOperator):
         )
 
 
-class CloudDataCatalogUpdateTagTemplateOperator(BaseOperator):
+class CloudDataCatalogUpdateTagTemplateOperator(GoogleCloudBaseOperator):
     """
     Updates a tag template.
 
@@ -2033,7 +2035,7 @@ class CloudDataCatalogUpdateTagTemplateOperator(BaseOperator):
         update_mask: dict | FieldMask,
         location: str | None = None,
         tag_template_id: str | None = None,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
@@ -2078,7 +2080,7 @@ class CloudDataCatalogUpdateTagTemplateOperator(BaseOperator):
         )
 
 
-class CloudDataCatalogUpdateTagTemplateFieldOperator(BaseOperator):
+class CloudDataCatalogUpdateTagTemplateFieldOperator(GoogleCloudBaseOperator):
     """
     Updates a field in a tag template. This method cannot be used to update the field type.
 
@@ -2150,7 +2152,7 @@ class CloudDataCatalogUpdateTagTemplateFieldOperator(BaseOperator):
         location: str | None = None,
         tag_template: str | None = None,
         tag_template_field_id: str | None = None,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
