@@ -15,119 +15,57 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google DataFusion operators."""
+
 from __future__ import annotations
 
-from time import sleep
+import time
 from typing import TYPE_CHECKING, Any, Sequence
 
+from deprecated import deprecated
 from google.api_core.retry import exponential_sleep_generator
 from googleapiclient.errors import HttpError
 
-from airflow.models import BaseOperator
+from airflow.configuration import conf
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.providers.google.cloud.hooks.datafusion import SUCCESS_STATES, DataFusionHook, PipelineStates
-from airflow.providers.google.cloud.links.base import BaseGoogleLink
+from airflow.providers.google.cloud.links.datafusion import (
+    DataFusionInstanceLink,
+    DataFusionPipelineLink,
+    DataFusionPipelinesLink,
+)
+from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
+from airflow.providers.google.cloud.triggers.datafusion import DataFusionStartPipelineTrigger
+from airflow.providers.google.cloud.utils.datafusion import DataFusionPipelineType
+from airflow.providers.google.cloud.utils.helpers import resource_path_to_dict
+from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
 
 
-BASE_LINK = "https://console.cloud.google.com/data-fusion"
-DATAFUSION_INSTANCE_LINK = BASE_LINK + "/locations/{region}/instances/{instance_name}?project={project_id}"
-DATAFUSION_PIPELINES_LINK = "{uri}/cdap/ns/default/pipelines"
-DATAFUSION_PIPELINE_LINK = "{uri}/pipelines/ns/default/view/{pipeline_name}"
-
-
 class DataFusionPipelineLinkHelper:
-    """Helper class for Pipeline links"""
+    """
+    Helper class for Pipeline links.
+
+    .. warning::
+        This class is deprecated. Consider using ``resource_path_to_dict()`` instead.
+    """
 
     @staticmethod
+    @deprecated(
+        reason="Please use `airflow.providers.google.cloud.utils.helpers.resource_path_to_dict` instead.",
+        category=AirflowProviderDeprecationWarning,
+    )
     def get_project_id(instance):
         instance = instance["name"]
-        project_id = [x for x in instance.split("/") if x.startswith("airflow")][0]
+        project_id = next(x for x in instance.split("/") if x.startswith("airflow"))
         return project_id
 
 
-class DataFusionInstanceLink(BaseGoogleLink):
-    """Helper class for constructing Data Fusion Instance link"""
-
-    name = "Data Fusion Instance"
-    key = "instance_conf"
-    format_str = DATAFUSION_INSTANCE_LINK
-
-    @staticmethod
-    def persist(
-        context: Context,
-        task_instance: (
-            CloudDataFusionRestartInstanceOperator
-            | CloudDataFusionCreateInstanceOperator
-            | CloudDataFusionUpdateInstanceOperator
-            | CloudDataFusionGetInstanceOperator
-        ),
-        project_id: str,
-    ):
-        task_instance.xcom_push(
-            context=context,
-            key=DataFusionInstanceLink.key,
-            value={
-                "region": task_instance.location,
-                "instance_name": task_instance.instance_name,
-                "project_id": project_id,
-            },
-        )
-
-
-class DataFusionPipelineLink(BaseGoogleLink):
-    """Helper class for constructing Data Fusion Pipeline link"""
-
-    name = "Data Fusion Pipeline"
-    key = "pipeline_conf"
-    format_str = DATAFUSION_PIPELINE_LINK
-
-    @staticmethod
-    def persist(
-        context: Context,
-        task_instance: (
-            CloudDataFusionCreatePipelineOperator
-            | CloudDataFusionStartPipelineOperator
-            | CloudDataFusionStopPipelineOperator
-        ),
-        uri: str,
-    ):
-        task_instance.xcom_push(
-            context=context,
-            key=DataFusionPipelineLink.key,
-            value={
-                "uri": uri,
-                "pipeline_name": task_instance.pipeline_name,
-            },
-        )
-
-
-class DataFusionPipelinesLink(BaseGoogleLink):
-    """Helper class for constructing list of Data Fusion Pipelines link"""
-
-    name = "Data Fusion Pipelines"
-    key = "pipelines_conf"
-    format_str = DATAFUSION_PIPELINES_LINK
-
-    @staticmethod
-    def persist(
-        context: Context,
-        task_instance: CloudDataFusionListPipelinesOperator,
-        uri: str,
-    ):
-        task_instance.xcom_push(
-            context=context,
-            key=DataFusionPipelinesLink.key,
-            value={
-                "uri": uri,
-            },
-        )
-
-
-class CloudDataFusionRestartInstanceOperator(BaseOperator):
+class CloudDataFusionRestartInstanceOperator(GoogleCloudBaseOperator):
     """
     Restart a single Data Fusion instance.
+
     At the end of an operation instance is fully restarted.
 
     .. seealso::
@@ -139,9 +77,6 @@ class CloudDataFusionRestartInstanceOperator(BaseOperator):
     :param project_id: The ID of the Google Cloud project that the instance belongs to.
     :param api_version: The version of the api that will be requested for example 'v3'.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -163,10 +98,9 @@ class CloudDataFusionRestartInstanceOperator(BaseOperator):
         *,
         instance_name: str,
         location: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         api_version: str = "v1beta1",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -176,13 +110,11 @@ class CloudDataFusionRestartInstanceOperator(BaseOperator):
         self.project_id = project_id
         self.api_version = api_version
         self.gcp_conn_id = gcp_conn_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> None:
         hook = DataFusionHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             api_version=self.api_version,
             impersonation_chain=self.impersonation_chain,
         )
@@ -195,11 +127,17 @@ class CloudDataFusionRestartInstanceOperator(BaseOperator):
         instance = hook.wait_for_operation(operation)
         self.log.info("Instance %s restarted successfully", self.instance_name)
 
-        project_id = self.project_id or DataFusionPipelineLinkHelper.get_project_id(instance)
-        DataFusionInstanceLink.persist(context=context, task_instance=self, project_id=project_id)
+        project_id = resource_path_to_dict(resource_name=instance["name"])["projects"]
+        DataFusionInstanceLink.persist(
+            context=context,
+            task_instance=self,
+            project_id=project_id,
+            instance_name=self.instance_name,
+            location=self.location,
+        )
 
 
-class CloudDataFusionDeleteInstanceOperator(BaseOperator):
+class CloudDataFusionDeleteInstanceOperator(GoogleCloudBaseOperator):
     """
     Deletes a single Date Fusion instance.
 
@@ -212,9 +150,6 @@ class CloudDataFusionDeleteInstanceOperator(BaseOperator):
     :param project_id: The ID of the Google Cloud project that the instance belongs to.
     :param api_version: The version of the api that will be requested for example 'v3'.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -235,10 +170,9 @@ class CloudDataFusionDeleteInstanceOperator(BaseOperator):
         *,
         instance_name: str,
         location: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         api_version: str = "v1beta1",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -248,13 +182,11 @@ class CloudDataFusionDeleteInstanceOperator(BaseOperator):
         self.project_id = project_id
         self.api_version = api_version
         self.gcp_conn_id = gcp_conn_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> None:
         hook = DataFusionHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             api_version=self.api_version,
             impersonation_chain=self.impersonation_chain,
         )
@@ -268,7 +200,7 @@ class CloudDataFusionDeleteInstanceOperator(BaseOperator):
         self.log.info("Instance %s deleted successfully", self.instance_name)
 
 
-class CloudDataFusionCreateInstanceOperator(BaseOperator):
+class CloudDataFusionCreateInstanceOperator(GoogleCloudBaseOperator):
     """
     Creates a new Data Fusion instance in the specified project and location.
 
@@ -283,9 +215,6 @@ class CloudDataFusionCreateInstanceOperator(BaseOperator):
     :param project_id: The ID of the Google Cloud project that the instance belongs to.
     :param api_version: The version of the api that will be requested for example 'v3'.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -309,10 +238,9 @@ class CloudDataFusionCreateInstanceOperator(BaseOperator):
         instance_name: str,
         instance: dict[str, Any],
         location: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         api_version: str = "v1beta1",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -323,13 +251,11 @@ class CloudDataFusionCreateInstanceOperator(BaseOperator):
         self.project_id = project_id
         self.api_version = api_version
         self.gcp_conn_id = gcp_conn_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> dict:
         hook = DataFusionHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             api_version=self.api_version,
             impersonation_chain=self.impersonation_chain,
         )
@@ -354,17 +280,23 @@ class CloudDataFusionCreateInstanceOperator(BaseOperator):
             for time_to_wait in exponential_sleep_generator(initial=10, maximum=120):
                 if instance["state"] != "CREATING":
                     break
-                sleep(time_to_wait)
+                time.sleep(time_to_wait)
                 instance = hook.get_instance(
                     instance_name=self.instance_name, location=self.location, project_id=self.project_id
                 )
 
-        project_id = self.project_id or DataFusionPipelineLinkHelper.get_project_id(instance)
-        DataFusionInstanceLink.persist(context=context, task_instance=self, project_id=project_id)
+        project_id = resource_path_to_dict(resource_name=instance["name"])["projects"]
+        DataFusionInstanceLink.persist(
+            context=context,
+            task_instance=self,
+            project_id=project_id,
+            instance_name=self.instance_name,
+            location=self.location,
+        )
         return instance
 
 
-class CloudDataFusionUpdateInstanceOperator(BaseOperator):
+class CloudDataFusionUpdateInstanceOperator(GoogleCloudBaseOperator):
     """
     Updates a single Data Fusion instance.
 
@@ -385,9 +317,6 @@ class CloudDataFusionUpdateInstanceOperator(BaseOperator):
     :param project_id: The ID of the Google Cloud project that the instance belongs to.
     :param api_version: The version of the api that will be requested for example 'v3'.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -412,10 +341,9 @@ class CloudDataFusionUpdateInstanceOperator(BaseOperator):
         instance: dict[str, Any],
         update_mask: str,
         location: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         api_version: str = "v1beta1",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -427,13 +355,11 @@ class CloudDataFusionUpdateInstanceOperator(BaseOperator):
         self.project_id = project_id
         self.api_version = api_version
         self.gcp_conn_id = gcp_conn_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> None:
         hook = DataFusionHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             api_version=self.api_version,
             impersonation_chain=self.impersonation_chain,
         )
@@ -448,11 +374,17 @@ class CloudDataFusionUpdateInstanceOperator(BaseOperator):
         instance = hook.wait_for_operation(operation)
         self.log.info("Instance %s updated successfully", self.instance_name)
 
-        project_id = self.project_id or DataFusionPipelineLinkHelper.get_project_id(instance)
-        DataFusionInstanceLink.persist(context=context, task_instance=self, project_id=project_id)
+        project_id = resource_path_to_dict(resource_name=instance["name"])["projects"]
+        DataFusionInstanceLink.persist(
+            context=context,
+            task_instance=self,
+            project_id=project_id,
+            instance_name=self.instance_name,
+            location=self.location,
+        )
 
 
-class CloudDataFusionGetInstanceOperator(BaseOperator):
+class CloudDataFusionGetInstanceOperator(GoogleCloudBaseOperator):
     """
     Gets details of a single Data Fusion instance.
 
@@ -465,9 +397,6 @@ class CloudDataFusionGetInstanceOperator(BaseOperator):
     :param project_id: The ID of the Google Cloud project that the instance belongs to.
     :param api_version: The version of the api that will be requested for example 'v3'.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -489,10 +418,9 @@ class CloudDataFusionGetInstanceOperator(BaseOperator):
         *,
         instance_name: str,
         location: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         api_version: str = "v1beta1",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -502,13 +430,11 @@ class CloudDataFusionGetInstanceOperator(BaseOperator):
         self.project_id = project_id
         self.api_version = api_version
         self.gcp_conn_id = gcp_conn_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> dict:
         hook = DataFusionHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             api_version=self.api_version,
             impersonation_chain=self.impersonation_chain,
         )
@@ -519,12 +445,18 @@ class CloudDataFusionGetInstanceOperator(BaseOperator):
             project_id=self.project_id,
         )
 
-        project_id = self.project_id or DataFusionPipelineLinkHelper.get_project_id(instance)
-        DataFusionInstanceLink.persist(context=context, task_instance=self, project_id=project_id)
+        project_id = resource_path_to_dict(resource_name=instance["name"])["projects"]
+        DataFusionInstanceLink.persist(
+            context=context,
+            task_instance=self,
+            project_id=project_id,
+            instance_name=self.instance_name,
+            location=self.location,
+        )
         return instance
 
 
-class CloudDataFusionCreatePipelineOperator(BaseOperator):
+class CloudDataFusionCreatePipelineOperator(GoogleCloudBaseOperator):
     """
     Creates a Cloud Data Fusion pipeline.
 
@@ -542,9 +474,6 @@ class CloudDataFusionCreatePipelineOperator(BaseOperator):
         can create a namespace.
     :param api_version: The version of the api that will be requested for example 'v3'.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -555,12 +484,13 @@ class CloudDataFusionCreatePipelineOperator(BaseOperator):
         account from the list granting this role to the originating account (templated).
     """
 
+    operator_extra_links = (DataFusionPipelineLink(),)
+
     template_fields: Sequence[str] = (
         "instance_name",
         "pipeline_name",
         "impersonation_chain",
     )
-    operator_extra_links = (DataFusionPipelineLink(),)
 
     def __init__(
         self,
@@ -570,10 +500,9 @@ class CloudDataFusionCreatePipelineOperator(BaseOperator):
         instance_name: str,
         location: str,
         namespace: str = "default",
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         api_version: str = "v1beta1",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -586,13 +515,11 @@ class CloudDataFusionCreatePipelineOperator(BaseOperator):
         self.project_id = project_id
         self.api_version = api_version
         self.gcp_conn_id = gcp_conn_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> None:
         hook = DataFusionHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             api_version=self.api_version,
             impersonation_chain=self.impersonation_chain,
         )
@@ -609,12 +536,17 @@ class CloudDataFusionCreatePipelineOperator(BaseOperator):
             instance_url=api_url,
             namespace=self.namespace,
         )
-
-        DataFusionPipelineLink.persist(context=context, task_instance=self, uri=instance["serviceEndpoint"])
-        self.log.info("Pipeline created")
+        DataFusionPipelineLink.persist(
+            context=context,
+            task_instance=self,
+            uri=instance["serviceEndpoint"],
+            pipeline_name=self.pipeline_name,
+            namespace=self.namespace,
+        )
+        self.log.info("Pipeline %s created", self.pipeline_name)
 
 
-class CloudDataFusionDeletePipelineOperator(BaseOperator):
+class CloudDataFusionDeletePipelineOperator(GoogleCloudBaseOperator):
     """
     Deletes a Cloud Data Fusion pipeline.
 
@@ -631,9 +563,6 @@ class CloudDataFusionDeletePipelineOperator(BaseOperator):
         can create a namespace.
     :param api_version: The version of the api that will be requested for example 'v3'.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -659,10 +588,9 @@ class CloudDataFusionDeletePipelineOperator(BaseOperator):
         location: str,
         version_id: str | None = None,
         namespace: str = "default",
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         api_version: str = "v1beta1",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -675,13 +603,11 @@ class CloudDataFusionDeletePipelineOperator(BaseOperator):
         self.project_id = project_id
         self.api_version = api_version
         self.gcp_conn_id = gcp_conn_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> None:
         hook = DataFusionHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             api_version=self.api_version,
             impersonation_chain=self.impersonation_chain,
         )
@@ -701,7 +627,7 @@ class CloudDataFusionDeletePipelineOperator(BaseOperator):
         self.log.info("Pipeline deleted")
 
 
-class CloudDataFusionListPipelinesOperator(BaseOperator):
+class CloudDataFusionListPipelinesOperator(GoogleCloudBaseOperator):
     """
     Lists Cloud Data Fusion pipelines.
 
@@ -719,9 +645,6 @@ class CloudDataFusionListPipelinesOperator(BaseOperator):
         can create a namespace.
     :param api_version: The version of the api that will be requested for example 'v3'.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -748,10 +671,9 @@ class CloudDataFusionListPipelinesOperator(BaseOperator):
         artifact_name: str | None = None,
         artifact_version: str | None = None,
         namespace: str = "default",
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         api_version: str = "v1beta1",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -764,13 +686,11 @@ class CloudDataFusionListPipelinesOperator(BaseOperator):
         self.project_id = project_id
         self.api_version = api_version
         self.gcp_conn_id = gcp_conn_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> dict:
         hook = DataFusionHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             api_version=self.api_version,
             impersonation_chain=self.impersonation_chain,
         )
@@ -781,19 +701,25 @@ class CloudDataFusionListPipelinesOperator(BaseOperator):
             project_id=self.project_id,
         )
         api_url = instance["apiEndpoint"]
+        service_endpoint = instance["serviceEndpoint"]
         pipelines = hook.list_pipelines(
             instance_url=api_url,
             namespace=self.namespace,
             artifact_version=self.artifact_version,
             artifact_name=self.artifact_name,
         )
-        self.log.info("%s", pipelines)
+        self.log.info("Pipelines: %s", pipelines)
 
-        DataFusionPipelinesLink.persist(context=context, task_instance=self, uri=instance["serviceEndpoint"])
+        DataFusionPipelinesLink.persist(
+            context=context,
+            task_instance=self,
+            uri=service_endpoint,
+            namespace=self.namespace,
+        )
         return pipelines
 
 
-class CloudDataFusionStartPipelineOperator(BaseOperator):
+class CloudDataFusionStartPipelineOperator(GoogleCloudBaseOperator):
     """
     Starts a Cloud Data Fusion pipeline. Works for both batch and stream pipelines.
 
@@ -802,6 +728,7 @@ class CloudDataFusionStartPipelineOperator(BaseOperator):
         :ref:`howto/operator:CloudDataFusionStartPipelineOperator`
 
     :param pipeline_name: Your pipeline name.
+    :param pipeline_type: Optional pipeline type (BATCH by default).
     :param instance_name: The name of the instance.
     :param success_states: If provided the operator will wait for pipeline to be in one of
         the provided states.
@@ -814,9 +741,6 @@ class CloudDataFusionStartPipelineOperator(BaseOperator):
         can create a namespace.
     :param api_version: The version of the api that will be requested for example 'v3'.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -825,9 +749,14 @@ class CloudDataFusionStartPipelineOperator(BaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
-    :param asynchronous: Flag to return after submitting the pipeline Id to the Data Fusion API.
-        This is useful for submitting long running pipelines and
+    :param asynchronous: Flag to return after submitting the pipeline ID to the Data Fusion API.
+        This is useful for submitting long-running pipelines and
         waiting on them asynchronously using the CloudDataFusionPipelineStateSensor
+    :param deferrable: Run operator in the deferrable mode. Is not related to asynchronous parameter. While
+        asynchronous parameter gives a possibility to wait until pipeline reaches terminate state using
+        sleep() method, deferrable mode checks for the state using asynchronous calls. It is not possible to
+        use both asynchronous and deferrable parameters at the same time.
+    :param poll_interval: Polling period in seconds to check for the status. Used only in deferrable mode.
     """
 
     template_fields: Sequence[str] = (
@@ -844,20 +773,23 @@ class CloudDataFusionStartPipelineOperator(BaseOperator):
         pipeline_name: str,
         instance_name: str,
         location: str,
+        pipeline_type: DataFusionPipelineType = DataFusionPipelineType.BATCH,
         runtime_args: dict[str, Any] | None = None,
         success_states: list[str] | None = None,
         namespace: str = "default",
         pipeline_timeout: int = 5 * 60,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         api_version: str = "v1beta1",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         asynchronous=False,
+        deferrable: bool = conf.getboolean("operators", "default_deferrable", fallback=False),
+        poll_interval=3.0,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
         self.pipeline_name = pipeline_name
+        self.pipeline_type = pipeline_type
         self.runtime_args = runtime_args
         self.namespace = namespace
         self.instance_name = instance_name
@@ -865,20 +797,20 @@ class CloudDataFusionStartPipelineOperator(BaseOperator):
         self.project_id = project_id
         self.api_version = api_version
         self.gcp_conn_id = gcp_conn_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
         self.asynchronous = asynchronous
         self.pipeline_timeout = pipeline_timeout
+        self.deferrable = deferrable
+        self.poll_interval = poll_interval
 
         if success_states:
             self.success_states = success_states
         else:
-            self.success_states = SUCCESS_STATES + [PipelineStates.RUNNING]
+            self.success_states = [*SUCCESS_STATES, PipelineStates.RUNNING]
 
     def execute(self, context: Context) -> str:
         hook = DataFusionHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             api_version=self.api_version,
             impersonation_chain=self.impersonation_chain,
         )
@@ -891,29 +823,74 @@ class CloudDataFusionStartPipelineOperator(BaseOperator):
         api_url = instance["apiEndpoint"]
         pipeline_id = hook.start_pipeline(
             pipeline_name=self.pipeline_name,
+            pipeline_type=self.pipeline_type,
             instance_url=api_url,
             namespace=self.namespace,
             runtime_args=self.runtime_args,
         )
         self.log.info("Pipeline %s submitted successfully.", pipeline_id)
 
-        DataFusionPipelineLink.persist(context=context, task_instance=self, uri=instance["serviceEndpoint"])
+        DataFusionPipelineLink.persist(
+            context=context,
+            task_instance=self,
+            uri=instance["serviceEndpoint"],
+            pipeline_name=self.pipeline_name,
+            namespace=self.namespace,
+        )
 
-        if not self.asynchronous:
-            self.log.info("Waiting when pipeline %s will be in one of the success states", pipeline_id)
-            hook.wait_for_pipeline_state(
-                success_states=self.success_states,
-                pipeline_id=pipeline_id,
-                pipeline_name=self.pipeline_name,
-                namespace=self.namespace,
-                instance_url=api_url,
-                timeout=self.pipeline_timeout,
+        if self.deferrable:
+            if self.asynchronous:
+                raise AirflowException(
+                    "Both asynchronous and deferrable parameters were passed. Please, provide only one."
+                )
+            self.defer(
+                trigger=DataFusionStartPipelineTrigger(
+                    success_states=self.success_states,
+                    instance_url=api_url,
+                    namespace=self.namespace,
+                    pipeline_name=self.pipeline_name,
+                    pipeline_type=self.pipeline_type.value,
+                    pipeline_id=pipeline_id,
+                    poll_interval=self.poll_interval,
+                    gcp_conn_id=self.gcp_conn_id,
+                    impersonation_chain=self.impersonation_chain,
+                ),
+                method_name="execute_complete",
             )
-            self.log.info("Job %s discover success state.", pipeline_id)
+        else:
+            if not self.asynchronous:
+                # when NOT using asynchronous mode it will just wait for pipeline to finish and print message
+                self.log.info("Waiting when pipeline %s will be in one of the success states", pipeline_id)
+                hook.wait_for_pipeline_state(
+                    success_states=self.success_states,
+                    pipeline_id=pipeline_id,
+                    pipeline_name=self.pipeline_name,
+                    pipeline_type=self.pipeline_type,
+                    namespace=self.namespace,
+                    instance_url=api_url,
+                    timeout=self.pipeline_timeout,
+                )
+                self.log.info("Pipeline %s discovered success state.", pipeline_id)
+            #  otherwise, return pipeline_id so that sensor can use it later to check the pipeline state
         return pipeline_id
 
+    def execute_complete(self, context: Context, event: dict[str, Any]):
+        """
+        Act as a callback for when the trigger fires - returns immediately.
 
-class CloudDataFusionStopPipelineOperator(BaseOperator):
+        Relies on trigger to throw an exception, otherwise it assumes execution was successful.
+        """
+        if event["status"] == "error":
+            raise AirflowException(event["message"])
+        self.log.info(
+            "%s completed with response %s ",
+            self.task_id,
+            event["message"],
+        )
+        return event["pipeline_id"]
+
+
+class CloudDataFusionStopPipelineOperator(GoogleCloudBaseOperator):
     """
     Stops a Cloud Data Fusion pipeline. Works for both batch and stream pipelines.
 
@@ -929,9 +906,6 @@ class CloudDataFusionStopPipelineOperator(BaseOperator):
         can create a namespace.
     :param api_version: The version of the api that will be requested for example 'v3'.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -956,10 +930,9 @@ class CloudDataFusionStopPipelineOperator(BaseOperator):
         instance_name: str,
         location: str,
         namespace: str = "default",
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         api_version: str = "v1beta1",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -971,13 +944,11 @@ class CloudDataFusionStopPipelineOperator(BaseOperator):
         self.project_id = project_id
         self.api_version = api_version
         self.gcp_conn_id = gcp_conn_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> None:
         hook = DataFusionHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             api_version=self.api_version,
             impersonation_chain=self.impersonation_chain,
         )
@@ -989,7 +960,13 @@ class CloudDataFusionStopPipelineOperator(BaseOperator):
         )
         api_url = instance["apiEndpoint"]
 
-        DataFusionPipelineLink.persist(context=context, task_instance=self, uri=instance["serviceEndpoint"])
+        DataFusionPipelineLink.persist(
+            context=context,
+            task_instance=self,
+            uri=instance["serviceEndpoint"],
+            pipeline_name=self.pipeline_name,
+            namespace=self.namespace,
+        )
         hook.stop_pipeline(
             pipeline_name=self.pipeline_name,
             instance_url=api_url,
