@@ -16,17 +16,18 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Dataproc Metastore operators."""
+
 from __future__ import annotations
 
 import time
 from typing import TYPE_CHECKING, Sequence
 
+from google.api_core.exceptions import AlreadyExists
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
 from google.api_core.retry import Retry, exponential_sleep_generator
 from google.cloud.metastore_v1 import MetadataExport, MetadataManagementActivity
 from google.cloud.metastore_v1.types import Backup, MetadataImport, Service
 from google.cloud.metastore_v1.types.metastore import DatabaseDumpSpec, Restore
-from googleapiclient.errors import HttpError
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator, BaseOperatorLink
@@ -146,7 +147,8 @@ class DataprocMetastoreDetailedLink(BaseOperatorLink):
 
 
 class DataprocMetastoreCreateBackupOperator(GoogleCloudBaseOperator):
-    """Create a new backup in a given project and location.
+    """
+    Create a new backup in a given project and location.
 
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
     :param region: Required. The ID of the Google Cloud region that the service belongs to.
@@ -240,9 +242,7 @@ class DataprocMetastoreCreateBackupOperator(GoogleCloudBaseOperator):
             )
             backup = hook.wait_for_operation(self.timeout, operation)
             self.log.info("Backup %s created successfully", self.backup_id)
-        except HttpError as err:
-            if err.resp.status not in (409, "409"):
-                raise
+        except AlreadyExists:
             self.log.info("Backup %s already exists", self.backup_id)
             backup = hook.get_backup(
                 project_id=self.project_id,
@@ -260,7 +260,8 @@ class DataprocMetastoreCreateBackupOperator(GoogleCloudBaseOperator):
 
 
 class DataprocMetastoreCreateMetadataImportOperator(GoogleCloudBaseOperator):
-    """Create a new MetadataImport in a given project and location.
+    """
+    Create a new MetadataImport in a given project and location.
 
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
     :param region: Required. The ID of the Google Cloud region that the service belongs to.
@@ -360,7 +361,8 @@ class DataprocMetastoreCreateMetadataImportOperator(GoogleCloudBaseOperator):
 
 
 class DataprocMetastoreCreateServiceOperator(GoogleCloudBaseOperator):
-    """Create a metastore service in a project and location.
+    """
+    Create a metastore service in a project and location.
 
     :param region: Required. The ID of the Google Cloud region that the service belongs to.
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
@@ -430,7 +432,7 @@ class DataprocMetastoreCreateServiceOperator(GoogleCloudBaseOperator):
         hook = DataprocMetastoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
-        self.log.info("Creating Dataproc Metastore service: %s", self.project_id)
+        self.log.info("Creating Dataproc Metastore service: %s", self.service_id)
         try:
             operation = hook.create_service(
                 region=self.region,
@@ -444,9 +446,7 @@ class DataprocMetastoreCreateServiceOperator(GoogleCloudBaseOperator):
             )
             service = hook.wait_for_operation(self.timeout, operation)
             self.log.info("Service %s created successfully", self.service_id)
-        except HttpError as err:
-            if err.resp.status not in (409, "409"):
-                raise
+        except AlreadyExists:
             self.log.info("Instance %s already exists", self.service_id)
             service = hook.get_service(
                 region=self.region,
@@ -461,7 +461,8 @@ class DataprocMetastoreCreateServiceOperator(GoogleCloudBaseOperator):
 
 
 class DataprocMetastoreDeleteBackupOperator(GoogleCloudBaseOperator):
-    """Delete a single backup.
+    """
+    Delete a single backup.
 
     :param project_id: Required. The ID of the Google Cloud project that the backup belongs to.
     :param region: Required. The ID of the Google Cloud region that the backup belongs to.
@@ -545,15 +546,27 @@ class DataprocMetastoreDeleteBackupOperator(GoogleCloudBaseOperator):
 
 
 class DataprocMetastoreDeleteServiceOperator(GoogleCloudBaseOperator):
-    """Delete a single service.
+    """
+    Delete a single service.
 
-    :param request:  The request object. Request message for
-        [DataprocMetastore.DeleteService][google.cloud.metastore.v1.DataprocMetastore.DeleteService].
+    :param region: Required. The ID of the Google Cloud region that the service belongs to.
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
+    :param service_id:  Required. The ID of the metastore service, which is used as the final component of
+        the metastore service's name. This value must be between 2 and 63 characters long inclusive, begin
+        with a letter, end with a letter or number, and consist of alphanumeric ASCII characters or
+        hyphens.
     :param retry: Designation of what errors, if any, should be retried.
     :param timeout: The timeout for this request.
     :param metadata: Strings which should be sent along with the request as metadata.
-    :param gcp_conn_id:
+    :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
+    :param impersonation_chain: Optional service account to impersonate using short-term
+        credentials, or chained list of accounts required to get the access_token
+        of the last account in the list, which will be impersonated in the request.
+        If set as a string, the account must grant the originating account
+        the Service Account Token Creator IAM role.
+        If set as a sequence, the identities from the list must grant
+        Service Account Token Creator IAM role to the directly preceding identity, with first
+        account from the list granting this role to the originating account (templated).
     """
 
     template_fields: Sequence[str] = (
@@ -588,7 +601,7 @@ class DataprocMetastoreDeleteServiceOperator(GoogleCloudBaseOperator):
         hook = DataprocMetastoreHook(
             gcp_conn_id=self.gcp_conn_id, impersonation_chain=self.impersonation_chain
         )
-        self.log.info("Deleting Dataproc Metastore service: %s", self.project_id)
+        self.log.info("Deleting Dataproc Metastore service: %s", self.service_id)
         operation = hook.delete_service(
             region=self.region,
             project_id=self.project_id,
@@ -598,11 +611,12 @@ class DataprocMetastoreDeleteServiceOperator(GoogleCloudBaseOperator):
             metadata=self.metadata,
         )
         hook.wait_for_operation(self.timeout, operation)
-        self.log.info("Service %s deleted successfully", self.project_id)
+        self.log.info("Service %s deleted successfully", self.service_id)
 
 
 class DataprocMetastoreExportMetadataOperator(GoogleCloudBaseOperator):
-    """Export metadata from a service.
+    """
+    Export metadata from a service.
 
     :param destination_gcs_folder: A Cloud Storage URI of a folder, in the format
         ``gs://<bucket_name>/<path_inside_bucket>``. A sub-folder
@@ -694,7 +708,8 @@ class DataprocMetastoreExportMetadataOperator(GoogleCloudBaseOperator):
         return destination_uri[5:] if destination_uri.startswith("gs://") else destination_uri
 
     def _wait_for_export_metadata(self, hook: DataprocMetastoreHook):
-        """Check that export was created successfully.
+        """
+        Check that export was created successfully.
 
         This is a workaround to an issue parsing result to MetadataExport inside
         the SDK.
@@ -720,7 +735,8 @@ class DataprocMetastoreExportMetadataOperator(GoogleCloudBaseOperator):
 
 
 class DataprocMetastoreGetServiceOperator(GoogleCloudBaseOperator):
-    """Get the details of a single service.
+    """
+    Get the details of a single service.
 
     :param region: Required. The ID of the Google Cloud region that the service belongs to.
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
@@ -792,7 +808,8 @@ class DataprocMetastoreGetServiceOperator(GoogleCloudBaseOperator):
 
 
 class DataprocMetastoreListBackupsOperator(GoogleCloudBaseOperator):
-    """List backups in a service.
+    """
+    List backups in a service.
 
     :param project_id: Required. The ID of the Google Cloud project that the backup belongs to.
     :param region: Required. The ID of the Google Cloud region that the backup belongs to.
@@ -876,7 +893,8 @@ class DataprocMetastoreListBackupsOperator(GoogleCloudBaseOperator):
 
 
 class DataprocMetastoreRestoreServiceOperator(GoogleCloudBaseOperator):
-    """Restore a service from a backup.
+    """
+    Restore a service from a backup.
 
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
     :param region: Required. The ID of the Google Cloud region that the service belongs to.
@@ -980,7 +998,8 @@ class DataprocMetastoreRestoreServiceOperator(GoogleCloudBaseOperator):
         DataprocMetastoreLink.persist(context=context, task_instance=self, url=METASTORE_SERVICE_LINK)
 
     def _wait_for_restore_service(self, hook: DataprocMetastoreHook):
-        """Check that export was created successfully.
+        """
+        Check that export was created successfully.
 
         This is a workaround to an issue parsing result to MetadataExport inside
         the SDK.
@@ -1004,7 +1023,8 @@ class DataprocMetastoreRestoreServiceOperator(GoogleCloudBaseOperator):
 
 
 class DataprocMetastoreUpdateServiceOperator(GoogleCloudBaseOperator):
-    """Update the parameters of a single service.
+    """
+    Update the parameters of a single service.
 
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
     :param region: Required. The ID of the Google Cloud region that the service belongs to.
