@@ -16,9 +16,9 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Datastore operators."""
+
 from __future__ import annotations
 
-import warnings
 from typing import TYPE_CHECKING, Any, Sequence
 
 from airflow.exceptions import AirflowException
@@ -29,6 +29,7 @@ from airflow.providers.google.cloud.links.datastore import (
     CloudDatastoreImportExportLink,
 )
 from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
+from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID
 from airflow.providers.google.common.links.storage import StorageLink
 
 if TYPE_CHECKING:
@@ -37,7 +38,7 @@ if TYPE_CHECKING:
 
 class CloudDatastoreExportEntitiesOperator(GoogleCloudBaseOperator):
     """
-    Export entities from Google Cloud Datastore to Cloud Storage
+    Export entities from Google Cloud Datastore to Cloud Storage.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -46,15 +47,12 @@ class CloudDatastoreExportEntitiesOperator(GoogleCloudBaseOperator):
     .. seealso::
         https://cloud.google.com/datastore/docs/export-import-entities
 
-    :param bucket: name of the cloud storage bucket to backup data
+    :param bucket: name of the cloud storage bucket to back up data
     :param namespace: optional namespace path in the specified Cloud Storage bucket
-        to backup data. If this namespace does not exist in GCS, it will be created.
+        to back up data. If this namespace does not exist in GCS, it will be created.
     :param datastore_conn_id: the name of the Datastore connection id to use
     :param cloud_storage_conn_id: the name of the cloud storage connection id to
         force-write backup
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param entity_filter: description of what data from the project is included in the
         export, refer to
         https://cloud.google.com/datastore/docs/reference/rest/Shared.Types/EntityFilter
@@ -89,23 +87,17 @@ class CloudDatastoreExportEntitiesOperator(GoogleCloudBaseOperator):
         namespace: str | None = None,
         datastore_conn_id: str = "google_cloud_default",
         cloud_storage_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         entity_filter: dict | None = None,
         labels: dict | None = None,
         polling_interval_in_seconds: int = 10,
         overwrite_existing: bool = False,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
         self.datastore_conn_id = datastore_conn_id
         self.cloud_storage_conn_id = cloud_storage_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.bucket = bucket
         self.namespace = namespace
         self.entity_filter = entity_filter
@@ -126,7 +118,6 @@ class CloudDatastoreExportEntitiesOperator(GoogleCloudBaseOperator):
 
         ds_hook = DatastoreHook(
             gcp_conn_id=self.datastore_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
         result = ds_hook.export_to_storage_bucket(
@@ -153,7 +144,7 @@ class CloudDatastoreExportEntitiesOperator(GoogleCloudBaseOperator):
 
 class CloudDatastoreImportEntitiesOperator(GoogleCloudBaseOperator):
     """
-    Import entities from Cloud Storage to Google Cloud Datastore
+    Import entities from Cloud Storage to Google Cloud Datastore.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -172,9 +163,6 @@ class CloudDatastoreImportEntitiesOperator(GoogleCloudBaseOperator):
         https://cloud.google.com/datastore/docs/reference/rest/Shared.Types/EntityFilter
     :param labels: client-assigned labels for cloud storage
     :param datastore_conn_id: the name of the connection id to use
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param polling_interval_in_seconds: number of seconds to wait before polling for
         execution status again
     :param impersonation_chain: Optional service account to impersonate using short-term
@@ -206,19 +194,13 @@ class CloudDatastoreImportEntitiesOperator(GoogleCloudBaseOperator):
         entity_filter: dict | None = None,
         labels: dict | None = None,
         datastore_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         polling_interval_in_seconds: float = 10,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
         self.datastore_conn_id = datastore_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.bucket = bucket
         self.file = file
         self.namespace = namespace
@@ -232,7 +214,6 @@ class CloudDatastoreImportEntitiesOperator(GoogleCloudBaseOperator):
         self.log.info("Importing data from Cloud Storage bucket %s", self.bucket)
         ds_hook = DatastoreHook(
             self.datastore_conn_id,
-            self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
         result = ds_hook.import_from_storage_bucket(
@@ -267,9 +248,6 @@ class CloudDatastoreAllocateIdsOperator(GoogleCloudBaseOperator):
 
     :param partial_keys: a list of partial keys.
     :param project_id: Google Cloud project ID against which to make the request.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
@@ -291,8 +269,7 @@ class CloudDatastoreAllocateIdsOperator(GoogleCloudBaseOperator):
         self,
         *,
         partial_keys: list,
-        project_id: str | None = None,
-        delegate_to: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -302,11 +279,6 @@ class CloudDatastoreAllocateIdsOperator(GoogleCloudBaseOperator):
         self.partial_keys = partial_keys
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> list:
@@ -335,9 +307,6 @@ class CloudDatastoreBeginTransactionOperator(GoogleCloudBaseOperator):
 
     :param transaction_options: Options for a new transaction.
     :param project_id: Google Cloud project ID against which to make the request.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
@@ -358,8 +327,7 @@ class CloudDatastoreBeginTransactionOperator(GoogleCloudBaseOperator):
         self,
         *,
         transaction_options: dict[str, Any],
-        project_id: str | None = None,
-        delegate_to: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -369,11 +337,6 @@ class CloudDatastoreBeginTransactionOperator(GoogleCloudBaseOperator):
         self.transaction_options = transaction_options
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> str:
@@ -401,9 +364,6 @@ class CloudDatastoreCommitOperator(GoogleCloudBaseOperator):
 
     :param body: the body of the commit request.
     :param project_id: Google Cloud project ID against which to make the request.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
@@ -425,8 +385,7 @@ class CloudDatastoreCommitOperator(GoogleCloudBaseOperator):
         self,
         *,
         body: dict[str, Any],
-        project_id: str | None = None,
-        delegate_to: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -436,11 +395,6 @@ class CloudDatastoreCommitOperator(GoogleCloudBaseOperator):
         self.body = body
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> dict:
@@ -469,9 +423,6 @@ class CloudDatastoreRollbackOperator(GoogleCloudBaseOperator):
 
     :param transaction: the transaction to roll back.
     :param project_id: Google Cloud project ID against which to make the request.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
@@ -492,8 +443,7 @@ class CloudDatastoreRollbackOperator(GoogleCloudBaseOperator):
         self,
         *,
         transaction: str,
-        project_id: str | None = None,
-        delegate_to: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -503,11 +453,6 @@ class CloudDatastoreRollbackOperator(GoogleCloudBaseOperator):
         self.transaction = transaction
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> None:
@@ -534,9 +479,6 @@ class CloudDatastoreRunQueryOperator(GoogleCloudBaseOperator):
 
     :param body: the body of the query request.
     :param project_id: Google Cloud project ID against which to make the request.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
@@ -557,8 +499,7 @@ class CloudDatastoreRunQueryOperator(GoogleCloudBaseOperator):
         self,
         *,
         body: dict[str, Any],
-        project_id: str | None = None,
-        delegate_to: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -568,11 +509,6 @@ class CloudDatastoreRunQueryOperator(GoogleCloudBaseOperator):
         self.body = body
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> dict:
@@ -599,9 +535,6 @@ class CloudDatastoreGetOperationOperator(GoogleCloudBaseOperator):
         https://cloud.google.com/datastore/docs/reference/data/rest/v1/projects.operations/get
 
     :param name: the name of the operation resource.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
@@ -622,7 +555,6 @@ class CloudDatastoreGetOperationOperator(GoogleCloudBaseOperator):
         self,
         *,
         name: str,
-        delegate_to: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -631,11 +563,6 @@ class CloudDatastoreGetOperationOperator(GoogleCloudBaseOperator):
 
         self.name = name
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context):
@@ -659,9 +586,6 @@ class CloudDatastoreDeleteOperationOperator(GoogleCloudBaseOperator):
         https://cloud.google.com/datastore/docs/reference/data/rest/v1/projects.operations/delete
 
     :param name: the name of the operation resource.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
@@ -682,7 +606,6 @@ class CloudDatastoreDeleteOperationOperator(GoogleCloudBaseOperator):
         self,
         *,
         name: str,
-        delegate_to: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -691,11 +614,6 @@ class CloudDatastoreDeleteOperationOperator(GoogleCloudBaseOperator):
 
         self.name = name
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context) -> None:
