@@ -299,7 +299,7 @@ class GCSDeleteObjectsOperator(GoogleCloudBaseOperator):
         *,
         bucket_name: str,
         objects: list[str] | None = None,
-        prefix: str | None = None,
+        prefix: str | list[str] | None = None,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -311,12 +311,14 @@ class GCSDeleteObjectsOperator(GoogleCloudBaseOperator):
         self.impersonation_chain = impersonation_chain
 
         if objects is None and prefix is None:
-            err_message = "(Task {task_id}) Either object or prefix should be set. Both are None.".format(
+            err_message = "(Task {task_id}) Either objects or prefix should be set. Both are None.".format(
                 **kwargs
             )
             raise ValueError(err_message)
+        if objects is not None and prefix is not None:
+            err_message = "(Task {task_id}) Objects or prefix should be set. Both provided.".format(**kwargs)
+            raise ValueError(err_message)
 
-        self._objects: list[str] = []
         super().__init__(**kwargs)
 
     def execute(self, context: Context) -> None:
@@ -326,26 +328,33 @@ class GCSDeleteObjectsOperator(GoogleCloudBaseOperator):
         )
 
         if self.objects is not None:
-            self._objects = self.objects
+            objects = self.objects
         else:
-            self._objects = hook.list(bucket_name=self.bucket_name, prefix=self.prefix)
-        self.log.info("Deleting %s objects from %s", len(self._objects), self.bucket_name)
-        for object_name in self._objects:
+            objects = hook.list(bucket_name=self.bucket_name, prefix=self.prefix)
+        self.log.info("Deleting %s objects from %s", len(objects), self.bucket_name)
+        for object_name in objects:
             hook.delete(bucket_name=self.bucket_name, object_name=object_name)
 
-    def get_openlineage_facets_on_complete(self, task_instance):
-        """Implement on_complete as execute() resolves object names."""
-        from openlineage.client.facet import (
+    def get_openlineage_facets_on_start(self):
+        from airflow.providers.common.compat.openlineage.facet import (
+            Dataset,
             LifecycleStateChange,
             LifecycleStateChangeDatasetFacet,
-            LifecycleStateChangeDatasetFacetPreviousIdentifier,
+            PreviousIdentifier,
         )
-        from openlineage.client.run import Dataset
-
         from airflow.providers.openlineage.extractors import OperatorLineage
 
-        if not self._objects:
-            return OperatorLineage()
+        objects = []
+        if self.objects is not None:
+            objects = self.objects
+        elif self.prefix is not None:
+            prefixes = [self.prefix] if isinstance(self.prefix, str) else self.prefix
+            for pref in prefixes:
+                # Use parent if not a file (dot not in name) and not a dir (ends with slash)
+                if "." not in pref.split("/")[-1] and not pref.endswith("/"):
+                    pref = Path(pref).parent.as_posix()
+                pref = "/" if pref in (".", "", "/") else pref.rstrip("/")
+                objects.append(pref)
 
         bucket_url = f"gs://{self.bucket_name}"
         input_datasets = [
@@ -355,14 +364,14 @@ class GCSDeleteObjectsOperator(GoogleCloudBaseOperator):
                 facets={
                     "lifecycleStateChange": LifecycleStateChangeDatasetFacet(
                         lifecycleStateChange=LifecycleStateChange.DROP.value,
-                        previousIdentifier=LifecycleStateChangeDatasetFacetPreviousIdentifier(
+                        previousIdentifier=PreviousIdentifier(
                             namespace=bucket_url,
                             name=object_name,
                         ),
                     )
                 },
             )
-            for object_name in self._objects
+            for object_name in objects
         ]
 
         return OperatorLineage(inputs=input_datasets)
@@ -635,8 +644,7 @@ class GCSFileTransformOperator(GoogleCloudBaseOperator):
             )
 
     def get_openlineage_facets_on_start(self):
-        from openlineage.client.run import Dataset
-
+        from airflow.providers.common.compat.openlineage.facet import Dataset
         from airflow.providers.openlineage.extractors import OperatorLineage
 
         input_dataset = Dataset(
@@ -729,7 +737,8 @@ class GCSTimeSpanFileTransformOperator(GoogleCloudBaseOperator):
 
     @staticmethod
     def interpolate_prefix(prefix: str, dt: datetime.datetime) -> str | None:
-        """Interpolate prefix with datetime.
+        """
+        Interpolate prefix with datetime.
 
         :param prefix: The prefix to interpolate
         :param dt: The datetime to interpolate
@@ -776,8 +785,8 @@ class GCSTimeSpanFileTransformOperator(GoogleCloudBaseOperator):
         self.upload_continue_on_fail = upload_continue_on_fail
         self.upload_num_attempts = upload_num_attempts
 
-        self._source_object_names: list[str] = []
-        self._destination_object_names: list[str] = []
+        self._source_prefix_interp: str | None = None
+        self._destination_prefix_interp: str | None = None
 
     def execute(self, context: Context) -> list[str]:
         # Define intervals and prefixes.
@@ -805,11 +814,11 @@ class GCSTimeSpanFileTransformOperator(GoogleCloudBaseOperator):
         timespan_start = timespan_start.in_timezone(timezone.utc)
         timespan_end = timespan_end.in_timezone(timezone.utc)
 
-        source_prefix_interp = GCSTimeSpanFileTransformOperator.interpolate_prefix(
+        self._source_prefix_interp = GCSTimeSpanFileTransformOperator.interpolate_prefix(
             self.source_prefix,
             timespan_start,
         )
-        destination_prefix_interp = GCSTimeSpanFileTransformOperator.interpolate_prefix(
+        self._destination_prefix_interp = GCSTimeSpanFileTransformOperator.interpolate_prefix(
             self.destination_prefix,
             timespan_start,
         )
@@ -830,9 +839,9 @@ class GCSTimeSpanFileTransformOperator(GoogleCloudBaseOperator):
         )
 
         # Fetch list of files.
-        self._source_object_names = source_hook.list_by_timespan(
+        blobs_to_transform = source_hook.list_by_timespan(
             bucket_name=self.source_bucket,
-            prefix=source_prefix_interp,
+            prefix=self._source_prefix_interp,
             timespan_start=timespan_start,
             timespan_end=timespan_end,
         )
@@ -842,7 +851,7 @@ class GCSTimeSpanFileTransformOperator(GoogleCloudBaseOperator):
             temp_output_dir_path = Path(temp_output_dir)
 
             # TODO: download in parallel.
-            for blob_to_transform in self._source_object_names:
+            for blob_to_transform in blobs_to_transform:
                 destination_file = temp_input_dir_path / blob_to_transform
                 destination_file.parent.mkdir(parents=True, exist_ok=True)
                 try:
@@ -879,6 +888,8 @@ class GCSTimeSpanFileTransformOperator(GoogleCloudBaseOperator):
 
             self.log.info("Transformation succeeded. Output temporarily located at %s", temp_output_dir_path)
 
+            files_uploaded = []
+
             # TODO: upload in parallel.
             for upload_file in temp_output_dir_path.glob("**/*"):
                 if upload_file.is_dir():
@@ -886,8 +897,8 @@ class GCSTimeSpanFileTransformOperator(GoogleCloudBaseOperator):
 
                 upload_file_name = str(upload_file.relative_to(temp_output_dir_path))
 
-                if self.destination_prefix is not None:
-                    upload_file_name = f"{destination_prefix_interp}/{upload_file_name}"
+                if self._destination_prefix_interp is not None:
+                    upload_file_name = f"{self._destination_prefix_interp.rstrip('/')}/{upload_file_name}"
 
                 self.log.info("Uploading file %s to %s", upload_file, upload_file_name)
 
@@ -899,35 +910,45 @@ class GCSTimeSpanFileTransformOperator(GoogleCloudBaseOperator):
                         chunk_size=self.chunk_size,
                         num_max_attempts=self.upload_num_attempts,
                     )
-                    self._destination_object_names.append(str(upload_file_name))
+                    files_uploaded.append(str(upload_file_name))
                 except GoogleCloudError:
                     if not self.upload_continue_on_fail:
                         raise
 
-            return self._destination_object_names
+            return files_uploaded
 
     def get_openlineage_facets_on_complete(self, task_instance):
-        """Implement on_complete as execute() resolves object names."""
-        from openlineage.client.run import Dataset
-
+        """Implement on_complete as execute() resolves object prefixes."""
+        from airflow.providers.common.compat.openlineage.facet import Dataset
         from airflow.providers.openlineage.extractors import OperatorLineage
 
-        input_datasets = [
-            Dataset(
-                namespace=f"gs://{self.source_bucket}",
-                name=object_name,
-            )
-            for object_name in self._source_object_names
-        ]
-        output_datasets = [
-            Dataset(
-                namespace=f"gs://{self.destination_bucket}",
-                name=object_name,
-            )
-            for object_name in self._destination_object_names
-        ]
+        def _parse_prefix(pref):
+            # Use parent if not a file (dot not in name) and not a dir (ends with slash)
+            if "." not in pref.split("/")[-1] and not pref.endswith("/"):
+                pref = Path(pref).parent.as_posix()
+            return "/" if pref in (".", "/", "") else pref.rstrip("/")
 
-        return OperatorLineage(inputs=input_datasets, outputs=output_datasets)
+        input_prefix, output_prefix = "/", "/"
+        if self._source_prefix_interp is not None:
+            input_prefix = _parse_prefix(self._source_prefix_interp)
+
+        if self._destination_prefix_interp is not None:
+            output_prefix = _parse_prefix(self._destination_prefix_interp)
+
+        return OperatorLineage(
+            inputs=[
+                Dataset(
+                    namespace=f"gs://{self.source_bucket}",
+                    name=input_prefix,
+                )
+            ],
+            outputs=[
+                Dataset(
+                    namespace=f"gs://{self.destination_bucket}",
+                    name=output_prefix,
+                )
+            ],
+        )
 
 
 class GCSDeleteBucketOperator(GoogleCloudBaseOperator):
