@@ -16,6 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Spanner operators."""
+
 from __future__ import annotations
 
 from typing import TYPE_CHECKING, Sequence
@@ -24,6 +25,7 @@ from airflow.exceptions import AirflowException
 from airflow.providers.google.cloud.hooks.spanner import SpannerHook
 from airflow.providers.google.cloud.links.spanner import SpannerDatabaseLink, SpannerInstanceLink
 from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
+from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID
 
 if TYPE_CHECKING:
     from airflow.utils.context import Context
@@ -31,8 +33,7 @@ if TYPE_CHECKING:
 
 class SpannerDeployInstanceOperator(GoogleCloudBaseOperator):
     """
-    Creates a new Cloud Spanner instance, or if an instance with the same instance_id
-    exists in the specified project, updates the Cloud Spanner instance.
+    Create or update a Cloud Spanner instance.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -79,7 +80,7 @@ class SpannerDeployInstanceOperator(GoogleCloudBaseOperator):
         configuration_name: str,
         node_count: int,
         display_name: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -128,8 +129,7 @@ class SpannerDeployInstanceOperator(GoogleCloudBaseOperator):
 
 class SpannerDeleteInstanceOperator(GoogleCloudBaseOperator):
     """
-    Deletes a Cloud Spanner instance. If an instance does not exist,
-    no action is taken and the operator succeeds.
+    Delete a Cloud Spanner instance; if an instance does not exist, no action is taken and the task succeeds.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -162,7 +162,7 @@ class SpannerDeleteInstanceOperator(GoogleCloudBaseOperator):
         self,
         *,
         instance_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -241,7 +241,7 @@ class SpannerQueryDatabaseInstanceOperator(GoogleCloudBaseOperator):
         instance_id: str,
         database_id: str,
         query: str | list[str],
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -299,18 +299,17 @@ class SpannerQueryDatabaseInstanceOperator(GoogleCloudBaseOperator):
     @staticmethod
     def sanitize_queries(queries: list[str]) -> None:
         """
-        Drops empty query in queries.
+        Drop empty query in queries.
 
         :param queries: queries
         """
         if queries and queries[-1] == "":
-            del queries[-1]
+            queries.pop()
 
 
 class SpannerDeployDatabaseInstanceOperator(GoogleCloudBaseOperator):
     """
-    Creates a new Cloud Spanner database, or if database exists,
-    the operator does nothing.
+    Creates a new Cloud Spanner database; if database exists, the operator does nothing.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -352,7 +351,7 @@ class SpannerDeployDatabaseInstanceOperator(GoogleCloudBaseOperator):
         instance_id: str,
         database_id: str,
         ddl_statements: list[str],
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
@@ -458,7 +457,7 @@ class SpannerUpdateDatabaseInstanceOperator(GoogleCloudBaseOperator):
         instance_id: str,
         database_id: str,
         ddl_statements: list[str],
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         operation_id: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
@@ -552,7 +551,7 @@ class SpannerDeleteDatabaseInstanceOperator(GoogleCloudBaseOperator):
         *,
         instance_id: str,
         database_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         gcp_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
