@@ -20,27 +20,29 @@ from __future__ import annotations
 from typing import TYPE_CHECKING, Sequence
 
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
-from google.api_core.retry import Retry
 from google.cloud.monitoring_v3 import AlertPolicy, NotificationChannel
 
-from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.stackdriver import StackdriverHook
 from airflow.providers.google.cloud.links.stackdriver import (
     StackdriverNotificationsLink,
     StackdriverPoliciesLink,
 )
+from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
+from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID
 
 if TYPE_CHECKING:
+    from google.api_core.retry import Retry
+
     from airflow.utils.context import Context
 
 
-class StackdriverListAlertPoliciesOperator(BaseOperator):
+class StackdriverListAlertPoliciesOperator(GoogleCloudBaseOperator):
     """
-    Fetches all the Alert Policies identified by the filter passed as
-    filter parameter. The desired return type can be specified by the
-    format parameter, the supported formats are "dict", "json" and None
-    which returns python dictionary, stringified JSON and protobuf
-    respectively.
+    Fetches all the Alert Policies identified by the filter passed as filter parameter.
+
+    The desired return type can be specified by the format parameter, the supported
+    formats are "dict", "json" and None which returns python dictionary, stringified
+    JSON and protobuf respectively.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -70,9 +72,6 @@ class StackdriverListAlertPoliciesOperator(BaseOperator):
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :param project_id: The project to fetch alerts from.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -101,8 +100,7 @@ class StackdriverListAlertPoliciesOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        project_id: str | None = None,
-        delegate_to: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -116,7 +114,6 @@ class StackdriverListAlertPoliciesOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
         self.hook: StackdriverHook | None = None
 
@@ -132,7 +129,6 @@ class StackdriverListAlertPoliciesOperator(BaseOperator):
         if self.hook is None:
             self.hook = StackdriverHook(
                 gcp_conn_id=self.gcp_conn_id,
-                delegate_to=self.delegate_to,
                 impersonation_chain=self.impersonation_chain,
             )
 
@@ -154,10 +150,11 @@ class StackdriverListAlertPoliciesOperator(BaseOperator):
         return [AlertPolicy.to_dict(policy) for policy in result]
 
 
-class StackdriverEnableAlertPoliciesOperator(BaseOperator):
+class StackdriverEnableAlertPoliciesOperator(GoogleCloudBaseOperator):
     """
-    Enables one or more disabled alerting policies identified by filter
-    parameter. Inoperative in case the policy is already enabled.
+    Enables one or more disabled alerting policies identified by filter parameter.
+
+    Inoperative in case the policy is already enabled.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -175,9 +172,6 @@ class StackdriverEnableAlertPoliciesOperator(BaseOperator):
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :param project_id: The project in which alert needs to be enabled.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -203,15 +197,13 @@ class StackdriverEnableAlertPoliciesOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        project_id: str | None = None,
-        delegate_to: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        self.delegate_to = delegate_to
         self.filter_ = filter_
         self.retry = retry
         self.timeout = timeout
@@ -224,7 +216,6 @@ class StackdriverEnableAlertPoliciesOperator(BaseOperator):
         if self.hook is None:
             self.hook = StackdriverHook(
                 gcp_conn_id=self.gcp_conn_id,
-                delegate_to=self.delegate_to,
                 impersonation_chain=self.impersonation_chain,
             )
         self.hook.enable_alert_policies(
@@ -242,10 +233,11 @@ class StackdriverEnableAlertPoliciesOperator(BaseOperator):
 
 
 # Disable Alert Operator
-class StackdriverDisableAlertPoliciesOperator(BaseOperator):
+class StackdriverDisableAlertPoliciesOperator(GoogleCloudBaseOperator):
     """
-    Disables one or more enabled alerting policies identified by filter
-    parameter. Inoperative in case the policy is already disabled.
+    Disables one or more enabled alerting policies identified by filter parameter.
+
+    Inoperative in case the policy is already disabled.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -263,9 +255,6 @@ class StackdriverDisableAlertPoliciesOperator(BaseOperator):
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :param project_id: The project in which alert needs to be disabled.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -291,15 +280,13 @@ class StackdriverDisableAlertPoliciesOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        project_id: str | None = None,
-        delegate_to: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        self.delegate_to = delegate_to
         self.filter_ = filter_
         self.retry = retry
         self.timeout = timeout
@@ -312,7 +299,6 @@ class StackdriverDisableAlertPoliciesOperator(BaseOperator):
         if self.hook is None:
             self.hook = StackdriverHook(
                 gcp_conn_id=self.gcp_conn_id,
-                delegate_to=self.delegate_to,
                 impersonation_chain=self.impersonation_chain,
             )
         self.hook.disable_alert_policies(
@@ -329,10 +315,9 @@ class StackdriverDisableAlertPoliciesOperator(BaseOperator):
         )
 
 
-class StackdriverUpsertAlertOperator(BaseOperator):
+class StackdriverUpsertAlertOperator(GoogleCloudBaseOperator):
     """
-    Creates a new alert or updates an existing policy identified
-    the name field in the alerts parameter.
+    Creates a new alert or updates an existing policy identified the name field in the alerts parameter.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -351,9 +336,6 @@ class StackdriverUpsertAlertOperator(BaseOperator):
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :param project_id: The project in which alert needs to be created/updated.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -381,8 +363,7 @@ class StackdriverUpsertAlertOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        project_id: str | None = None,
-        delegate_to: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -393,7 +374,6 @@ class StackdriverUpsertAlertOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
         self.hook: StackdriverHook | None = None
 
@@ -402,7 +382,6 @@ class StackdriverUpsertAlertOperator(BaseOperator):
         if self.hook is None:
             self.hook = StackdriverHook(
                 gcp_conn_id=self.gcp_conn_id,
-                delegate_to=self.delegate_to,
                 impersonation_chain=self.impersonation_chain,
             )
         self.hook.upsert_alert(
@@ -419,7 +398,7 @@ class StackdriverUpsertAlertOperator(BaseOperator):
         )
 
 
-class StackdriverDeleteAlertOperator(BaseOperator):
+class StackdriverDeleteAlertOperator(GoogleCloudBaseOperator):
     """
     Deletes an alerting policy.
 
@@ -438,9 +417,6 @@ class StackdriverDeleteAlertOperator(BaseOperator):
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :param project_id: The project from which alert needs to be deleted.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -466,8 +442,7 @@ class StackdriverDeleteAlertOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        project_id: str | None = None,
-        delegate_to: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -478,7 +453,6 @@ class StackdriverDeleteAlertOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
         self.hook: StackdriverHook | None = None
 
@@ -487,7 +461,6 @@ class StackdriverDeleteAlertOperator(BaseOperator):
         if self.hook is None:
             self.hook = StackdriverHook(
                 gcp_conn_id=self.gcp_conn_id,
-                delegate_to=self.delegate_to,
                 impersonation_chain=self.impersonation_chain,
             )
         self.hook.delete_alert_policy(
@@ -498,13 +471,13 @@ class StackdriverDeleteAlertOperator(BaseOperator):
         )
 
 
-class StackdriverListNotificationChannelsOperator(BaseOperator):
+class StackdriverListNotificationChannelsOperator(GoogleCloudBaseOperator):
     """
-    Fetches all the Notification Channels identified by the filter passed as
-    filter parameter. The desired return type can be specified by the
-    format parameter, the supported formats are "dict", "json" and None
-    which returns python dictionary, stringified JSON and protobuf
-    respectively.
+    Fetches all the Notification Channels identified by the filter passed as filter parameter.
+
+    The desired return type can be specified by the format parameter, the
+    supported formats are "dict", "json" and None which returns python
+    dictionary, stringified JSON and protobuf respectively.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -534,9 +507,6 @@ class StackdriverListNotificationChannelsOperator(BaseOperator):
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :param project_id: The project to fetch notification channels from.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -566,8 +536,7 @@ class StackdriverListNotificationChannelsOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        project_id: str | None = None,
-        delegate_to: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -581,7 +550,6 @@ class StackdriverListNotificationChannelsOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
         self.hook: StackdriverHook | None = None
 
@@ -597,7 +565,6 @@ class StackdriverListNotificationChannelsOperator(BaseOperator):
         if self.hook is None:
             self.hook = StackdriverHook(
                 gcp_conn_id=self.gcp_conn_id,
-                delegate_to=self.delegate_to,
                 impersonation_chain=self.impersonation_chain,
             )
         channels = self.hook.list_notification_channels(
@@ -618,10 +585,11 @@ class StackdriverListNotificationChannelsOperator(BaseOperator):
         return [NotificationChannel.to_dict(channel) for channel in channels]
 
 
-class StackdriverEnableNotificationChannelsOperator(BaseOperator):
+class StackdriverEnableNotificationChannelsOperator(GoogleCloudBaseOperator):
     """
-    Enables one or more disabled alerting policies identified by filter
-    parameter. Inoperative in case the policy is already enabled.
+    Enables one or more disabled alerting policies identified by filter parameter.
+
+    Inoperative in case the policy is already enabled.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -639,9 +607,6 @@ class StackdriverEnableNotificationChannelsOperator(BaseOperator):
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :param project_id: The location used for the operation.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -668,8 +633,7 @@ class StackdriverEnableNotificationChannelsOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        project_id: str | None = None,
-        delegate_to: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -680,7 +644,6 @@ class StackdriverEnableNotificationChannelsOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
         self.hook: StackdriverHook | None = None
 
@@ -691,7 +654,6 @@ class StackdriverEnableNotificationChannelsOperator(BaseOperator):
         if self.hook is None:
             self.hook = StackdriverHook(
                 gcp_conn_id=self.gcp_conn_id,
-                delegate_to=self.delegate_to,
                 impersonation_chain=self.impersonation_chain,
             )
         self.hook.enable_notification_channels(
@@ -708,10 +670,11 @@ class StackdriverEnableNotificationChannelsOperator(BaseOperator):
         )
 
 
-class StackdriverDisableNotificationChannelsOperator(BaseOperator):
+class StackdriverDisableNotificationChannelsOperator(GoogleCloudBaseOperator):
     """
-    Disables one or more enabled notification channels identified by filter
-    parameter. Inoperative in case the policy is already disabled.
+    Disables one or more enabled notification channels identified by filter parameter.
+
+    Inoperative in case the policy is already disabled.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -729,9 +692,6 @@ class StackdriverDisableNotificationChannelsOperator(BaseOperator):
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :param project_id: The project in which notification channels needs to be enabled.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -758,8 +718,7 @@ class StackdriverDisableNotificationChannelsOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        project_id: str | None = None,
-        delegate_to: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -770,7 +729,6 @@ class StackdriverDisableNotificationChannelsOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
         self.hook: StackdriverHook | None = None
 
@@ -781,7 +739,6 @@ class StackdriverDisableNotificationChannelsOperator(BaseOperator):
         if self.hook is None:
             self.hook = StackdriverHook(
                 gcp_conn_id=self.gcp_conn_id,
-                delegate_to=self.delegate_to,
                 impersonation_chain=self.impersonation_chain,
             )
         self.hook.disable_notification_channels(
@@ -798,10 +755,11 @@ class StackdriverDisableNotificationChannelsOperator(BaseOperator):
         )
 
 
-class StackdriverUpsertNotificationChannelOperator(BaseOperator):
+class StackdriverUpsertNotificationChannelOperator(GoogleCloudBaseOperator):
     """
-    Creates a new notification or updates an existing notification channel
-    identified the name field in the alerts parameter.
+    Create a new notification or updates an existing notification channel.
+
+    Channel is identified by the name field in the alerts parameter.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -820,9 +778,6 @@ class StackdriverUpsertNotificationChannelOperator(BaseOperator):
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :param project_id: The project in which notification channels needs to be created/updated.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -850,8 +805,7 @@ class StackdriverUpsertNotificationChannelOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        project_id: str | None = None,
-        delegate_to: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -862,7 +816,6 @@ class StackdriverUpsertNotificationChannelOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
         self.hook: StackdriverHook | None = None
 
@@ -873,7 +826,6 @@ class StackdriverUpsertNotificationChannelOperator(BaseOperator):
         if self.hook is None:
             self.hook = StackdriverHook(
                 gcp_conn_id=self.gcp_conn_id,
-                delegate_to=self.delegate_to,
                 impersonation_chain=self.impersonation_chain,
             )
         self.hook.upsert_channel(
@@ -890,7 +842,7 @@ class StackdriverUpsertNotificationChannelOperator(BaseOperator):
         )
 
 
-class StackdriverDeleteNotificationChannelOperator(BaseOperator):
+class StackdriverDeleteNotificationChannelOperator(GoogleCloudBaseOperator):
     """
     Deletes a notification channel.
 
@@ -909,9 +861,6 @@ class StackdriverDeleteNotificationChannelOperator(BaseOperator):
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google
         Cloud Platform.
     :param project_id: The project from which notification channel needs to be deleted.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -937,8 +886,7 @@ class StackdriverDeleteNotificationChannelOperator(BaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        project_id: str | None = None,
-        delegate_to: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -949,7 +897,6 @@ class StackdriverDeleteNotificationChannelOperator(BaseOperator):
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
         self.project_id = project_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
         self.hook: StackdriverHook | None = None
 
@@ -958,7 +905,6 @@ class StackdriverDeleteNotificationChannelOperator(BaseOperator):
         if self.hook is None:
             self.hook = StackdriverHook(
                 gcp_conn_id=self.gcp_conn_id,
-                delegate_to=self.delegate_to,
                 impersonation_chain=self.impersonation_chain,
             )
         self.hook.delete_notification_channel(
