@@ -15,27 +15,20 @@
 # KIND, either express or implied.  See the License for the
 # specific language governing permissions and limitations
 # under the License.
-"""This module contains Google Vertex AI operators.
 
-.. spelling::
+"""This module contains Google Vertex AI operators."""
 
-    irreproducible
-    codepoints
-    Tensorboard
-    aiplatform
-    myVPC
-"""
 from __future__ import annotations
 
 import warnings
-from typing import TYPE_CHECKING, Sequence
+from typing import TYPE_CHECKING, Any, Sequence
 
 from google.api_core.exceptions import NotFound
 from google.api_core.gapic_v1.method import DEFAULT, _MethodDefault
-from google.api_core.retry import Retry
-from google.cloud.aiplatform import gapic, hyperparameter_tuning
-from google.cloud.aiplatform_v1.types import HyperparameterTuningJob
+from google.cloud.aiplatform_v1 import types
 
+from airflow.configuration import conf
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.providers.google.cloud.hooks.vertex_ai.hyperparameter_tuning_job import (
     HyperparameterTuningJobHook,
 )
@@ -44,14 +37,18 @@ from airflow.providers.google.cloud.links.vertex_ai import (
     VertexAITrainingLink,
 )
 from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
+from airflow.providers.google.cloud.triggers.vertex_ai import CreateHyperparameterTuningJobTrigger
 
 if TYPE_CHECKING:
+    from google.api_core.retry import Retry
+    from google.cloud.aiplatform import HyperparameterTuningJob, gapic, hyperparameter_tuning
+
     from airflow.utils.context import Context
 
 
 class CreateHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
     """
-    Create Hyperparameter Tuning job
+    Create Hyperparameter Tuning job.
 
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
     :param region: Required. The ID of the Google Cloud region that the service belongs to.
@@ -67,7 +64,7 @@ class CreateHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
     :param max_trial_count: Required. The desired total number of Trials.
     :param parallel_trial_count: Required. The desired number of Trials to run in parallel.
     :param worker_pool_specs: Required. The spec of the worker pools including machine type and Docker
-        image. Can provided as a list of dictionaries or list of WorkerPoolSpec proto messages.
+        image. Can be provided as a list of dictionaries or list of WorkerPoolSpec proto messages.
     :param base_output_dir: Optional. GCS output directory of job. If not provided a timestamped
         directory in the staging directory will be used.
     :param custom_job_labels: Optional. The labels with user-defined metadata to organize CustomJobs.
@@ -131,12 +128,9 @@ class CreateHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
         `service_account` is required with provided `tensorboard`. For more information on configuring
         your service account please visit:
         https://cloud.google.com/vertex-ai/docs/experiments/tensorboard-training
-    :param sync: Whether to execute this method synchronously. If False, this method will unblock and it
-        will be executed in a concurrent Future.
+    :param sync: (Deprecated) Whether to execute this method synchronously. If False, this method will
+        unblock, and it will be executed in a concurrent Future.
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -145,6 +139,8 @@ class CreateHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
         If set as a sequence, the identities from the list must grant
         Service Account Token Creator IAM role to the directly preceding identity, with first
         account from the list granting this role to the originating account (templated).
+    :param deferrable: Run operator in the deferrable mode.
+    :param poll_interval: Interval size which defines how often job status is checked in deferrable mode.
     """
 
     template_fields = [
@@ -186,8 +182,9 @@ class CreateHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
         sync: bool = True,
         # END: run param
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
+        deferrable: bool = conf.getboolean("operators", "default_deferrable", fallback=False),
+        poll_interval: int = 10,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -218,22 +215,24 @@ class CreateHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
         self.tensorboard = tensorboard
         self.sync = sync
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
         self.hook: HyperparameterTuningJobHook | None = None
+        self.deferrable = deferrable
+        self.poll_interval = poll_interval
 
     def execute(self, context: Context):
+        warnings.warn(
+            "The 'sync' parameter is deprecated and will be removed after 01.09.2024.",
+            AirflowProviderDeprecationWarning,
+            stacklevel=2,
+        )
+
         self.log.info("Creating Hyperparameter Tuning job")
         self.hook = HyperparameterTuningJobHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
-        result = self.hook.create_hyperparameter_tuning_job(
+        hyperparameter_tuning_job: HyperparameterTuningJob = self.hook.create_hyperparameter_tuning_job(
             project_id=self.project_id,
             region=self.region,
             display_name=self.display_name,
@@ -259,33 +258,52 @@ class CreateHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
             restart_job_on_worker_restart=self.restart_job_on_worker_restart,
             enable_web_access=self.enable_web_access,
             tensorboard=self.tensorboard,
-            sync=self.sync,
+            sync=False,
+            wait_job_completed=False,
         )
 
-        hyperparameter_tuning_job = result.to_dict()
-        hyperparameter_tuning_job_id = self.hook.extract_hyperparameter_tuning_job_id(
-            hyperparameter_tuning_job
-        )
+        hyperparameter_tuning_job.wait_for_resource_creation()
+        hyperparameter_tuning_job_id = hyperparameter_tuning_job.name
         self.log.info("Hyperparameter Tuning job was created. Job id: %s", hyperparameter_tuning_job_id)
 
         self.xcom_push(context, key="hyperparameter_tuning_job_id", value=hyperparameter_tuning_job_id)
         VertexAITrainingLink.persist(
             context=context, task_instance=self, training_id=hyperparameter_tuning_job_id
         )
-        return hyperparameter_tuning_job
+
+        if self.deferrable:
+            self.defer(
+                trigger=CreateHyperparameterTuningJobTrigger(
+                    conn_id=self.gcp_conn_id,
+                    project_id=self.project_id,
+                    location=self.region,
+                    job_id=hyperparameter_tuning_job_id,
+                    poll_interval=self.poll_interval,
+                    impersonation_chain=self.impersonation_chain,
+                ),
+                method_name="execute_complete",
+            )
+            return
+
+        hyperparameter_tuning_job.wait_for_completion()
+        return hyperparameter_tuning_job.to_dict()
 
     def on_kill(self) -> None:
-        """
-        Callback called when the operator is killed.
-        Cancel any running job.
-        """
+        """Act as a callback called when the operator is killed; cancel any running job."""
         if self.hook:
             self.hook.cancel_hyperparameter_tuning_job()
 
+    def execute_complete(self, context: Context, event: dict[str, Any]) -> dict[str, Any]:
+        if event and event["status"] == "error":
+            raise AirflowException(event["message"])
+        job: dict[str, Any] = event["job"]
+        self.log.info("Hyperparameter tuning job %s created and completed successfully.", job["name"])
+        return job
+
 
 class GetHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
     """
-    Gets a HyperparameterTuningJob
+    Gets a HyperparameterTuningJob.
 
     :param project_id: Required. The ID of the Google Cloud project that the service belongs to.
     :param region: Required. The ID of the Google Cloud region that the service belongs to.
@@ -294,9 +312,6 @@ class GetHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
     :param timeout: The timeout for this request.
     :param metadata: Strings which should be sent along with the request as metadata.
     :param gcp_conn_id: The connection ID to use connecting to Google Cloud.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -320,7 +335,6 @@ class GetHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -332,17 +346,11 @@ class GetHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
         self.timeout = timeout
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context):
         hook = HyperparameterTuningJobHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
 
@@ -360,7 +368,7 @@ class GetHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
                 context=context, task_instance=self, training_id=self.hyperparameter_tuning_job_id
             )
             self.log.info("Hyperparameter tuning job was gotten.")
-            return HyperparameterTuningJob.to_dict(result)
+            return types.HyperparameterTuningJob.to_dict(result)
         except NotFound:
             self.log.info(
                 "The Hyperparameter tuning job %s does not exist.", self.hyperparameter_tuning_job_id
@@ -392,7 +400,6 @@ class DeleteHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -404,17 +411,11 @@ class DeleteHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
         self.timeout = timeout
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context):
         hook = HyperparameterTuningJobHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
         try:
@@ -479,7 +480,6 @@ class ListHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
         timeout: float | None = None,
         metadata: Sequence[tuple[str, str]] = (),
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -494,17 +494,11 @@ class ListHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
         self.timeout = timeout
         self.metadata = metadata
         self.gcp_conn_id = gcp_conn_id
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def execute(self, context: Context):
         hook = HyperparameterTuningJobHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
         results = hook.list_hyperparameter_tuning_jobs(
@@ -519,4 +513,4 @@ class ListHyperparameterTuningJobOperator(GoogleCloudBaseOperator):
             metadata=self.metadata,
         )
         VertexAIHyperparameterTuningJobListLink.persist(context=context, task_instance=self)
-        return [HyperparameterTuningJob.to_dict(result) for result in results]
+        return [types.HyperparameterTuningJob.to_dict(result) for result in results]
