@@ -16,6 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains a Google Cloud Vision operator."""
+
 from __future__ import annotations
 
 from copy import deepcopy
@@ -33,6 +34,7 @@ from google.cloud.vision_v1 import (
 
 from airflow.providers.google.cloud.hooks.vision import CloudVisionHook
 from airflow.providers.google.cloud.operators.cloud_base import GoogleCloudBaseOperator
+from airflow.providers.google.common.hooks.base_google import PROVIDE_PROJECT_ID
 
 if TYPE_CHECKING:
     from google.api_core.retry import Retry
@@ -45,7 +47,8 @@ MetaData = Sequence[Tuple[str, str]]
 
 
 class CloudVisionCreateProductSetOperator(GoogleCloudBaseOperator):
-    """Create a new ProductSet resource.
+    """
+    Create a new ProductSet resource.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -93,7 +96,7 @@ class CloudVisionCreateProductSetOperator(GoogleCloudBaseOperator):
         *,
         product_set: dict | ProductSet,
         location: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         product_set_id: str | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
@@ -137,7 +140,8 @@ class CloudVisionCreateProductSetOperator(GoogleCloudBaseOperator):
 
 
 class CloudVisionGetProductSetOperator(GoogleCloudBaseOperator):
-    """Get information associated with a ProductSet.
+    """
+    Get information associated with a ProductSet.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -180,7 +184,7 @@ class CloudVisionGetProductSetOperator(GoogleCloudBaseOperator):
         *,
         location: str,
         product_set_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: MetaData = (),
@@ -214,7 +218,8 @@ class CloudVisionGetProductSetOperator(GoogleCloudBaseOperator):
 
 
 class CloudVisionUpdateProductSetOperator(GoogleCloudBaseOperator):
-    """Make changes to a `ProductSet` resource.
+    """
+    Make changes to a `ProductSet` resource.
 
     Only ``display_name`` can be updated currently.
 
@@ -278,7 +283,7 @@ class CloudVisionUpdateProductSetOperator(GoogleCloudBaseOperator):
         product_set: dict | ProductSet,
         location: str | None = None,
         product_set_id: str | None = None,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         update_mask: dict | FieldMask | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
@@ -320,7 +325,8 @@ class CloudVisionUpdateProductSetOperator(GoogleCloudBaseOperator):
 
 
 class CloudVisionDeleteProductSetOperator(GoogleCloudBaseOperator):
-    """Permanently deletes a ``ProductSet``.
+    """
+    Permanently deletes a ``ProductSet``.
 
     ``Products`` and ``ReferenceImages`` in the ``ProductSet`` are not deleted.
     The actual image files are not deleted from Google Cloud Storage.
@@ -366,7 +372,7 @@ class CloudVisionDeleteProductSetOperator(GoogleCloudBaseOperator):
         *,
         location: str,
         product_set_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: MetaData = (),
@@ -400,7 +406,8 @@ class CloudVisionDeleteProductSetOperator(GoogleCloudBaseOperator):
 
 
 class CloudVisionCreateProductOperator(GoogleCloudBaseOperator):
-    """Create and return a new product resource.
+    """
+    Create and return a new product resource.
 
     Possible errors regarding the ``Product`` object provided:
 
@@ -454,7 +461,7 @@ class CloudVisionCreateProductOperator(GoogleCloudBaseOperator):
         *,
         location: str,
         product: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         product_id: str | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
@@ -497,7 +504,8 @@ class CloudVisionCreateProductOperator(GoogleCloudBaseOperator):
 
 
 class CloudVisionGetProductOperator(GoogleCloudBaseOperator):
-    """Get information associated with a ``Product``.
+    """
+    Get information associated with a ``Product``.
 
     Possible errors:
 
@@ -544,7 +552,7 @@ class CloudVisionGetProductOperator(GoogleCloudBaseOperator):
         *,
         location: str,
         product_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: MetaData = (),
@@ -578,7 +586,8 @@ class CloudVisionGetProductOperator(GoogleCloudBaseOperator):
 
 
 class CloudVisionUpdateProductOperator(GoogleCloudBaseOperator):
-    """Make changes to a Product resource.
+    """
+    Make changes to a Product resource.
 
     Only the display_name, description, and labels fields can be updated right now.
 
@@ -651,7 +660,7 @@ class CloudVisionUpdateProductOperator(GoogleCloudBaseOperator):
         product: dict | Product,
         location: str | None = None,
         product_id: str | None = None,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         update_mask: dict | FieldMask | None = None,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
@@ -691,7 +700,8 @@ class CloudVisionUpdateProductOperator(GoogleCloudBaseOperator):
 
 
 class CloudVisionDeleteProductOperator(GoogleCloudBaseOperator):
-    """Permanently delete a product and its reference images.
+    """
+    Permanently delete a product and its reference images.
 
     Metadata of the product and all its images will be deleted right away, but
     search queries against ProductSets containing the product may still work
@@ -742,7 +752,7 @@ class CloudVisionDeleteProductOperator(GoogleCloudBaseOperator):
         *,
         location: str,
         product_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: MetaData = (),
@@ -776,7 +786,8 @@ class CloudVisionDeleteProductOperator(GoogleCloudBaseOperator):
 
 
 class CloudVisionImageAnnotateOperator(GoogleCloudBaseOperator):
-    """Run image detection and annotation for an image or a batch of images.
+    """
+    Run image detection and annotation for an image or a batch of images.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -843,7 +854,8 @@ class CloudVisionImageAnnotateOperator(GoogleCloudBaseOperator):
 
 
 class CloudVisionCreateReferenceImageOperator(GoogleCloudBaseOperator):
-    """Create and return a new ReferenceImage ID resource.
+    """
+    Create and return a new ReferenceImage ID resource.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -898,7 +910,7 @@ class CloudVisionCreateReferenceImageOperator(GoogleCloudBaseOperator):
         reference_image: dict | ReferenceImage,
         product_id: str,
         reference_image_id: str | None = None,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: MetaData = (),
@@ -946,7 +958,8 @@ class CloudVisionCreateReferenceImageOperator(GoogleCloudBaseOperator):
 
 
 class CloudVisionDeleteReferenceImageOperator(GoogleCloudBaseOperator):
-    """Delete a ReferenceImage ID resource.
+    """
+    Delete a ReferenceImage ID resource.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -995,7 +1008,7 @@ class CloudVisionDeleteReferenceImageOperator(GoogleCloudBaseOperator):
         location: str,
         product_id: str,
         reference_image_id: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: MetaData = (),
@@ -1031,7 +1044,8 @@ class CloudVisionDeleteReferenceImageOperator(GoogleCloudBaseOperator):
 
 
 class CloudVisionAddProductToProductSetOperator(GoogleCloudBaseOperator):
-    """Add a Product to the specified ProductSet.
+    """
+    Add a Product to the specified ProductSet.
 
     If the Product is already present, no change is made. One Product can be
     added to at most 100 ProductSets.
@@ -1084,7 +1098,7 @@ class CloudVisionAddProductToProductSetOperator(GoogleCloudBaseOperator):
         product_set_id: str,
         product_id: str,
         location: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: MetaData = (),
@@ -1120,7 +1134,8 @@ class CloudVisionAddProductToProductSetOperator(GoogleCloudBaseOperator):
 
 
 class CloudVisionRemoveProductFromProductSetOperator(GoogleCloudBaseOperator):
-    """Remove a Product from the specified ProductSet.
+    """
+    Remove a Product from the specified ProductSet.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -1166,7 +1181,7 @@ class CloudVisionRemoveProductFromProductSetOperator(GoogleCloudBaseOperator):
         product_set_id: str,
         product_id: str,
         location: str,
-        project_id: str | None = None,
+        project_id: str = PROVIDE_PROJECT_ID,
         retry: Retry | _MethodDefault = DEFAULT,
         timeout: float | None = None,
         metadata: MetaData = (),
@@ -1202,7 +1217,8 @@ class CloudVisionRemoveProductFromProductSetOperator(GoogleCloudBaseOperator):
 
 
 class CloudVisionDetectTextOperator(GoogleCloudBaseOperator):
-    """Detect Text in the image.
+    """
+    Detect Text in the image.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -1283,7 +1299,8 @@ class CloudVisionDetectTextOperator(GoogleCloudBaseOperator):
 
 
 class CloudVisionTextDetectOperator(GoogleCloudBaseOperator):
-    """Detect Document Text in the image.
+    """
+    Detect Document Text in the image.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -1363,7 +1380,8 @@ class CloudVisionTextDetectOperator(GoogleCloudBaseOperator):
 
 
 class CloudVisionDetectImageLabelsOperator(GoogleCloudBaseOperator):
-    """Detect Document Text in the image.
+    """
+    Detect Document Text in the image.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -1433,7 +1451,8 @@ class CloudVisionDetectImageLabelsOperator(GoogleCloudBaseOperator):
 
 
 class CloudVisionDetectImageSafeSearchOperator(GoogleCloudBaseOperator):
-    """Detect Document Text in the image.
+    """
+    Detect Document Text in the image.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -1505,7 +1524,8 @@ class CloudVisionDetectImageSafeSearchOperator(GoogleCloudBaseOperator):
 def prepare_additional_parameters(
     additional_properties: dict | None, language_hints: Any, web_detection_params: Any
 ) -> dict | None:
-    """Create a value for the ``additional_properties`` parameter.
+    """
+    Create a value for the ``additional_properties`` parameter.
 
     The new value is based on ``language_hints``, ``web_detection_params``, and
     ``additional_properties`` parameters specified by the user.
