@@ -16,19 +16,19 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Cloud Storage sensors."""
+
 from __future__ import annotations
 
 import os
 import textwrap
-import warnings
 from datetime import datetime, timedelta
 from typing import TYPE_CHECKING, Any, Callable, Sequence
 
-from google.api_core.retry import Retry
+from deprecated import deprecated
 from google.cloud.storage.retry import DEFAULT_RETRY
 
 from airflow.configuration import conf
-from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning, AirflowSkipException
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
 from airflow.providers.google.cloud.triggers.gcs import (
     GCSBlobTrigger,
@@ -39,6 +39,8 @@ from airflow.providers.google.cloud.triggers.gcs import (
 from airflow.sensors.base import BaseSensorOperator, poke_mode_only
 
 if TYPE_CHECKING:
+    from google.api_core.retry import Retry
+
     from airflow.utils.context import Context
 
 
@@ -49,6 +51,7 @@ class GCSObjectExistenceSensor(BaseSensorOperator):
     :param bucket: The Google Cloud Storage bucket where the object is.
     :param object: The name of the object to check in the Google cloud
         storage bucket.
+    :param use_glob: When set to True the object parameter is interpreted as glob
     :param google_cloud_conn_id: The connection ID to use when
         connecting to Google Cloud Storage.
     :param impersonation_chain: Optional service account to impersonate using short-term
@@ -74,6 +77,7 @@ class GCSObjectExistenceSensor(BaseSensorOperator):
         *,
         bucket: str,
         object: str,
+        use_glob: bool = False,
         google_cloud_conn_id: str = "google_cloud_default",
         impersonation_chain: str | Sequence[str] | None = None,
         retry: Retry = DEFAULT_RETRY,
@@ -83,7 +87,9 @@ class GCSObjectExistenceSensor(BaseSensorOperator):
         super().__init__(**kwargs)
         self.bucket = bucket
         self.object = object
+        self.use_glob = use_glob
         self.google_cloud_conn_id = google_cloud_conn_id
+        self._matches: bool = False
         self.impersonation_chain = impersonation_chain
         self.retry = retry
 
@@ -95,19 +101,23 @@ class GCSObjectExistenceSensor(BaseSensorOperator):
             gcp_conn_id=self.google_cloud_conn_id,
             impersonation_chain=self.impersonation_chain,
         )
-        return hook.exists(self.bucket, self.object, self.retry)
+        self._matches = (
+            bool(hook.list(self.bucket, match_glob=self.object))
+            if self.use_glob
+            else hook.exists(self.bucket, self.object, self.retry)
+        )
+        return self._matches
 
-    def execute(self, context: Context) -> None:
+    def execute(self, context: Context):
         """Airflow runs this method on the worker and defers using the trigger."""
-        if not self.deferrable:
-            super().execute(context)
-        else:
+        if self.deferrable:
             if not self.poke(context=context):
                 self.defer(
                     timeout=timedelta(seconds=self.timeout),
                     trigger=GCSBlobTrigger(
                         bucket=self.bucket,
                         object_name=self.object,
+                        use_glob=self.use_glob,
                         poke_interval=self.poke_interval,
                         google_cloud_conn_id=self.google_cloud_conn_id,
                         hook_params={
@@ -116,19 +126,32 @@ class GCSObjectExistenceSensor(BaseSensorOperator):
                     ),
                     method_name="execute_complete",
                 )
+        else:
+            super().execute(context)
+        return self._matches
 
-    def execute_complete(self, context: Context, event: dict[str, str]) -> str:
+    def execute_complete(self, context: Context, event: dict[str, str]) -> bool:
         """
-        Callback for when the trigger fires - returns immediately.
+        Act as a callback for when the trigger fires - returns immediately.
 
         Relies on trigger to throw an exception, otherwise it assumes execution was successful.
         """
         if event["status"] == "error":
+            # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
+            if self.soft_fail:
+                raise AirflowSkipException(event["message"])
             raise AirflowException(event["message"])
         self.log.info("File %s was found in bucket %s.", self.object, self.bucket)
-        return event["message"]
+        return True
 
 
+@deprecated(
+    reason=(
+        "Class `GCSObjectExistenceAsyncSensor` is deprecated and will be removed in a future release. "
+        "Please use `GCSObjectExistenceSensor` and set `deferrable` attribute to `True` instead"
+    ),
+    category=AirflowProviderDeprecationWarning,
+)
 class GCSObjectExistenceAsyncSensor(GCSObjectExistenceSensor):
     """
     Checks for the existence of a file in Google Cloud Storage.
@@ -152,17 +175,12 @@ class GCSObjectExistenceAsyncSensor(GCSObjectExistenceSensor):
     """
 
     def __init__(self, **kwargs: Any) -> None:
-        warnings.warn(
-            "Class `GCSObjectExistenceAsyncSensor` is deprecated and will be removed in a future release. "
-            "Please use `GCSObjectExistenceSensor` and set `deferrable` attribute to `True` instead",
-            AirflowProviderDeprecationWarning,
-        )
         super().__init__(deferrable=True, **kwargs)
 
 
 def ts_function(context):
     """
-    Default callback for the GoogleCloudStorageObjectUpdatedSensor.
+    Act as a default callback for the GoogleCloudStorageObjectUpdatedSensor.
 
     The default behaviour is check for the object being updated after the data interval's end,
     or execution_date + interval on Airflow versions prior to 2.2 (before AIP-39 implementation).
@@ -170,7 +188,15 @@ def ts_function(context):
     try:
         return context["data_interval_end"]
     except KeyError:
-        return context["dag"].following_schedule(context["execution_date"])
+        from airflow.utils import timezone
+
+        data_interval = context["dag"].infer_automated_data_interval(
+            timezone.coerce_datetime(context["execution_date"])
+        )
+        next_info = context["dag"].next_dagrun_info(data_interval, restricted=False)
+        if next_info is None:
+            return None
+        return next_info.data_interval.start
 
 
 class GCSObjectUpdateSensor(BaseSensorOperator):
@@ -251,15 +277,23 @@ class GCSObjectUpdateSensor(BaseSensorOperator):
                 )
 
     def execute_complete(self, context: dict[str, Any], event: dict[str, str] | None = None) -> str:
-        """Callback for when the trigger fires."""
+        """Return immediately and rely on trigger to throw a success event. Callback for the trigger."""
         if event:
             if event["status"] == "success":
                 self.log.info(
                     "Checking last updated time for object %s in bucket : %s", self.object, self.bucket
                 )
                 return event["message"]
+            # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
+            if self.soft_fail:
+                raise AirflowSkipException(event["message"])
             raise AirflowException(event["message"])
-        raise AirflowException("No event received in trigger callback")
+
+        # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
+        message = "No event received in trigger callback"
+        if self.soft_fail:
+            raise AirflowSkipException(message)
+        raise AirflowException(message)
 
 
 class GCSObjectsWithPrefixExistenceSensor(BaseSensorOperator):
@@ -340,17 +374,22 @@ class GCSObjectsWithPrefixExistenceSensor(BaseSensorOperator):
                     ),
                     method_name="execute_complete",
                 )
+            else:
+                return self._matches
 
     def execute_complete(self, context: dict[str, Any], event: dict[str, str | list[str]]) -> str | list[str]:
-        """Callback for the trigger; returns immediately and relies on trigger to throw a success event."""
+        """Return immediately and rely on trigger to throw a success event. Callback for the trigger."""
         self.log.info("Resuming from trigger and checking status")
         if event["status"] == "success":
             return event["matches"]
+        # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
+        if self.soft_fail:
+            raise AirflowSkipException(event["message"])
         raise AirflowException(event["message"])
 
 
 def get_time():
-    """This is just a wrapper of datetime.datetime.now to simplify mocking in the unittests."""
+    """Act as a wrapper of datetime.datetime.now to simplify mocking in the unittests."""
     return datetime.now()
 
 
@@ -420,7 +459,7 @@ class GCSUploadSessionCompleteSensor(BaseSensorOperator):
             raise ValueError("inactivity_period must be non-negative")
         self.inactivity_period = inactivity_period
         self.min_objects = min_objects
-        self.previous_objects = previous_objects if previous_objects else set()
+        self.previous_objects = previous_objects or set()
         self.inactivity_seconds = 0
         self.allow_delete = allow_delete
         self.google_cloud_conn_id = google_cloud_conn_id
@@ -475,10 +514,14 @@ class GCSUploadSessionCompleteSensor(BaseSensorOperator):
                 )
                 return False
 
-            raise AirflowException(
+            # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
+            message = (
                 "Illegal behavior: objects were deleted in "
                 f"{os.path.join(self.bucket, self.prefix)} between pokes."
             )
+            if self.soft_fail:
+                raise AirflowSkipException(message)
+            raise AirflowException(message)
 
         if self.last_activity_time:
             self.inactivity_seconds = (get_time() - self.last_activity_time).total_seconds()
@@ -541,12 +584,21 @@ class GCSUploadSessionCompleteSensor(BaseSensorOperator):
 
     def execute_complete(self, context: dict[str, Any], event: dict[str, str] | None = None) -> str:
         """
+        Rely on trigger to throw an exception, otherwise it assumes execution was successful.
+
         Callback for when the trigger fires - returns immediately.
 
-        Relies on trigger to throw an exception, otherwise it assumes execution was successful.
         """
         if event:
             if event["status"] == "success":
                 return event["message"]
+            # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
+            if self.soft_fail:
+                raise AirflowSkipException(event["message"])
             raise AirflowException(event["message"])
-        raise AirflowException("No event received in trigger callback")
+
+        # TODO: remove this if check when min_airflow_version is set to higher than 2.7.1
+        message = "No event received in trigger callback"
+        if self.soft_fail:
+            raise AirflowSkipException(message)
+        raise AirflowException(message)
