@@ -16,9 +16,9 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google BigQuery to BigQuery operator."""
+
 from __future__ import annotations
 
-import warnings
 from typing import TYPE_CHECKING, Sequence
 
 from airflow.models import BaseOperator
@@ -33,6 +33,9 @@ class BigQueryToBigQueryOperator(BaseOperator):
     """
     Copies data from one BigQuery table to another.
 
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:BigQueryToBigQueryOperator`
     .. seealso::
         For more details about these parameters:
         https://cloud.google.com/bigquery/docs/reference/v2/jobs#configuration.copy
@@ -47,16 +50,14 @@ class BigQueryToBigQueryOperator(BaseOperator):
     :param write_disposition: The write disposition if the table already exists.
     :param create_disposition: The create disposition if the table doesn't exist.
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param labels: a dictionary containing labels for the job/query,
         passed to BigQuery
     :param encryption_configuration: [Optional] Custom encryption configuration (e.g., Cloud KMS keys).
-        **Example**: ::
+
+        .. code-block:: python
 
             encryption_configuration = {
-                "kmsKeyName": "projects/testp/locations/us/keyRings/test-kr/cryptoKeys/test-key"
+                "kmsKeyName": "projects/testp/locations/us/keyRings/test-kr/cryptoKeys/test-key",
             }
     :param location: The geographic location of the job. You must specify the location to run the job if
         the location to run a job is not in the US or the EU multi-regional location or
@@ -91,7 +92,6 @@ class BigQueryToBigQueryOperator(BaseOperator):
         write_disposition: str = "WRITE_EMPTY",
         create_disposition: str = "CREATE_IF_NEEDED",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         labels: dict | None = None,
         encryption_configuration: dict | None = None,
         location: str | None = None,
@@ -105,11 +105,62 @@ class BigQueryToBigQueryOperator(BaseOperator):
         self.write_disposition = write_disposition
         self.create_disposition = create_disposition
         self.gcp_conn_id = gcp_conn_id
-        self.delegate_to = delegate_to
         self.labels = labels
         self.encryption_configuration = encryption_configuration
         self.location = location
         self.impersonation_chain = impersonation_chain
+        self.hook: BigQueryHook | None = None
+
+    def _prepare_job_configuration(self):
+        self.source_project_dataset_tables = (
+            [self.source_project_dataset_tables]
+            if not isinstance(self.source_project_dataset_tables, list)
+            else self.source_project_dataset_tables
+        )
+
+        source_project_dataset_tables_fixup = []
+        for source_project_dataset_table in self.source_project_dataset_tables:
+            source_project, source_dataset, source_table = self.hook.split_tablename(
+                table_input=source_project_dataset_table,
+                default_project_id=self.hook.project_id,
+                var_name="source_project_dataset_table",
+            )
+            source_project_dataset_tables_fixup.append(
+                {"projectId": source_project, "datasetId": source_dataset, "tableId": source_table}
+            )
+
+        destination_project, destination_dataset, destination_table = self.hook.split_tablename(
+            table_input=self.destination_project_dataset_table,
+            default_project_id=self.hook.project_id,
+        )
+        configuration = {
+            "copy": {
+                "createDisposition": self.create_disposition,
+                "writeDisposition": self.write_disposition,
+                "sourceTables": source_project_dataset_tables_fixup,
+                "destinationTable": {
+                    "projectId": destination_project,
+                    "datasetId": destination_dataset,
+                    "tableId": destination_table,
+                },
+            }
+        }
+
+        if self.labels:
+            configuration["labels"] = self.labels
+
+        if self.encryption_configuration:
+            configuration["copy"]["destinationEncryptionConfiguration"] = self.encryption_configuration
+
+        return configuration
+
+    def _submit_job(
+        self,
+        hook: BigQueryHook,
+        configuration: dict,
+    ) -> str:
+        job = hook.insert_job(configuration=configuration, project_id=hook.project_id)
+        return job.job_id
 
     def execute(self, context: Context) -> None:
         self.log.info(
@@ -119,28 +170,23 @@ class BigQueryToBigQueryOperator(BaseOperator):
         )
         hook = BigQueryHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             location=self.location,
             impersonation_chain=self.impersonation_chain,
         )
+        self.hook = hook
 
-        with warnings.catch_warnings():
-            warnings.simplefilter("ignore", DeprecationWarning)
-            job_id = hook.run_copy(
-                source_project_dataset_tables=self.source_project_dataset_tables,
-                destination_project_dataset_table=self.destination_project_dataset_table,
-                write_disposition=self.write_disposition,
-                create_disposition=self.create_disposition,
-                labels=self.labels,
-                encryption_configuration=self.encryption_configuration,
-            )
+        if not hook.project_id:
+            raise ValueError("The project_id should be set")
 
-            job = hook.get_job(job_id=job_id, location=self.location).to_api_repr()
-            conf = job["configuration"]["copy"]["destinationTable"]
-            BigQueryTableLink.persist(
-                context=context,
-                task_instance=self,
-                dataset_id=conf["datasetId"],
-                project_id=conf["projectId"],
-                table_id=conf["tableId"],
-            )
+        configuration = self._prepare_job_configuration()
+        job_id = self._submit_job(hook=hook, configuration=configuration)
+
+        job = hook.get_job(job_id=job_id, location=self.location).to_api_repr()
+        conf = job["configuration"]["copy"]["destinationTable"]
+        BigQueryTableLink.persist(
+            context=context,
+            task_instance=self,
+            dataset_id=conf["datasetId"],
+            project_id=conf["projectId"],
+            table_id=conf["tableId"],
+        )
