@@ -17,15 +17,16 @@
 from __future__ import annotations
 
 import json
-import warnings
-from datetime import datetime
 from tempfile import NamedTemporaryFile
-from typing import Any, Sequence
+from typing import TYPE_CHECKING, Any, Sequence
 
 from airflow.models import BaseOperator
 from airflow.providers.google.cloud.hooks.gcs import GCSHook
 from airflow.providers.google.suite.hooks.calendar import GoogleCalendarHook
 
+if TYPE_CHECKING:
+    from datetime import datetime
+
 
 class GoogleCalendarToGCSOperator(BaseOperator):
     """
@@ -65,9 +66,6 @@ class GoogleCalendarToGCSOperator(BaseOperator):
     :param destination_path: The Google Cloud Storage URI array for the object created by the operator.
         For example: ``path/to/my/files``.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -108,7 +106,6 @@ class GoogleCalendarToGCSOperator(BaseOperator):
         updated_min: datetime | None = None,
         destination_path: str | None = None,
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: str | None = None,
         impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
@@ -133,11 +130,6 @@ class GoogleCalendarToGCSOperator(BaseOperator):
         self.updated_min = updated_min
         self.destination_bucket = destination_bucket
         self.destination_path = destination_path
-        if delegate_to:
-            warnings.warn(
-                "'delegate_to' parameter is deprecated, please use 'impersonation_chain'", DeprecationWarning
-            )
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
     def _upload_data(
@@ -146,7 +138,6 @@ class GoogleCalendarToGCSOperator(BaseOperator):
     ) -> str:
         gcs_hook = GCSHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
 
@@ -173,7 +164,6 @@ class GoogleCalendarToGCSOperator(BaseOperator):
         calendar_hook = GoogleCalendarHook(
             api_version=self.api_version,
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
 
