@@ -16,9 +16,12 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Cloud Storage to SFTP operator."""
+
+from __future__ import annotations
+
 import os
 from tempfile import NamedTemporaryFile
-from typing import TYPE_CHECKING, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Sequence
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
@@ -35,7 +38,7 @@ class GCSToSFTPOperator(BaseOperator):
     """
     Transfer files from a Google Cloud Storage bucket to SFTP server.
 
-    **Example**: ::
+    .. code-block:: python
 
         with models.DAG(
             "example_gcs_to_sftp",
@@ -82,9 +85,6 @@ class GCSToSFTPOperator(BaseOperator):
     :param gcp_conn_id: (Optional) The connection ID used to connect to Google Cloud.
     :param sftp_conn_id: The sftp connection id. The name or identifier for
         establishing a connection to the SFTP server.
-    :param delegate_to: The account to impersonate using domain-wide delegation of authority,
-        if any. For this to work, the service account making the request must have
-        domain-wide delegation enabled.
     :param impersonation_chain: Optional service account to impersonate using short-term
         credentials, or chained list of accounts required to get the access_token
         of the last account in the list, which will be impersonated in the request.
@@ -113,8 +113,7 @@ class GCSToSFTPOperator(BaseOperator):
         move_object: bool = False,
         gcp_conn_id: str = "google_cloud_default",
         sftp_conn_id: str = "ssh_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -126,14 +125,12 @@ class GCSToSFTPOperator(BaseOperator):
         self.move_object = move_object
         self.gcp_conn_id = gcp_conn_id
         self.sftp_conn_id = sftp_conn_id
-        self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
         self.sftp_dirs = None
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         gcs_hook = GCSHook(
             gcp_conn_id=self.gcp_conn_id,
-            delegate_to=self.delegate_to,
             impersonation_chain=self.impersonation_chain,
         )
 
@@ -149,8 +146,11 @@ class GCSToSFTPOperator(BaseOperator):
 
             prefix, delimiter = self.source_object.split(WILDCARD, 1)
             prefix_dirname = os.path.dirname(prefix)
-
             objects = gcs_hook.list(self.source_bucket, prefix=prefix, delimiter=delimiter)
+            # TODO: After deprecating delimiter and wildcards in source objects,
+            #       remove the previous line and uncomment the following:
+            # match_glob = f"**/*{delimiter}" if delimiter else None
+            # objects = gcs_hook.list(self.source_bucket, prefix=prefix, match_glob=match_glob)
 
             for source_object in objects:
                 destination_path = self._resolve_destination_path(source_object, prefix=prefix_dirname)
@@ -162,7 +162,7 @@ class GCSToSFTPOperator(BaseOperator):
             self._copy_single_object(gcs_hook, sftp_hook, self.source_object, destination_path)
             self.log.info("Done. Uploaded '%s' file to %s", self.source_object, destination_path)
 
-    def _resolve_destination_path(self, source_object: str, prefix: Optional[str] = None) -> str:
+    def _resolve_destination_path(self, source_object: str, prefix: str | None = None) -> str:
         if not self.keep_directory_structure:
             if prefix:
                 source_object = os.path.relpath(source_object, start=prefix)
@@ -177,7 +177,7 @@ class GCSToSFTPOperator(BaseOperator):
         source_object: str,
         destination_path: str,
     ) -> None:
-        """Helper function to copy single object."""
+        """Copy single object."""
         self.log.info(
             "Executing copy of gs://%s/%s to %s",
             self.source_bucket,
