@@ -16,6 +16,7 @@
 # specific language governing permissions and limitations
 # under the License.
 """PostgreSQL to GCS operator."""
+
 from __future__ import annotations
 
 import datetime
@@ -25,6 +26,7 @@ import uuid
 from decimal import Decimal
 
 import pendulum
+from slugify import slugify
 
 from airflow.providers.google.cloud.transfers.sql_to_gcs import BaseSQLToGCSOperator
 from airflow.providers.postgres.hooks.postgres import PostgresHook
@@ -69,6 +71,10 @@ class PostgresToGCSOperator(BaseSQLToGCSOperator):
     """
     Copy data from Postgres to Google Cloud Storage in JSON, CSV or Parquet format.
 
+    .. seealso::
+        For more information on how to use this operator, take a look at the guide:
+        :ref:`howto/operator:PostgresToGCSOperator`
+
     :param postgres_conn_id: Reference to a specific Postgres hook.
     :param use_server_side_cursor: If server-side cursor should be used for querying postgres.
         For detailed info, check https://www.psycopg.org/docs/usage.html#server-side-cursors
@@ -108,10 +114,26 @@ class PostgresToGCSOperator(BaseSQLToGCSOperator):
         self.cursor_itersize = cursor_itersize
 
     def _unique_name(self):
-        return f"{self.dag_id}__{self.task_id}__{uuid.uuid4()}" if self.use_server_side_cursor else None
+        """
+        Generate a non-deterministic UUID for the cursor name using the task_id and dag_id.
+
+        Ensures the resulting name fits within the maximum length allowed for an identifier in Postgres.
+        """
+        if self.use_server_side_cursor:
+            separator = "__"
+            random_sufix = str(uuid.uuid4())
+            available_length = 63 - len(random_sufix) - (len(separator) * 2)
+            return separator.join(
+                (
+                    slugify(self.dag_id, allow_unicode=False, max_length=available_length // 2),
+                    slugify(self.task_id, allow_unicode=False, max_length=available_length // 2),
+                    random_sufix,
+                )
+            )
+        return None
 
     def query(self):
-        """Queries Postgres and returns a cursor to the results."""
+        """Query Postgres and returns a cursor to the results."""
         hook = PostgresHook(postgres_conn_id=self.postgres_conn_id)
         conn = hook.get_conn()
         cursor = conn.cursor(name=self._unique_name())
@@ -130,8 +152,8 @@ class PostgresToGCSOperator(BaseSQLToGCSOperator):
 
     def convert_type(self, value, schema_type, stringify_dict=True):
         """
-        Takes a value from Postgres, and converts it to a value that's safe for
-        JSON/Google Cloud Storage/BigQuery.
+        Take a value from Postgres and convert it to a value safe for JSON/Google Cloud Storage/BigQuery.
+
         Timezone aware Datetime are converted to UTC seconds.
         Unaware Datetime, Date and Time are converted to ISO formatted strings.
         Decimals are converted to floats.
