@@ -16,7 +16,10 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Search Ads 360 hook."""
-from typing import Any, Dict, Optional, Sequence, Union
+
+from __future__ import annotations
+
+from typing import Any, Sequence
 
 from googleapiclient.discovery import build
 
@@ -26,14 +29,14 @@ from airflow.providers.google.common.hooks.base_google import GoogleBaseHook
 class GoogleSearchAdsHook(GoogleBaseHook):
     """Hook for Google Search Ads 360."""
 
-    _conn = None  # type: Optional[Any]
+    _conn: build | None = None
 
     def __init__(
         self,
         api_version: str = "v2",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
     ) -> None:
         super().__init__(
             gcp_conn_id=gcp_conn_id,
@@ -43,7 +46,7 @@ class GoogleSearchAdsHook(GoogleBaseHook):
         self.api_version = api_version
 
     def get_conn(self):
-        """Retrieves connection to Google SearchAds."""
+        """Retrieve connection to Google SearchAds."""
         if not self._conn:
             http_authorized = self._authorize()
             self._conn = build(
@@ -54,9 +57,9 @@ class GoogleSearchAdsHook(GoogleBaseHook):
             )
         return self._conn
 
-    def insert_report(self, report: Dict[str, Any]) -> Any:
+    def insert_report(self, report: dict[str, Any]) -> Any:
         """
-        Inserts a report request into the reporting system.
+        Insert a report request into the reporting system.
 
         :param report: Report to be generated.
         """
@@ -65,7 +68,7 @@ class GoogleSearchAdsHook(GoogleBaseHook):
 
     def get(self, report_id: str) -> Any:
         """
-        Polls for the status of a report request.
+        Poll for the status of a report request.
 
         :param report_id: ID of the report request being polled.
         """
@@ -74,7 +77,7 @@ class GoogleSearchAdsHook(GoogleBaseHook):
 
     def get_file(self, report_fragment: int, report_id: str) -> Any:
         """
-        Downloads a report file encoded in UTF-8.
+        Download a report file encoded in UTF-8.
 
         :param report_fragment: The index of the report fragment to download.
         :param report_id: ID of the report.
