@@ -16,10 +16,13 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google CampaignManager operators."""
+
+from __future__ import annotations
+
 import json
 import tempfile
 import uuid
-from typing import TYPE_CHECKING, Any, Dict, List, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Any, Sequence
 
 from googleapiclient import http
 
@@ -38,7 +41,7 @@ class GoogleCampaignManagerDeleteReportOperator(BaseOperator):
 
     .. seealso::
         Check official API docs:
-        https://developers.google.com/doubleclick-advertisers/v3.3/reports/delete
+        `https://developers.google.com/doubleclick-advertisers/rest/v4/reports/delete`
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -47,7 +50,7 @@ class GoogleCampaignManagerDeleteReportOperator(BaseOperator):
     :param profile_id: The DFA user profile ID.
     :param report_name: The name of the report to delete.
     :param report_id: The ID of the report.
-    :param api_version: The version of the api that will be requested for example 'v3'.
+    :param api_version: The version of the api that will be requested, for example 'v4'.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
@@ -76,12 +79,12 @@ class GoogleCampaignManagerDeleteReportOperator(BaseOperator):
         self,
         *,
         profile_id: str,
-        report_name: Optional[str] = None,
-        report_id: Optional[str] = None,
-        api_version: str = "v3.3",
+        report_name: str | None = None,
+        report_id: str | None = None,
+        api_version: str = "v4",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -98,7 +101,7 @@ class GoogleCampaignManagerDeleteReportOperator(BaseOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = GoogleCampaignManagerHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -125,7 +128,7 @@ class GoogleCampaignManagerDownloadReportOperator(BaseOperator):
 
     .. seealso::
         Check official API docs:
-        https://developers.google.com/doubleclick-advertisers/v3.3/reports/files/get
+        `https://developers.google.com/doubleclick-advertisers/rest/v4/reports/get`
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -138,7 +141,7 @@ class GoogleCampaignManagerDownloadReportOperator(BaseOperator):
     :param report_name: The report name to set when uploading the local file.
     :param gzip: Option to compress local file or file data for upload
     :param chunk_size: File will be downloaded in chunks of this many bytes.
-    :param api_version: The version of the api that will be requested for example 'v3'.
+    :param api_version: The version of the api that will be requested, for example 'v4'.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
@@ -173,13 +176,13 @@ class GoogleCampaignManagerDownloadReportOperator(BaseOperator):
         report_id: str,
         file_id: str,
         bucket_name: str,
-        report_name: Optional[str] = None,
+        report_name: str | None = None,
         gzip: bool = True,
         chunk_size: int = 10 * 1024 * 1024,
-        api_version: str = "v3.3",
+        api_version: str = "v4",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -209,7 +212,7 @@ class GoogleCampaignManagerDownloadReportOperator(BaseOperator):
         bucket = name if not name.startswith("gs://") else name[5:]
         return bucket.strip("/")
 
-    def execute(self, context: 'Context') -> None:
+    def execute(self, context: Context) -> None:
         hook = GoogleCampaignManagerHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -257,7 +260,7 @@ class GoogleCampaignManagerInsertReportOperator(BaseOperator):
 
     .. seealso::
         Check official API docs:
-        https://developers.google.com/doubleclick-advertisers/v3.3/reports/insert
+        `https://developers.google.com/doubleclick-advertisers/rest/v4/reports/insert`
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -265,7 +268,7 @@ class GoogleCampaignManagerInsertReportOperator(BaseOperator):
 
     :param profile_id: The DFA user profile ID.
     :param report: Report to be created.
-    :param api_version: The version of the api that will be requested for example 'v3'.
+    :param api_version: The version of the api that will be requested, for example 'v4'.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
@@ -295,11 +298,11 @@ class GoogleCampaignManagerInsertReportOperator(BaseOperator):
         self,
         *,
         profile_id: str,
-        report: Dict[str, Any],
-        api_version: str = "v3.3",
+        report: dict[str, Any],
+        api_version: str = "v4",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -312,11 +315,11 @@ class GoogleCampaignManagerInsertReportOperator(BaseOperator):
 
     def prepare_template(self) -> None:
         # If .json is passed then we have to read the file
-        if isinstance(self.report, str) and self.report.endswith('.json'):
+        if isinstance(self.report, str) and self.report.endswith(".json"):
             with open(self.report) as file:
                 self.report = json.load(file)
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = GoogleCampaignManagerHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -337,7 +340,7 @@ class GoogleCampaignManagerRunReportOperator(BaseOperator):
 
     .. seealso::
         Check official API docs:
-        https://developers.google.com/doubleclick-advertisers/v3.3/reports/run
+        `https://developers.google.com/doubleclick-advertisers/rest/v4/reports/run`
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -346,7 +349,7 @@ class GoogleCampaignManagerRunReportOperator(BaseOperator):
     :param profile_id: The DFA profile ID.
     :param report_id: The ID of the report.
     :param synchronous: If set and true, tries to run the report synchronously.
-    :param api_version: The version of the api that will be requested for example 'v3'.
+    :param api_version: The version of the api that will be requested, for example 'v4'.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
@@ -377,10 +380,10 @@ class GoogleCampaignManagerRunReportOperator(BaseOperator):
         profile_id: str,
         report_id: str,
         synchronous: bool = False,
-        api_version: str = "v3.3",
+        api_version: str = "v4",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -392,7 +395,7 @@ class GoogleCampaignManagerRunReportOperator(BaseOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = GoogleCampaignManagerHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -417,15 +420,15 @@ class GoogleCampaignManagerBatchInsertConversionsOperator(BaseOperator):
 
     .. seealso::
         Check official API docs:
-        https://developers.google.com/doubleclick-advertisers/v3.3/conversions/batchinsert
+        `https://developers.google.com/doubleclick-advertisers/rest/v4/conversions/batchinsert`
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:GoogleCampaignManagerBatchInsertConversionsOperator`
 
     :param profile_id: User profile ID associated with this request.
-    :param conversions: Conversations to insert, should by type of Conversation:
-        https://developers.google.com/doubleclick-advertisers/v3.3/conversions#resource
+    :param conversions: Conversions to insert, should be type of Conversion:
+        https://developers.google.com/doubleclick-advertisers/rest/v4/conversions
     :param encryption_entity_type: The encryption entity type. This should match the encryption
         configuration for ad serving or Data Transfer.
     :param encryption_entity_id: The encryption entity ID. This should match the encryption
@@ -433,7 +436,7 @@ class GoogleCampaignManagerBatchInsertConversionsOperator(BaseOperator):
     :param encryption_source: Describes whether the encrypted cookie was received from ad serving
         (the %m macro) or from Data Transfer.
     :param max_failed_inserts: The maximum number of conversions that failed to be inserted
-    :param api_version: The version of the api that will be requested for example 'v3'.
+    :param api_version: The version of the api that will be requested, for example 'v4'.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
@@ -461,15 +464,15 @@ class GoogleCampaignManagerBatchInsertConversionsOperator(BaseOperator):
         self,
         *,
         profile_id: str,
-        conversions: List[Dict[str, Any]],
+        conversions: list[dict[str, Any]],
         encryption_entity_type: str,
         encryption_entity_id: int,
         encryption_source: str,
         max_failed_inserts: int = 0,
-        api_version: str = "v3.3",
+        api_version: str = "v4",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -484,7 +487,7 @@ class GoogleCampaignManagerBatchInsertConversionsOperator(BaseOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = GoogleCampaignManagerHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -508,15 +511,15 @@ class GoogleCampaignManagerBatchUpdateConversionsOperator(BaseOperator):
 
     .. seealso::
         Check official API docs:
-        https://developers.google.com/doubleclick-advertisers/v3.3/conversions/batchupdate
+        `https://developers.google.com/doubleclick-advertisers/rest/v4/conversions/batchupdate`
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
         :ref:`howto/operator:GoogleCampaignManagerBatchUpdateConversionsOperator`
 
     :param profile_id: User profile ID associated with this request.
-    :param conversions: Conversations to update, should by type of Conversation:
-        https://developers.google.com/doubleclick-advertisers/v3.3/conversions#resource
+    :param conversions: Conversations to update, should be type of Conversion:
+        https://developers.google.com/doubleclick-advertisers/rest/v4/conversions
     :param encryption_entity_type: The encryption entity type. This should match the encryption
         configuration for ad serving or Data Transfer.
     :param encryption_entity_id: The encryption entity ID. This should match the encryption
@@ -524,7 +527,7 @@ class GoogleCampaignManagerBatchUpdateConversionsOperator(BaseOperator):
     :param encryption_source: Describes whether the encrypted cookie was received from ad serving
         (the %m macro) or from Data Transfer.
     :param max_failed_updates: The maximum number of conversions that failed to be updated
-    :param api_version: The version of the api that will be requested for example 'v3'.
+    :param api_version: The version of the api that will be requested, for example 'v4'.
     :param gcp_conn_id: The connection ID to use when fetching connection info.
     :param delegate_to: The account to impersonate using domain-wide delegation of authority,
         if any. For this to work, the service account making the request must have
@@ -552,15 +555,15 @@ class GoogleCampaignManagerBatchUpdateConversionsOperator(BaseOperator):
         self,
         *,
         profile_id: str,
-        conversions: List[Dict[str, Any]],
+        conversions: list[dict[str, Any]],
         encryption_entity_type: str,
         encryption_entity_id: int,
         encryption_source: str,
         max_failed_updates: int = 0,
-        api_version: str = "v3.3",
+        api_version: str = "v4",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -575,7 +578,7 @@ class GoogleCampaignManagerBatchUpdateConversionsOperator(BaseOperator):
         self.delegate_to = delegate_to
         self.impersonation_chain = impersonation_chain
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = GoogleCampaignManagerHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
