@@ -16,9 +16,12 @@
 # specific language governing permissions and limitations
 # under the License.
 """This module contains Google Search Ads operators."""
+
+from __future__ import annotations
+
 import json
 from tempfile import NamedTemporaryFile
-from typing import TYPE_CHECKING, Any, Dict, Optional, Sequence, Union
+from typing import TYPE_CHECKING, Any, Sequence
 
 from airflow.exceptions import AirflowException
 from airflow.models import BaseOperator
@@ -66,11 +69,11 @@ class GoogleSearchAdsInsertReportOperator(BaseOperator):
     def __init__(
         self,
         *,
-        report: Dict[str, Any],
+        report: dict[str, Any],
         api_version: str = "v2",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -82,11 +85,11 @@ class GoogleSearchAdsInsertReportOperator(BaseOperator):
 
     def prepare_template(self) -> None:
         # If .json is passed then we have to read the file
-        if isinstance(self.report, str) and self.report.endswith('.json'):
+        if isinstance(self.report, str) and self.report.endswith(".json"):
             with open(self.report) as file:
                 self.report = json.load(file)
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = GoogleSearchAdsHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -145,13 +148,13 @@ class GoogleSearchAdsDownloadReportOperator(BaseOperator):
         *,
         report_id: str,
         bucket_name: str,
-        report_name: Optional[str] = None,
+        report_name: str | None = None,
         gzip: bool = True,
         chunk_size: int = 10 * 1024 * 1024,
         api_version: str = "v2",
         gcp_conn_id: str = "google_cloud_default",
-        delegate_to: Optional[str] = None,
-        impersonation_chain: Optional[Union[str, Sequence[str]]] = None,
+        delegate_to: str | None = None,
+        impersonation_chain: str | Sequence[str] | None = None,
         **kwargs,
     ) -> None:
         super().__init__(**kwargs)
@@ -187,7 +190,7 @@ class GoogleSearchAdsDownloadReportOperator(BaseOperator):
             return fragment_records[1]
         return b""
 
-    def execute(self, context: 'Context'):
+    def execute(self, context: Context):
         hook = GoogleSearchAdsHook(
             gcp_conn_id=self.gcp_conn_id,
             delegate_to=self.delegate_to,
@@ -206,8 +209,8 @@ class GoogleSearchAdsDownloadReportOperator(BaseOperator):
         report_name = self._resolve_file_name(report_name)
 
         response = hook.get(report_id=self.report_id)
-        if not response['isReportReady']:
-            raise AirflowException(f'Report {self.report_id} is not ready yet')
+        if not response["isReportReady"]:
+            raise AirflowException(f"Report {self.report_id} is not ready yet")
 
         # Resolve report fragments
         fragments_count = len(response["files"])
