@@ -21,14 +21,16 @@ import ast
 import json
 import socket
 import time
+from functools import cached_property
 from typing import Any, Iterable, Mapping, Sequence, Union
 from urllib.error import HTTPError, URLError
 
 import jenkins
+from deprecated.classic import deprecated
 from jenkins import Jenkins, JenkinsException
 from requests import Request
 
-from airflow.exceptions import AirflowException
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.models import BaseOperator
 from airflow.providers.jenkins.hooks.jenkins import JenkinsHook
 
@@ -37,7 +39,8 @@ ParamType = Union[str, dict, list, None]
 
 
 def jenkins_request_with_headers(jenkins_server: Jenkins, req: Request) -> JenkinsRequest | None:
-    """Create a Jenkins request from a raw request.
+    """
+    Create a Jenkins request from a raw request.
 
     We need to get the headers in addition to the body answer to get the
     location from them. This function uses ``jenkins_request`` from
@@ -73,7 +76,8 @@ def jenkins_request_with_headers(jenkins_server: Jenkins, req: Request) -> Jenki
 
 
 class JenkinsJobTriggerOperator(BaseOperator):
-    """Trigger a Jenkins Job and monitor its execution.
+    """
+    Trigger a Jenkins Job and monitor its execution.
 
     This operator depend on the python-jenkins library version >= 0.4.15 to
     communicate with the Jenkins server. You'll also need to configure a Jenkins
@@ -114,7 +118,8 @@ class JenkinsJobTriggerOperator(BaseOperator):
         self.allowed_jenkins_states = list(allowed_jenkins_states) if allowed_jenkins_states else ["SUCCESS"]
 
     def build_job(self, jenkins_server: Jenkins, params: ParamType = None) -> JenkinsRequest | None:
-        """Trigger a build job.
+        """
+        Trigger a build job.
 
         This returns a dict with 2 keys ``body`` and ``headers``. ``headers``
         contains also a dict-like object which can be queried to get the
@@ -134,7 +139,8 @@ class JenkinsJobTriggerOperator(BaseOperator):
         return jenkins_request_with_headers(jenkins_server, request)
 
     def poll_job_in_queue(self, location: str, jenkins_server: Jenkins) -> int:
-        """Poll the jenkins queue until the job is executed.
+        """
+        Poll the jenkins queue until the job is executed.
 
         When we trigger a job through an API call, the job is first put in the
         queue without having a build number assigned. We have to wait until the
@@ -149,12 +155,14 @@ class JenkinsJobTriggerOperator(BaseOperator):
         :param jenkins_server: The jenkins server to poll
         :return: The build_number corresponding to the triggered job
         """
-        try_count = 0
         location += "/api/json"
         # TODO Use get_queue_info instead
         # once it will be available in python-jenkins (v > 0.4.15)
         self.log.info("Polling jenkins queue at the url %s", location)
-        while try_count < self.max_try_before_job_appears:
+        for attempt in range(self.max_try_before_job_appears):
+            if attempt:
+                time.sleep(self.sleep_time)
+
             try:
                 location_answer = jenkins_request_with_headers(
                     jenkins_server, Request(method="POST", url=location)
@@ -163,31 +171,33 @@ class JenkinsJobTriggerOperator(BaseOperator):
             # until max_try_before_job_appears reached
             except (HTTPError, JenkinsException):
                 self.log.warning("polling failed, retrying", exc_info=True)
-                try_count += 1
-                time.sleep(self.sleep_time)
-                continue
+            else:
+                if location_answer is not None:
+                    json_response = json.loads(location_answer["body"])
+                    if (
+                        "executable" in json_response
+                        and json_response["executable"] is not None
+                        and "number" in json_response["executable"]
+                    ):
+                        build_number = json_response["executable"]["number"]
+                        self.log.info("Job executed on Jenkins side with the build number %s", build_number)
+                        return build_number
+        else:
+            raise AirflowException(
+                f"The job hasn't been executed after polling the queue "
+                f"{self.max_try_before_job_appears} times"
+            )
 
-            if location_answer is not None:
-                json_response = json.loads(location_answer["body"])
-                if (
-                    "executable" in json_response
-                    and json_response["executable"] is not None
-                    and "number" in json_response["executable"]
-                ):
-                    build_number = json_response["executable"]["number"]
-                    self.log.info("Job executed on Jenkins side with the build number %s", build_number)
-                    return build_number
-            try_count += 1
-            time.sleep(self.sleep_time)
-
-        raise AirflowException(
-            f"The job hasn't been executed after polling the queue {self.max_try_before_job_appears} times"
-        )
-
-    def get_hook(self) -> JenkinsHook:
+    @cached_property
+    def hook(self) -> JenkinsHook:
         """Instantiate the Jenkins hook."""
         return JenkinsHook(self.jenkins_connection_id)
 
+    @deprecated(reason="use `hook` property instead.", category=AirflowProviderDeprecationWarning)
+    def get_hook(self) -> JenkinsHook:
+        """Instantiate the Jenkins hook."""
+        return self.hook
+
     def execute(self, context: Mapping[Any, Any]) -> str | None:
         self.log.info(
             "Triggering the job %s on the jenkins : %s with the parameters : %s",
@@ -195,7 +205,7 @@ class JenkinsJobTriggerOperator(BaseOperator):
             self.jenkins_connection_id,
             self.parameters,
         )
-        jenkins_server = self.get_hook().get_jenkins_server()
+        jenkins_server = self.hook.get_jenkins_server()
         jenkins_response = self.build_job(jenkins_server, self.parameters)
         if jenkins_response:
             build_number = self.poll_job_in_queue(jenkins_response["headers"]["Location"], jenkins_server)
@@ -203,9 +213,8 @@ class JenkinsJobTriggerOperator(BaseOperator):
         time.sleep(self.sleep_time)
         keep_polling_job = True
         build_info = None
-
-        while keep_polling_job:
-            try:
+        try:
+            while keep_polling_job:
                 build_info = jenkins_server.get_build_info(name=self.job_name, number=build_number)
                 if build_info["result"] is not None:
                     keep_polling_job = False
@@ -218,17 +227,16 @@ class JenkinsJobTriggerOperator(BaseOperator):
                 else:
                     self.log.info("Waiting for job to complete : %s , build %s", self.job_name, build_number)
                     time.sleep(self.sleep_time)
-            except jenkins.NotFoundException as err:
-
-                raise AirflowException(f"Jenkins job status check failed. Final error was: {err.resp.status}")
-            except jenkins.JenkinsException as err:
-                raise AirflowException(
-                    f"Jenkins call failed with error : {err}, if you have parameters "
-                    "double check them, jenkins sends back "
-                    "this exception for unknown parameters"
-                    "You can also check logs for more details on this exception "
-                    "(jenkins_url/log/rss)"
-                )
+        except jenkins.NotFoundException as err:
+            raise AirflowException(f"Jenkins job status check failed. Final error was: {err.resp.status}")
+        except jenkins.JenkinsException as err:
+            raise AirflowException(
+                f"Jenkins call failed with error : {err}, if you have parameters "
+                "double check them, jenkins sends back "
+                "this exception for unknown parameters"
+                "You can also check logs for more details on this exception "
+                "(jenkins_url/log/rss)"
+            )
         if build_info:
             # If we can we return the url of the job
             # for later use (like retrieving an artifact)
