@@ -17,16 +17,17 @@
 # under the License.
 from __future__ import annotations
 
-import warnings
 from functools import cached_property
 from typing import TYPE_CHECKING, Any, cast
 
 from azure.common.client_factory import get_client_from_auth_file, get_client_from_json_dict
 from azure.identity import ClientSecretCredential, DefaultAzureCredential
 from azure.mgmt.containerinstance import ContainerInstanceManagementClient
+from deprecated import deprecated
 
 from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.providers.microsoft.azure.hooks.base_azure import AzureBaseHook
+from airflow.providers.microsoft.azure.utils import get_sync_default_azure_credential
 
 if TYPE_CHECKING:
     from azure.mgmt.containerinstance.models import (
@@ -65,7 +66,7 @@ class AzureContainerInstanceHook(AzureBaseHook):
 
     def get_conn(self) -> Any:
         """
-        Authenticates the resource using the connection id passed during init.
+        Authenticate the resource using the connection id passed during init.
 
         :return: the authenticated client.
         """
@@ -92,7 +93,12 @@ class AzureContainerInstanceHook(AzureBaseHook):
             )
         else:
             self.log.info("Using DefaultAzureCredential as credential")
-            credential = DefaultAzureCredential()
+            managed_identity_client_id = conn.extra_dejson.get("managed_identity_client_id")
+            workload_identity_tenant_id = conn.extra_dejson.get("workload_identity_tenant_id")
+            credential = get_sync_default_azure_credential(
+                managed_identity_client_id=managed_identity_client_id,
+                workload_identity_tenant_id=workload_identity_tenant_id,
+            )
 
         subscription_id = cast(str, conn.extra_dejson.get("subscriptionId"))
         return ContainerInstanceManagementClient(
@@ -110,6 +116,10 @@ class AzureContainerInstanceHook(AzureBaseHook):
         """
         self.connection.container_groups.begin_create_or_update(resource_group, name, container_group)
 
+    @deprecated(
+        reason="get_state_exitcode_details() is deprecated. Related method is get_state()",
+        category=AirflowProviderDeprecationWarning,
+    )
     def get_state_exitcode_details(self, resource_group: str, name: str) -> tuple:
         """
         Get the state and exitcode of a container group.
@@ -119,17 +129,16 @@ class AzureContainerInstanceHook(AzureBaseHook):
         :return: A tuple with the state, exitcode, and details.
             If the exitcode is unknown 0 is returned.
         """
-        warnings.warn(
-            "get_state_exitcode_details() is deprecated. Related method is get_state()",
-            AirflowProviderDeprecationWarning,
-            stacklevel=2,
-        )
         cg_state = self.get_state(resource_group, name)
         container = cg_state.containers[0]
         instance_view: ContainerPropertiesInstanceView = container.instance_view  # type: ignore[assignment]
         c_state: ContainerState = instance_view.current_state  # type: ignore[assignment]
         return c_state.state, c_state.exit_code, c_state.detail_status
 
+    @deprecated(
+        reason="get_messages() is deprecated. Related method is get_state()",
+        category=AirflowProviderDeprecationWarning,
+    )
     def get_messages(self, resource_group: str, name: str) -> list:
         """
         Get the messages of a container group.
@@ -138,11 +147,6 @@ class AzureContainerInstanceHook(AzureBaseHook):
         :param name: the name of the container group
         :return: A list of the event messages
         """
-        warnings.warn(
-            "get_messages() is deprecated. Related method is get_state()",
-            AirflowProviderDeprecationWarning,
-            stacklevel=2,
-        )
         cg_state = self.get_state(resource_group, name)
         container = cg_state.containers[0]
         instance_view: ContainerPropertiesInstanceView = container.instance_view  # type: ignore[assignment]
@@ -169,6 +173,8 @@ class AzureContainerInstanceHook(AzureBaseHook):
         :return: A list of log messages
         """
         logs = self.connection.containers.list_logs(resource_group, name, name, tail=tail)
+        if logs.content is None:
+            return [None]
         return logs.content.splitlines(True)
 
     def delete(self, resource_group: str, name: str) -> None:
