@@ -22,7 +22,7 @@ from typing import Any, Union
 
 from azure.core.exceptions import ResourceExistsError, ResourceNotFoundError
 from azure.datalake.store import core, lib, multithread
-from azure.identity import ClientSecretCredential
+from azure.identity import ClientSecretCredential, DefaultAzureCredential
 from azure.storage.filedatalake import (
     DataLakeDirectoryClient,
     DataLakeFileClient,
@@ -38,13 +38,15 @@ from airflow.providers.microsoft.azure.utils import (
     AzureIdentityCredentialAdapter,
     add_managed_identity_connection_widgets,
     get_field,
+    get_sync_default_azure_credential,
 )
 
-Credentials = Union[ClientSecretCredential, AzureIdentityCredentialAdapter]
+Credentials = Union[ClientSecretCredential, AzureIdentityCredentialAdapter, DefaultAzureCredential]
 
 
 class AzureDataLakeHook(BaseHook):
-    """Integration with Azure Data Lake.
+    """
+    Integration with Azure Data Lake.
 
     AzureDataLakeHook communicates via a REST API compatible with WebHDFS. Make
     sure that a Airflow connection of type ``azure_data_lake`` exists.
@@ -134,7 +136,8 @@ class AzureDataLakeHook(BaseHook):
         return self._conn
 
     def check_for_file(self, file_path: str) -> bool:
-        """Check if a file exists on Azure Data Lake.
+        """
+        Check if a file exists on Azure Data Lake.
 
         :param file_path: Path and name of the file.
         :return: True if the file exists, False otherwise.
@@ -155,7 +158,8 @@ class AzureDataLakeHook(BaseHook):
         blocksize: int = 4194304,
         **kwargs,
     ) -> None:
-        """Upload a file to Azure Data Lake.
+        """
+        Upload a file to Azure Data Lake.
 
         :param local_path: local path. Can be single file, directory (in which case,
             upload recursively) or glob pattern. Recursive glob patterns using `**`
@@ -195,7 +199,8 @@ class AzureDataLakeHook(BaseHook):
         blocksize: int = 4194304,
         **kwargs,
     ) -> None:
-        """Download a file from Azure Blob Storage.
+        """
+        Download a file from Azure Blob Storage.
 
         :param local_path: local path. If downloading a single file, will write to this
             specific file, unless it is an existing directory, in which case a file is
@@ -227,7 +232,8 @@ class AzureDataLakeHook(BaseHook):
         )
 
     def list(self, path: str) -> list:
-        """List files in Azure Data Lake Storage.
+        """
+        List files in Azure Data Lake Storage.
 
         :param path: full path/globstring to use to list files in ADLS
         """
@@ -237,7 +243,8 @@ class AzureDataLakeHook(BaseHook):
             return self.get_conn().walk(path)
 
     def remove(self, path: str, recursive: bool = False, ignore_not_found: bool = True) -> None:
-        """Remove files in Azure Data Lake Storage.
+        """
+        Remove files in Azure Data Lake Storage.
 
         :param path: A directory or file to remove in ADLS
         :param recursive: Whether to loop into directories in the location and remove the files
@@ -253,7 +260,8 @@ class AzureDataLakeHook(BaseHook):
 
 
 class AzureDataLakeStorageV2Hook(BaseHook):
-    """Interact with a ADLS gen2 storage account.
+    """
+    Interact with a ADLS gen2 storage account.
 
     It mainly helps to create and manage directories and files in storage
     accounts that have a hierarchical namespace. Using Adls_v2 connection
@@ -358,7 +366,7 @@ class AzureDataLakeStorageV2Hook(BaseHook):
         else:
             managed_identity_client_id = self._get_field(extra, "managed_identity_client_id")
             workload_identity_tenant_id = self._get_field(extra, "workload_identity_tenant_id")
-            credential = AzureIdentityCredentialAdapter(
+            credential = get_sync_default_azure_credential(
                 managed_identity_client_id=managed_identity_client_id,
                 workload_identity_tenant_id=workload_identity_tenant_id,
             )
@@ -374,7 +382,8 @@ class AzureDataLakeStorageV2Hook(BaseHook):
         )
 
     def create_file_system(self, file_system_name: str) -> None:
-        """Create a new file system under the specified account.
+        """
+        Create a new file system under the specified account.
 
         A container acts as a file system for your files.
 
@@ -392,7 +401,8 @@ class AzureDataLakeStorageV2Hook(BaseHook):
             raise
 
     def get_file_system(self, file_system: FileSystemProperties | str) -> FileSystemClient:
-        """Get a client to interact with the specified file system.
+        """
+        Get a client to interact with the specified file system.
 
         :param file_system: This can either be the name of the file system
             or an instance of FileSystemProperties.
@@ -410,7 +420,8 @@ class AzureDataLakeStorageV2Hook(BaseHook):
     def create_directory(
         self, file_system_name: FileSystemProperties | str, directory_name: str, **kwargs
     ) -> DataLakeDirectoryClient:
-        """Create a directory under the specified file system.
+        """
+        Create a directory under the specified file system.
 
         :param file_system_name: Name of the file system or instance of FileSystemProperties.
         :param directory_name: Name of the directory which needs to be created in the file system.
@@ -423,7 +434,8 @@ class AzureDataLakeStorageV2Hook(BaseHook):
         file_system_name: FileSystemProperties | str,
         directory_name: DirectoryProperties | str,
     ) -> DataLakeDirectoryClient:
-        """Get the specific directory under the specified file system.
+        """
+        Get the specific directory under the specified file system.
 
         :param file_system_name: Name of the file system or instance of FileSystemProperties.
         :param directory_name: Name of the directory or instance of DirectoryProperties which needs to be
@@ -442,7 +454,8 @@ class AzureDataLakeStorageV2Hook(BaseHook):
             raise
 
     def create_file(self, file_system_name: FileSystemProperties | str, file_name: str) -> DataLakeFileClient:
-        """Create a file under the file system.
+        """
+        Create a file under the file system.
 
         :param file_system_name: Name of the file system or instance of FileSystemProperties.
         :param file_name: Name of the file which needs to be created in the file system.
@@ -458,7 +471,8 @@ class AzureDataLakeStorageV2Hook(BaseHook):
         overwrite: bool = False,
         **kwargs: Any,
     ) -> None:
-        """Create a file with data in the file system.
+        """
+        Create a file with data in the file system.
 
         :param file_system_name: Name of the file system or instance of FileSystemProperties.
         :param file_name: Name of the file to be created with name.
@@ -478,7 +492,8 @@ class AzureDataLakeStorageV2Hook(BaseHook):
         overwrite: bool = False,
         **kwargs: Any,
     ) -> None:
-        """Upload data to a file.
+        """
+        Upload data to a file.
 
         :param file_system_name: Name of the file system or instance of FileSystemProperties.
         :param directory_name: Name of the directory.
@@ -494,7 +509,8 @@ class AzureDataLakeStorageV2Hook(BaseHook):
     def list_files_directory(
         self, file_system_name: FileSystemProperties | str, directory_name: str
     ) -> list[str]:
-        """List files or directories under the specified file system.
+        """
+        List files or directories under the specified file system.
 
         :param file_system_name: Name of the file system or instance of FileSystemProperties.
         :param directory_name: Name of the directory.
@@ -508,7 +524,8 @@ class AzureDataLakeStorageV2Hook(BaseHook):
     def list_file_system(
         self, prefix: str | None = None, include_metadata: bool = False, **kwargs: Any
     ) -> list[str]:
-        """List file systems under the specified account.
+        """
+        List file systems under the specified account.
 
         :param prefix:
             Filters the results to return only file systems whose names
@@ -525,7 +542,8 @@ class AzureDataLakeStorageV2Hook(BaseHook):
         return file_system_list
 
     def delete_file_system(self, file_system_name: FileSystemProperties | str) -> None:
-        """Delete the file system.
+        """
+        Delete the file system.
 
         :param file_system_name: Name of the file system or instance of FileSystemProperties.
         """
@@ -539,7 +557,8 @@ class AzureDataLakeStorageV2Hook(BaseHook):
             raise
 
     def delete_directory(self, file_system_name: FileSystemProperties | str, directory_name: str) -> None:
-        """Delete the specified directory in a file system.
+        """
+        Delete the specified directory in a file system.
 
         :param file_system_name: Name of the file system or instance of FileSystemProperties.
         :param directory_name: Name of the directory.
