@@ -16,13 +16,16 @@
 # under the License.
 from __future__ import annotations
 
-import datetime
 from typing import TYPE_CHECKING, Any, Sequence
 
+from azure.core.exceptions import ResourceNotFoundError
+
 from airflow.models import BaseOperator
 from airflow.providers.microsoft.azure.hooks.asb import AdminClientHook, MessageHook
 
 if TYPE_CHECKING:
+    import datetime
+
     from azure.servicebus.management._models import AuthorizationRule
 
     from airflow.utils.context import Context
@@ -30,7 +33,7 @@ if TYPE_CHECKING:
 
 class AzureServiceBusCreateQueueOperator(BaseOperator):
     """
-    Creates a Azure Service Bus queue under a Service Bus Namespace by using ServiceBusAdministrationClient
+    Create a Azure Service Bus queue under a Service Bus Namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -68,7 +71,7 @@ class AzureServiceBusCreateQueueOperator(BaseOperator):
         self.azure_service_bus_conn_id = azure_service_bus_conn_id
 
     def execute(self, context: Context) -> None:
-        """Creates Queue in Azure Service Bus namespace, by connecting to Service Bus Admin client in hook"""
+        """Create Queue in Azure Service Bus namespace, by connecting to Service Bus Admin client in hook."""
         hook = AdminClientHook(azure_service_bus_conn_id=self.azure_service_bus_conn_id)
 
         # create queue with name
@@ -83,7 +86,7 @@ class AzureServiceBusCreateQueueOperator(BaseOperator):
 
 class AzureServiceBusSendMessageOperator(BaseOperator):
     """
-    Send Message or batch message to the Service Bus queue
+    Send Message or batch message to the Service Bus queue.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -116,10 +119,7 @@ class AzureServiceBusSendMessageOperator(BaseOperator):
         self.azure_service_bus_conn_id = azure_service_bus_conn_id
 
     def execute(self, context: Context) -> None:
-        """
-        Sends Message to the specific queue in Service Bus namespace, by
-        connecting to Service Bus  client
-        """
+        """Send Message to the specific queue in Service Bus namespace."""
         # Create the hook
         hook = MessageHook(azure_service_bus_conn_id=self.azure_service_bus_conn_id)
 
@@ -129,7 +129,7 @@ class AzureServiceBusSendMessageOperator(BaseOperator):
 
 class AzureServiceBusReceiveMessageOperator(BaseOperator):
     """
-    Receive a batch of messages at once in a specified Queue name
+    Receive a batch of messages at once in a specified Queue name.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -161,10 +161,7 @@ class AzureServiceBusReceiveMessageOperator(BaseOperator):
         self.max_wait_time = max_wait_time
 
     def execute(self, context: Context) -> None:
-        """
-        Receive Message in specific queue in Service Bus namespace,
-        by connecting to Service Bus client
-        """
+        """Receive Message in specific queue in Service Bus namespace by connecting to Service Bus client."""
         # Create the hook
         hook = MessageHook(azure_service_bus_conn_id=self.azure_service_bus_conn_id)
 
@@ -176,7 +173,7 @@ class AzureServiceBusReceiveMessageOperator(BaseOperator):
 
 class AzureServiceBusDeleteQueueOperator(BaseOperator):
     """
-    Deletes the Queue in the Azure Service Bus namespace
+    Delete the Queue in the Azure Service Bus namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -202,7 +199,7 @@ class AzureServiceBusDeleteQueueOperator(BaseOperator):
         self.azure_service_bus_conn_id = azure_service_bus_conn_id
 
     def execute(self, context: Context) -> None:
-        """Delete Queue in Service Bus namespace, by connecting to Service Bus Admin client"""
+        """Delete Queue in Service Bus namespace, by connecting to Service Bus Admin client."""
         # Create the hook
         hook = AdminClientHook(azure_service_bus_conn_id=self.azure_service_bus_conn_id)
 
@@ -212,7 +209,7 @@ class AzureServiceBusDeleteQueueOperator(BaseOperator):
 
 class AzureServiceBusTopicCreateOperator(BaseOperator):
     """
-    Create an Azure Service Bus Topic under a Service Bus Namespace by using ServiceBusAdministrationClient
+    Create an Azure Service Bus Topic under a Service Bus Namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -296,7 +293,7 @@ class AzureServiceBusTopicCreateOperator(BaseOperator):
         self.max_message_size_in_kilobytes = max_message_size_in_kilobytes
 
     def execute(self, context: Context) -> str:
-        """Creates Topic in Service Bus namespace, by connecting to Service Bus Admin client"""
+        """Create Topic in Service Bus namespace, by connecting to Service Bus Admin client."""
         if self.topic_name is None:
             raise TypeError("Topic name cannot be None.")
 
@@ -304,7 +301,10 @@ class AzureServiceBusTopicCreateOperator(BaseOperator):
         hook = AdminClientHook(azure_service_bus_conn_id=self.azure_service_bus_conn_id)
 
         with hook.get_conn() as service_mgmt_conn:
-            topic_properties = service_mgmt_conn.get_topic(self.topic_name)
+            try:
+                topic_properties = service_mgmt_conn.get_topic(self.topic_name)
+            except ResourceNotFoundError:
+                topic_properties = None
             if topic_properties and topic_properties.name == self.topic_name:
                 self.log.info("Topic name already exists")
                 return topic_properties.name
@@ -331,8 +331,7 @@ class AzureServiceBusTopicCreateOperator(BaseOperator):
 
 class AzureServiceBusSubscriptionCreateOperator(BaseOperator):
     """
-    Create an Azure Service Bus Topic Subscription under a Service Bus Namespace
-    by using ServiceBusAdministrationClient
+    Create an Azure Service Bus Topic Subscription under a Service Bus Namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -409,7 +408,7 @@ class AzureServiceBusSubscriptionCreateOperator(BaseOperator):
         self.azure_service_bus_conn_id = azure_service_bus_conn_id
 
     def execute(self, context: Context) -> None:
-        """Creates Subscription in Service Bus namespace, by connecting to Service Bus Admin client"""
+        """Create Subscription in Service Bus namespace, by connecting to Service Bus Admin client."""
         if self.subscription_name is None:
             raise TypeError("Subscription name cannot be None.")
         if self.topic_name is None:
@@ -439,8 +438,7 @@ class AzureServiceBusSubscriptionCreateOperator(BaseOperator):
 
 class AzureServiceBusUpdateSubscriptionOperator(BaseOperator):
     """
-    Update an Azure ServiceBus Topic Subscription under a ServiceBus Namespace
-    by using ServiceBusAdministrationClient
+    Update an Azure ServiceBus Topic Subscription under a ServiceBus Namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -481,7 +479,7 @@ class AzureServiceBusUpdateSubscriptionOperator(BaseOperator):
         self.azure_service_bus_conn_id = azure_service_bus_conn_id
 
     def execute(self, context: Context) -> None:
-        """Updates Subscription properties, by connecting to Service Bus Admin client"""
+        """Update Subscription properties, by connecting to Service Bus Admin client."""
         hook = AdminClientHook(azure_service_bus_conn_id=self.azure_service_bus_conn_id)
 
         with hook.get_conn() as service_mgmt_conn:
@@ -540,10 +538,7 @@ class ASBReceiveSubscriptionMessageOperator(BaseOperator):
         self.azure_service_bus_conn_id = azure_service_bus_conn_id
 
     def execute(self, context: Context) -> None:
-        """
-        Receive Message in specific queue in Service Bus namespace,
-        by connecting to Service Bus client
-        """
+        """Receive Message in specific queue in Service Bus namespace by connecting to Service Bus client."""
         # Create the hook
         hook = MessageHook(azure_service_bus_conn_id=self.azure_service_bus_conn_id)
 
@@ -555,7 +550,7 @@ class ASBReceiveSubscriptionMessageOperator(BaseOperator):
 
 class AzureServiceBusSubscriptionDeleteOperator(BaseOperator):
     """
-    Deletes the topic subscription in the Azure ServiceBus namespace
+    Delete the topic subscription in the Azure ServiceBus namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -584,7 +579,7 @@ class AzureServiceBusSubscriptionDeleteOperator(BaseOperator):
         self.azure_service_bus_conn_id = azure_service_bus_conn_id
 
     def execute(self, context: Context) -> None:
-        """Delete topic subscription in Service Bus namespace, by connecting to Service Bus Admin client"""
+        """Delete topic subscription in Service Bus namespace, by connecting to Service Bus Admin client."""
         # Create the hook
         hook = AdminClientHook(azure_service_bus_conn_id=self.azure_service_bus_conn_id)
 
@@ -594,7 +589,7 @@ class AzureServiceBusSubscriptionDeleteOperator(BaseOperator):
 
 class AzureServiceBusTopicDeleteOperator(BaseOperator):
     """
-    Deletes the topic in the Azure Service Bus namespace
+    Delete the topic in the Azure Service Bus namespace.
 
     .. seealso::
         For more information on how to use this operator, take a look at the guide:
@@ -620,7 +615,7 @@ class AzureServiceBusTopicDeleteOperator(BaseOperator):
         self.azure_service_bus_conn_id = azure_service_bus_conn_id
 
     def execute(self, context: Context) -> None:
-        """Delete topic in Service Bus namespace, by connecting to Service Bus Admin client"""
+        """Delete topic in Service Bus namespace, by connecting to Service Bus Admin client."""
         if self.topic_name is None:
             raise TypeError("Topic name cannot be None.")
         hook = AdminClientHook(azure_service_bus_conn_id=self.azure_service_bus_conn_id)
