@@ -16,15 +16,16 @@
 # under the License.
 from __future__ import annotations
 
+import logging
 from collections import defaultdict
 from contextlib import closing
 from enum import IntEnum
 from typing import TYPE_CHECKING, Dict, List, Optional
 
 from attrs import define
-from openlineage.client.facet import SchemaDatasetFacet, SchemaField
-from openlineage.client.run import Dataset
-from sqlalchemy import Column, MetaData, Table, and_, union_all
+from openlineage.client.event_v2 import Dataset
+from openlineage.client.facet_v2 import schema_dataset
+from sqlalchemy import Column, MetaData, Table, and_, or_, union_all
 
 if TYPE_CHECKING:
     from sqlalchemy.engine import Engine
@@ -33,6 +34,9 @@ if TYPE_CHECKING:
     from airflow.hooks.base import BaseHook
 
 
+log = logging.getLogger(__name__)
+
+
 class ColumnIndex(IntEnum):
     """Enumerates the indices of columns in information schema view."""
 
@@ -42,7 +46,7 @@ class ColumnIndex(IntEnum):
     ORDINAL_POSITION = 3
     # Use 'udt_name' which is the underlying type of column
     UDT_NAME = 4
-    # Database is optional as 5th column
+    # Database is optional as 6th column
     DATABASE = 5
 
 
@@ -56,7 +60,7 @@ class TableSchema:
     table: str
     schema: str | None
     database: str | None
-    fields: list[SchemaField]
+    fields: list[schema_dataset.SchemaDatasetFacetFields]
 
     def to_dataset(self, namespace: str, database: str | None = None, schema: str | None = None) -> Dataset:
         # Prefix the table name with database and schema name using
@@ -69,7 +73,7 @@ class TableSchema:
         return Dataset(
             namespace=namespace,
             name=name,
-            facets={"schema": SchemaDatasetFacet(fields=self.fields)} if self.fields else {},
+            facets={"schema": schema_dataset.SchemaDatasetFacet(fields=self.fields)} if self.fields else {},
         )
 
 
@@ -81,7 +85,8 @@ def get_table_schemas(
     in_query: str | None,
     out_query: str | None,
 ) -> tuple[list[Dataset], list[Dataset]]:
-    """Query database for table schemas.
+    """
+    Query database for table schemas.
 
     Uses provided hook. Responsibility to provide queries for this function is on particular extractors.
     If query for input or output table isn't provided, the query is skipped.
@@ -90,6 +95,7 @@ def get_table_schemas(
     if not in_query and not out_query:
         return [], []
 
+    log.debug("Starting to query database for table schemas")
     with closing(hook.get_conn()) as conn, closing(conn.cursor()) as cursor:
         if in_query:
             cursor.execute(in_query)
@@ -101,11 +107,13 @@ def get_table_schemas(
             out_datasets = [x.to_dataset(namespace, database, schema) for x in parse_query_result(cursor)]
         else:
             out_datasets = []
+    log.debug("Got table schema query result from database.")
     return in_datasets, out_datasets
 
 
 def parse_query_result(cursor) -> list[TableSchema]:
-    """Fetch results from DB-API 2.0 cursor and creates list of table schemas.
+    """
+    Fetch results from DB-API 2.0 cursor and creates list of table schemas.
 
     For each row it creates :class:`TableSchema`.
     """
@@ -114,7 +122,7 @@ def parse_query_result(cursor) -> list[TableSchema]:
     for row in cursor.fetchall():
         table_schema_name: str = row[ColumnIndex.SCHEMA]
         table_name: str = row[ColumnIndex.TABLE_NAME]
-        table_column: SchemaField = SchemaField(
+        table_column = schema_dataset.SchemaDatasetFacetFields(
             name=row[ColumnIndex.COLUMN_NAME],
             type=row[ColumnIndex.UDT_NAME],
             description=None,
@@ -145,55 +153,96 @@ def create_information_schema_query(
     information_schema_table_name: str,
     tables_hierarchy: TablesHierarchy,
     uppercase_names: bool = False,
+    use_flat_cross_db_query: bool = False,
     sqlalchemy_engine: Engine | None = None,
 ) -> str:
-    """Creates query for getting table schemas from information schema."""
-    metadata = MetaData(sqlalchemy_engine)
+    """Create query for getting table schemas from information schema."""
+    metadata = MetaData()
     select_statements = []
-    for db, schema_mapping in tables_hierarchy.items():
-        # Information schema table name is expected to be "< information_schema schema >.<view/table name>"
-        # usually "information_schema.columns". In order to use table identifier correct for various table
-        # we need to pass first part of dot-separated identifier as `schema` argument to `sqlalchemy.Table`.
-        if db:
-            # Use database as first part of table identifier.
-            schema = db
-            table_name = information_schema_table_name
-        else:
-            # When no database passed, use schema as first part of table identifier.
-            schema, table_name = information_schema_table_name.split(".")
+    # Don't iterate over tables hierarchy, just pass it to query single information schema table
+    if use_flat_cross_db_query:
         information_schema_table = Table(
-            table_name,
+            information_schema_table_name,
             metadata,
             *[Column(column) for column in columns],
-            schema=schema,
             quote=False,
         )
-        filter_clauses = create_filter_clauses(schema_mapping, information_schema_table, uppercase_names)
-        select_statements.append(information_schema_table.select().filter(*filter_clauses))
+        filter_clauses = create_filter_clauses(
+            tables_hierarchy,
+            information_schema_table,
+            uppercase_names=uppercase_names,
+        )
+        select_statements.append(information_schema_table.select().filter(filter_clauses))
+    else:
+        for db, schema_mapping in tables_hierarchy.items():
+            # Information schema table name is expected to be "< information_schema schema >.<view/table name>"
+            # usually "information_schema.columns". In order to use table identifier correct for various table
+            # we need to pass first part of dot-separated identifier as `schema` argument to `sqlalchemy.Table`.
+            if db:
+                # Use database as first part of table identifier.
+                schema = db
+                table_name = information_schema_table_name
+            else:
+                # When no database passed, use schema as first part of table identifier.
+                schema, table_name = information_schema_table_name.split(".")
+            information_schema_table = Table(
+                table_name,
+                metadata,
+                *[Column(column) for column in columns],
+                schema=schema,
+                quote=False,
+            )
+            filter_clauses = create_filter_clauses(
+                {None: schema_mapping},
+                information_schema_table,
+                uppercase_names=uppercase_names,
+            )
+            select_statements.append(information_schema_table.select().filter(filter_clauses))
     return str(
         union_all(*select_statements).compile(sqlalchemy_engine, compile_kwargs={"literal_binds": True})
     )
 
 
 def create_filter_clauses(
-    schema_mapping: dict, information_schema_table: Table, uppercase_names: bool = False
+    mapping: dict,
+    information_schema_table: Table,
+    uppercase_names: bool = False,
 ) -> ClauseElement:
     """
-    Creates comprehensive filter clauses for all tables in one database.
+    Create comprehensive filter clauses for all tables in one database.
 
-    :param schema_mapping: a dictionary of schema names and list of tables in each
+    :param mapping: a nested dictionary of database, schema names and list of tables in each
     :param information_schema_table: `sqlalchemy.Table` instance used to construct clauses
         For most SQL dbs it contains `table_name` and `table_schema` columns,
         therefore it is expected the table has them defined.
     :param uppercase_names: if True use schema and table names uppercase
     """
+    table_schema_column_name = information_schema_table.columns[ColumnIndex.SCHEMA].name
+    table_name_column_name = information_schema_table.columns[ColumnIndex.TABLE_NAME].name
+    try:
+        table_database_column_name = information_schema_table.columns[ColumnIndex.DATABASE].name
+    except IndexError:
+        table_database_column_name = ""
+
     filter_clauses = []
-    for schema, tables in schema_mapping.items():
-        filter_clause = information_schema_table.c.table_name.in_(
-            name.upper() if uppercase_names else name for name in tables
-        )
-        if schema:
-            schema = schema.upper() if uppercase_names else schema
-            filter_clause = and_(information_schema_table.c.table_schema == schema, filter_clause)
-        filter_clauses.append(filter_clause)
-    return filter_clauses
+    for db, schema_mapping in mapping.items():
+        schema_level_clauses = []
+        for schema, tables in schema_mapping.items():
+            filter_clause = information_schema_table.c[table_name_column_name].in_(
+                name.upper() if uppercase_names else name for name in tables
+            )
+            if schema:
+                schema = schema.upper() if uppercase_names else schema
+                filter_clause = and_(
+                    information_schema_table.c[table_schema_column_name] == schema, filter_clause
+                )
+            schema_level_clauses.append(filter_clause)
+        if db and table_database_column_name:
+            db = db.upper() if uppercase_names else db
+            filter_clause = and_(
+                information_schema_table.c[table_database_column_name] == db, or_(*schema_level_clauses)
+            )
+            filter_clauses.append(filter_clause)
+        else:
+            filter_clauses.extend(schema_level_clauses)
+    return or_(*filter_clauses)
