@@ -17,6 +17,8 @@
 # under the License.
 from __future__ import annotations
 
+from typing import Any
+
 from opsgenie_sdk import (
     AlertApi,
     ApiClient,
@@ -156,3 +158,11 @@ class OpsgenieAlertHook(BaseHook):
         except OpenApiException as e:
             self.log.exception("Exception when calling AlertApi->delete_alert: %s\n", e)
             raise e
+
+    @classmethod
+    def get_ui_field_behaviour(cls) -> dict[str, Any]:
+        """Return custom UI field behaviour for Opsgenie connection."""
+        return {
+            "hidden_fields": ["port", "schema", "login", "extra"],
+            "relabeling": {"password": "Opsgenie API Key"},
+        }
