@@ -16,14 +16,15 @@
 # specific language governing permissions and limitations
 # under the License.
 """Hook for sending or receiving data from PagerDuty as well as creating PagerDuty incidents."""
+
 from __future__ import annotations
 
-import warnings
 from typing import Any
 
 import pdpyras
+from deprecated import deprecated
 
-from airflow.exceptions import AirflowException
+from airflow.exceptions import AirflowException, AirflowProviderDeprecationWarning
 from airflow.hooks.base import BaseHook
 from airflow.providers.pagerduty.hooks.pagerduty_events import PagerdutyEventsHook
 
@@ -50,16 +51,33 @@ class PagerdutyHook(BaseHook):
     conn_type = "pagerduty"
     hook_name = "Pagerduty"
 
-    @staticmethod
-    def get_ui_field_behaviour() -> dict[str, Any]:
-        """Returns custom field behaviour"""
+    @classmethod
+    def get_ui_field_behaviour(cls) -> dict[str, Any]:
+        """Return custom field behaviour."""
         return {
-            "hidden_fields": ["port", "login", "schema", "host"],
+            "hidden_fields": ["port", "login", "schema", "host", "extra"],
             "relabeling": {
                 "password": "Pagerduty API token",
             },
         }
 
+    @classmethod
+    def get_connection_form_widgets(cls) -> dict[str, Any]:
+        """Return connection widgets to add to connection form."""
+        from flask_appbuilder.fieldwidgets import BS3PasswordFieldWidget
+        from flask_babel import lazy_gettext
+        from wtforms import PasswordField
+        from wtforms.validators import Optional
+
+        return {
+            "routing_key": PasswordField(
+                lazy_gettext("Routing Key"),
+                widget=BS3PasswordFieldWidget(),
+                validators=[Optional()],
+                default=None,
+            ),
+        }
+
     def __init__(self, token: str | None = None, pagerduty_conn_id: str | None = None) -> None:
         super().__init__()
         self.routing_key = None
@@ -81,7 +99,7 @@ class PagerdutyHook(BaseHook):
 
     def get_session(self) -> pdpyras.APISession:
         """
-        Returns `pdpyras.APISession` for use with sending or receiving data through the PagerDuty REST API.
+        Return `pdpyras.APISession` for use with sending or receiving data through the PagerDuty REST API.
 
         The `pdpyras` library supplies a class `pdpyras.APISession` extending `requests.Session` from the
         Requests HTTP library.
@@ -92,6 +110,13 @@ class PagerdutyHook(BaseHook):
         self._session = pdpyras.APISession(self.token)
         return self._session
 
+    @deprecated(
+        reason=(
+            "This method will be deprecated. Please use the "
+            "`airflow.providers.pagerduty.hooks.PagerdutyEventsHook` to interact with the Events API"
+        ),
+        category=AirflowProviderDeprecationWarning,
+    )
     def create_event(
         self,
         summary: str,
@@ -137,13 +162,6 @@ class PagerdutyHook(BaseHook):
             link's text.
         :return: PagerDuty Events API v2 response.
         """
-        warnings.warn(
-            "This method will be deprecated. Please use the "
-            "`airflow.providers.pagerduty.hooks.PagerdutyEventsHook` to interact with the Events API",
-            DeprecationWarning,
-            stacklevel=2,
-        )
-
         routing_key = routing_key or self.routing_key
 
         return PagerdutyEventsHook(integration_key=routing_key).create_event(
@@ -159,3 +177,11 @@ class PagerdutyHook(BaseHook):
             images=images,
             links=links,
         )
+
+    def test_connection(self):
+        try:
+            session = pdpyras.APISession(self.token)
+            session.list_all("services", params={"query": "some_non_existing_service"})
+        except Exception:
+            return False, "connection test failed, invalid token"
+        return True, "connection tested successfully"
