@@ -84,7 +84,7 @@ class PagerdutyNotifier(BaseNotifier):
         class_type: str | None = None,
         images: list[Any] | None = None,
         links: list[Any] | None = None,
-        pagerduty_events_conn_id: str = "pagerduty_events_default",
+        pagerduty_events_conn_id: str | None = "pagerduty_events_default",
         integration_key: str | None = None,
     ):
         super().__init__()
@@ -96,11 +96,9 @@ class PagerdutyNotifier(BaseNotifier):
         self.action = action
         self.dedup_key = dedup_key
         self.custom_details = custom_details
-        self.custom_details = custom_details
         self.group = group
         self.component = component
         self.class_type = class_type
-        self.class_type = class_type
         self.images = images
         self.links = links
 
