@@ -23,11 +23,12 @@ from functools import cached_property
 from pathlib import Path
 from typing import TYPE_CHECKING, Any, Sequence, TypedDict
 
+from deprecated import deprecated
 from slack_sdk import WebClient
 from slack_sdk.errors import SlackApiError
 from typing_extensions import NotRequired
 
-from airflow.exceptions import AirflowNotFoundException
+from airflow.exceptions import AirflowNotFoundException, AirflowProviderDeprecationWarning
 from airflow.hooks.base import BaseHook
 from airflow.providers.slack.utils import ConnectionExtraConfig
 from airflow.utils.helpers import exactly_one
@@ -184,6 +185,14 @@ class SlackHook(BaseHook):
         """
         return self.client.api_call(api_method, **kwargs)
 
+    @deprecated(
+        reason=(
+            "This method utilise `files.upload` Slack API method which is being sunset on March 11, 2025. "
+            "Beginning May 8, 2024, newly-created apps will be unable to 'files.upload' Slack API. "
+            "Please use `send_file_v2` or `send_file_v1_to_v2` instead."
+        ),
+        category=AirflowProviderDeprecationWarning,
+    )
     def send_file(
         self,
         *,
@@ -359,7 +368,8 @@ class SlackHook(BaseHook):
         return channel_id
 
     def test_connection(self):
-        """Tests the Slack API connection.
+        """
+        Tests the Slack API connection.
 
         .. seealso::
             https://api.slack.com/methods/auth.test
