@@ -23,7 +23,8 @@ from airflow.utils.types import NOTSET
 
 
 class ConnectionExtraConfig:
-    """Helper class for rom Connection Extra.
+    """
+    Helper class for rom Connection Extra.
 
     :param conn_type: Hook connection type.
     :param conn_id: Connection ID uses for appropriate error messages.
@@ -37,7 +38,8 @@ class ConnectionExtraConfig:
         self.extra = extra or {}
 
     def get(self, field, default: Any = NOTSET):
-        """Get specified field from Connection Extra.
+        """
+        Get specified field from Connection Extra.
 
         :param field: Connection extra field name.
         :param default: If specified then use as default value if field not present in Connection Extra.
@@ -48,7 +50,9 @@ class ConnectionExtraConfig:
                 warnings.warn(
                     f"Conflicting params `{field}` and `{backcompat_key}` found in extras for conn "
                     f"{self.conn_id}. Using value for `{field}`.  Please ensure this is the correct value "
-                    f"and remove the backcompat key `{backcompat_key}`."
+                    f"and remove the backcompat key `{backcompat_key}`.",
+                    UserWarning,
+                    stacklevel=2,
                 )
             return self.extra[field]
         elif backcompat_key in self.extra and self.extra[backcompat_key] not in (None, ""):
@@ -68,7 +72,8 @@ class ConnectionExtraConfig:
             return default
 
     def getint(self, field, default: Any = NOTSET) -> Any:
-        """Get specified field from Connection Extra and evaluate as integer.
+        """
+        Get specified field from Connection Extra and evaluate as integer.
 
         :param field: Connection extra field name.
         :param default: If specified then use as default value if field not present in Connection Extra.
@@ -84,6 +89,7 @@ def parse_filename(
 ) -> tuple[str, str | None]:
     """
     Parse filetype and compression from given filename.
+
     :param filename: filename to parse.
     :param supported_file_formats: list of supported file extensions.
     :param fallback: fallback to given file format.
