@@ -18,8 +18,10 @@
 from __future__ import annotations
 
 from functools import cached_property
+from pathlib import Path
 from typing import Any, Iterable
 
+from airflow.configuration import conf
 from airflow.notifications.basenotifier import BaseNotifier
 from airflow.providers.smtp.hooks.smtp import SmtpHook
 
@@ -28,6 +30,26 @@ class SmtpNotifier(BaseNotifier):
     """
     SMTP Notifier.
 
+    Accepts keyword arguments. The only required arguments are `from_email` and `to`. Examples:
+
+    .. code-block:: python
+
+        EmptyOperator(task_id="task", on_failure_callback=SmtpNotifier(from_email=None, to="myemail@myemail.com"))
+
+        EmptyOperator(
+            task_id="task",
+            on_failure_callback=SmtpNotifier(
+                from_email="myemail@myemail.com",
+                to="myemail@myemail.com",
+                subject="Task {{ ti.task_id }} failed",
+            ),
+        )
+
+    Default template can be overridden via the following provider configuration data:
+        - templated_email_subject_path
+        - templated_html_content_path
+
+
     :param smtp_conn_id: The :ref:`smtp connection id <howto/connection:smtp>`
         that contains the information used to authenticate the client.
     """
@@ -47,10 +69,12 @@ class SmtpNotifier(BaseNotifier):
 
     def __init__(
         self,
+        # TODO: Move from_email to keyword parameter in next major release so that users do not
+        # need to specify from_email. No argument here will lead to defaults from conf being used.
         from_email: str | None,
         to: str | Iterable[str],
-        subject: str,
-        html_content: str,
+        subject: str | None = None,
+        html_content: str | None = None,
         files: list[str] | None = None,
         cc: str | Iterable[str] | None = None,
         bcc: str | Iterable[str] | None = None,
@@ -58,13 +82,13 @@ class SmtpNotifier(BaseNotifier):
         mime_charset: str = "utf-8",
         custom_headers: dict[str, Any] | None = None,
         smtp_conn_id: str = SmtpHook.default_conn_name,
+        *,
+        template: str | None = None,
     ):
         super().__init__()
         self.smtp_conn_id = smtp_conn_id
-        self.from_email = from_email
+        self.from_email = from_email or conf.get("smtp", "smtp_mail_from")
         self.to = to
-        self.subject = subject
-        self.html_content = html_content
         self.files = files
         self.cc = cc
         self.bcc = bcc
@@ -72,6 +96,28 @@ class SmtpNotifier(BaseNotifier):
         self.mime_charset = mime_charset
         self.custom_headers = custom_headers
 
+        smtp_default_templated_subject_path = conf.get(
+            "smtp",
+            "templated_email_subject_path",
+            fallback=(Path(__file__).parent / "templates" / "email_subject.jinja2").as_posix(),
+        )
+        self.subject = (
+            subject or Path(smtp_default_templated_subject_path).read_text().replace("\n", "").strip()
+        )
+        # If html_content is passed, prioritize it. Otherwise, if template is passed, use
+        # it to populate html_content. Else, fall back to defaults defined in settings
+        if html_content is not None:
+            self.html_content = html_content
+        elif template is not None:
+            self.html_content = Path(template).read_text()
+        else:
+            smtp_default_templated_html_content_path = conf.get(
+                "smtp",
+                "templated_html_content_path",
+                fallback=(Path(__file__).parent / "templates" / "email.html").as_posix(),
+            )
+            self.html_content = Path(smtp_default_templated_html_content_path).read_text()
+
     @cached_property
     def hook(self) -> SmtpHook:
         """Smtp Events Hook."""
